//=============================================================================
// VisuStella MZ - Items & Equips Core
// VisuMZ_1_ItemsEquipsCore.js
//=============================================================================

var Imported = Imported || {};
Imported.VisuMZ_1_ItemsEquipsCore = true;

var VisuMZ = VisuMZ || {};
VisuMZ.ItemsEquipsCore = VisuMZ.ItemsEquipsCore || {};
VisuMZ.ItemsEquipsCore.version = 1.36;

//=============================================================================
 /*:
 * @target MZ
 * @plugindesc [RPG Maker MZ] [Tier 1] [Version 1.36] [ItemsEquipsCore]
 * @author VisuStella
 * @url http://www.yanfly.moe/wiki/Items_and_Equips_Core_VisuStella_MZ
 * @orderAfter VisuMZ_0_CoreEngine
 *
 * @help
 * ============================================================================
 * Introduction
 * ============================================================================
 *
 * The Items & Equips Core makes improvements to the RPG Maker MZ item and
 * equipment dedicated scenes (including the shop) and how they're handled.
 * From more item categories, better parameter control, rulings, and more, game
 * devs are able to take control over key aspects of their game's items.
 *
 * Features include all (but not limited to) the following:
 *
 * * Modifying the appearances to the Item Scene, Equip Scene, and Shop Scene.
 * * Categorizing items in unique and multiple categories.
 * * Item Scene and Shop Scene will now display detailed information on items.
 * * NEW! marker can be displayed over recently acquired items in-game.
 * * Equipment notetags to adjust parameters past the editor limitations.
 * * Equipment Rulings to adjust what slot types can and can't be unequipped
 *   and/or optimized.
 * * Equipment Type Handling offers more control over equipment loadouts.
 * * Items sold in shops can be hidden/shown based on Switches.
 * * Items sold in shops can have varying prices adjusted by notetags.
 *
 * ============================================================================
 * Requirements
 * ============================================================================
 *
 * This plugin is made for RPG Maker MZ. This will not work in other iterations
 * of RPG Maker.
 *
 * ------ Tier 1 ------
 *
 * This plugin is a Tier 1 plugin. Place it under other plugins of lower tier
 * value on your Plugin Manager list (ie: 0, 1, 2, 3, 4, 5). This is to ensure
 * that your plugins will have the best compatibility with the rest of the
 * VisuStella MZ library.
 *
 * ============================================================================
 * Major Changes: New Hard-Coded Features
 * ============================================================================
 *
 * This plugin adds some new hard-coded features to RPG Maker MZ's functions.
 * The following is a list of them.
 *
 * ---
 *
 * Equipment Type Handling
 *
 * - Characters will no longer have one universal equipment slot setting.
 * Classes can have different equipment type loadouts, made possible through
 * the usage of notetags. Also, equipment types of matching names would be
 * treated as the same type, where previously, they would be different types.
 * This means if you have two "Accessory" slots, be it in the form of notetags
 * or through the Database > Types tab, they can both equip the same type of
 * accessories.
 *
 * - The Change Equip event command is now updated to reflect this new change.
 * When processing an equip change, the slot changed will go to the first
 * empty slot of matching type. If all of the actor's matching slot types are
 * equipped, then the equip will replace the last slot available.
 *
 * ---
 *
 * Shop Status Window
 *
 * - The Status Window found in the Shop Scene was originally barren and did
 * not display much information at all. This is changed through this plugin's
 * new features. While the contents of the Shop Status Window can be customized
 * through the Plugin Parameters, it is a change that cannot be reversed and
 * for the better since it gives players the much needed information revolving
 * around the game's items.
 *
 * ---
 *
 * Core Engine Compatibility: Modern Controls
 *
 * - If the VisuStella Core Engine is added to your game with Modern Controls
 * enabled, then the Item Menu Scene, Equip Menu Scene, and Shop Menu Scene's
 * controls will be changed a bit.
 *
 * - The Item Menu Scene will automatically have the Item List Window active,
 * with using the Left/Right (for single column) or Page Up/Page Down (for
 * multi-columns) to navigate between the Item Categories. Similar will occur
 * when trying to sell items in the Shop Menu Scene.
 *
 * - The Equip Menu Scene will automatically have the Equip Slots Window active
 * and only activate the command window upon moving up to it.
 *
 * ---
 *
 * ============================================================================
 * VisuStella MZ Compatibility
 * ============================================================================
 *
 * While this plugin is compatible with the majority of the VisuStella MZ
 * plugin library, it is not compatible with specific plugins or specific
 * features. This section will highlight the main plugins/features that will
 * not be compatible with this plugin or put focus on how the make certain
 * features compatible.
 * 
 * ---
 * 
 * VisuMZ_1_BattleCore
 * 
 * Changing the "Damage Multiplier" or "Healing Multiplier" vocabulary for the
 * Item and Equip Core's Shop Status Window is not done with the Item and Equip
 * Core's Plugin Parameters if you have the Battle Core installed.
 * 
 * Instead, go to Battle Core's Plugin Parameters, Damage Settings, Damage
 * Styles, and adjust the style's version of the "Damage Multiplier" or
 * "Healing Multiplier" text instead.
 * 
 * Why does this work this way? Because not all damage styles work off
 * "Multipliers" so in order for it to convey the proper message to the player,
 * each damage style has its own vocabulary to be more accurate.
 * 
 * In case you forget about that, when you visit the Item and Equip Core's
 * plugin parameters for these, it should also remind you in the parameter's
 * description on where to change it.
 * 
 * ---
 *
 * VisuMZ_2_WeaponSwapSystem
 *
 * The custom equip slots feature from the VisuStella MZ Items and Equips Core
 * allowed you to add in extra weapon slots. This is now curated up to a max
 * of one weapon slot per character. This needs to be done to make the Weapon
 * Swap System viable.
 *
 * ---
 *
 * ============================================================================
 * Notetags
 * ============================================================================
 *
 * The following are notetags that have been added through this plugin. These
 * notetags will not work with your game if this plugin is OFF or not present.
 *
 * === General ===
 * 
 * These notetags affect the Items, Weapons, and Armors on a general scale.
 *
 * ---
 *
 * <Max: x>
 *
 * - Used for: Item, Weapon, Armor Notetags
 * - Determines the maximum quantity that can be held for this item.
 * - Replace 'x' with a number value to determine the maximum amount.
 *
 * ---
 *
 * <Color: x>
 * <Color: #rrggbb>
 *
 * - Used for: Item, Weapon, Armor, Skill Notetags
 * - Determines the color of the object inside the in-game menus.
 * - Replace 'x' with a number value depicting a window text color.
 * - Replace 'rrggbb' with a hex color code for a more custom color.
 *
 * ---
 *
 * <Category: x>
 *
 * - Used for: Item, Weapon, Armor Notetags
 * - Arranges items into certain/multiple categories to work with the Category
 *   Plugin Parameter setting: "Category:x".
 * - Replace 'x' with a category name to mark this item as.
 *
 * ---
 *
 * <Categories>
 *  x
 *  x
 * </Categories>
 *
 * - Used for: Item, Weapon, Armor Notetags
 * - Arranges items into certain/multiple categories to work with the Category
 *   Plugin Parameter setting: "Category:x".
 * - Replace each 'x' with a category name to mark this item as.
 *
 * ---
 *
 * === Item Accessibility Notetags ===
 *
 * The following notetags allow you to choose when items can/cannot be used
 * based on switches.
 *
 * ---
 *
 * <Enable Switch: x>
 *
 * <Enable All Switches: x,x,x>
 * <Enable Any Switches: x,x,x>
 *
 * - Used for: Item Notetags
 * - Determines the enabled status of the item based on switches.
 * - Replace 'x' with the switch ID to determine the item's enabled status.
 * - If 'All' notetag variant is used, item will be disabled until all
 *   switches are ON. Then, it would be enabled.
 * - If 'Any' notetag variant is used, item will be enabled if any of the
 *   switches are ON. Otherwise, it would be disabled.
 *
 * ---
 *
 * <Disable Switch: x>
 *
 * <Disable All Switches: x,x,x>
 * <Disable Any Switches: x,x,x>
 *
 * - Used for: Item Notetags
 * - Determines the enabled status of the item based on switches.
 * - Replace 'x' with the switch ID to determine the item's enabled status.
 * - If 'All' notetag variant is used, item will be enabled until all switches
 *   are ON. Then, it would be disabled.
 * - If 'Any' notetag variant is used, item will be disabled if any of the
 *   switches are ON. Otherwise, it would be enabled.
 *
 * ---
 *
 * === JavaScript Notetags: Item Accessibility ===
 *
 * The following are notetags made for users with JavaScript knowledge to
 * determine if an item can be accessible by code.
 *
 * ---
 *
 * <JS Item Enable>
 *  code
 *  code
 *  enabled = code;
 * </JS Item Enable>
 *
 * - Used for: Item Notetags
 * - Determines the enabled status of the item based on JavaScript code.
 * - If the actor this is disabled for is the only party member, it will not be
 *   visible in the item list unless the VisuStella Battle Core is installed.
 *   - If the VisuStella Battle Core is installed, then all battle scope items
 *     will be visible even if they're disabled.
 * - Replace 'code' to determine the type enabled status of the item.
 * - The 'enabled' variable returns a boolean (true/false) to determine if the
 *   item will be enabled or not.
 * - The 'user' variable refers to the user with the item.
 * - The 'item' variable refers to the item being checked.
 * - All other item conditions must be met in order for this to code to count.
 *
 * ---
 *
 * === Equipment Notetags ===
 *
 * The following notetags provide equipment-related effects from deciding what
 * equip slots can be given to classes to the base parameter changes asigned
 * to weapons and armors.
 *
 * ---
 *
 * <Equip Slots>
 *  slotName
 *  slotName
 *  slotName
 * </Equip Slots>
 *
 * - Used for: Class Notetags
 * - Changes the equipment slot loadout for any actor who is that class.
 * - Replace 'slotName' with an Equipment Type name from Database > Types.
 *   This is case-sensitive.
 * - Insert or remove as many "slotName" equipment types as needed.
 *
 * ---
 *
 * <param: +x>
 * <param: -x>
 *
 * - Used for: Weapon, Armor Notetags
 * - Changes the base parameter value for the equip item.
 * - Replace 'param' with any of the following: 'MaxHP', 'MaxMP', 'ATK', 'DEF',
 *   'MAT', 'MDF', 'AGI', or 'LUK' to change that specific parameter's value.
 *   - These notetags do NOT work with X Parameters, S Parameters, or any
 *     custom parameters. These notetags ONLY work with the base parameters.
 * - Replace 'x' with a number value to set the parameter value to.
 * - This allows you to bypass the Database Editor's number limitations.
 *
 * ---
 * 
 * <Equip Copy Limit: x>
 * 
 * - Used for: Weapon, Armor Notetags
 * - Sets a maximum number of copies that the actor can wear of this equipment.
 * - Replace 'x' with a number value to determine the copy limit.
 * - This can be bypassed using Event Commands and/or Script Calls.
 * - Usage Example: Actors can only equip one copy of the "One-of-a-Kind Ring"
 *   on at any time despite having empty accessory slots because the ring has a
 *   <Equip Copy Limit: 1> notetag.
 * 
 * ---
 * 
 * <Equip Weapon Type Limit: x>
 * 
 * - Used for: Weapon
 * - This weapon cannot be equipped with other weapons of the same type once
 *   the limited amount has been reached.
 * - Replace 'x' with a number value to determine the weapon type limit.
 * - This can be bypassed using Event Commands and/or Script Calls.
 * - Usage Example: A dualwielding warrior who can only equip one sword and a
 *   dagger but never two swords or two daggers because the swords and daggers
 *   all have the <Equip Weapon Type Limit: 1> notetags on them.
 * 
 * ---
 * 
 * <Equip Armor Type Limit: x>
 * 
 * - Used for: Armor
 * - This armor cannot be equipped with other armors of the same type once the
 *   limited amount has been reached.
 * - Replace 'x' with a number value to determine the armor type limit.
 * - This can be bypassed using Event Commands and/or Script Calls.
 * - Usage Example: People cannot equip more than two glove accessories on at a
 *   time because the glove is a "Glove" armor-type and each glove item has the
 *   <Equip Armor Type Limit: 2> notetags on them.
 * 
 * ---
 *
 * === JavaScript Notetags: Equipment ===
 *
 * The following are notetags made for users with JavaScript knowledge to
 * adjust the parameter through code.
 *
 * ---
 *
 * <JS Parameters>
 *  MaxHP = code;
 *  MaxMP = code;
 *  ATK = code;
 *  DEF = code;
 *  MAT = code;
 *  MDF = code;
 *  AGI = code;
 *  LUK = code;
 * </JS Parameters>
 *
 * - Used for: Weapon, Armor Notetags
 * - Uses JavaScript to determine the values for the basic parameters based on
 *   the code used to calculate its value.
 * - The variables 'MaxHP', 'MaxMP', 'ATK', 'DEF', 'MAT', 'MDF', 'AGI', and
 *   'LUK' are used to determine the finalized value of the parameter. This
 *   variable is case sensitive.
 * - If a parameter is not present, its value will be treated as +0.
 *
 * ---
 *
 * === Status Window Notetags ===
 *
 * The following notetags will affect the Shop Status Window info. If for any
 * reason the data that is displayed is not to your liking or insufficient,
 * you can change it up using the following notetags.
 *
 * ---
 *
 * <Status Info>
 *  key: data
 *  key: data
 *  key: data
 * </Status Info>
 *
 * - Used for: Skill, Item Notetags
 * - If you do not like the generated data that's displayed, you can change it
 *   using this notetag to display what you want.
 * - Replace 'key' with one of the following:
 *   - Consumable
 *   - Quantity
 *   - Occasion
 *   - Scope
 *   - Speed
 *   - Success Rate
 *   - Repeat
 *   - Hit Type
 *   - Element
 *   - Damage Multiplier
 *   - HP Recovery
 *   - MP Recovery
 *   - TP Recovery
 *   - HP Damage
 *   - MP Damage
 *   - TP Damage
 *   - User TP Gain
 *   - Added Effects
 *   - Removed Effects
 * - Replace 'data' with the text data you want to visually appear. You may use
 *   text codes for this.
 * - This only affects info entries that are already visible and won't make
 *   other categories suddenly appear.
 * - Insert or remove as many "key: data" lines as needed.
 *
 * ---
 *
 * <Custom Status Info>
 *  key: data
 *  key: data
 *  key: data
 * </Custom Status Info>
 *
 * - Used for: Skill, Item
 * - If you want custom categories and data to be displayed for your items that
 *   aren't provided by the Shop Status Window Info to begin with, you can use
 *   this notetag to add in your own entries.
 * - Replace 'key' with text of the exact label you want. You may use text
 *   codes for this.
 * - Replace 'data' with text of the exact text data you want. You may use text
 *   codes for this.
 * - Insert or remove as many "key: data" lines as needed.
 *
 * ---
 * 
 * <Shop Picture Name: filename>
 * 
 * - Used for: Skill, Item, Weapon, Armor Notetags
 * - Enables a shop picture for the status window. This image can be seen in
 *   the item scene, shop scene, and skill scene if enabled.
 * - If this notetag is not used, there will be no image.
 * - Replace 'filename' with the filename of the graphic to use from the game
 *   project's img/pictures/ folder. Filenames are case sensitive. Leave out
 *   the filename extension from the notetag.
 * - Use the supporting notetags to determine where the image appears. If not,
 *   they will default to the background, fit to the window dimensions,
 *   centered at the middle of the window.
 * 
 * ---
 * 
 * <Shop Picture Layer: Background>
 * <Shop Picture Layer: Foreground>
 * 
 * - Used for: Skill, Item, Weapon, Armor Notetags
 * - Determines which layer the graphic will be drawn on.
 * - If the background layer is selected, the picture will appear behind the
 *   data text.
 * - If the foreground layer is selected, the picture will appear in front of
 *   the data text.
 * - If this notetag is not used, it will default to the background layer.
 * 
 * ---
 * 
 * <Shop Picture Max Width: x>
 * <Shop Picture Max Height: y>
 * <Shop Picture Max Dimensions: x, y>
 * 
 * - Used for: Skill, Item, Weapon, Armor Notetags
 * - Determines the maximum width and/or height for the image.
 * - This means the image will be automatically scaled proportionally to that
 *   width or height as long as everything else does not break boundaries.
 * - Replace 'x' and 'y' with number values representing the maximum dimensions
 *   the image can be in pixels.
 * - If these notetags are not used, the image will be automatically scaled to
 *   the dimensions of the shop status window.
 * 
 * ---
 * 
 * <Shop Picture Alignment: Left>
 * <Shop Picture Alignment: Center>
 * <Shop Picture Alignment: Right>
 * 
 * - Used for: Skill, Item, Weapon, Armor Notetags
 * - Adjusts the horizontal alignment for the image.
 * - Left, center, right determines how it's aligned horizontally if the
 *   image does not horizontally fit in the width of the window.
 * - If any of these notetags are not used, the image will default to the
 *   'center' alignment.
 * 
 * ---
 * 
 * <Shop Picture Position: Top>
 * <Shop Picture Position: Middle>
 * <Shop Picture Position: Bottom>
 * 
 * - Used for: Skill, Item, Weapon, Armor Notetags
 * - Adjusts the vertical position for the image.
 * - Top, middle, bottom determines how it's positioned vertically if the
 *   image does not vertically fit in the width of the window.
 * - If any of these notetags are not used, the image will default to the
 *   'middle' position.
 * 
 * ---
 * 
 * <Shop Picture Offset X: +x>
 * <Shop Picture Offset X: -x>
 * 
 * <Shop Picture Offset Y: +y>
 * <Shop Picture Offset Y: -y>
 * 
 * <Shop Picture Offset: +x, +y>
 * <Shop Picture Offset: -y, -y>
 * 
 * - Used for: Skill, Item, Weapon, Armor Notetags
 * - Offsets the X and Y positions of the image in the shop status window.
 * - X offsets adjust the horizontal position by x pixels.
 *   - Positive goes right.
 *   - Negative goes left.
 * - Y offsets adjust the horizontal position by y pixels.
 *   - Positive goes down.
 *   - Negative goes up.
 * - Replace 'x' and 'y' with number values representing the pixels to offset
 *   the image by. The '+' and '-' signs are required.
 * - If none of these notetags are used, there will be no offsets.
 * 
 * ---
 * 
 * <Shop Picture Opacity: x>
 * <Shop Picture Opacity: x%>
 * 
 * - Used for: Skill, Item, Weapon, Armor Notetags
 * - Adjusts the opacity of the image used.
 * - When using 'x' and not 'x%', use a number between 0 and 255.
 *   - The closer to 0, the more transparent the image is.
 *   - The closer to 255, the more opaque the image is.
 * - When using 'x%' and not 'x', use a number between 0% and 100%.
 *   - The closer to 0%, the more transparent the image is.
 *   - The closer to 100%, the more opaque the image is.
 * 
 * ---
 *
 * === Shop Menu Notetags ===
 *
 * These notetags adjust how prices and such are managed inside the Shop Menu
 * as well as whether or not some items are visible depending on switch states.
 *
 * ---
 *
 * <Price: x>
 *
 * - Used for: Item, Weapon, Armor Notetags
 * - Adjusts the buying price for this item.
 * - Replace 'x' with a number depicting the desired value for the buy price.
 * - This allows you to bypass the RPG Maker MZ editor's limitation of 999,999.
 *
 * ---
 *
 * <Can Sell>
 * <Cannot Sell>
 *
 * - Used for: Item, Weapon, Armor Notetags
 * - Makes the item either always sellable or cannot be sold.
 * - This bypasses the game's internal hard-coding to prevent items with a
 *   price of 0 from being able to be sold.
 * - This bypasses the game's internal hard-coding to always allow items with
 *   a price value of being able to be sold.
 *
 * ---
 *
 * <Sell Price: x>
 *
 * - Used for: Item, Weapon, Armor Notetags
 * - Changes the sell price to be something different than the default amount.
 * - Replace 'x' with a number depicting the desired value for the sell price.
 *
 * ---
 *
 * <Show Shop Switch: x>
 *
 * <Show Shop All Switches: x,x,x>
 * <Show Shop Any Switches: x,x,x>
 *
 * - Used for: Item, Weapon, Armor Notetags
 * - Determines the visibility of the shop item based on switches.
 * - Replace 'x' with the switch ID to determine the shop item's visibility.
 * - If 'All' notetag variant is used, item will be hidden until all switches
 *   are ON. Then, it would be shown.
 * - If 'Any' notetag variant is used, item will be shown if any of the
 *   switches are ON. Otherwise, it would be hidden.
 *
 * ---
 *
 * <Hide Shop Switch: x>
 *
 * <Hide Shop All Switches: x,x,x>
 * <Hide Shop Any Switches: x,x,x>
 *
 * - Used for: Item, Weapon, Armor Notetags
 * - Determines the visibility of the shop item based on switches.
 * - Replace 'x' with the switch ID to determine the shop item's visibility.
 * - If 'All' notetag variant is used, item will be shown until all switches
 *   are ON. Then, it would be hidden.
 * - If 'Any' notetag variant is used, item will be hidden if any of the
 *   switches are ON. Otherwise, it would be shown.
 *
 * ---
 *
 * <Cannot Sell Switch: x>
 *
 * <Cannot Sell All Switches: x,x,x>
 * <Cannot Sell Any Switches: x,x,x>
 *
 * - Used for: Item, Weapon, Armor Notetags
 * - Determines the sellability of the shop item based on switches.
 * - Replace 'x' with the switch ID to determine the shop item's sellability.
 * - If 'All' notetag variant is used, item cannot be sold until all switches
 *   are ON. Otherwise, it can be sold.
 * - If 'Any' notetag variant is used, item cannot be sold if any of the
 *   switches are ON. Otherwise, it can be sold.
 *
 * ---
 *
 * === JavaScript Notetags: Shop Menu ===
 *
 * The following are notetags made for users with JavaScript knowledge. These
 * notetags are primarily aimed at Buy and Sell prices.
 *
 * ---
 *
 * <JS Buy Price>
 *  code
 *  code
 *  price = code;
 * </JS Buy Price>
 *
 * - Used for: Item, Weapon, Armor Notetags
 * - Replace 'code' to determine the buying 'price' of the item.
 * - Insert the final buy price into the 'price' variable.
 * - The 'item' variable refers to the item being bought.
 *
 * ---
 *
 * <JS Sell Price>
 *  code
 *  code
 *  price = code;
 * </JS Sell Price>
 *
 * - Used for: Item, Weapon, Armor Notetags
 * - Replace 'code' to determine the selling 'price' of the item.
 * - Insert the final sell price into the 'price' variable.
 * - The 'item' variable refers to the item being sold.
 *
 * ---
 *
 * ============================================================================
 * Plugin Commands
 * ============================================================================
 *
 * The following are Plugin Commands that come with this plugin. They can be
 * accessed through the Plugin Command event command.
 *
 * ---
 * 
 * === Actor Plugin Commands ===
 * 
 * ---
 *
 * Actor: Change Equip Slots
 * - Forcefully change the actor(s) equip slots.
 * - These will persist through class changes.
 *
 *   Actor ID(s):
 *   - Select which Actor ID(s) to affect.
 *
 *   Equip Slots:
 *   - Insert the equip slots you want the actor(s) to have.
 *   - These entries are case-sensitive.
 *
 * ---
 *
 * Actor: Reset Equip Slots
 * - Reset any forced equip slots for the actor(s).
 * - Equip slots will then be based on class.
 *
 *   Actor ID(s):
 *   - Select which Actor ID(s) to affect.
 *
 * ---
 * 
 * === Shop Plugin Commands ===
 * 
 * ---
 *
 * Shop: Advanced
 * - Make it easier to put together inventories for a shop.
 * - WARNING: Does not allow for event-specific prices.
 *
 *   Step 1: Item ID's
 *   - Select which Item ID ranges to add.
 *
 *   Step 2: Weapon ID's
 *   - Select which Weapon ID ranges to add.
 *
 *   Step 3: Armor ID's
 *   - Select which Armor ID ranges to add.
 *
 *   Step 4: Purchase Only?
 *   - Make the shop purchase-only?
 * 
 *   Optional:
 * 
 *     Blacklist
 *     - A list of categories to blacklist from the shop.
 *     - Not used if empty. Mark categories with <Category: x>
 * 
 *     Whitelist
 *     - A list of categories to whitelist for the shop.
 *     - Not used if empty. Mark categories with <Category: x>
 *
 * This Plugin Command primarily functions as an alternative to the editor's
 * "Shop Processing" event command as that one requires you to add items one at
 * a time, making it extremely tedious to add large amounts of items. This
 * Plugin Command will mitigate that by allowing ID ranges to determine which
 * items to make available.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Item Menu Settings
 * ============================================================================
 *
 * The Item Menu Settings allow you to adjust specifics on how key objects and
 * windows in the Item Menu Scene operate.
 *
 * ---
 *
 * General Window
 *
 *   Use Updated Layout:
 *   - Use the Updated Item Menu Layout provided by this plugin?
 *   - This will automatically enable the Status Window.
 *   - This will override the Core Engine windows settings.
 *
 *   Layout Style:
 *   - If using an updated layout, how do you want to style the menu scene?
 *     - Upper Help, Left Input
 *     - Upper Help, Right Input
 *     - Lower Help, Left Input
 *     - Lower Help, Right Input
 *
 * ---
 *
 * List Window
 * 
 *   Columns:
 *   - Number of maximum columns.
 *   - If you are using the VisuStella MZ Core Engine and the "Modern Controls"
 *     Plugin Parameter, please read through that section in case you have any
 *     questions about how to switch between categories when using multiple
 *     columns of items at a time.
 *
 * ---
 *
 * Item Quantity
 *
 *   Item Max:
 *   Weapon Max:
 *   Armor Max:
 *   - The default maximum quantity for items, weapons, and/or armors.
 * 
 *   Quantity Format:
 *   - How to display an item's quantity.
 *   - %1 - Item Quantity
 *
 *   Font Size:
 *   - Default font size for item quantity.
 *
 * ---
 *
 * Shop Status Window
 * 
 *   Show in Item Menu?:
 *   - Show the Shop Status Window in the Item Menu?
 *   - This is enabled if the Updated Layout is on.
 *
 *   Adjust List Window?:
 *   - Automatically adjust the Item List Window in the Item Menu if using the
 *     Shop Status Window?
 * 
 *   Background Type:
 *   - Select background type for this window.
 *     - 0 - Window
 *     - 1 - Dim
 *     - 2 - Transparent
 *
 *   JS: X, Y, W, H:
 *   - Code used to determine the dimensions for this Status Window in the
 *     Item Menu.
 *
 * ---
 *
 * Button Assist Window
 *
 *   Switch Category:
 *   - Button assist text used for switching categories.
 *   - For VisuStella MZ's Core Engine's Button Assist Window.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Item Categories
 * ============================================================================
 *
 * Item Categories appear both in the Item Menu Scene and Shop Menu Scene (but
 * only under the Sell command). These Plugin Parameters give you the ability
 * to add in the specific categories you want displayed, remove the ones you
 * don't, and associate them with icons.
 *
 * ---
 *
 * List
 *
 *   Category List
 *   - A list of the item categories displayed in the Item/Shop menus.
 * 
 *     Type:
 *     - A list of the item categories displayed in the Item/Shop menus.
 *     - Replace x with ID numbers or text.
 *     - AllItems, RegularItems, KeyItems
 *     - HiddenItemA, HiddenItemB
 *     - Consumable, Nonconsumable
 *     - AlwaysUsable, BattleUsable, FieldUsable, NeverUsable
 *     - AllWeapons, WType:x
 *     - AllArmors, AType:x, EType:x
 *     - Category:x
 * 
 *     Icon:
 *     - Icon used for this category.
 *     - Use 0 for no icon.
 * 
 *     Visibility Switch:
 *     - This Switch must be turned ON in order for the category to show.
 *     - Use 0 for no Switch requirement.
 *
 *   Style:
 *   - How do you wish to draw categorie entries in the Category Window?
 *   - Text Only: Display only the text.
 *   - Icon Only: Display only the icon.
 *   - Icon + Text: Display the icon first, then the text.
 *   - Auto: Determine which is better to use based on the size of the cell.
 *
 *   Text Alignment
 *   - Decide how you want the text to be aligned.
 *
 * ---
 *
 * Vocabulary
 *
 *   Hidden Item A
 *   Hidden Item B
 *   Consumable
 *   Nonconsumable
 *   Always Usable
 *   Battle Usable
 *   Field Usable
 *   Never Usable
 *   - How these categories are named in the Item Menu.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: NEW! Labels
 * ============================================================================
 *
 * Whenever the player receives a new item(s), a NEW! Label can be placed on
 * top of the item's icon when browsing a menu displaying the item(s). This is
 * a quality of life addition from more modern RPG's to help players figure out
 * what they've recently received. The following are Plugin Parameters made to
 * adjust how the NEW! Labels are handled in-game.
 *
 * ---
 *
 * NEW! Labels
 * 
 *   Use NEW! Labels?:
 *   - Use the NEW! Labels or not?
 * 
 *   Icon:
 *   - The icon index used to represent the NEW! text.
 *   - Use 0 to not draw any icons.
 * 
 *   Text:
 *   - The text written on the NEW! Label.
 * 
 *     Font Color:
 *     - Use #rrggbb for custom colors or regular numbers for text colors from
 *       the Window Skin.
 * 
 *     Font Size:
 *     - The font size used for the NEW! text.
 * 
 *   Fade Limit:
 *   - What's the upper opaque limit before reversing?
 * 
 *   Fade Speed:
 *   - What's the fade speed of the NEW! Label?
 * 
 *   Offset X:
 *   - How much to offset the NEW! Label's X position by.
 * 
 *   Offset Y:
 *   - How much to offset the NEW! Label's Y position by.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Equip Menu Settings
 * ============================================================================
 *
 * These Plugin Parameters adjust the Equipment Menu Scene, ranging from using
 * a more updated and modern layout, changing the styles of other windows, and
 * other key visual aspects of the Equip Menu Scene. Other settings here allow
 * you to adjust how equipment operate under certain rulings, too.
 *
 * ---
 *
 * General
 * 
 *   Use Updated Layout:
 *   - Use the Updated Equip Layout provided by this plugin?
 *   - This will override the Core Engine windows settings.
 * 
 *     Param Font Size:
 *     - The font size used for parameter values.
 * 
 *     Show Menu Portraits?:
 *     - If Main Menu Core is installed, display the Menu Portraits instead of
 *       the actor's face in the status window?
 * 
 *     JS: Portrait Upper:
 *     - If Menu Portraits are available, this is code used to draw the upper
 *       data like this in the Status Window.
 * 
 *     JS: Face Upper:
 *     - If faces used used, this is code used to draw the upper data like this
 *       in the Status Window.
 * 
 *     JS: Parameter Lower:
 *     - Code to determine how parameters are drawn in the Status Window.
 *
 *   Layout Style:
 *   - If using an updated layout, how do you want to style the menu scene?
 *     - Upper Help, Left Input
 *     - Upper Help, Right Input
 *     - Lower Help, Left Input
 *     - Lower Help, Right Input
 * 
 *   Status Window Width:
 *   - The usual width of the status window if using the non-Updated Equip
 *     Menu Layout.
 * 
 *   Show Back Rectangles?:
 *   - Show back rectangles of darker colors to display information better?
 * 
 *     Back Rectangle Color:
 *     - Use #rrggbb for custom colors or regular numbers for text colors
 *       from the Window Skin.
 *
 * ---
 *
 * Command Window
 * 
 *   Style:
 *   - How do you wish to draw commands in the Command Window?
 *   - Text Only: Display only the text.
 *   - Icon Only: Display only the icon.
 *   - Icon + Text: Display the icon first, then the text.
 *   - Auto: Determine which is better to use based on the size of the cell.
 * 
 *   Text Align:
 *   - Text alignment for the Command Window.
 * 
 *   Equip Icon:
 *   - The icon used for the Equip command.
 * 
 *   Add Optimize Command?:
 *   - Add the "Optimize" command to the Command Window?
 * 
 *     Optimize Icon:
 *     - The icon used for the Optimize command.
 * 
 *   Add Clear Command?:
 *   - Add the "Clear" command to the Command Window?
 * 
 *     Clear Icon:
 *     - The icon used for the Clear command.
 *
 * ---
 *
 * Remove Equip
 * 
 *   Icon:
 *   - Icon used for equipment removal.
 * 
 *   Text:
 *   - Text used for equipment removal.
 * 
 *   Use SHIFT Shortcut?:
 *   - Add the "Shift" button as a shortcut key to removing items?
 *
 * ---
 *
 * Rulings
 * 
 *   Equip-Adjust HP/MP:
 *   - Adjust HP/MP differences after changing equips with MaxHP/MaxMP values.
 * 
 *   Non-Removable Types:
 *   - Insert ID's of the Equipment Types that must always have an item
 *     equipped and cannot be empty.
 * 
 *   Non-Optimized Types:
 *   - Insert ID's of the Equipment Types that will be ignored when equipment
 *     is being optimized.
 *
 * ---
 *
 * Button Assist Window
 *
 *   SHIFT: Remove:
 *   - Button assist text used for the SHIFT Remove Shortcut.
 *   - For VisuStella MZ's Core Engine's Button Assist Window.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Shop Menu Settings
 * ============================================================================
 *
 * These Plugin Parameters allow you a number of options to adjust the Shop
 * Menu Scene. These options range from enabling an updated and modern layout,
 * adjust how various key visual aspects appear, and determine how prices can
 * be affected when it comes to selling them or buying them (for coders).
 *
 * ---
 *
 * General
 * 
 *   Use Updated Layout:
 *   - Use the Updated Shop Layout provided by this plugin?
 *   - This will override the Core Engine windows settings.
 *
 *   Layout Style:
 *   - If using an updated layout, how do you want to style the menu scene?
 *     - Upper Help, Left Input
 *     - Upper Help, Right Input
 *     - Lower Help, Left Input
 *     - Lower Help, Right Input
 *
 * ---
 * 
 * Switches:
 * 
 *   Switch: Buy:
 *   - Buying items in the Shop Scene turns this Switch to ON.
 *   - Switch reverts to OFF whenever the Shop Scene opens.
 * 
 *   Switch: Sell
 *   - Selling items in the Shop Scene turns this Switch to ON.
 *   - Switch reverts to OFF whenever the Shop Scene opens.
 * 
 * ---
 *
 * Command Window
 * 
 *   Hide Unavailable?:
 *   - Hide all unavailable commands like when a shop is set to Purchase Only?
 * 
 *   Style:
 *   - How do you wish to draw commands in the Command Window?
 *   - Text Only: Display only the text.
 *   - Icon Only: Display only the icon.
 *   - Icon + Text: Display the icon first, then the text.
 *   - Auto: Determine which is better to use based on the size of the cell.
 * 
 *   Text Align:
 *   - Text alignment for the Command Window.
 * 
 *   Buy Icon:
 *   - The icon used for the Buy command.
 * 
 *   Sell Icon:
 *   - The icon used for the Sell command.
 * 
 *   Cancel Icon:
 *   - The icon used for the Cancel command.
 * 
 *   Rename "Cancel":
 *   - Rename Cancel to something more logical for the Shop Menu Scene.
 *
 * ---
 *
 * Prices
 * 
 *   Sell Price Rate:
 *   - The default sell price rate.
 * 
 *   JS: Buy Price:
 *   - Modificatons made to the buy price before finalizing it.
 * 
 *   JS: Sell Price:
 *   - Modificatons made to the sell price before finalizing it.
 *
 * ---
 *
 * Button Assist Window
 *
 *   Small Increment:
 *   Large Increment:
 *   - Text used for changing amount bought/sold.
 *   - For VisuStella MZ's Core Engine's Button Assist Window.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Shop Status Window
 * ============================================================================
 *
 * These Plugin Parameters focuses on the Shop Status Window and determines how
 * its data is displayed.
 *
 * ---
 *
 * General
 * 
 *   Window Width:
 *   - The usual width of the status window.
 * 
 *   Parameter Font Size:
 *   - Font size used for parameter changes.
 * 
 *   Translucent Opacity:
 *   - Opacity setting used for translucent window objects.
 * 
 *   Show Back Rectangles?:
 *   - Show back rectangles of darker colors to display information better?
 * 
 *     Back Rectangle Color:
 *     - Use #rrggbb for custom colors or regular numbers for text colors
 *       from the Window Skin.
 *
 * ---
 *
 * Equipment Data
 * 
 *   Already Equipped:
 *   - Marker used to show an actor cannot equip an item.
 * 
 *   Can't Equip:
 *   - Marker used to show an actor cannot equip an item.
 * 
 *   No Changes:
 *   - Marker used to show no changes have occurred.
 * 
 *   JS: Draw Equip Data:
 *   - Code used to draw the equipment data for the Shop Status Window.
 *
 * ---
 *
 * Item Data
 * 
 *   Max State/Buff Icons:
 *   - Maximum number of icons that can be displayed for Add/Remove
 *     States/Buffs.
 * 
 *   Multiplier Standard:
 *   - Constant standard to filter out random values when calculating the
 *     damage multiplier.
 * 
 *   JS: Draw Item Data:
 *   - Code used to draw the item data for the Shop Status Window.
 *
 * ---
 *
 * Vocabulary
 * 
 *   Consumable:
 *   Occasions:
 *   Scope:
 *   Speed:
 *   Success Rate:
 *   Repeats:
 *   Hit Type:
 *   Element:
 *   Damage Type:
 *   Effects:
 *   - Vocabulary used for these data entries.
 *   - Some of these have Plugin Parameters have sub-entries.
 * 
 *   NOTE: Regarding Damage Labels
 * 
 *   If Visu_1_BattleCore is installed, priority goes to its Damage Style
 *   settings. The label displayed is based on the damage style settings in
 *   place for that specific skill or item.
 * 
 *   Go to Battle Core > Plugin Parameters > Damage Settings > Style List >
 *   pick the damage style you want to edit > Damage Label and change the
 *   text settings you'd like there.
 *
 * ---
 *
 * ============================================================================
 * Terms of Use
 * ============================================================================
 *
 * 1. These plugins may be used in free or commercial games provided that they
 * have been acquired through legitimate means at VisuStella.com and/or any
 * other official approved VisuStella sources. Exceptions and special
 * circumstances that may prohibit usage will be listed on VisuStella.com.
 * 
 * 2. All of the listed coders found in the Credits section of this plugin must
 * be given credit in your games or credited as a collective under the name:
 * "VisuStella".
 * 
 * 3. You may edit the source code to suit your needs, so long as you do not
 * claim the source code belongs to you. VisuStella also does not take
 * responsibility for the plugin if any changes have been made to the plugin's
 * code, nor does VisuStella take responsibility for user-provided custom code
 * used for custom control effects including advanced JavaScript notetags
 * and/or plugin parameters that allow custom JavaScript code.
 * 
 * 4. You may NOT redistribute these plugins nor take code from this plugin to
 * use as your own. These plugins and their code are only to be downloaded from
 * VisuStella.com and other official/approved VisuStella sources. A list of
 * official/approved sources can also be found on VisuStella.com.
 *
 * 5. VisuStella is not responsible for problems found in your game due to
 * unintended usage, incompatibility problems with plugins outside of the
 * VisuStella MZ library, plugin versions that aren't up to date, nor
 * responsible for the proper working of compatibility patches made by any
 * third parties. VisuStella is not responsible for errors caused by any
 * user-provided custom code used for custom control effects including advanced
 * JavaScript notetags and/or plugin parameters that allow JavaScript code.
 *
 * 6. If a compatibility patch needs to be made through a third party that is
 * unaffiliated with VisuStella that involves using code from the VisuStella MZ
 * library, contact must be made with a member from VisuStella and have it
 * approved. The patch would be placed on VisuStella.com as a free download
 * to the public. Such patches cannot be sold for monetary gain, including
 * commissions, crowdfunding, and/or donations.
 *
 * ============================================================================
 * Credits
 * ============================================================================
 * 
 * If you are using this plugin, credit the following people in your game:
 * 
 * Team VisuStella
 * * Yanfly
 * * Arisu
 * * Olivia
 * * Irina
 *
 * ============================================================================
 * Changelog
 * ============================================================================
 * 
 * Version 1.36: December 2, 2021
 * * Feature Update!
 * ** For those using custom parameters from the Core Engine and do not have
 *    the parameters all-capitalized, the plugin will automatically do it for
 *    you to prevent errors. Update made by Olivia.
 * 
 * Version 1.35: November 18, 2021
 * * Compatibility Update!
 * ** If this plugin's updated scene is disabled, the Help Window locations for
 *    the Item, Equip, and Shop Scenes should now be at their designated
 *    locations as calculated by the VisuMZ Core Engine instead of the RMMZ
 *    default location. Update made by Irina.
 * 
 * Version 1.34: October 28, 2021
 * * Feature Update
 * ** Added fail safe checks for projects that are using old data for starting
 *    equipment that no longer exist, thus preventing the game from opening.
 *    Update made by Arisu.
 * 
 * Version 1.33: August 6, 2021
 * * Documentation Update!
 * ** Removed "Weapon" and "Armor" from "Used For" for <Status Info>. This was
 *    an unintended piece of documentation.
 * 
 * Version 1.32: July 23, 2021
 * * Bug Fixes!
 * ** Fixed a bug that would cause armor duplication when changing to classes
 *    with unaligned equipment slot types. Fix made by Arisu.
 * 
 * Version 1.31: July 9, 2021
 * * Feature Update!
 * ** Added a failsafe for price manipulation JavaScript to never have prices
 *    drop below 0 if possible. Update made by Arisu.
 * 
 * Version 1.30: July 2, 2021
 * * Documentation Update!
 * ** Added an extra note to the help file for the following:
 *    Plugin Parameters > Item Menu Settings > List Window > Columns
 * *** If you are using the VisuStella MZ Core Engine and the "Modern Controls"
 *     Plugin Parameter, please read through that section in case you have any
 *     questions about how to switch between categories when using multiple
 *     columns of items at a time.
 *    
 * 
 * Version 1.29: June 25, 2021
 * * Compatibility Update
 * ** Compatibility update with RPG Maker MZ 1.3.0+.
 * * Feature Update!
 * ** Phantom data when changing equipment types in the database should no
 *    longer affect actors with cached equip ID's. Update made by Arisu.
 * 
 * Version 1.28: June 4, 2021
 * * Optimization Update!
 * ** Plugin should run more optimized.
 * 
 * Version 1.27: May 21, 2021
 * * Bug Fixes!
 * ** Using the mouse right click in the Equip Scene while inside of the item
 *    to slot window will no longer exit the Equip Scene. Fix made by Yanfly.
 * 
 * Version 1.26: April 30, 2021
 * * Documentation Update!
 * ** Help file updated for new features.
 * ** "VisuStella MZ Compatibility" added VisuMZ_1_BattleCore section regarding
 *    Damage Multiplier and Healing Multiplier vocabulary settings to reduce
 *    commonly asked questions.
 * * New Features!
 * ** New notetags added by Irina and sponsored by Archeia:
 * *** <Shop Picture Name: filename>
 * *** <Shop Picture Layer: x>
 * *** <Shop Picture Max Width: x>
 * *** <Shop Picture Max Height: y>
 * *** <Shop Picture Max Dimensions: x, y>
 * *** <Shop Picture Alignment: x>
 * *** <Shop Picture Position: y>
 * *** <Shop Picture Offset X: +x>
 * *** <Shop Picture Offset X: -x>
 * *** <Shop Picture Offset Y: +y>
 * *** <Shop Picture Offset Y: -y>
 * *** <Shop Picture Offset: +x, +y>
 * *** <Shop Picture Offset: -x, -y>
 * *** <Shop Picture Opacity: x>
 * *** <Shop Picture Opacity: x%>
 * **** Add images from the game project's img/pictures/ folder to display in
 *      the Shop Status Window.
 * 
 * Version 1.25: April 23, 2021
 * * Documentation Update!
 * ** Added clarity to the <param: +x> and <param: -x> notetags:
 * *** These notetags do NOT work with X Parameters, S Parameters, or any
 *     custom parameters. These notetags ONLY work with the base parameters.
 * 
 * Version 1.24: April 16, 2021
 * * Bug Fixes!
 * ** Changing an actor's equipment slots to past their original amount will no
 *    longer yield errors with duplicate slot types. Fix made by Arisu.
 * ** Completely selling an item should now refresh the help window to the new
 *    selected item's help description. Fix made by Arisu.
 * * Optimization Update!
 * ** Non-removable equipment restrictions for the equipment scene are now
 *    better optimized. Update made by Olivia.
 * 
 * Version 1.23: April 2, 2021
 * * Optimization Update!
 * ** Plugin should run more optimized.
 * 
 * Version 1.22: March 26, 2021
 * * Documentation Update!
 * ** Added "VisuStella MZ Compatibility" section for detailed compatibility
 *    explanations with the VisuMZ_4_BreakShields plugin.
 * 
 * Version 1.21: March 5, 2021
 * * Feature Update!
 * ** Custom equipment slots are disabled during Battle Testing for better
 *    accuracy and results.
 * 
 * Version 1.20: February 26, 2021
 * * Documentation Update!
 * ** Help file updated for new features.
 * * New Features!
 * ** New Plugin Parameters added by Irina and sponsored by AndyL:
 * *** Plugin Parameters > Shop Menu Settings > Switches > Switch: Buy
 * *** Plugin Parameters > Shop Menu Settings > Switches > Switch: Sell
 * **** Buying/selling items in the Shop Scene turns this Switch to ON.
 * **** Switch reverts to OFF whenever the Shop Scene opens.
 * **** These switches can be used after a "Shop Processing" event command to
 *      determine if the player has bought an item, bought and sold an item,
 *      sold an item, or neither.
 * 
 * Version 1.19: January 29, 2021
 * * Documentation Update!
 * ** Help file updated for new features.
 * * New Features!
 * ** New notetags added by Irina.
 * *** <Equip Copy Limit: x>
 * **** Sets a maximum number of copies that the actor can wear of this
 *      equipment. Usage Example: Actors can only equip one copy of the
 *      "One-of-a-Kind Ring" on at any time despite having empty accessory
 *      slots because the ring has a <Equip Copy Limit: 1> notetag.
 * *** <Equip Weapon Type Limit: x>
 * **** This weapon cannot be equipped with other weapons of the same type once
 *      the limited amount has been reached. Usage Example: A dualwielding
 *      warrior who can only equip one sword and a dagger but never two swords
 *      or two daggers because the swords and daggers all have the
 *      <Equip Weapon Type Limit: 1> notetags on them.
 * *** <Equip Armor Type Limit: x>
 * **** This armor cannot be equipped with other armors of the same type once
 *      the limited amount has been reached. Usage Example: People cannot equip
 *      more than two glove accessories on at a time because the glove is a
 *      "Glove" armor-type and each glove item has the
 *      <Equip Armor Type Limit: 2> notetags on them.
 * 
 * Version 1.18: January 15, 2021
 * * Bug Fixes!
 * ** Pressing "Shift" to remove equipment will now refresh the status window
 *    unlike before. Fix made by Olivia.
 * * Documentation Update!
 * ** Help file updated for new features.
 * * New Feature!
 * ** New Plugin Parameters added
 * *** Plugin Parameters > Item Menu Settings > Background Type
 * 
 * Version 1.17: January 1, 2021
 * * Bug Fixes!
 * ** Equipping should be working properly again. Fix made by Yanfly.
 * 
 * Version 1.16: December 25, 2020
 * * Bug Fixes!
 * ** Equip-Adjust HP/MP should work properly now. Fix made by Yanfly.
 * * Documentation Update!
 * ** Added more clarity for <JS Item Enable> to state that if the VisuStella
 *    Battle Core is installed, then all battle scope items are visible, but
 *    not necessarily enabled if they are disabled otherwise.
 * 
 * Version 1.15: December 18, 2020
 * * Bug Fixes!
 * ** RPG Maker MZ Bug: Unusable items on an individual-actor basis will no
 *    longer be overwritten by party-based usability for battle. Fix by Yanfly.
 * * Documentation Update!
 * ** Added more clarity for <JS Item Enable> to state that it removes the
 *    usable item from visibility as well if the actor unable to use it is the
 *    only person in the party.
 * 
 * Version 1.14: December 11, 2020
 * * Compatibility Update!
 * ** Added compatibility functionality for future plugins.
 * 
 * Version 1.13: December 4, 2020
 * * Documentation Update!
 * ** Added documentation for new feature(s)!
 * * New Features!
 * ** New Plugin Commands added by Arisu!
 * *** Actor: Change Equip Slots
 * *** Actor: Reset Equip Slots
 * **** These plugin commands allow you to forcefully change the equip slots
 *      available to an actor regardless of the slots provided by its class as
 *      well as reset them.
 * 
 * Version 1.12: November 15, 2020
 * * Optimization Update!
 * ** Plugin should run more optimized.
 * 
 * Version 1.11: November 8, 2020
 * * Bug Fix!
 * ** Font size ratio for the shop status window now scales to a hard coded
 *    value to prevent smaller font sizes from expanding icon sizes. Fix made
 *    by Arisu.
 * * Feature Update!
 * ** Currency display in the shop menu is now reflected upon how the plugin
 *    parameters set them to display. Update made by Arisu.
 * 
 * Version 1.10: November 1, 2020
 * * Feature Update!
 * ** Modern Controls compatibility with Core Engine no longer enables the
 *    Item Categories window and child classes to utilize the Home/End keys.
 * 
 * Version 1.09: October 25, 2020
 * * Bug Fixes!
 * ** "All Items" category should now display the "Items" text. Fix by Irina.
 * ** WType, AType, and EType categories now work with text. Fix by Irina.
 *
 * Version 1.08: October 18, 2020
 * * Compatibility Update!
 * ** Plugins should be more compatible with one another.
 * 
 * Version 1.07: October 11, 2020
 * * Bug Fixes!
 * ** XParams and SParams in the Window_EquipStatus window will no longer show
 *    a non-percentile difference if the original value is not a whole value.
 *    Fix made by Yanfly.
 * 
 * Version 1.06: October 4, 2020
 * * Bug Fixes!
 * ** Select Item event command now displays the default amount of columns
 *    instead of whatever setting is made with the plugin parameters.
 * 
 * Version 1.05: September 27, 2020
 * * Bug Fixes!
 * ** When using the updated shop layout, leaving the sell option will no
 *    longer cause the dummy window to appear.
 * * Documentation Update
 * ** "Use Updated Layout" plugin parameters now have the added clause:
 *    "This will override the Core Engine windows settings." to reduce
 *    confusion. Added by Irina.
 * 
 * Version 1.04: September 13, 2020
 * * Bug Fixes!
 * ** Pressing Shift to quickly remove equipment should no longer crash the
 *    game. This will also clear the help window text. Fix made by Arisu.
 * 
 * Version 1.03: September 6, 2020
 * * Bug Fixes!
 * ** If both Optimize and Clear commands have been removed and using modern
 *    controls, pressing up at the top of the slot window list will not go to
 *    the window. Fix made by Yanfly.
 * ** If both Optimize and Clear commands have been removed, the window will no
 *    longer appear and the slot window will be moved upward to fill any empty
 *    spaces. Fix made by Yanfly.
 * * New Features!
 * ** New Plugin Parameter added in NEW! Label to let you adjust the font face.
 * ** New Plugin Parameters added in Equip Menu Scene Settings for disabling
 *    the back rectangles and/or changing their colors.
 * ** New Plugin Parameters added in Shop Status Window Settings for disabling
 *    the back rectangles and/or changing their colors.
 * 
 * Version 1.02: August 30, 2020
 * * Documentation Fix!
 * ** Added: NOTE: Regarding Damage Labels
 * *** If Visu_1_BattleCore is installed, priority goes to its Damage Style
 *   settings. The label displayed is based on the damage style settings in
 *   place for that specific skill or item.
 * *** Go to Battle Core > Plugin Parameters > Damage Settings > Style List >
 *   pick the damage style you want to edit > Damage Label and change the
 *   text settings you'd like there.
 * *** Documentation update added by Yanfly.
 * 
 * Version 1.01: August 23, 2020
 * * Added failsafe to prevent non-existent equipment (because the database
 *   entries have been deleted) from being equipped as initial equipment.
 *   Fix made by Olivia.
 *
 * Version 1.00: August 20, 2020
 * * Finished Plugin!
 *
 * ============================================================================
 * End of Helpfile
 * ============================================================================
 *
 * @ --------------------------------------------------------------------------
 *
 * @command ActorChangeEquipSlots
 * @text Actor: Change Equip Slots
 * @desc Forcefully change the actor(s) equip slots.
 * These will persist through class changes.
 *
 * @arg Actors:arraynum
 * @text Actor ID(s)
 * @type actor[]
 * @desc Select which Actor ID(s) to affect.
 * @default ["1"]
 * 
 * @arg Slots:arraystr
 * @text Equip Slots
 * @type string[]
 * @desc Insert the equip slots you want the actor(s) to have.
 * These entries are case-sensitive.
 * @default ["Weapon","Shield","Head","Body","Accessory"]
 *
 * @ --------------------------------------------------------------------------
 *
 * @command ActorResetEquipSlots
 * @text Actor: Reset Equip Slots
 * @desc Reset any forced equip slots for the actor(s).
 * Equip slots will then be based on class.
 *
 * @arg Actors:arraynum
 * @text Actor ID(s)
 * @type actor[]
 * @desc Select which Actor ID(s) to affect.
 * @default ["1"]
 *
 * @ --------------------------------------------------------------------------
 *
 * @command BatchShop
 * @text Shop: Advanced
 * @desc Make it easier to put together inventories for a shop.
 * WARNING: Does not allow for event-specific prices.
 *
 * @arg Step1
 * @text Step 1: Item ID's
 *
 * @arg Step1Start:num
 * @text Range Start
 * @parent Step1
 * @type item
 * @desc Select which Item ID to start from.
 * @default 1
 *
 * @arg Step1End:num
 * @text Range End
 * @parent Step1
 * @type item
 * @desc Select which Item ID to end at.
 * @default 4
 *
 * @arg Step2
 * @text Step 2: Weapon ID's
 *
 * @arg Step2Start:num
 * @text Range Start
 * @parent Step2
 * @type weapon
 * @desc Select which Weapon ID to start from.
 * @default 1
 *
 * @arg Step2End:num
 * @text Range End
 * @parent Step2
 * @type weapon
 * @desc Select which Weapon ID to end at.
 * @default 4
 *
 * @arg Step3
 * @text Step 3: Armor ID's
 *
 * @arg Step3Start:num
 * @text Range Start
 * @parent Step3
 * @type armor
 * @desc Select which Armor ID to start from.
 * @default 1
 *
 * @arg Step3End:num
 * @text Range End
 * @parent Step3
 * @type armor
 * @desc Select which Armor ID to end at.
 * @default 4
 *
 * @arg PurchaseOnly:eval
 * @text Step 4: Purchase Only?
 * @type boolean
 * @on Purchase-Only
 * @off Sell Accessible
 * @desc Make the shop purchase-only?
 * @default false
 * 
 * @arg Optional
 * 
 * @arg Blacklist:arraystr
 * @text Blacklisted Categories
 * @parent Optional
 * @type string[]
 * @desc A list of categories to blacklist from the shop.
 * Not used if empty. Mark categories with <Category: x>
 * @default []
 * 
 * @arg Whitelist:arraystr
 * @text Whitelisted Categories
 * @parent Optional
 * @type string[]
 * @desc A list of categories to whitelist for the shop.
 * Not used if empty. Mark categories with <Category: x>
 * @default []
 *
 * @ --------------------------------------------------------------------------
 *
 * @ ==========================================================================
 * @ Plugin Parameters
 * @ ==========================================================================
 *
 * @param BreakHead
 * @text --------------------------
 * @default ----------------------------------
 *
 * @param ItemsEquipsCore
 * @default Plugin Parameters
 *
 * @param ATTENTION
 * @default READ THE HELP FILE
 *
 * @param BreakSettings
 * @text --------------------------
 * @default ----------------------------------
 *
 * @param ItemScene:struct
 * @text Item Menu Settings
 * @type struct<ItemScene>
 * @desc Change the Item Menu Scene settings.
 * @default {"General":"","EnableLayout:eval":"true","LayoutStyle:str":"upper/left","ListWindow":"","ListWindowCols:num":"1","ItemQt":"","MaxItems:num":"99","MaxWeapons:num":"99","MaxArmors:num":"99","ItemQuantityFmt:str":"×%1","ItemQuantityFontSize:num":"22","ShopStatusWindow":"","ShowShopStatus:eval":"true","ItemSceneAdjustItemList:eval":"true","ItemMenuStatusRect:func":"\"const width = this.statusWidth();\\nconst height = this._itemWindow.height;\\nconst x = Graphics.boxWidth - width;\\nconst y = this._itemWindow.y;\\nreturn new Rectangle(x, y, width, height);\"","ButtonAssist":"","buttonAssistCategory:str":"Switch Category"}
 *
 * @param Categories:struct
 * @text Item Categories
 * @parent ItemScene:struct
 * @type struct<Categories>
 * @desc Change the categories displayed in the Item/Shop menus.
 * @default {"MainList":"","List:arraystruct":"[\"{\\\"Type:str\\\":\\\"FieldUsable\\\",\\\"Icon:num\\\":\\\"208\\\"}\",\"{\\\"Type:str\\\":\\\"BattleUsable\\\",\\\"Icon:num\\\":\\\"218\\\"}\",\"{\\\"Type:str\\\":\\\"NeverUsable\\\",\\\"Icon:num\\\":\\\"302\\\"}\",\"{\\\"Type:str\\\":\\\"AllWeapons\\\",\\\"Icon:num\\\":\\\"97\\\"}\",\"{\\\"Type:str\\\":\\\"EType:2\\\",\\\"Icon:num\\\":\\\"128\\\"}\",\"{\\\"Type:str\\\":\\\"EType:3\\\",\\\"Icon:num\\\":\\\"131\\\"}\",\"{\\\"Type:str\\\":\\\"EType:4\\\",\\\"Icon:num\\\":\\\"137\\\"}\",\"{\\\"Type:str\\\":\\\"EType:5\\\",\\\"Icon:num\\\":\\\"145\\\"}\",\"{\\\"Type:str\\\":\\\"KeyItems\\\",\\\"Icon:num\\\":\\\"195\\\"}\"]","Style:str":"icon","TextAlign:str":"center","Vocabulary":"","HiddenItemA:str":"Special Items","HiddenItemB:str":"Unique Items","Consumable:str":"Consumable","Nonconsumable:str":"Nonconsumable","AlwaysUsable:str":"Usable","BattleUsable:str":"Battle","FieldUsable:str":"Field","NeverUsable:str":"Materials"}
 *
 * @param New:struct
 * @text NEW! Labels
 * @parent ItemScene:struct
 * @type struct<NewLabel>
 * @desc Change how NEW! Labels apply to your game project.
 * @default {"Enable:eval":"true","Icon:num":"0","Text:str":"NEW!","FontColor:str":"17","FontFace:str":"Verdana","FontSize:str":"16","FadeLimit:num":"360","FadeSpeed:num":"4","OffsetX:num":"0","OffsetY:num":"4"}
 *
 * @param EquipScene:struct
 * @text Equip Menu Settings
 * @type struct<EquipScene>
 * @desc Adjust the settings regarding the Equip Menu Scene.
 * @default {"General":"","EnableLayout:eval":"true","ParamValueFontSize:num":"22","MenuPortraits:eval":"true","DrawPortraitJS:func":"\"// Declare Variables\\nconst lineHeight = this.lineHeight();\\nconst padding = this.itemPadding();\\nconst x1 = padding;\\nconst x2 = this.innerWidth - 128 - padding;\\n\\n// Draw Menu Image\\nthis.drawItemActorMenuImage(this._actor, 0, 0, this.innerWidth, this.innerHeight);\\n\\n// Draw Data\\nthis.drawActorName(this._actor, x1, lineHeight * 0);\\nthis.drawActorClass(this._actor, x1, lineHeight * 1);\\nthis.drawActorIcons(this._actor, x1, lineHeight * 2);\\nthis.drawActorLevel(this._actor, x2, lineHeight * 0);\\nthis.placeBasicGauges(this._actor, x2, lineHeight * 1);\"","DrawFaceJS:func":"\"// Declare Variables\\nconst lineHeight = this.lineHeight();\\nconst gaugeLineHeight = this.gaugeLineHeight();\\nconst x = Math.floor(this.innerWidth / 2);\\nconst limitHeight = this.innerHeight - (this.actorParams().length * lineHeight);\\nconst actorX = Math.floor((x - ImageManager.faceWidth) / 2);\\nconst actorY = Math.floor((limitHeight - ImageManager.faceHeight) / 2);\\nlet dataHeight = lineHeight * 3;\\ndataHeight += gaugeLineHeight * ($dataSystem.optDisplayTp ? 3 : 2);\\nconst dataY = Math.floor((limitHeight - dataHeight) / 2);\\n\\n// Draw Data\\nthis.drawActorFace(this._actor, actorX, actorY, ImageManager.faceWidth, ImageManager.faceHeight);\\nthis.drawActorIcons(this._actor, actorX + 16, actorY + ImageManager.faceHeight - lineHeight);\\nthis.drawActorName(this._actor, x, dataY + lineHeight * 0);\\nthis.drawActorLevel(this._actor, x, dataY + lineHeight * 1);\\nthis.drawActorClass(this._actor, x, dataY + lineHeight * 2);\\nthis.placeBasicGauges(this._actor, x, dataY + lineHeight * 3);\"","DrawParamJS:func":"\"// Declare variables\\nconst params = this.actorParams();\\nconst lineHeight = this.lineHeight();\\nconst padding = this.itemPadding();\\nconst baseX = 0;\\nconst baseY = this.innerHeight - params.length * lineHeight;\\nconst baseWidth = this.innerWidth;\\nconst valueFontSize = this.paramValueFontSize();\\n\\n// Calculate Widths\\nlet paramNameWidth = Math.max(...params.map(param => this.textWidth(TextManager.param(param))));\\nparamNameWidth += padding * 2;\\nif (this.isUseParamNamesWithIcons()) {\\n    paramNameWidth += ImageManager.iconWidth + 4;\\n}\\nlet arrowWidth = this.rightArrowWidth();\\nconst totalDivides = this.innerWidth >= 500 ? 3 : 2;\\nlet paramValueWidth = Math.floor((baseWidth - paramNameWidth - arrowWidth) / totalDivides);\\nparamNameWidth = baseWidth - (paramValueWidth * totalDivides) - arrowWidth;\\n\\n// Draw Parameters\\nlet x = baseX;\\nlet y = baseY;\\nlet value = 0;\\nlet diffValue = 0;\\nlet alter = 2;\\nfor (const paramId of params) {\\n    // Draw Param Name\\n    this.drawItemDarkRect(x, y, paramNameWidth, lineHeight, alter);\\n    this.drawUpdatedParamName(paramId, x, y, paramNameWidth);\\n    this.resetFontSettings();\\n    x += paramNameWidth;\\n\\n    // Draw Param Before\\n    this.contents.fontSize = valueFontSize;\\n    this.drawItemDarkRect(x, y, paramValueWidth, lineHeight, alter);\\n    this.drawUpdatedBeforeParamValue(paramId, x, y, paramValueWidth);\\n    this.resetFontSettings();\\n    x += paramValueWidth;\\n\\n    // Draw Arrow\\n    this.drawItemDarkRect(x, y, arrowWidth, lineHeight, alter);\\n    this.drawRightArrow(x, y);\\n    x += arrowWidth;\\n\\n    // Draw Param After\\n    this.contents.fontSize = valueFontSize;\\n    this.drawItemDarkRect(x, y, paramValueWidth, lineHeight, alter);\\n    this.drawUpdatedAfterParamValue(paramId, x, y, paramValueWidth);\\n    x += paramValueWidth;\\n\\n    // Draw Param Change\\n    if (totalDivides > 2) {\\n        this.drawItemDarkRect(x, y, paramValueWidth, lineHeight, alter);\\n        this.drawUpdatedParamValueDiff(paramId, x, y, paramValueWidth);\\n    }\\n\\n    // Prepare Next Parameter\\n    x = baseX;\\n    y += lineHeight;\\n    alter = alter === 2 ? 1 : 2;\\n}\"","LayoutStyle:str":"upper/right","StatusWindowWidth:num":"312","DrawBackRect:eval":"true","BackRectColor:str":"19","Command":"","CmdStyle:str":"auto","CmdTextAlign:str":"center","CmdIconEquip:num":"136","CommandAddOptimize:eval":"false","CmdIconOptimize:num":"137","CommandAddClear:eval":"false","CmdIconClear:num":"135","RemoveEquip":"","RemoveEquipIcon:num":"16","RemoveEquipText:str":"Remove","ShiftShortcutKey:eval":"true","Rulings":"","EquipAdjustHpMp:eval":"true","NonRemoveETypes:arraynum":"[]","NonOptimizeETypes:arraynum":"[]","ButtonAssist":"","buttonAssistRemove:str":"Unequip"}
 *
 * @param ShopScene:struct
 * @text Shop Menu Settings
 * @type struct<ShopScene>
 * @desc Change the Shop Menu Scene settings.
 * @default {"General":"","EnableLayout:eval":"true","LayoutStyle:str":"upper/left","Command":"","CmdHideDisabled:eval":"true","CmdStyle:str":"auto","CmdTextAlign:str":"center","CmdIconBuy:num":"208","CmdIconSell:num":"314","CmdIconCancel:num":"82","CmdCancelRename:str":"Exit","Prices":"","SellPriceRate:num":"0.50","BuyPriceJS:func":"\"// Declare variables\\nlet item = arguments[0];\\nlet price = arguments[1];\\n\\n// Return the finalized price\\nreturn price;\"","SellPriceJS:func":"\"// Declare variables\\nlet item = arguments[0];\\nlet price = arguments[1];\\n\\n// Return the finalized price\\nreturn price;\"","ButtonAssist":"","buttonAssistSmallIncrement:str":"-1/+1","buttonAssistLargeIncrement:str":"-10/+10"}
 *
 * @param StatusWindow:struct
 * @text Shop Status Window
 * @parent ShopScene:struct
 * @type struct<StatusWindow>
 * @desc Change the Item Status Window settings.
 * @default {"General":"","Width:num":"352","ParamChangeFontSize:num":"22","Translucent:num":"64","DrawBackRect:eval":"true","BackRectColor:str":"19","EquipData":"","AlreadyEquipMarker:str":"E","CannotEquipMarker:str":"-","NoChangeMarker:str":"-","DrawEquipData:func":"\"// Set Variables\\nconst lineHeight = this.lineHeight();\\nconst paramheight = this.gaugeLineHeight() + 8;\\nlet x = 0;\\nlet y = 0;\\nlet width = this.innerWidth;\\nlet height = this.innerHeight;\\nlet hw = Math.floor(width / 2);\\nlet hx = x + width - hw;\\n\\n// Draw Item Name, Type, and Quantity\\nthis.drawItemName(this._item, x + this.itemPadding(), y, width - this.itemPadding() * 2);\\nthis.drawItemDarkRect(x, y, width);\\ny += lineHeight;\\nif (this.drawItemEquipType(x, y, hw)) y += 0;\\nif (this.drawItemQuantity(hx, y, hw)) y += lineHeight;\\n\\n// Draw Parameter Names\\nconst params = this.actorParams();\\nconst backY = y;\\ny = height - (params.length * paramheight) - 4;\\nlet paramX = x;\\nlet paramWidth = 0;\\nlet tableY = y;\\nfor (const paramId of params) {\\n    paramWidth = Math.max(this.drawParamName(paramId, x + 4, y + 4, width), paramWidth);\\n    y += paramheight;\\n}\\n\\n// Draw Actor Data\\nconst actorMax = $gameParty.maxBattleMembers();\\nconst actorWidth = Math.floor((width - paramWidth) / actorMax);\\nparamWidth = width - (actorWidth * actorMax);\\nfor (const actor of $gameParty.battleMembers()) {\\n    const index = $gameParty.battleMembers().indexOf(actor);\\n    const actorX = paramX + paramWidth + (index * actorWidth);\\n    this.changePaintOpacity(actor.canEquip(this._item));\\n    this.drawActorCharacter(actor, actorX + (actorWidth / 2), tableY);\\n    let actorY = tableY;\\n\\n    // Draw Parameter Changes\\n    for (const paramId of params) {\\n        const diffY = actorY - ((lineHeight - paramheight) / 2);\\n        this.drawActorParamDifference(actor, paramId, actorX, diffY, actorWidth);\\n        actorY += paramheight;\\n    }\\n}\\n\\n// Draw Back Rectangles\\nthis.drawItemDarkRect(paramX, backY, paramWidth, tableY - backY);\\nfor (let i = 0; i < actorMax; i++) {\\n    const actorX = paramX + paramWidth + (i * actorWidth);\\n    this.drawItemDarkRect(actorX, backY, actorWidth, tableY - backY);\\n}\\nfor (const paramId of params) {\\n    this.drawItemDarkRect(paramX, tableY, paramWidth, paramheight);\\n    for (let i = 0; i < actorMax; i++) {\\n        const actorX = paramX + paramWidth + (i * actorWidth);\\n        this.drawItemDarkRect(actorX, tableY, actorWidth, paramheight);\\n    }\\n    tableY += paramheight;\\n}\"","ItemData":"","ItemGeneral":"","MaxIcons:num":"8","MultiplierStandard:num":"1000000","DrawItemData:func":"\"const lineHeight = this.lineHeight();\\nlet x = 0;\\nlet y = 0;\\nlet width = this.innerWidth;\\nlet height = this.innerHeight;\\nlet hw = Math.floor(width / 2);\\nlet hx = x + width - hw;\\n\\n// Draw Item Name and Quantity\\nthis.drawItemName(this._item, x + this.itemPadding(), y, width - this.itemPadding() * 2);\\nthis.drawItemDarkRect(x, y, width);\\ny += lineHeight;\\n\\n// Draw Main Item Properties\\nif (this.drawItemConsumable(x, y, hw)) y += 0;\\nif (this.drawItemQuantity(hx, y, hw)) y += lineHeight;\\nif (this._item.occasion < 3) {\\n    y = this.drawItemDamage(x, y, width);\\n    y = this.drawItemEffects(x, y, width);\\n}\\ny = this.drawItemCustomEntries(x, y, width);\\n\\n// Draw Remaining Item Properties\\nif (this._item.occasion < 3) {\\n    if (this.drawItemOccasion(x, y, hw)) y += 0;\\n    if (this.drawItemScope(hx, y, hw)) y += lineHeight;\\n    if (this.drawItemHitType(x, y, hw)) y += 0;\\n    if (this.drawItemSuccessRate(hx, y, hw)) y += lineHeight;\\n    if (this.drawItemSpeed(x, y, hw)) y += 0;\\n    if (this.drawItemRepeats(hx, y, hw)) y += lineHeight;\\n}\\n\\n// Fill Rest of the Window\\nthis.drawItemDarkRect(x, y, width, height - y);\"","Vocabulary":"","LabelConsume:str":"Consumable","Consumable:str":"✔","NotConsumable:str":"✘","Occasions":"","Occasion0:str":"Anytime Use","Occasion1:str":"Battle-Only","Occasion2:str":"Field-Only","Occasion3:str":"-","Scope":"","Scope0:str":"No Target","Scope1:str":"1 Foe","Scope2:str":"All Foes","Scope3:str":"Random Foe","Scope4:str":"2 Random Foes","Scope5:str":"3 Random Foes","Scope6:str":"4 Random Foes","Scope7:str":"1 Ally","Scope8:str":"Alive Allies","Scope9:str":"Dead Ally","Scope10:str":"Dead Allies","Scope11:str":"User","Scope12:str":"Any Ally","Scope13:str":"All Allies","Scope14:str":"Everybody","BattleCore":"","ScopeRandomAny:str":"%1 Random Units","ScopeRandomEnemies:str":"%1 Random Foes","ScopeRandomAllies:str":"%1 Random Allies","ScopeAlliesButUser:str":"Other Allies","LabelSpeed:str":"Speed","Speed2000:str":"Fastest","Speed1000:str":"Faster","Speed1:str":"Fast","Speed0:str":"Normal","SpeedNeg999:str":"Slow","SpeedNeg1999:str":"Slower","SpeedNeg2000:str":"Slowest","LabelSuccessRate:str":"Accuracy","LabelRepeats:str":"Hits","LabelHitType:str":"Type","HitType0:str":"Neutral","HitType1:str":"Physical","HitType2:str":"Magical","LabelElement:str":"Element","ElementWeapon:str":"\\I[97]Weapon","ElementNone:str":"\\I[160]No Element","DamageType":"","DamageType1:str":"%1 Damage Multiplier","DamageType2:str":"%1 Damage Multiplier","DamageType3:str":"%1 Recovery Multiplier","DamageType4:str":"%1 Recovery Multiplier","DamageType5:str":"%1 Drain Multiplier","DamageType6:str":"%1 Drain Multiplier","Effects":"","LabelRecoverHP:str":"%1 Recovery","LabelRecoverMP:str":"%1 Recovery","LabelRecoverTP:str":"%1 Recovery","LabelSelfGainTP:str":"User %1","LabelDamageHP:str":"%1 Damage","LabelDamageMP:str":"%1 Damage","LabelDamageTP:str":"%1 Damage","LabelApply:str":"Applies","LabelRemove:str":"Removes"}
 *
 * @param BreakEnd1
 * @text --------------------------
 * @default ----------------------------------
 *
 * @param End Of
 * @default Plugin Parameters
 *
 * @param BreakEnd2
 * @text --------------------------
 * @default ----------------------------------
 *
 */
/* ----------------------------------------------------------------------------
 * Item Menu Scene Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~ItemScene:
 *
 * @param General
 *
 * @param EnableLayout:eval
 * @text Use Updated Layout
 * @parent General
 * @type boolean
 * @on Use
 * @off Don't Use
 * @desc Use the Updated Item Menu Layout provided by this plugin?
 * This will override the Core Engine windows settings.
 * @default true
 *
 * @param LayoutStyle:str
 * @text Layout Style
 * @parent General
 * @type select
 * @option Upper Help, Left Input
 * @value upper/left
 * @option Upper Help, Right Input
 * @value upper/right
 * @option Lower Help, Left Input
 * @value lower/left
 * @option Lower Help, Right Input
 * @value lower/right
 * @desc If using an updated layout, how do you want to style
 * the menu scene layout?
 * @default upper/left
 *
 * @param ListWindow
 * @text List Window
 *
 * @param ListWindowCols:num
 * @text Columns
 * @parent ListWindow
 * @type number
 * @min 1
 * @desc Number of maximum columns.
 * @default 1
 *
 * @param ItemQt
 * @text Item Quantity
 *
 * @param MaxItems:num
 * @text Item Max
 * @parent ItemQt
 * @desc The default maximum quantity for items.
 * @default 99
 *
 * @param MaxWeapons:num
 * @text Weapon Max
 * @parent ItemQt
 * @desc The default maximum quantity for weapons.
 * @default 99
 *
 * @param MaxArmors:num
 * @text Armor Max
 * @parent ItemQt
 * @desc The default maximum quantity for armors.
 * @default 99
 *
 * @param ItemQuantityFmt:str
 * @text Quantity Format
 * @parent ItemQt
 * @desc How to display an item's quantity.
 * %1 - Item Quantity
 * @default ×%1
 *
 * @param ItemQuantityFontSize:num
 * @text Font Size
 * @parent ItemQt
 * @desc Default font size for item quantity.
 * @default 22
 *
 * @param ShopStatusWindow
 * @text Shop Status Window
 *
 * @param ShowShopStatus:eval
 * @text Show in Item Menu?
 * @parent ShopStatusWindow
 * @type boolean
 * @on Show
 * @off Don't Show
 * @desc Show the Shop Status Window in the Item Menu?
 * This is enabled if the Updated Layout is on.
 * @default true
 *
 * @param ItemSceneAdjustItemList:eval
 * @text Adjust List Window?
 * @parent ShopStatusWindow
 * @type boolean
 * @on Adjust
 * @off Don't
 * @desc Automatically adjust the Item List Window in the Item Menu if using the Shop Status Window?
 * @default true
 *
 * @param ItemMenuStatusBgType:num
 * @text Background Type
 * @parent ShopStatusWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param ItemMenuStatusRect:func
 * @text JS: X, Y, W, H
 * @parent ShopStatusWindow
 * @type note
 * @desc Code used to determine the dimensions for this Status Window in the Item Menu.
 * @default "const width = this.statusWidth();\nconst height = this._itemWindow.height;\nconst x = Graphics.boxWidth - width;\nconst y = this._itemWindow.y;\nreturn new Rectangle(x, y, width, height);"
 *
 * @param ButtonAssist
 * @text Button Assist Window
 *
 * @param buttonAssistCategory:str
 * @text Switch Category
 * @parent ButtonAssist
 * @desc Button assist text used for switching categories.
 * For VisuStella MZ's Core Engine's Button Assist Window.
 * @default Switch Category
 *
 */
/* ----------------------------------------------------------------------------
 * Item Categories
 * ----------------------------------------------------------------------------
 */
/*~struct~Categories:
 *
 * @param MainList
 * @text List
 * 
 * @param List:arraystruct
 * @text Category List
 * @parent MainList
 * @type struct<Category>[]
 * @desc A list of the item categories displayed in the Item/Shop menus.
 * @default ["{\"Type:str\":\"RegularItems\",\"Icon:num\":\"208\"}","{\"Type:str\":\"AllWeapons\",\"Icon:num\":\"97\"}","{\"Type:str\":\"AllArmors\",\"Icon:num\":\"137\"}","{\"Type:str\":\"KeyItems\",\"Icon:num\":\"195\"}"]
 *
 * @param Style:str
 * @text Category Style
 * @parent MainList
 * @type select
 * @option Text Only
 * @value text
 * @option Icon Only
 * @value icon
 * @option Icon + Text
 * @value iconText
 * @option Automatic
 * @value auto
 * @desc How do you wish to draw categorie entries in the Category Window?
 * @default icon
 *
 * @param TextAlign:str
 * @text Text Alignment
 * @parent MainList
 * @type combo
 * @option left
 * @option center
 * @option right
 * @desc Decide how you want the text to be aligned.
 * @default center
 *
 * @param Vocabulary
 *
 * @param HiddenItemA:str
 * @text Hidden Item A
 * @parent Vocabulary
 * @desc How this category is named in the Item Menu.
 * @default Special Items
 *
 * @param HiddenItemB:str
 * @text Hidden Item B
 * @parent Vocabulary
 * @desc How this category is named in the Item Menu.
 * @default Unique Items
 *
 * @param Consumable:str
 * @text Consumable
 * @parent Vocabulary
 * @desc How this category is named in the Item Menu.
 * @default Consumable
 *
 * @param Nonconsumable:str
 * @text Nonconsumable
 * @parent Vocabulary
 * @desc How this category is named in the Item Menu.
 * @default Nonconsumable
 *
 * @param AlwaysUsable:str
 * @text Always Usable
 * @parent Vocabulary
 * @desc How this category is named in the Item Menu.
 * @default Usable
 *
 * @param BattleUsable:str
 * @text Battle Usable
 * @parent Vocabulary
 * @desc How this category is named in the Item Menu.
 * @default Battle
 *
 * @param FieldUsable:str
 * @text Field Usable
 * @parent Vocabulary
 * @desc How this category is named in the Item Menu.
 * @default Field
 *
 * @param NeverUsable:str
 * @text Never Usable
 * @parent Vocabulary
 * @desc How this category is named in the Item Menu.
 * @default Materials
 *
 */
/* ----------------------------------------------------------------------------
 * Category Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~Category:
 *
 * @param Type:str
 * @text Type
 * @type combo
 * @option AllItems
 * @option 
 * @option RegularItems
 * @option KeyItems
 * @option HiddenItemA
 * @option HiddenItemB
 * @option 
 * @option Consumable
 * @option Nonconsumable
 * @option 
 * @option AlwaysUsable
 * @option BattleUsable
 * @option FieldUsable
 * @option NeverUsable
 * @option 
 * @option AllWeapons
 * @option WType:x
 * @option 
 * @option AllArmors
 * @option AType:x
 * @option 
 * @option EType:x
 * @option 
 * @option Category:x
 * @option
 * @desc A list of the item categories displayed in the Item/Shop
 * menus. Replace x with ID numbers or text.
 * @default RegularItems
 *
 * @param Icon:num
 * @text Icon
 * @desc Icon used for this category.
 * Use 0 for no icon.
 * @default 0
 *
 * @param SwitchID:num
 * @text Visibility Switch
 * @type switch
 * @desc This Switch must be turned ON in order for the category to show.
 * Use 0 for no Switch requirement.
 * @default 0
 *
 */
/* ----------------------------------------------------------------------------
 * New Label Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~NewLabel:
 *
 * @param Enable:eval
 * @text Use NEW! Labels?
 * @type boolean
 * @on Use
 * @off Don't Use
 * @desc Use the NEW! Labels or not?
 * @default true
 *
 * @param Icon:num
 * @text Icon
 * @desc The icon index used to represent the NEW! text.
 * Use 0 to not draw any icons.
 * @default 0
 *
 * @param Text:str
 * @text Text
 * @desc The text written on the NEW! Label.
 * @default NEW!
 *
 * @param FontColor:str
 * @text Font Color
 * @parent Text:str
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 17
 *
 * @param FontFace:str
 * @text Font Face
 * @parent Text:str
 * @desc Font face used for the NEW! Label.
 * @default Verdana
 *
 * @param FontSize:str
 * @text Font Size
 * @parent Text:str
 * @desc The font size used for the NEW! text.
 * @default 16
 *
 * @param FadeLimit:num
 * @text Fade Limit
 * @desc What's the upper opaque limit before reversing?
 * @default 360
 *
 * @param FadeSpeed:num
 * @text Fade Speed
 * @desc What's the fade speed of the NEW! Label?
 * @default 4
 *
 * @param OffsetX:num
 * @text Offset X
 * @desc How much to offset the NEW! Label's X position by.
 * @default 0
 *
 * @param OffsetY:num
 * @text Offset Y
 * @desc How much to offset the NEW! Label's Y position by.
 * @default 4
 *
 */
/* ----------------------------------------------------------------------------
 * Equip Menu Scene Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~EquipScene:
 *
 * @param General
 *
 * @param EnableLayout:eval
 * @text Use Updated Layout
 * @parent General
 * @type boolean
 * @on Use
 * @off Don't Use
 * @desc Use the Updated Equip Layout provided by this plugin?
 * This will override the Core Engine windows settings.
 * @default true
 *
 * @param LayoutStyle:str
 * @text Layout Style
 * @parent General
 * @type select
 * @option Upper Help, Left Input
 * @value upper/left
 * @option Upper Help, Right Input
 * @value upper/right
 * @option Lower Help, Left Input
 * @value lower/left
 * @option Lower Help, Right Input
 * @value lower/right
 * @desc If using an updated layout, how do you want to style
 * the menu scene layout?
 * @default upper/right
 *
 * @param ParamValueFontSize:num
 * @text Param Font Size
 * @parent EnableLayout:eval
 * @desc The font size used for parameter values.
 * @default 22
 *
 * @param MenuPortraits:eval
 * @text Show Menu Portraits?
 * @parent EnableLayout:eval
 * @type boolean
 * @on Use Portraits
 * @off Use Faces
 * @desc If Main Menu Core is installed, display the Menu Portraits
 * instead of the actor's face in the status window?
 * @default true
 *
 * @param DrawPortraitJS:func
 * @text JS: Portrait Upper
 * @parent EnableLayout:eval
 * @type note
 * @desc If Menu Portraits are available, this is code used to draw
 * the upper data like this in the Status Window.
 * @default "// Declare Variables\nconst lineHeight = this.lineHeight();\nconst padding = this.itemPadding();\nconst x1 = padding;\nconst x2 = this.innerWidth - 128 - padding;\n\n// Draw Menu Image\nthis.drawItemActorMenuImage(this._actor, 0, 0, this.innerWidth, this.innerHeight);\n\n// Draw Data\nthis.drawActorName(this._actor, x1, lineHeight * 0);\nthis.drawActorClass(this._actor, x1, lineHeight * 1);\nthis.drawActorIcons(this._actor, x1, lineHeight * 2);\nthis.drawActorLevel(this._actor, x2, lineHeight * 0);\nthis.placeBasicGauges(this._actor, x2, lineHeight * 1);"
 *
 * @param DrawFaceJS:func
 * @text JS: Face Upper
 * @parent EnableLayout:eval
 * @type note
 * @desc If faces used used, this is code used to draw the upper
 * data like this in the Status Window.
 * @default "// Declare Variables\nconst lineHeight = this.lineHeight();\nconst gaugeLineHeight = this.gaugeLineHeight();\nconst x = Math.floor(this.innerWidth / 2);\nconst limitHeight = this.innerHeight - (this.actorParams().length * lineHeight);\nconst actorX = Math.floor((x - ImageManager.faceWidth) / 2);\nconst actorY = Math.floor((limitHeight - ImageManager.faceHeight) / 2);\nlet dataHeight = lineHeight * 3;\ndataHeight += gaugeLineHeight * ($dataSystem.optDisplayTp ? 3 : 2);\nconst dataY = Math.floor((limitHeight - dataHeight) / 2);\n\n// Draw Data\nthis.drawActorFace(this._actor, actorX, actorY, ImageManager.faceWidth, ImageManager.faceHeight);\nthis.drawActorIcons(this._actor, actorX + 16, actorY + ImageManager.faceHeight - lineHeight);\nthis.drawActorName(this._actor, x, dataY + lineHeight * 0);\nthis.drawActorLevel(this._actor, x, dataY + lineHeight * 1);\nthis.drawActorClass(this._actor, x, dataY + lineHeight * 2);\nthis.placeBasicGauges(this._actor, x, dataY + lineHeight * 3);"
 *
 * @param DrawParamJS:func
 * @text JS: Parameter Lower
 * @parent EnableLayout:eval
 * @type note
 * @desc Code to determine how parameters are drawn in the
 * Status Window.
 * @default "// Declare variables\nconst params = this.actorParams();\nconst lineHeight = this.lineHeight();\nconst padding = this.itemPadding();\nconst baseX = 0;\nconst baseY = this.innerHeight - params.length * lineHeight;\nconst baseWidth = this.innerWidth;\nconst valueFontSize = this.paramValueFontSize();\n\n// Calculate Widths\nlet paramNameWidth = Math.max(...params.map(param => this.textWidth(TextManager.param(param))));\nparamNameWidth += padding * 2;\nif (this.isUseParamNamesWithIcons()) {\n    paramNameWidth += ImageManager.iconWidth + 4;\n}\nlet arrowWidth = this.rightArrowWidth();\nconst totalDivides = this.innerWidth >= 500 ? 3 : 2;\nlet paramValueWidth = Math.floor((baseWidth - paramNameWidth - arrowWidth) / totalDivides);\nparamNameWidth = baseWidth - (paramValueWidth * totalDivides) - arrowWidth;\n\n// Draw Parameters\nlet x = baseX;\nlet y = baseY;\nlet value = 0;\nlet diffValue = 0;\nlet alter = 2;\nfor (const paramId of params) {\n    // Draw Param Name\n    this.drawItemDarkRect(x, y, paramNameWidth, lineHeight, alter);\n    this.drawUpdatedParamName(paramId, x, y, paramNameWidth);\n    this.resetFontSettings();\n    x += paramNameWidth;\n\n    // Draw Param Before\n    this.contents.fontSize = valueFontSize;\n    this.drawItemDarkRect(x, y, paramValueWidth, lineHeight, alter);\n    this.drawUpdatedBeforeParamValue(paramId, x, y, paramValueWidth);\n    this.resetFontSettings();\n    x += paramValueWidth;\n\n    // Draw Arrow\n    this.drawItemDarkRect(x, y, arrowWidth, lineHeight, alter);\n    this.drawRightArrow(x, y);\n    x += arrowWidth;\n\n    // Draw Param After\n    this.contents.fontSize = valueFontSize;\n    this.drawItemDarkRect(x, y, paramValueWidth, lineHeight, alter);\n    this.drawUpdatedAfterParamValue(paramId, x, y, paramValueWidth);\n    x += paramValueWidth;\n\n    // Draw Param Change\n    if (totalDivides > 2) {\n        this.drawItemDarkRect(x, y, paramValueWidth, lineHeight, alter);\n        this.drawUpdatedParamValueDiff(paramId, x, y, paramValueWidth);\n    }\n\n    // Prepare Next Parameter\n    x = baseX;\n    y += lineHeight;\n    alter = alter === 2 ? 1 : 2;\n}"
 *
 * @param StatusWindowWidth:num
 * @text Status Window Width
 * @parent General
 * @desc The usual width of the status window if using the 
 * non-Updated Equip Menu Layout.
 * @default 312
 *
 * @param DrawBackRect:eval
 * @text Show Back Rectangles?
 * @parent General
 * @type boolean
 * @on Draw
 * @off Don't Draw
 * @desc Show back rectangles of darker colors to display information better?
 * @default true
 *
 * @param BackRectColor:str
 * @text Back Rectangle Color
 * @parent DrawBackRect:eval
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 19
 *
 * @param Command
 * @text Command Window
 *
 * @param CmdStyle:str
 * @text Style
 * @parent Command
 * @type select
 * @option Text Only
 * @value text
 * @option Icon Only
 * @value icon
 * @option Icon + Text
 * @value iconText
 * @option Automatic
 * @value auto
 * @desc How do you wish to draw commands in the Command Window?
 * @default auto
 *
 * @param CmdTextAlign:str
 * @text Text Align
 * @parent Command
 * @type combo
 * @option left
 * @option center
 * @option right
 * @desc Text alignment for the Command Window.
 * @default center
 *
 * @param CmdIconEquip:num
 * @text Equip Icon
 * @parent Command
 * @desc The icon used for the Equip command.
 * @default 136
 *
 * @param CommandAddOptimize:eval
 * @text Add Optimize Command?
 * @parent Command
 * @type boolean
 * @on Add
 * @off Don't
 * @desc Add the "Optimize" command to the Command Window?
 * @default true
 *
 * @param CmdIconOptimize:num
 * @text Optimize Icon
 * @parent CommandAddOptimize:eval
 * @desc The icon used for the Optimize command.
 * @default 137
 *
 * @param CommandAddClear:eval
 * @text Add Clear Command?
 * @parent Command
 * @type boolean
 * @on Add
 * @off Don't
 * @desc Add the "Clear" command to the Command Window?
 * @default true
 *
 * @param CmdIconClear:num
 * @text Clear Icon
 * @parent CommandAddClear:eval
 * @desc The icon used for the Clear command.
 * @default 135
 *
 * @param RemoveEquip
 * @text Remove Equip
 *
 * @param RemoveEquipIcon:num
 * @text Icon
 * @parent RemoveEquip
 * @desc Icon used for equipment removal.
 * @default 16
 *
 * @param RemoveEquipText:str
 * @text Text
 * @parent RemoveEquip
 * @desc Text used for equipment removal.
 * @default Remove
 *
 * @param ShiftShortcutKey:eval
 * @text Use SHIFT Shortcut?
 * @parent RemoveEquip
 * @type boolean
 * @on Use
 * @off Don't
 * @desc Add the "Shift" button as a shortcut key to removing items?
 * @default true

 * @param Rulings
 *
 * @param EquipAdjustHpMp:eval
 * @text Equip-Adjust HP/MP
 * @parent Rulings
 * @type boolean
 * @on Adjust
 * @off Don't
 * @desc Adjust HP/MP differences after changing equips with MaxHP/MaxMP values.
 * @default true
 * 
 * @param NonRemoveETypes:arraynum
 * @text Non-Removable Types
 * @parent Rulings
 * @type number[]
 * @min 1
 * @max 100
 * @desc Insert ID's of the Equipment Types that must always have
 * an item equipped and cannot be empty.
 * @default []
 *
 * @param NonOptimizeETypes:arraynum
 * @text Non-Optimized Types
 * @parent Rulings
 * @type number[]
 * @min 1
 * @max 100
 * @desc Insert ID's of the Equipment Types that will be ignored
 * when equipment is being optimized.
 * @default []
 *
 * @param ButtonAssist
 * @text Button Assist Window
 *
 * @param buttonAssistRemove:str
 * @text SHIFT: Remove
 * @parent ButtonAssist
 * @desc Button assist text used for the SHIFT Remove Shortcut.
 * For VisuStella MZ's Core Engine's Button Assist Window.
 * @default Unequip
 * 
 */
/* ----------------------------------------------------------------------------
 * Shop Menu Scene Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~ShopScene:
 *
 * @param General
 *
 * @param EnableLayout:eval
 * @text Use Updated Layout
 * @parent General
 * @type boolean
 * @on Use
 * @off Don't Use
 * @desc Use the Updated Shop Layout provided by this plugin?
 * This will override the Core Engine windows settings.
 * @default true
 *
 * @param LayoutStyle:str
 * @text Layout Style
 * @parent General
 * @type select
 * @option Upper Help, Left Input
 * @value upper/left
 * @option Upper Help, Right Input
 * @value upper/right
 * @option Lower Help, Left Input
 * @value lower/left
 * @option Lower Help, Right Input
 * @value lower/right
 * @desc If using an updated layout, how do you want to style
 * the menu scene layout?
 * @default upper/left
 *
 * @param Switches
 *
 * @param SwitchBuy:num
 * @text Switch: Buy
 * @parent Switches
 * @type switch
 * @desc Buying items in the Shop Scene turns this Switch to ON.
 * Switch reverts to OFF whenever the Shop Scene opens.
 * @default 0
 *
 * @param SwitchSell:num
 * @text Switch: Sell
 * @parent Switches
 * @type switch
 * @desc Selling items in the Shop Scene turns this Switch to ON.
 * Switch reverts to OFF whenever the Shop Scene opens.
 * @default 0
 *
 * @param Command
 * @text Command Window
 *
 * @param CmdHideDisabled:eval
 * @text Hide Unavailable?
 * @parent Command
 * @type boolean
 * @on Hide
 * @off Default
 * @desc Hide all unavailable commands like when a shop is set to Purchase Only?
 * @default true
 *
 * @param CmdStyle:str
 * @text Style
 * @parent Command
 * @type select
 * @option Text Only
 * @value text
 * @option Icon Only
 * @value icon
 * @option Icon + Text
 * @value iconText
 * @option Automatic
 * @value auto
 * @desc How do you wish to draw commands in the Command Window?
 * @default auto
 *
 * @param CmdTextAlign:str
 * @text Text Align
 * @parent Command
 * @type combo
 * @option left
 * @option center
 * @option right
 * @desc Text alignment for the Command Window.
 * @default center
 *
 * @param CmdIconBuy:num
 * @text Buy Icon
 * @parent Command
 * @desc The icon used for the Buy command.
 * @default 208
 *
 * @param CmdIconSell:num
 * @text Sell Icon
 * @parent Command
 * @desc The icon used for the Sell command.
 * @default 314
 *
 * @param CmdIconCancel:num
 * @text Cancel Icon
 * @parent Command
 * @desc The icon used for the Cancel command.
 * @default 82
 *
 * @param CmdCancelRename:str
 * @text Rename "Cancel"
 * @parent Command
 * @desc Rename Cancel to something more logical for the Shop Menu Scene.
 * @default Exit
 *
 * @param Prices
 *
 * @param SellPriceRate:num
 * @text Sell Price Rate
 * @parent Prices
 * @desc The default sell price rate.
 * @default 0.50
 *
 * @param BuyPriceJS:func
 * @text JS: Buy Price
 * @parent Prices
 * @type note
 * @desc Modificatons made to the buy price before finalizing it.
 * @default "// Declare variables\nlet item = arguments[0];\nlet price = arguments[1];\n\n// Return the finalized price\nreturn price;"
 *
 * @param SellPriceJS:func
 * @text JS: Sell Price
 * @parent Prices
 * @type note
 * @desc Modificatons made to the sell price before finalizing it.
 * @default "// Declare variables\nlet item = arguments[0];\nlet price = arguments[1];\n\n// Return the finalized price\nreturn price;"
 * 
 * @param ButtonAssist
 * @text Button Assist Window
 *
 * @param buttonAssistSmallIncrement:str
 * @text Small Increment
 * @parent ButtonAssist
 * @desc Text used for changing amount bought/sold.
 * For VisuStella MZ's Core Engine's Button Assist Window.
 * @default -1/+1
 *
 * @param buttonAssistLargeIncrement:str
 * @text Large Increment
 * @parent ButtonAssist
 * @desc Text used for changing amount bought/sold.
 * For VisuStella MZ's Core Engine's Button Assist Window.
 * @default -10/+10
 *
 */
/* ----------------------------------------------------------------------------
 * Shop Status Window Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~StatusWindow:
 *
 * @param General
 *
 * @param Width:num
 * @text Window Width
 * @parent General
 * @desc The usual width of the status window.
 * @default 352
 *
 * @param ParamChangeFontSize:num
 * @text Parameter Font Size
 * @parent General
 * @desc Font size used for parameter changes.
 * @default 22
 *
 * @param Translucent:num
 * @text Translucent Opacity
 * @parent General
 * @desc Opacity setting used for translucent window objects.
 * @default 64
 *
 * @param DrawBackRect:eval
 * @text Show Back Rectangles?
 * @parent General
 * @type boolean
 * @on Draw
 * @off Don't Draw
 * @desc Show back rectangles of darker colors to display information better?
 * @default true
 *
 * @param BackRectColor:str
 * @text Back Rectangle Color
 * @parent DrawBackRect:eval
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 19
 *
 * @param EquipData
 * @text Equipment Data
 *
 * @param AlreadyEquipMarker:str
 * @text Already Equipped
 * @parent EquipData
 * @desc Marker used to show an actor cannot equip an item.
 * @default E
 *
 * @param CannotEquipMarker:str
 * @text Can't Equip
 * @parent EquipData
 * @desc Marker used to show an actor cannot equip an item.
 * @default -
 *
 * @param NoChangeMarker:str
 * @text No Changes
 * @parent EquipData
 * @desc Marker used to show no changes have occurred.
 * @default -
 *
 * @param DrawEquipData:func
 * @text JS: Draw Equip Data
 * @parent EquipData
 * @type note
 * @desc Code used to draw the equipment data for the Shop Status Window.
 * @default "// Set Variables\nconst lineHeight = this.lineHeight();\nconst paramheight = this.gaugeLineHeight() + 8;\nlet x = 0;\nlet y = 0;\nlet width = this.innerWidth;\nlet height = this.innerHeight;\nlet hw = Math.floor(width / 2);\nlet hx = x + width - hw;\n\n// Draw Item Name, Type, and Quantity\nthis.drawItemName(this._item, x + this.itemPadding(), y, width - this.itemPadding() * 2);\nthis.drawItemDarkRect(x, y, width);\ny += lineHeight;\nif (this.drawItemEquipType(x, y, hw)) y += 0;\nif (this.drawItemQuantity(hx, y, hw)) y += lineHeight;\n\n// Draw Parameter Names\nconst params = this.actorParams();\nconst backY = y;\ny = height - (params.length * paramheight) - 4;\nlet paramX = x;\nlet paramWidth = 0;\nlet tableY = y;\nfor (const paramId of params) {\n    paramWidth = Math.max(this.drawParamName(paramId, x + 4, y + 4, width), paramWidth);\n    y += paramheight;\n}\n\n// Draw Actor Data\nconst actorMax = $gameParty.maxBattleMembers();\nconst actorWidth = Math.floor((width - paramWidth) / actorMax);\nparamWidth = width - (actorWidth * actorMax);\nfor (const actor of $gameParty.battleMembers()) {\n    const index = $gameParty.battleMembers().indexOf(actor);\n    const actorX = paramX + paramWidth + (index * actorWidth);\n    this.changePaintOpacity(actor.canEquip(this._item));\n    this.drawActorCharacter(actor, actorX + (actorWidth / 2), tableY);\n    let actorY = tableY;\n\n    // Draw Parameter Changes\n    for (const paramId of params) {\n        const diffY = actorY - ((lineHeight - paramheight) / 2);\n        this.drawActorParamDifference(actor, paramId, actorX, diffY, actorWidth);\n        actorY += paramheight;\n    }\n}\n\n// Draw Back Rectangles\nthis.drawItemDarkRect(paramX, backY, paramWidth, tableY - backY);\nfor (let i = 0; i < actorMax; i++) {\n    const actorX = paramX + paramWidth + (i * actorWidth);\n    this.drawItemDarkRect(actorX, backY, actorWidth, tableY - backY);\n}\nfor (const paramId of params) {\n    this.drawItemDarkRect(paramX, tableY, paramWidth, paramheight);\n    for (let i = 0; i < actorMax; i++) {\n        const actorX = paramX + paramWidth + (i * actorWidth);\n        this.drawItemDarkRect(actorX, tableY, actorWidth, paramheight);\n    }\n    tableY += paramheight;\n}"
 *
 * @param ItemData
 * @text Item Data
 *
 * @param ItemGeneral
 * @parent ItemData
 *
 * @param MaxIcons:num
 * @text Max State/Buff Icons
 * @parent ItemGeneral
 * @desc Maximum number of icons that can be displayed for Add/Remove States/Buffs.
 * @default 8
 *
 * @param MultiplierStandard:num
 * @text Multiplier Standard
 * @parent ItemGeneral
 * @desc Constant standard to filter out random values when calculating the damage multiplier.
 * @default 1000000
 *
 * @param DrawItemData:func
 * @text JS: Draw Item Data
 * @parent ItemGeneral
 * @type note
 * @desc Code used to draw the item data for the Shop Status Window.
 * @default "const lineHeight = this.lineHeight();\nlet x = 0;\nlet y = 0;\nlet width = this.innerWidth;\nlet height = this.innerHeight;\nlet hw = Math.floor(width / 2);\nlet hx = x + width - hw;\n\n// Draw Item Name and Quantity\nthis.drawItemName(this._item, x + this.itemPadding(), y, width - this.itemPadding() * 2);\nthis.drawItemDarkRect(x, y, width);\ny += lineHeight;\n\n// Draw Main Item Properties\nif (this.drawItemConsumable(x, y, hw)) y += 0;\nif (this.drawItemQuantity(hx, y, hw)) y += lineHeight;\nif (this._item.occasion < 3) {\n    y = this.drawItemDamage(x, y, width);\n    y = this.drawItemEffects(x, y, width);\n}\ny = this.drawItemCustomEntries(x, y, width);\n\n// Draw Remaining Item Properties\nif (this._item.occasion < 3) {\n    if (this.drawItemOccasion(x, y, hw)) y += 0;\n    if (this.drawItemScope(hx, y, hw)) y += lineHeight;\n    if (this.drawItemHitType(x, y, hw)) y += 0;\n    if (this.drawItemSuccessRate(hx, y, hw)) y += lineHeight;\n    if (this.drawItemSpeed(x, y, hw)) y += 0;\n    if (this.drawItemRepeats(hx, y, hw)) y += lineHeight;\n}\n\n// Fill Rest of the Window\nthis.drawItemDarkRect(x, y, width, height - y);"
 *
 * @param Vocabulary
 * @parent ItemData
 *
 * @param LabelConsume:str
 * @text Consumable
 * @parent Vocabulary
 * @desc Vocabulary used for this data entry.
 * @default Consumable
 *
 * @param Consumable:str
 * @text Yes
 * @parent LabelConsume:str
 * @desc Vocabulary used for this data entry.
 * @default ✔
 *
 * @param NotConsumable:str
 * @text No
 * @parent LabelConsume:str
 * @desc Vocabulary used for this data entry.
 * @default ✘
 *
 * @param Occasions
 * @parent Vocabulary
 *
 * @param Occasion0:str
 * @text Always
 * @parent Occasions
 * @desc Vocabulary used for this data entry.
 * @default Anytime Use
 *
 * @param Occasion1:str
 * @text Battle Screen
 * @parent Occasions
 * @desc Vocabulary used for this data entry.
 * @default Battle-Only
 *
 * @param Occasion2:str
 * @text Menu Screen
 * @parent Occasions
 * @desc Vocabulary used for this data entry.
 * @default Field-Only
 *
 * @param Occasion3:str
 * @text Never
 * @parent Occasions
 * @desc Vocabulary used for this data entry.
 * @default -
 *
 * @param Scope
 * @parent Vocabulary
 *
 * @param Scope0:str
 * @text None
 * @parent Scope
 * @desc Vocabulary used for this data entry.
 * @default No Target
 *
 * @param Scope1:str
 * @text 1 Enemy
 * @parent Scope
 * @desc Vocabulary used for this data entry.
 * @default 1 Foe
 *
 * @param Scope2:str
 * @text All Enemies
 * @parent Scope
 * @desc Vocabulary used for this data entry.
 * @default All Foes
 *
 * @param Scope3:str
 * @text 1 Random Enemy
 * @parent Scope
 * @desc Vocabulary used for this data entry.
 * @default Random Foe
 *
 * @param Scope4:str
 * @text 2 Random Enemies
 * @parent Scope
 * @desc Vocabulary used for this data entry.
 * @default 2 Random Foes
 *
 * @param Scope5:str
 * @text 3 Random Enemies
 * @parent Scope
 * @desc Vocabulary used for this data entry.
 * @default 3 Random Foes
 *
 * @param Scope6:str
 * @text 4 Random Enemies
 * @parent Scope
 * @desc Vocabulary used for this data entry.
 * @default 4 Random Foes
 *
 * @param Scope7:str
 * @text 1 Ally
 * @parent Scope
 * @desc Vocabulary used for this data entry.
 * @default 1 Ally
 *
 * @param Scope8:str
 * @text All Allies
 * @parent Scope
 * @desc Vocabulary used for this data entry.
 * @default Alive Allies
 *
 * @param Scope9:str
 * @text 1 Ally (Dead)
 * @parent Scope
 * @desc Vocabulary used for this data entry.
 * @default Dead Ally
 *
 * @param Scope10:str
 * @text All Allies (Dead)
 * @parent Scope
 * @desc Vocabulary used for this data entry.
 * @default Dead Allies
 *
 * @param Scope11:str
 * @text The User
 * @parent Scope
 * @desc Vocabulary used for this data entry.
 * @default User
 *
 * @param Scope12:str
 * @text 1 Ally (DoA)
 * @parent Scope
 * @desc Vocabulary used for this data entry.
 * @default Any Ally
 *
 * @param Scope13:str
 * @text All Allies (DoA)
 * @parent Scope
 * @desc Vocabulary used for this data entry.
 * @default All Allies
 *
 * @param Scope14:str
 * @text Enemies & Allies
 * @parent Scope
 * @desc Vocabulary used for this data entry.
 * @default Everybody
 *
 * @param BattleCore
 * @text Battle Core Support
 * @parent Vocabulary
 *
 * @param ScopeRandomAny:str
 * @text x Random Any
 * @parent BattleCore
 * @desc Vocabulary used for <Target: x Random Any> notetag.
 * @default %1 Random Units
 *
 * @param ScopeRandomEnemies:str
 * @text x Random Enemies
 * @parent BattleCore
 * @desc Vocabulary used for <Target: x Random Enemies> notetag.
 * @default %1 Random Foes
 *
 * @param ScopeRandomAllies:str
 * @text x Random Allies
 * @parent BattleCore
 * @desc Vocabulary used for <Target: x Random Allies> notetag.
 * @default %1 Random Allies
 *
 * @param ScopeAlliesButUser:str
 * @text All Allies But User
 * @parent BattleCore
 * @desc Vocabulary used for <Target: All Allies But User> notetag.
 * @default Other Allies
 *
 * @param LabelSpeed:str
 * @text Speed
 * @parent Vocabulary
 * @desc Vocabulary used for this data entry.
 * @default Speed
 *
 * @param Speed2000:str
 * @text >= 2000 Speed
 * @parent LabelSpeed:str
 * @desc Vocabulary used for this data entry.
 * @default Fastest
 *
 * @param Speed1000:str
 * @text >= 1000 Speed
 * @parent LabelSpeed:str
 * @desc Vocabulary used for this data entry.
 * @default Faster
 *
 * @param Speed1:str
 * @text >= 1 Speed
 * @parent LabelSpeed:str
 * @desc Vocabulary used for this data entry.
 * @default Fast
 *
 * @param Speed0:str
 * @text == 0 Speed
 * @parent LabelSpeed:str
 * @desc Vocabulary used for this data entry.
 * @default Normal
 *
 * @param SpeedNeg999:str
 * @text >= -999 Speed
 * @parent LabelSpeed:str
 * @desc Vocabulary used for this data entry.
 * @default Slow
 *
 * @param SpeedNeg1999:str
 * @text >= -1999 Speed
 * @parent LabelSpeed:str
 * @desc Vocabulary used for this data entry.
 * @default Slower
 *
 * @param SpeedNeg2000:str
 * @text <= -2000 Speed
 * @parent LabelSpeed:str
 * @desc Vocabulary used for this data entry.
 * @default Slowest
 *
 * @param LabelSuccessRate:str
 * @text Success Rate
 * @parent Vocabulary
 * @desc Vocabulary used for this data entry.
 * @default Accuracy
 *
 * @param LabelRepeats:str
 * @text Repeats
 * @parent Vocabulary
 * @desc Vocabulary used for this data entry.
 * @default Hits
 *
 * @param LabelHitType:str
 * @text Hit Type
 * @parent Vocabulary
 * @desc Vocabulary used for this data entry.
 * @default Type
 *
 * @param HitType0:str
 * @text Certain Hit
 * @parent LabelHitType:str
 * @desc Vocabulary used for this data entry.
 * @default Neutral
 *
 * @param HitType1:str
 * @text Physical
 * @parent LabelHitType:str
 * @desc Vocabulary used for this data entry.
 * @default Physical
 *
 * @param HitType2:str
 * @text Magical
 * @parent LabelHitType:str
 * @desc Vocabulary used for this data entry.
 * @default Magical
 *
 * @param LabelElement:str
 * @text Element
 * @parent Vocabulary
 * @desc Vocabulary used for this data entry.
 * @default Element
 *
 * @param ElementWeapon:str
 * @text Weapon-Based
 * @parent LabelElement:str
 * @desc Vocabulary used for this data entry.
 * @default \I[97]Weapon
 *
 * @param ElementNone:str
 * @text Nonelement Element
 * @parent LabelElement:str
 * @desc Vocabulary used for this data entry.
 * @default \I[160]No Element
 *
 * @param DamageType
 * @text Damage Type
 * @parent Vocabulary
 *
 * @param DamageType1:str
 * @text HP Damage
 * @parent DamageType
 * @desc Vocabulary used for this data entry. If Visu_1_BattleCore
 * is installed, priority goes to its Damage Style settings.
 * @default %1 Damage Multiplier
 *
 * @param DamageType2:str
 * @text MP Damage
 * @parent DamageType
 * @desc Vocabulary used for this data entry. If Visu_1_BattleCore
 * is installed, priority goes to its Damage Style settings.
 * @default %1 Damage Multiplier
 *
 * @param DamageType3:str
 * @text HP Recovery
 * @parent DamageType
 * @desc Vocabulary used for this data entry. If Visu_1_BattleCore
 * is installed, priority goes to its Damage Style settings.
 * @default %1 Recovery Multiplier
 *
 * @param DamageType4:str
 * @text MP Recovery
 * @parent DamageType
 * @desc Vocabulary used for this data entry. If Visu_1_BattleCore
 * is installed, priority goes to its Damage Style settings.
 * @default %1 Recovery Multiplier
 *
 * @param DamageType5:str
 * @text HP Drain
 * @parent DamageType
 * @desc Vocabulary used for this data entry. If Visu_1_BattleCore
 * is installed, priority goes to its Damage Style settings.
 * @default %1 Drain Multiplier
 *
 * @param DamageType6:str
 * @text MP Drain
 * @parent DamageType
 * @desc Vocabulary used for this data entry. If Visu_1_BattleCore
 * is installed, priority goes to its Damage Style settings.
 * @default %1 Drain Multiplier
 *
 * @param Effects
 * @parent Vocabulary
 *
 * @param LabelRecoverHP:str
 * @text Recover HP
 * @parent Effects
 * @desc Vocabulary used for this data entry.
 * @default %1 Recovery
 *
 * @param LabelRecoverMP:str
 * @text Recover MP
 * @parent Effects
 * @desc Vocabulary used for this data entry.
 * @default %1 Recovery
 *
 * @param LabelRecoverTP:str
 * @text Recover TP
 * @parent Effects
 * @desc Vocabulary used for this data entry.
 * @default %1 Recovery
 *
 * @param LabelSelfGainTP:str
 * @text Self Gain TP
 * @parent Effects
 * @desc Vocabulary used for this data entry.
 * @default User %1
 *
 * @param LabelDamageHP:str
 * @text Damage HP
 * @parent Effects
 * @desc Vocabulary used for this data entry.
 * @default %1 Damage
 *
 * @param LabelDamageMP:str
 * @text Damage MP
 * @parent Effects
 * @desc Vocabulary used for this data entry.
 * @default %1 Damage
 *
 * @param LabelDamageTP:str
 * @text Damage TP
 * @parent Effects
 * @desc Vocabulary used for this data entry.
 * @default %1 Damage
 *
 * @param LabelApply:str
 * @text Add State/Buff
 * @parent Effects
 * @desc Vocabulary used for this data entry.
 * @default Applies
 *
 * @param LabelRemove:str
 * @text Remove State/Buff
 * @parent Effects
 * @desc Vocabulary used for this data entry.
 * @default Removes
 *
 */
//=============================================================================

function _0x2bb7(_0x2b1c40,_0x40067e){const _0x4480cf=_0x4480();return _0x2bb7=function(_0x2bb76c,_0x8c48e8){_0x2bb76c=_0x2bb76c-0x19d;let _0x173351=_0x4480cf[_0x2bb76c];return _0x173351;},_0x2bb7(_0x2b1c40,_0x40067e);}const _0x541333=_0x2bb7;(function(_0x5f4d6e,_0x553062){const _0x3f0e37=_0x2bb7,_0x25ae45=_0x5f4d6e();while(!![]){try{const _0x12b51c=parseInt(_0x3f0e37(0x3c9))/0x1+parseInt(_0x3f0e37(0x48f))/0x2*(-parseInt(_0x3f0e37(0x483))/0x3)+-parseInt(_0x3f0e37(0x222))/0x4*(parseInt(_0x3f0e37(0x3a6))/0x5)+parseInt(_0x3f0e37(0x1da))/0x6+parseInt(_0x3f0e37(0x559))/0x7+parseInt(_0x3f0e37(0x38e))/0x8+-parseInt(_0x3f0e37(0x1d2))/0x9*(parseInt(_0x3f0e37(0x2c9))/0xa);if(_0x12b51c===_0x553062)break;else _0x25ae45['push'](_0x25ae45['shift']());}catch(_0x13872e){_0x25ae45['push'](_0x25ae45['shift']());}}}(_0x4480,0xe35fa));var label=_0x541333(0x1db),tier=tier||0x0,dependencies=[],pluginData=$plugins[_0x541333(0x3ef)](function(_0x5771f8){const _0x4862ce=_0x541333;return _0x5771f8[_0x4862ce(0x2db)]&&_0x5771f8[_0x4862ce(0x523)][_0x4862ce(0x53c)]('['+label+']');})[0x0];VisuMZ[label][_0x541333(0x522)]=VisuMZ[label]['Settings']||{},VisuMZ[_0x541333(0x4ac)]=function(_0x15903d,_0x19e806){const _0x45f3ca=_0x541333;for(const _0x6f33d5 in _0x19e806){if(_0x6f33d5['match'](/(.*):(.*)/i)){const _0x448ff9=String(RegExp['$1']),_0x4b1929=String(RegExp['$2'])[_0x45f3ca(0x58a)]()['trim']();let _0x3aeb0c,_0x1859d9,_0x557498;switch(_0x4b1929){case _0x45f3ca(0x4e9):_0x3aeb0c=_0x19e806[_0x6f33d5]!==''?Number(_0x19e806[_0x6f33d5]):0x0;break;case'ARRAYNUM':_0x1859d9=_0x19e806[_0x6f33d5]!==''?JSON[_0x45f3ca(0x5f9)](_0x19e806[_0x6f33d5]):[],_0x3aeb0c=_0x1859d9[_0x45f3ca(0x374)](_0x48a2a=>Number(_0x48a2a));break;case _0x45f3ca(0x51a):_0x3aeb0c=_0x19e806[_0x6f33d5]!==''?eval(_0x19e806[_0x6f33d5]):null;break;case _0x45f3ca(0x430):_0x1859d9=_0x19e806[_0x6f33d5]!==''?JSON[_0x45f3ca(0x5f9)](_0x19e806[_0x6f33d5]):[],_0x3aeb0c=_0x1859d9['map'](_0x232b39=>eval(_0x232b39));break;case'JSON':_0x3aeb0c=_0x19e806[_0x6f33d5]!==''?JSON[_0x45f3ca(0x5f9)](_0x19e806[_0x6f33d5]):'';break;case _0x45f3ca(0x1b5):_0x1859d9=_0x19e806[_0x6f33d5]!==''?JSON[_0x45f3ca(0x5f9)](_0x19e806[_0x6f33d5]):[],_0x3aeb0c=_0x1859d9[_0x45f3ca(0x374)](_0x4cc312=>JSON[_0x45f3ca(0x5f9)](_0x4cc312));break;case _0x45f3ca(0x3dd):_0x3aeb0c=_0x19e806[_0x6f33d5]!==''?new Function(JSON[_0x45f3ca(0x5f9)](_0x19e806[_0x6f33d5])):new Function(_0x45f3ca(0x23e));break;case _0x45f3ca(0x1b8):_0x1859d9=_0x19e806[_0x6f33d5]!==''?JSON[_0x45f3ca(0x5f9)](_0x19e806[_0x6f33d5]):[],_0x3aeb0c=_0x1859d9[_0x45f3ca(0x374)](_0x217e12=>new Function(JSON[_0x45f3ca(0x5f9)](_0x217e12)));break;case'STR':_0x3aeb0c=_0x19e806[_0x6f33d5]!==''?String(_0x19e806[_0x6f33d5]):'';break;case'ARRAYSTR':_0x1859d9=_0x19e806[_0x6f33d5]!==''?JSON[_0x45f3ca(0x5f9)](_0x19e806[_0x6f33d5]):[],_0x3aeb0c=_0x1859d9[_0x45f3ca(0x374)](_0x921745=>String(_0x921745));break;case _0x45f3ca(0x24b):_0x557498=_0x19e806[_0x6f33d5]!==''?JSON['parse'](_0x19e806[_0x6f33d5]):{},_0x15903d[_0x448ff9]={},VisuMZ[_0x45f3ca(0x4ac)](_0x15903d[_0x448ff9],_0x557498);continue;case _0x45f3ca(0x392):_0x1859d9=_0x19e806[_0x6f33d5]!==''?JSON[_0x45f3ca(0x5f9)](_0x19e806[_0x6f33d5]):[],_0x3aeb0c=_0x1859d9[_0x45f3ca(0x374)](_0x441f58=>VisuMZ['ConvertParams']({},JSON[_0x45f3ca(0x5f9)](_0x441f58)));break;default:continue;}_0x15903d[_0x448ff9]=_0x3aeb0c;}}return _0x15903d;},(_0x470964=>{const _0x2633e6=_0x541333,_0x327724=_0x470964[_0x2633e6(0x3bf)];for(const _0x393561 of dependencies){if(!Imported[_0x393561]){alert('%1\x20is\x20missing\x20a\x20required\x20plugin.\x0aPlease\x20install\x20%2\x20into\x20the\x20Plugin\x20Manager.'['format'](_0x327724,_0x393561)),SceneManager[_0x2633e6(0x380)]();break;}}const _0x18845b=_0x470964[_0x2633e6(0x523)];if(_0x18845b[_0x2633e6(0x2a3)](/\[Version[ ](.*?)\]/i)){const _0x3c7c09=Number(RegExp['$1']);_0x3c7c09!==VisuMZ[label]['version']&&(_0x2633e6(0x440)!==_0x2633e6(0x40e)?(alert('%1\x27s\x20version\x20does\x20not\x20match\x20plugin\x27s.\x20Please\x20update\x20it\x20in\x20the\x20Plugin\x20Manager.'['format'](_0x327724,_0x3c7c09)),SceneManager[_0x2633e6(0x380)]()):(_0x400410['ItemsEquipsCore'][_0x2633e6(0x531)][_0x2633e6(0x562)](this),this[_0x2633e6(0x1b6)][_0x2633e6(0x1b1)]()));}if(_0x18845b[_0x2633e6(0x2a3)](/\[Tier[ ](\d+)\]/i)){if(_0x2633e6(0x2f0)!==_0x2633e6(0x2f0)){const _0x278cbd=_0x28c369[_0x2633e6(0x1db)][_0x2633e6(0x1ef)]['call'](this);return this['allowCreateStatusWindow']()&&this[_0x2633e6(0x40f)]()&&(_0x278cbd[_0x2633e6(0x5bc)]-=this['statusWidth']()),_0x278cbd;}else{const _0x4c0292=Number(RegExp['$1']);if(_0x4c0292<tier)_0x2633e6(0x3fa)!==_0x2633e6(0x3fa)?_0x78eaae=_0x2633e6(0x592)[_0x2633e6(0x52b)](_0x9ff9a['id']):(alert(_0x2633e6(0x20c)[_0x2633e6(0x52b)](_0x327724,_0x4c0292,tier)),SceneManager['exit']());else{if(_0x2633e6(0x387)===_0x2633e6(0x387))tier=Math[_0x2633e6(0x52c)](_0x4c0292,tier);else return _0x59f0ea['ItemsEquipsCore']['Settings'][_0x2633e6(0x3c6)][_0x2633e6(0x48d)];}}}VisuMZ[_0x2633e6(0x4ac)](VisuMZ[label]['Settings'],_0x470964['parameters']);})(pluginData),PluginManager[_0x541333(0x457)](pluginData[_0x541333(0x3bf)],'ActorChangeEquipSlots',_0xa15b16=>{const _0x279988=_0x541333;VisuMZ[_0x279988(0x4ac)](_0xa15b16,_0xa15b16);const _0x1cd78d=_0xa15b16[_0x279988(0x3b8)]['map'](_0x45be90=>$gameActors['actor'](_0x45be90)),_0x15da1e=_0xa15b16[_0x279988(0x43c)]['map'](_0x3f88e1=>$dataSystem['equipTypes'][_0x279988(0x525)](_0x3f88e1[_0x279988(0x399)]()));for(const _0x38c48e of _0x1cd78d){if(!_0x38c48e)continue;_0x38c48e['forceChangeEquipSlots'](_0x15da1e);}}),PluginManager[_0x541333(0x457)](pluginData[_0x541333(0x3bf)],_0x541333(0x363),_0x2e5861=>{const _0x50647d=_0x541333;VisuMZ[_0x50647d(0x4ac)](_0x2e5861,_0x2e5861);const _0x1b5ccc=_0x2e5861[_0x50647d(0x3b8)]['map'](_0xf304f=>$gameActors[_0x50647d(0x40a)](_0xf304f));for(const _0x5ddfdd of _0x1b5ccc){if(_0x50647d(0x1fd)!==_0x50647d(0x1f7)){if(!_0x5ddfdd)continue;_0x5ddfdd[_0x50647d(0x499)]();}else for(const _0x5b78dd of _0x29de02['_data']){if(_0x5b78dd)_0x5b78dd[_0x50647d(0x5d7)]();}}}),PluginManager[_0x541333(0x457)](pluginData[_0x541333(0x3bf)],_0x541333(0x4c7),_0x2c1b5b=>{const _0xc6a11b=_0x541333;VisuMZ[_0xc6a11b(0x4ac)](_0x2c1b5b,_0x2c1b5b);const _0x134edd=[],_0x499609=_0x2c1b5b[_0xc6a11b(0x57c)][_0xc6a11b(0x374)](_0x124577=>_0x124577[_0xc6a11b(0x58a)]()[_0xc6a11b(0x399)]()),_0x35d61f=_0x2c1b5b[_0xc6a11b(0x2bf)][_0xc6a11b(0x374)](_0x317439=>_0x317439[_0xc6a11b(0x58a)]()[_0xc6a11b(0x399)]()),_0x21872b=_0x2c1b5b[_0xc6a11b(0x341)]>=_0x2c1b5b[_0xc6a11b(0x530)]?_0x2c1b5b[_0xc6a11b(0x530)]:_0x2c1b5b[_0xc6a11b(0x341)],_0x763466=_0x2c1b5b[_0xc6a11b(0x341)]>=_0x2c1b5b[_0xc6a11b(0x530)]?_0x2c1b5b[_0xc6a11b(0x341)]:_0x2c1b5b['Step1Start'],_0xf6a01c=Array(_0x763466-_0x21872b+0x1)['fill']()[_0xc6a11b(0x374)]((_0x525c65,_0x43831d)=>_0x21872b+_0x43831d);for(const _0x5e702c of _0xf6a01c){if('dhIJk'!=='EaoCH'){const _0x50c05f=$dataItems[_0x5e702c];if(!_0x50c05f)continue;if(!VisuMZ[_0xc6a11b(0x1db)]['IncludeShopItem'](_0x50c05f,_0x499609,_0x35d61f))continue;_0x134edd[_0xc6a11b(0x282)]([0x0,_0x5e702c,0x0,_0x50c05f[_0xc6a11b(0x1b9)]]);}else{if(this[_0xc6a11b(0x54a)]&&this['_numberWindow'][_0xc6a11b(0x566)])return _0x44f41[_0xc6a11b(0x1db)][_0xc6a11b(0x522)][_0xc6a11b(0x3c6)][_0xc6a11b(0x42f)];return _0x387020[_0xc6a11b(0x5f1)][_0xc6a11b(0x3d6)]['call'](this);}}const _0x1c16b3=_0x2c1b5b['Step2End']>=_0x2c1b5b[_0xc6a11b(0x4d7)]?_0x2c1b5b['Step2Start']:_0x2c1b5b[_0xc6a11b(0x55b)],_0x1406d1=_0x2c1b5b['Step2End']>=_0x2c1b5b[_0xc6a11b(0x4d7)]?_0x2c1b5b[_0xc6a11b(0x55b)]:_0x2c1b5b[_0xc6a11b(0x4d7)],_0x14ccd1=Array(_0x1406d1-_0x1c16b3+0x1)[_0xc6a11b(0x5c4)]()['map']((_0x169d6a,_0x12fa44)=>_0x1c16b3+_0x12fa44);for(const _0x376c85 of _0x14ccd1){const _0x274b94=$dataWeapons[_0x376c85];if(!_0x274b94)continue;if(!VisuMZ[_0xc6a11b(0x1db)]['IncludeShopItem'](_0x274b94,_0x499609,_0x35d61f))continue;_0x134edd[_0xc6a11b(0x282)]([0x1,_0x376c85,0x0,_0x274b94[_0xc6a11b(0x1b9)]]);}const _0x325c6d=_0x2c1b5b['Step3End']>=_0x2c1b5b['Step3Start']?_0x2c1b5b[_0xc6a11b(0x59d)]:_0x2c1b5b[_0xc6a11b(0x585)],_0x914972=_0x2c1b5b[_0xc6a11b(0x585)]>=_0x2c1b5b[_0xc6a11b(0x59d)]?_0x2c1b5b[_0xc6a11b(0x585)]:_0x2c1b5b[_0xc6a11b(0x59d)],_0x37b55b=Array(_0x914972-_0x325c6d+0x1)['fill']()[_0xc6a11b(0x374)]((_0x2cd996,_0x5ddff6)=>_0x325c6d+_0x5ddff6);for(const _0x558d47 of _0x37b55b){const _0x2b681d=$dataArmors[_0x558d47];if(!_0x2b681d)continue;if(!VisuMZ[_0xc6a11b(0x1db)]['IncludeShopItem'](_0x2b681d,_0x499609,_0x35d61f))continue;_0x134edd[_0xc6a11b(0x282)]([0x2,_0x558d47,0x0,_0x2b681d[_0xc6a11b(0x1b9)]]);}SceneManager[_0xc6a11b(0x282)](Scene_Shop),SceneManager[_0xc6a11b(0x536)](_0x134edd,_0x2c1b5b[_0xc6a11b(0x5c3)]);}),VisuMZ[_0x541333(0x1db)][_0x541333(0x358)]=function(_0x4c330c,_0x962dd8,_0x226101){const _0x358631=_0x541333;if(_0x4c330c[_0x358631(0x3bf)][_0x358631(0x399)]()==='')return![];if(_0x4c330c[_0x358631(0x3bf)][_0x358631(0x2a3)](/-----/i))return![];const _0x2400fe=_0x4c330c['categories'];if(_0x962dd8['length']>0x0)for(const _0x41f755 of _0x962dd8){if(!_0x41f755)continue;if(_0x2400fe[_0x358631(0x53c)](_0x41f755))return![];}if(_0x226101['length']>0x0){for(const _0x486e51 of _0x226101){if(!_0x486e51)continue;if(_0x2400fe[_0x358631(0x53c)](_0x486e51))return!![];}return![];}return!![];},VisuMZ[_0x541333(0x1db)][_0x541333(0x320)]=Scene_Boot[_0x541333(0x5f1)][_0x541333(0x5e0)],Scene_Boot[_0x541333(0x5f1)][_0x541333(0x5e0)]=function(){const _0x32ad00=_0x541333;this['process_VisuMZ_ItemsEquipsCore_RegExp'](),VisuMZ[_0x32ad00(0x1db)][_0x32ad00(0x320)][_0x32ad00(0x562)](this),this[_0x32ad00(0x52a)]();},Scene_Boot['prototype']['process_VisuMZ_ItemsEquipsCore_RegExp']=function(){const _0x13374a=_0x541333;VisuMZ[_0x13374a(0x1db)][_0x13374a(0x4e6)]={},VisuMZ[_0x13374a(0x1db)][_0x13374a(0x4e6)][_0x13374a(0x573)]=[],VisuMZ[_0x13374a(0x1db)][_0x13374a(0x4e6)][_0x13374a(0x4c9)]=[];const _0x14a430=[_0x13374a(0x3ca),'MaxMP',_0x13374a(0x216),_0x13374a(0x209),_0x13374a(0x2a0),_0x13374a(0x1dc),_0x13374a(0x420),_0x13374a(0x4ab)];for(const _0x5e50d8 of _0x14a430){const _0x39f367='<%1:[\x20]([\x5c+\x5c-]\x5cd+)>'[_0x13374a(0x52b)](_0x5e50d8);VisuMZ['ItemsEquipsCore'][_0x13374a(0x4e6)][_0x13374a(0x573)][_0x13374a(0x282)](new RegExp(_0x39f367,'i'));const _0x4b00ba='\x5cb%1\x5cb'[_0x13374a(0x52b)](_0x5e50d8);VisuMZ[_0x13374a(0x1db)][_0x13374a(0x4e6)][_0x13374a(0x4c9)][_0x13374a(0x282)](new RegExp(_0x4b00ba,'g'));}},Scene_Boot[_0x541333(0x5f1)][_0x541333(0x52a)]=function(){const _0x5ef598=_0x541333;if(VisuMZ[_0x5ef598(0x436)])return;this[_0x5ef598(0x336)]();const _0x3085e9=[$dataItems,$dataWeapons,$dataArmors];for(const _0x14ab82 of _0x3085e9){for(const _0x1c0e19 of _0x14ab82){if(_0x5ef598(0x3c5)==='kKdgW'){if(!_0x1c0e19)continue;VisuMZ[_0x5ef598(0x1db)][_0x5ef598(0x47d)](_0x1c0e19,_0x14ab82),VisuMZ[_0x5ef598(0x1db)][_0x5ef598(0x3db)](_0x1c0e19,_0x14ab82),VisuMZ['ItemsEquipsCore'][_0x5ef598(0x551)](_0x1c0e19,_0x14ab82),VisuMZ[_0x5ef598(0x1db)][_0x5ef598(0x4c0)](_0x1c0e19,_0x14ab82),VisuMZ['ItemsEquipsCore'][_0x5ef598(0x33f)](_0x1c0e19,_0x14ab82);}else{const _0x2b727a=this['_categoryNameWindow'];_0x2b727a['drawText'](_0x370da6,0x0,_0x2476e8['y'],_0x2b727a[_0x5ef598(0x20f)],_0x5ef598(0x42a));}}}},Scene_Boot[_0x541333(0x5f1)]['process_VisuMZ_ItemsEquipsCore_EquipSlots']=function(){const _0x47ee8e=_0x541333;for(const _0x2b873c of $dataClasses){if(_0x47ee8e(0x1aa)!==_0x47ee8e(0x563)){if(!_0x2b873c)continue;VisuMZ['ItemsEquipsCore'][_0x47ee8e(0x1a7)](_0x2b873c);}else{if(_0x2d7dc4)_0x445e5e+=this[_0x47ee8e(0x4f2)](_0x1b5714,_0xa65ec9);}}},VisuMZ[_0x541333(0x1db)][_0x541333(0x1f9)]=VisuMZ['ParseClassNotetags'],VisuMZ[_0x541333(0x1f9)]=function(_0x3c4225){const _0x224d71=_0x541333;VisuMZ[_0x224d71(0x1db)][_0x224d71(0x1f9)][_0x224d71(0x562)](this,_0x3c4225),VisuMZ[_0x224d71(0x1db)]['Parse_Notetags_EquipSlots'](_0x3c4225);},VisuMZ[_0x541333(0x1db)]['ParseItemNotetags']=VisuMZ[_0x541333(0x2e3)],VisuMZ[_0x541333(0x2e3)]=function(_0x20a9f1){const _0x205640=_0x541333;VisuMZ['ItemsEquipsCore'][_0x205640(0x2e3)][_0x205640(0x562)](this,_0x20a9f1),VisuMZ[_0x205640(0x1db)][_0x205640(0x3d7)](_0x20a9f1,$dataItems);},VisuMZ['ItemsEquipsCore'][_0x541333(0x494)]=VisuMZ[_0x541333(0x494)],VisuMZ[_0x541333(0x494)]=function(_0x44f68d){const _0x27138f=_0x541333;VisuMZ[_0x27138f(0x1db)]['ParseWeaponNotetags'][_0x27138f(0x562)](this,_0x44f68d),VisuMZ[_0x27138f(0x1db)][_0x27138f(0x3d7)](_0x44f68d,$dataWeapons);},VisuMZ[_0x541333(0x1db)][_0x541333(0x1c4)]=VisuMZ[_0x541333(0x1c4)],VisuMZ[_0x541333(0x1c4)]=function(_0x2566dc){const _0x1ad2f2=_0x541333;VisuMZ[_0x1ad2f2(0x1db)]['ParseArmorNotetags']['call'](this,_0x2566dc),VisuMZ[_0x1ad2f2(0x1db)][_0x1ad2f2(0x3d7)](_0x2566dc,$dataArmors);},VisuMZ[_0x541333(0x1db)][_0x541333(0x1a7)]=function(_0x5023b5){const _0x133e40=_0x541333;_0x5023b5[_0x133e40(0x2b4)]=[];if(!BattleManager[_0x133e40(0x54d)]()&&_0x5023b5[_0x133e40(0x266)][_0x133e40(0x2a3)](/<EQUIP SLOTS>\s*([\s\S]*)\s*<\/EQUIP SLOTS>/i)){const _0x450cd2=String(RegExp['$1'])[_0x133e40(0x3b1)](/[\r\n]+/);for(const _0x2f2a0e of _0x450cd2){if(_0x133e40(0x49e)!==_0x133e40(0x554)){const _0x3d5834=$dataSystem[_0x133e40(0x1af)]['indexOf'](_0x2f2a0e[_0x133e40(0x399)]());if(_0x3d5834>0x0)_0x5023b5[_0x133e40(0x2b4)][_0x133e40(0x282)](_0x3d5834);}else return _0x4f4434[_0x133e40(0x1db)][_0x133e40(0x522)][_0x133e40(0x394)][_0x133e40(0x544)];}}else for(const _0x449c91 of $dataSystem[_0x133e40(0x1af)]){const _0x4edc15=$dataSystem['equipTypes']['indexOf'](_0x449c91[_0x133e40(0x399)]());if(_0x4edc15>0x0)_0x5023b5[_0x133e40(0x2b4)]['push'](_0x4edc15);}},VisuMZ[_0x541333(0x1db)][_0x541333(0x3d7)]=function(_0x3c859d,_0x246225){const _0x1ae816=_0x541333;VisuMZ[_0x1ae816(0x1db)]['Parse_Notetags_Category'](_0x3c859d,_0x246225),VisuMZ[_0x1ae816(0x1db)][_0x1ae816(0x3db)](_0x3c859d,_0x246225),VisuMZ[_0x1ae816(0x1db)][_0x1ae816(0x551)](_0x3c859d,_0x246225),VisuMZ[_0x1ae816(0x1db)][_0x1ae816(0x4c0)](_0x3c859d,_0x246225),VisuMZ['ItemsEquipsCore'][_0x1ae816(0x33f)](_0x3c859d,_0x246225);},VisuMZ[_0x541333(0x1db)][_0x541333(0x47d)]=function(_0x33e5c4,_0x12f87b){const _0x267167=_0x541333;_0x33e5c4['categories']=[];const _0x103b58=_0x33e5c4[_0x267167(0x266)],_0x32f92d=_0x103b58[_0x267167(0x2a3)](/<(?:CATEGORY|CATEGORIES):[ ](.*)>/gi);if(_0x32f92d)for(const _0x1d9b66 of _0x32f92d){if(_0x267167(0x4cb)===_0x267167(0x4cb)){_0x1d9b66[_0x267167(0x2a3)](/<(?:CATEGORY|CATEGORIES):[ ](.*)>/gi);const _0xcfe97b=String(RegExp['$1'])[_0x267167(0x58a)]()[_0x267167(0x399)]()['split'](',');for(const _0x1039cc of _0xcfe97b){_0x33e5c4[_0x267167(0x264)][_0x267167(0x282)](_0x1039cc[_0x267167(0x399)]());}}else return _0x2ff603['ItemsEquipsCore']['Window_ItemList_maxCols'][_0x267167(0x562)](this);}if(_0x103b58[_0x267167(0x2a3)](/<(?:CATEGORY|CATEGORIES)>\s*([\s\S]*)\s*<\/(?:CATEGORY|CATEGORIES)>/i)){if(_0x267167(0x215)!==_0x267167(0x4a6)){const _0x1d58aa=RegExp['$1'][_0x267167(0x3b1)](/[\r\n]+/);for(const _0xedc0f7 of _0x1d58aa){'iIfeR'!=='iIfeR'?(this[_0x267167(0x540)]=_0x26b7dd,this['refresh'](),this[_0x267167(0x580)]()):_0x33e5c4[_0x267167(0x264)][_0x267167(0x282)](_0xedc0f7['toUpperCase']()[_0x267167(0x399)]());}}else return _0x267167(0x259);}},VisuMZ[_0x541333(0x1db)][_0x541333(0x3db)]=function(_0x2b211d,_0x2e962){const _0x5d99bc=_0x541333;_0x2b211d[_0x5d99bc(0x266)][_0x5d99bc(0x2a3)](/<PRICE:[ ](\d+)>/i)&&(_0x2b211d[_0x5d99bc(0x1b9)]=Number(RegExp['$1']));},VisuMZ[_0x541333(0x1db)]['Parse_Notetags_ParamValues']=function(_0x230011,_0x5176c5){const _0x76dcd6=_0x541333;if(_0x5176c5===$dataItems)return;for(let _0x4cd4e4=0x0;_0x4cd4e4<0x8;_0x4cd4e4++){const _0x3922c2=VisuMZ[_0x76dcd6(0x1db)][_0x76dcd6(0x4e6)][_0x76dcd6(0x573)][_0x4cd4e4];_0x230011['note']['match'](_0x3922c2)&&(_0x230011['params'][_0x4cd4e4]=parseInt(RegExp['$1']));}},VisuMZ[_0x541333(0x1db)][_0x541333(0x4ae)]={},VisuMZ[_0x541333(0x1db)][_0x541333(0x4c0)]=function(_0x4eef95,_0x371576){const _0x3ac330=_0x541333;if(_0x371576===$dataItems)return;if(_0x4eef95['note'][_0x3ac330(0x2a3)](/<JS PARAMETERS>\s*([\s\S]*)\s*<\/JS PARAMETERS>/i)){const _0x37b198=String(RegExp['$1']),_0x1a648f=(_0x371576===$dataWeapons?'W%1':_0x3ac330(0x56f))['format'](_0x4eef95['id']),_0x3d3e80=_0x3ac330(0x303)[_0x3ac330(0x52b)](_0x37b198);for(let _0x259f55=0x0;_0x259f55<0x8;_0x259f55++){if(_0x3ac330(0x5e6)!=='JZaDa')return this['isUseItemsEquipsCoreUpdatedLayout']()?this[_0x3ac330(0x4ce)]():_0x3d44ee['ItemsEquipsCore']['Scene_Shop_buyWindowRect'][_0x3ac330(0x562)](this);else{if(_0x37b198[_0x3ac330(0x2a3)](VisuMZ['ItemsEquipsCore'][_0x3ac330(0x4e6)][_0x3ac330(0x4c9)][_0x259f55])){if(_0x3ac330(0x41e)!==_0x3ac330(0x41e))this[_0x3ac330(0x5a6)]=_0x40d05e,this[_0x3ac330(0x210)](),this[_0x3ac330(0x21e)]&&this[_0x3ac330(0x21e)][_0x3ac330(0x539)]()?this[_0x3ac330(0x43f)](0x0):this[_0x3ac330(0x360)](0x0,0x0);else{const _0x38ffc5='%1-%2'['format'](_0x1a648f,_0x259f55);VisuMZ[_0x3ac330(0x1db)][_0x3ac330(0x4ae)][_0x38ffc5]=new Function(_0x3ac330(0x37a),_0x3ac330(0x587),_0x3d3e80);}}}}}},VisuMZ[_0x541333(0x1db)]['itemEnableJS']={},VisuMZ[_0x541333(0x1db)][_0x541333(0x33f)]=function(_0x5925d9,_0x51088d){const _0x12dd23=_0x541333;if(_0x51088d!==$dataItems)return;if(_0x5925d9[_0x12dd23(0x266)][_0x12dd23(0x2a3)](/<JS ITEM ENABLE>\s*([\s\S]*)\s*<\/JS ITEM ENABLE>/i)){const _0x3c775a=String(RegExp['$1']),_0x1a4760=_0x12dd23(0x4ad)[_0x12dd23(0x52b)](_0x3c775a);VisuMZ['ItemsEquipsCore']['itemEnableJS'][_0x5925d9['id']]=new Function(_0x12dd23(0x37a),_0x1a4760);}},DataManager[_0x541333(0x3c3)]=function(_0xd07c51){const _0x155527=_0x541333;return this['isItem'](_0xd07c51)&&_0xd07c51[_0x155527(0x283)]===0x2;},DataManager['maxItemAmount']=function(_0x2970ca){const _0x1381fd=_0x541333;if(!_0x2970ca){if(_0x1381fd(0x39b)===_0x1381fd(0x447))_0x436bbd[_0x1381fd(0x1db)][_0x1381fd(0x1c9)]['call'](this,_0x55364e),this[_0x1381fd(0x533)](_0x2420f6);else return 0x63;}else return _0x2970ca['note'][_0x1381fd(0x2a3)](/<MAX:[ ](\d+)>/i)?parseInt(RegExp['$1']):this[_0x1381fd(0x5a3)](_0x2970ca);},DataManager[_0x541333(0x5a3)]=function(_0x23b30f){const _0x467702=_0x541333;if(this[_0x467702(0x577)](_0x23b30f))return VisuMZ[_0x467702(0x1db)][_0x467702(0x522)][_0x467702(0x394)][_0x467702(0x39e)];else{if(this['isWeapon'](_0x23b30f)){if(_0x467702(0x578)==='clrJi')this[_0x467702(0x46c)]();else return VisuMZ[_0x467702(0x1db)][_0x467702(0x522)][_0x467702(0x394)]['MaxWeapons'];}else{if(this[_0x467702(0x1a6)](_0x23b30f))return VisuMZ[_0x467702(0x1db)]['Settings'][_0x467702(0x394)]['MaxArmors'];}}},ColorManager[_0x541333(0x5a4)]=function(_0x2cfb03){const _0x47c8a9=_0x541333;if(!_0x2cfb03)return'zrtJB'!==_0x47c8a9(0x316)?_0x1a0e9d[_0x47c8a9(0x1db)][_0x47c8a9(0x522)][_0x47c8a9(0x510)][_0x47c8a9(0x3e6)]:this[_0x47c8a9(0x1fe)]();else{if(_0x2cfb03[_0x47c8a9(0x266)]['match'](/<COLOR:[ ](\d+)>/i))return this[_0x47c8a9(0x5cb)](Number(RegExp['$1'])[_0x47c8a9(0x514)](0x0,0x1f));else return _0x2cfb03[_0x47c8a9(0x266)]['match'](/<COLOR:[ ]#(.*)>/i)?'erLQc'!==_0x47c8a9(0x1b3)?'#'+String(RegExp['$1']):_0x5ab915[_0x47c8a9(0x1db)]['Settings']['StatusWindow']['ElementNone']:this['normalColor']();}},ColorManager[_0x541333(0x418)]=function(_0x5a981f){const _0x517b25=_0x541333;_0x5a981f=String(_0x5a981f);if(_0x5a981f[_0x517b25(0x2a3)](/#(.*)/i))return'#%1'[_0x517b25(0x52b)](String(RegExp['$1']));else{if('MJfko'===_0x517b25(0x4e8)){const _0x500fa9=this['getItemRepeatsLabel']();this[_0x517b25(0x4b2)](_0x500fa9,_0x4349ea,_0x54d242,_0x59975a,!![]);const _0x3851eb=this[_0x517b25(0x4c8)]();return this['drawItemKeyData'](_0x3851eb,_0x339160,_0x521894,_0x265415,![],_0x517b25(0x263)),this[_0x517b25(0x28c)](_0x36c7ff,_0x5755c4,_0x3be31b),this[_0x517b25(0x33e)](),!![];}else return this[_0x517b25(0x5cb)](Number(_0x5a981f));}},SceneManager['isSceneShop']=function(){const _0x19d332=_0x541333;return this[_0x19d332(0x38a)]&&this['_scene']['constructor']===Scene_Shop;},Game_Temp['prototype'][_0x541333(0x487)]=function(){const _0x50d73c=_0x541333;if(this[_0x50d73c(0x35a)])return![];return VisuMZ[_0x50d73c(0x1db)][_0x50d73c(0x522)][_0x50d73c(0x590)]['Enable'];},VisuMZ['ShopMenuStatusStandard']=VisuMZ[_0x541333(0x1db)]['Settings'][_0x541333(0x510)][_0x541333(0x4bd)],VisuMZ[_0x541333(0x1db)][_0x541333(0x36f)]=Game_BattlerBase[_0x541333(0x5f1)][_0x541333(0x334)],Game_BattlerBase[_0x541333(0x5f1)]['param']=function(_0x3bba10){const _0x34aae9=_0x541333;return this[_0x34aae9(0x42c)]?this[_0x34aae9(0x529)]?VisuMZ[_0x34aae9(0x1ac)]:0x1:VisuMZ[_0x34aae9(0x1db)][_0x34aae9(0x36f)]['call'](this,_0x3bba10);},VisuMZ['ItemsEquipsCore']['Game_BattlerBase_meetsItemConditions']=Game_BattlerBase[_0x541333(0x5f1)][_0x541333(0x5ef)],Game_BattlerBase[_0x541333(0x5f1)][_0x541333(0x5ef)]=function(_0x538029){const _0x24a604=_0x541333;if(!_0x538029)return![];if(!VisuMZ[_0x24a604(0x1db)]['Game_BattlerBase_meetsItemConditions'][_0x24a604(0x562)](this,_0x538029))return![];if(!this[_0x24a604(0x29b)](_0x538029))return![];if(!this[_0x24a604(0x4a8)](_0x538029))return![];return!![];},Game_BattlerBase['prototype'][_0x541333(0x29b)]=function(_0x4571e1){const _0x1992b2=_0x541333;if(!this[_0x1992b2(0x2fc)](_0x4571e1))return![];return!![];},Game_BattlerBase[_0x541333(0x5f1)]['checkItemConditionsSwitchNotetags']=function(_0x6caef5){const _0x5dd577=_0x541333,_0x25076e=_0x6caef5[_0x5dd577(0x266)];if(_0x25076e[_0x5dd577(0x2a3)](/<ENABLE[ ](?:SW|SWITCH|SWITCHES):[ ]*(\d+(?:\s*,\s*\d+)*)>/i)){const _0x576bd4=JSON[_0x5dd577(0x5f9)]('['+RegExp['$1']['match'](/\d+/g)+']');for(const _0x192b22 of _0x576bd4){if(!$gameSwitches[_0x5dd577(0x5e9)](_0x192b22))return![];}return!![];}if(_0x25076e[_0x5dd577(0x2a3)](/<ENABLE ALL[ ](?:SW|SWITCH|SWITCHES):[ ]*(\d+(?:\s*,\s*\d+)*)>/i)){const _0x8d6e1e=JSON[_0x5dd577(0x5f9)]('['+RegExp['$1']['match'](/\d+/g)+']');for(const _0x53048e of _0x8d6e1e){if(!$gameSwitches[_0x5dd577(0x5e9)](_0x53048e))return![];}return!![];}if(_0x25076e[_0x5dd577(0x2a3)](/<ENABLE ANY[ ](?:SW|SWITCH|SWITCHES):[ ]*(\d+(?:\s*,\s*\d+)*)>/i)){const _0x388696=JSON['parse']('['+RegExp['$1'][_0x5dd577(0x2a3)](/\d+/g)+']');for(const _0x5bca56 of _0x388696){if(_0x5dd577(0x519)===_0x5dd577(0x519)){if($gameSwitches[_0x5dd577(0x5e9)](_0x5bca56))return!![];}else{const _0x1d3245=_0x5dd577(0x348);if(this['_customItemInfo'][_0x1d3245])return this[_0x5dd577(0x212)][_0x1d3245];const _0x179f48=_0xdef203[_0x5dd577(0x1db)][_0x5dd577(0x522)]['StatusWindow'],_0x7072a9=_0x5dd577(0x5ea)[_0x5dd577(0x52b)](this['_item'][_0x5dd577(0x4c1)]);return _0x179f48[_0x7072a9];}}return![];}if(_0x25076e[_0x5dd577(0x2a3)](/<DISABLE[ ](?:SW|SWITCH|SWITCHES):[ ]*(\d+(?:\s*,\s*\d+)*)>/i)){const _0x2bba8f=JSON['parse']('['+RegExp['$1']['match'](/\d+/g)+']');for(const _0x3a2199 of _0x2bba8f){if(!$gameSwitches['value'](_0x3a2199))return!![];}return![];}if(_0x25076e[_0x5dd577(0x2a3)](/<DISABLE ALL[ ](?:SW|SWITCH|SWITCHES):[ ]*(\d+(?:\s*,\s*\d+)*)>/i)){const _0x5ea36f=JSON[_0x5dd577(0x5f9)]('['+RegExp['$1'][_0x5dd577(0x2a3)](/\d+/g)+']');for(const _0x5080f of _0x5ea36f){if(_0x5dd577(0x5fd)==='usEOF'){if(!$gameSwitches[_0x5dd577(0x5e9)](_0x5080f))return!![];}else{const _0x29919d='MP\x20DAMAGE';if(this[_0x5dd577(0x212)][_0x29919d])return this['_customItemInfo'][_0x29919d];let _0x2adebf='';if(this['_itemData'][_0x5dd577(0x1de)]<0x0)_0x2adebf+='%1%'[_0x5dd577(0x52b)](_0x3c729e[_0x5dd577(0x254)](this[_0x5dd577(0x3e3)]['rateMP']*0x64));if(this['_itemData']['rateMP']<0x0&&this[_0x5dd577(0x3e3)][_0x5dd577(0x389)]<0x0)_0x2adebf+='\x20';if(this['_itemData'][_0x5dd577(0x389)]<0x0)_0x2adebf+='%1'['format'](this[_0x5dd577(0x3e3)]['flatMP']);return _0x2adebf;}}return![];}if(_0x25076e[_0x5dd577(0x2a3)](/<DISABLE ANY[ ](?:SW|SWITCH|SWITCHES):[ ]*(\d+(?:\s*,\s*\d+)*)>/i)){const _0x32fe8b=JSON['parse']('['+RegExp['$1']['match'](/\d+/g)+']');for(const _0x4907e0 of _0x32fe8b){if(_0x5dd577(0x4e7)===_0x5dd577(0x4e7)){if($gameSwitches[_0x5dd577(0x5e9)](_0x4907e0))return![];}else{const _0x466711=this['_commandNameWindow'];_0x466711[_0x5dd577(0x1f8)][_0x5dd577(0x456)]();const _0x269307=this[_0x5dd577(0x290)](this[_0x5dd577(0x593)]());if(_0x269307===_0x5dd577(0x495)){const _0x42bda1=this[_0x5dd577(0x347)](this[_0x5dd577(0x593)]());let _0x43b6ac=this[_0x5dd577(0x4f3)](this[_0x5dd577(0x593)]());_0x43b6ac=_0x43b6ac[_0x5dd577(0x217)](/\\I\[(\d+)\]/gi,''),_0x466711[_0x5dd577(0x33e)](),this[_0x5dd577(0x20d)](_0x43b6ac,_0x42bda1),this['commandNameWindowDrawText'](_0x43b6ac,_0x42bda1),this[_0x5dd577(0x2bc)](_0x43b6ac,_0x42bda1);}}}return!![];}return!![];},Game_BattlerBase[_0x541333(0x5f1)][_0x541333(0x4a8)]=function(_0x4b601a){const _0x172b4f=_0x541333,_0x54848e=_0x4b601a['note'],_0x4a9e41=VisuMZ[_0x172b4f(0x1db)]['itemEnableJS'];if(_0x4a9e41[_0x4b601a['id']])return _0x172b4f(0x4d1)===_0x172b4f(0x376)?_0x35d442:_0x4a9e41[_0x4b601a['id']]['call'](this,_0x4b601a);else{if(_0x172b4f(0x1e2)===_0x172b4f(0x1fb))this[_0x172b4f(0x465)](),this[_0x172b4f(0x21f)]();else return!![];}},Game_Actor[_0x541333(0x5f1)][_0x541333(0x281)]=function(_0x413e7b){const _0x2dc2fd=_0x541333;_0x413e7b=this[_0x2dc2fd(0x600)](_0x413e7b);const _0x294e11=this[_0x2dc2fd(0x2b4)]();this['_equips']=[];for(let _0x2f459e=0x0;_0x2f459e<_0x294e11[_0x2dc2fd(0x33d)];_0x2f459e++){this[_0x2dc2fd(0x240)][_0x2f459e]=new Game_Item();}for(let _0x5e5c76=0x0;_0x5e5c76<_0x294e11[_0x2dc2fd(0x33d)];_0x5e5c76++){if(_0x2dc2fd(0x42b)===_0x2dc2fd(0x42b)){const _0x4bef05=_0x294e11[_0x5e5c76],_0x4cd2ad=this[_0x2dc2fd(0x3ed)](_0x413e7b,_0x4bef05);if(this[_0x2dc2fd(0x3cb)](_0x4cd2ad))this['_equips'][_0x5e5c76]['setObject'](_0x4cd2ad);}else{_0x4e10ad+=_0x2dc2fd(0x438)[_0x2dc2fd(0x52b)](_0x1d7cb4),_0x541ae2++;if(_0x2a0378>=_0x569f7c)return _0x1c2ec0;}}this[_0x2dc2fd(0x576)](!![]),this[_0x2dc2fd(0x210)]();},Game_Actor[_0x541333(0x5f1)]['convertInitEquipsToItems']=function(_0x3c89dc){const _0x27414c=_0x541333,_0x393a36=[];for(let _0x3e7824=0x0;_0x3e7824<_0x3c89dc[_0x27414c(0x33d)];_0x3e7824++){const _0x5b32f7=_0x3c89dc[_0x3e7824];if(_0x5b32f7<=0x0)continue;const _0x24860e=$dataSystem['equipTypes'][_0x3e7824+0x1];if(_0x24860e===$dataSystem['equipTypes'][0x1]||_0x3e7824===0x1&&this[_0x27414c(0x3ad)]())_0x393a36['push']($dataWeapons[_0x5b32f7]);else{if(BattleManager['isBattleTest']()){const _0x4b1d81=$dataArmors[_0x5b32f7];_0x4b1d81&&_0x4b1d81[_0x27414c(0x25f)]===_0x3e7824+0x1&&_0x393a36['push'](_0x4b1d81);}else{const _0x25d55c=$dataArmors[_0x5b32f7];_0x25d55c&&_0x25d55c[_0x27414c(0x25f)]===_0x3e7824+0x1&&(_0x27414c(0x46a)===_0x27414c(0x37b)?this[_0x27414c(0x301)]():_0x393a36[_0x27414c(0x282)](_0x25d55c));}}}return _0x393a36;},Game_Actor[_0x541333(0x5f1)][_0x541333(0x3ed)]=function(_0x1e2427,_0x2481ae){const _0x135823=_0x541333;for(const _0x30b242 of _0x1e2427){if(!_0x30b242)continue;if(_0x30b242['etypeId']===_0x2481ae){if(_0x135823(0x5bb)===_0x135823(0x2a5)){if(_0x1fed46[_0xc12e17]===_0x2362fb){_0x305ff8=_0x3f1e3a;if(!_0x98a73d[_0x327dd8])return _0x615b3b;}}else return _0x1e2427['splice'](_0x1e2427[_0x135823(0x525)](_0x30b242),0x1),_0x30b242;}}return null;},Game_Actor[_0x541333(0x5f1)]['equipSlots']=function(){const _0x2205a=_0x541333,_0x25d395=JsonEx[_0x2205a(0x472)](this['_forcedSlots']||this[_0x2205a(0x1f0)]()[_0x2205a(0x2b4)]);if(_0x25d395['length']>=0x2&&this[_0x2205a(0x3ad)]())_0x25d395[0x1]=0x1;return _0x25d395;},Game_Actor[_0x541333(0x5f1)][_0x541333(0x2aa)]=function(_0x4f7c8d){const _0x225162=_0x541333;_0x4f7c8d['remove'](0x0),_0x4f7c8d[_0x225162(0x5ec)](-0x1),this[_0x225162(0x540)]=_0x4f7c8d,this[_0x225162(0x210)](),this[_0x225162(0x580)]();},Game_Actor[_0x541333(0x5f1)]['forceResetEquipSlots']=function(){const _0x2713ad=_0x541333;this['_forcedSlots']=undefined,this[_0x2713ad(0x210)](),this[_0x2713ad(0x580)]();},Game_Actor[_0x541333(0x5f1)][_0x541333(0x580)]=function(){const _0x233944=_0x541333;let _0x324e8e=this[_0x233944(0x2b4)]()['length'];while(this['_equips'][_0x233944(0x33d)]>_0x324e8e){if('iKPtY'===_0x233944(0x2e1)){const _0x3b5fe0=this[_0x233944(0x240)][this['_equips'][_0x233944(0x33d)]-0x1];_0x3b5fe0&&_0x3b5fe0['object']()&&$gameParty[_0x233944(0x2c7)](_0x3b5fe0[_0x233944(0x4d3)](),0x1),this['_equips'][_0x233944(0x564)]();}else{this[_0x233944(0x46b)]=![];if(this['isCursorMovable']()){const _0x2eecae=this[_0x233944(0x593)](),_0x3a7f40=this[_0x233944(0x23b)]();_0x3a7f40>=0x0&&_0x3a7f40!==this[_0x233944(0x593)]()&&this[_0x233944(0x251)](_0x3a7f40),_0x33a630&&this[_0x233944(0x593)]()!==_0x2eecae&&this[_0x233944(0x403)]();}}}while(_0x324e8e>this['_equips']['length']){_0x233944(0x2f7)===_0x233944(0x411)?_0x188a2f=_0x5f31d7['CoreEngine'][_0x233944(0x522)][_0x233944(0x5d5)]['ExtDisplayedParams']:this[_0x233944(0x240)][_0x233944(0x282)](new Game_Item());}},Game_Actor[_0x541333(0x5f1)]['prepareNewEquipSlotsOnLoad']=function(){const _0x5c69f8=_0x541333,_0x38b7b8=this['equipSlots']();for(let _0x17570f=0x0;_0x17570f<_0x38b7b8[_0x5c69f8(0x33d)];_0x17570f++){if(!this[_0x5c69f8(0x240)][_0x17570f])this['_equips'][_0x17570f]=new Game_Item();}this[_0x5c69f8(0x576)](![]),this['refresh']();},VisuMZ[_0x541333(0x1db)][_0x541333(0x4dd)]=Game_Actor[_0x541333(0x5f1)][_0x541333(0x23c)],Game_Actor['prototype']['changeEquip']=function(_0x5b83e4,_0x5d2d6d){const _0x45d3ef=_0x541333;if(!this[_0x45d3ef(0x59a)]){if(_0x45d3ef(0x1d9)===_0x45d3ef(0x1d9)){const _0xcf3325=JsonEx['makeDeepCopy'](this);_0xcf3325[_0x45d3ef(0x59a)]=!![],VisuMZ[_0x45d3ef(0x1db)][_0x45d3ef(0x4dd)][_0x45d3ef(0x562)](this,_0x5b83e4,_0x5d2d6d),this[_0x45d3ef(0x1c6)](_0xcf3325);}else return _0x2f5aec[_0x45d3ef(0x1db)][_0x45d3ef(0x522)][_0x45d3ef(0x510)][_0x45d3ef(0x28d)];}else VisuMZ['ItemsEquipsCore']['Game_Actor_changeEquip'][_0x45d3ef(0x562)](this,_0x5b83e4,_0x5d2d6d);},VisuMZ['ItemsEquipsCore'][_0x541333(0x244)]=Game_Actor[_0x541333(0x5f1)]['forceChangeEquip'],Game_Actor[_0x541333(0x5f1)][_0x541333(0x5fe)]=function(_0x4a5b5d,_0x10e889){const _0xdcc051=_0x541333;if(!this[_0xdcc051(0x59a)]){if(_0xdcc051(0x541)===_0xdcc051(0x234)){const _0x3f80e3=this['itemLineRect'](_0x6e08fe),_0x2fcc66=this['commandName'](_0x2d0b04),_0x53879a=this[_0xdcc051(0x3f9)](_0x2fcc66)['width'];this['changePaintOpacity'](this[_0xdcc051(0x2a1)](_0x19a944));const _0x2550b7=this['itemTextAlign']();if(_0x2550b7===_0xdcc051(0x263))this['drawTextEx'](_0x2fcc66,_0x3f80e3['x']+_0x3f80e3[_0xdcc051(0x5bc)]-_0x53879a,_0x3f80e3['y'],_0x53879a);else{if(_0x2550b7===_0xdcc051(0x42a)){const _0x3d14df=_0x3f80e3['x']+_0x3eb5a6[_0xdcc051(0x254)]((_0x3f80e3[_0xdcc051(0x5bc)]-_0x53879a)/0x2);this['drawTextEx'](_0x2fcc66,_0x3d14df,_0x3f80e3['y'],_0x53879a);}else this[_0xdcc051(0x5fa)](_0x2fcc66,_0x3f80e3['x'],_0x3f80e3['y'],_0x53879a);}}else{const _0x1956c7=JsonEx['makeDeepCopy'](this);_0x1956c7[_0xdcc051(0x59a)]=!![],VisuMZ[_0xdcc051(0x1db)][_0xdcc051(0x244)][_0xdcc051(0x562)](this,_0x4a5b5d,_0x10e889),this[_0xdcc051(0x1c6)](_0x1956c7);}}else _0xdcc051(0x50f)!==_0xdcc051(0x34f)?VisuMZ[_0xdcc051(0x1db)]['Game_Actor_forceChangeEquip'][_0xdcc051(0x562)](this,_0x4a5b5d,_0x10e889):_0x4cd78e[_0xdcc051(0x5f1)]['drawItem']['call'](this,_0x5ab736);},VisuMZ[_0x541333(0x1db)][_0x541333(0x311)]=Game_Actor[_0x541333(0x5f1)]['discardEquip'],Game_Actor[_0x541333(0x5f1)][_0x541333(0x442)]=function(_0x478d50){const _0x265076=_0x541333;if(!this[_0x265076(0x59a)]){const _0x152619=JsonEx[_0x265076(0x472)](this);_0x152619['_tempActor']=!![],VisuMZ['ItemsEquipsCore']['Game_Actor_discardEquip']['call'](this,_0x478d50),this[_0x265076(0x1c6)](_0x152619);}else _0x265076(0x475)==='RIDLq'?this[_0x265076(0x1c2)]():VisuMZ[_0x265076(0x1db)][_0x265076(0x311)]['call'](this,_0x478d50);},Game_Actor[_0x541333(0x5f1)]['releaseUnequippableItems']=function(_0x32a6db){const _0x3b3e23=_0x541333;if(this[_0x3b3e23(0x33b)])return;for(;;){if('ziBwR'!==_0x3b3e23(0x23f)){const _0x15e799=this[_0x3b3e23(0x593)](),_0x4574d2=this[_0x3b3e23(0x23b)]();_0x4574d2>=0x0&&_0x4574d2!==this[_0x3b3e23(0x593)]()&&this[_0x3b3e23(0x251)](_0x4574d2),_0x184315&&this[_0x3b3e23(0x593)]()!==_0x15e799&&this[_0x3b3e23(0x403)]();}else{const _0x203137=this[_0x3b3e23(0x2b4)](),_0xecab13=this[_0x3b3e23(0x34b)](),_0x57c719=_0xecab13[_0x3b3e23(0x33d)];let _0x5abea1=![];for(let _0x106e8d=0x0;_0x106e8d<_0x57c719;_0x106e8d++){if(_0x3b3e23(0x26c)!==_0x3b3e23(0x26c))_0x5dc00e[_0x3b3e23(0x1db)][_0x3b3e23(0x2b9)][_0x3b3e23(0x562)](this),this['_statusWindow']&&this['_statusWindow'][_0x3b3e23(0x5db)]===_0x98605&&this[_0x3b3e23(0x1ee)][_0x3b3e23(0x41f)](this['item']());else{const _0x5a7efb=_0xecab13[_0x106e8d];if(_0x5a7efb&&(!this['canEquip'](_0x5a7efb)||_0x5a7efb[_0x3b3e23(0x25f)]!==_0x203137[_0x106e8d])){if(_0x3b3e23(0x51f)!=='IZval')return _0xb37595[_0x3b3e23(0x1db)][_0x3b3e23(0x522)][_0x3b3e23(0x59f)]['StatusWindowWidth'];else{!_0x32a6db&&this[_0x3b3e23(0x340)](null,_0x5a7efb);if(!this[_0x3b3e23(0x59a)]){if(_0x3b3e23(0x27c)==='thZEG'){const _0x4a07d4=JsonEx[_0x3b3e23(0x472)](this);_0x4a07d4['_tempActor']=!![],this[_0x3b3e23(0x240)][_0x106e8d][_0x3b3e23(0x1ce)](null),this[_0x3b3e23(0x33b)]=!![],this[_0x3b3e23(0x1c6)](_0x4a07d4),this[_0x3b3e23(0x33b)]=undefined;}else return _0x1abe01['VisuMZ_1_MainMenuCore']&&this[_0x3b3e23(0x4bb)][_0x3b3e23(0x205)]()!==''&&_0x3817ae['ItemsEquipsCore'][_0x3b3e23(0x522)]['EquipScene'][_0x3b3e23(0x473)];}else this['_equips'][_0x106e8d]['setObject'](null);_0x5abea1=!![];}}}}if(!_0x5abea1){if(_0x3b3e23(0x342)===_0x3b3e23(0x2dc))_0x30af12=_0x3b3e23(0x592)[_0x3b3e23(0x52b)](_0x4c5dde['id']);else break;}}}},Game_Actor[_0x541333(0x5f1)][_0x541333(0x1c6)]=function(_0x24f03e){const _0x291b19=_0x541333;if(this['_tempActor'])return;if(!VisuMZ[_0x291b19(0x1db)][_0x291b19(0x522)][_0x291b19(0x59f)][_0x291b19(0x1a4)])return;const _0x496c85=Math['round'](_0x24f03e[_0x291b19(0x1d4)]()*this[_0x291b19(0x5a0)]),_0x67dd71=Math[_0x291b19(0x243)](_0x24f03e[_0x291b19(0x59e)]()*this[_0x291b19(0x410)]);if(this['hp']>0x0)this[_0x291b19(0x211)](_0x496c85);if(this['mp']>0x0)this[_0x291b19(0x479)](_0x67dd71);},Game_Actor[_0x541333(0x5f1)]['clearEquipments']=function(){const _0x469316=_0x541333,_0x408956=this[_0x469316(0x2b4)]()[_0x469316(0x33d)];for(let _0x5cb717=0x0;_0x5cb717<_0x408956;_0x5cb717++){if(this['isClearEquipOk'](_0x5cb717))this[_0x469316(0x23c)](_0x5cb717,null);}},Game_Actor['prototype'][_0x541333(0x219)]=function(_0x2ed051){const _0x5655c0=_0x541333;if(this[_0x5655c0(0x433)]()[_0x5655c0(0x53c)](this[_0x5655c0(0x2b4)]()[_0x2ed051])){if('invKQ'!==_0x5655c0(0x49d)){const _0x12c80d=_0x5e4d67[_0x5655c0(0x1db)][_0x5655c0(0x522)][_0x5655c0(0x510)][_0x5655c0(0x5cf)];return _0x12c80d[_0x5655c0(0x52b)](_0x30c6c7['mp']);}else return![];}else{if('fYTcj'==='fYTcj')return this[_0x5655c0(0x304)](_0x2ed051);else this[_0x5655c0(0x481)][_0x5655c0(0x285)](),this[_0x5655c0(0x3b3)][_0x5655c0(0x285)]();}},Game_Actor[_0x541333(0x5f1)][_0x541333(0x433)]=function(){const _0x561934=_0x541333;return VisuMZ['ItemsEquipsCore']['Settings'][_0x561934(0x59f)][_0x561934(0x4e0)];},Game_Actor[_0x541333(0x5f1)][_0x541333(0x3eb)]=function(){const _0xfdc803=_0x541333,_0x2ff59e=this[_0xfdc803(0x2b4)]()[_0xfdc803(0x33d)];for(let _0x2c94b2=0x0;_0x2c94b2<_0x2ff59e;_0x2c94b2++){if('vtjCL'!==_0xfdc803(0x229)){const _0x231868=_0x5d8bf7[_0xfdc803(0x49f)];this[_0xfdc803(0x4b2)](_0x231868,_0x534658,_0x48cd0b,_0x28f3b0,!![],_0xfdc803(0x42a));}else{if(this['isOptimizeEquipOk'](_0x2c94b2))this[_0xfdc803(0x23c)](_0x2c94b2,null);}}for(let _0x9797e1=0x0;_0x9797e1<_0x2ff59e;_0x9797e1++){if(_0xfdc803(0x31a)!=='wIGAM'){if(this['isOptimizeEquipOk'](_0x9797e1))this['changeEquip'](_0x9797e1,this['bestEquipItem'](_0x9797e1));}else{const _0x44837f=this[_0xfdc803(0x231)](_0x52d644);_0x5c2d7d[_0xfdc803(0x1db)]['Game_Party_gainItem'][_0xfdc803(0x562)](this,_0x70ca14,_0x2ede55,_0x1ea5d8);if(this[_0xfdc803(0x231)](_0x41c5a6)>_0x44837f)this[_0xfdc803(0x452)](_0x59ad1e);}}},Game_Actor[_0x541333(0x5f1)][_0x541333(0x2ad)]=function(_0xf876bc){const _0x245940=_0x541333;return this['nonOptimizeEtypes']()[_0x245940(0x53c)](this['equipSlots']()[_0xf876bc])?_0x245940(0x425)==='NVsgw'?![]:_0x6ed210[_0x245940(0x1db)][_0x245940(0x522)][_0x245940(0x59f)][_0x245940(0x28b)]:this[_0x245940(0x304)](_0xf876bc);},Game_Actor[_0x541333(0x5f1)][_0x541333(0x548)]=function(){const _0x2ec194=_0x541333;return VisuMZ[_0x2ec194(0x1db)][_0x2ec194(0x522)]['EquipScene'][_0x2ec194(0x201)];},VisuMZ[_0x541333(0x1db)][_0x541333(0x379)]=Game_Actor[_0x541333(0x5f1)]['tradeItemWithParty'],Game_Actor[_0x541333(0x5f1)][_0x541333(0x340)]=function(_0x47f235,_0x5b2f89){const _0x5ade2d=_0x541333;if(this[_0x5ade2d(0x59a)])return![];$gameTemp[_0x5ade2d(0x35a)]=!![];const _0x5d7e29=VisuMZ[_0x5ade2d(0x1db)][_0x5ade2d(0x379)][_0x5ade2d(0x562)](this,_0x47f235,_0x5b2f89);return $gameTemp[_0x5ade2d(0x35a)]=![],_0x5d7e29;},Game_Actor[_0x541333(0x5f1)][_0x541333(0x4b4)]=function(_0x187487,_0x3e997a){const _0x54c887=_0x541333,_0x424cff=this['getNextAvailableEtypeId'](_0x187487);if(_0x424cff<0x0)return;const _0x1ca0c4=_0x187487===0x1?$dataWeapons[_0x3e997a]:$dataArmors[_0x3e997a];this[_0x54c887(0x23c)](_0x424cff,_0x1ca0c4);},Game_Actor[_0x541333(0x5f1)][_0x541333(0x4f6)]=function(_0x54ad8d){const _0x3da130=_0x541333;let _0x58c381=0x0;const _0x144b52=this[_0x3da130(0x2b4)](),_0x4a83f7=this[_0x3da130(0x34b)]();for(let _0x4a13d6=0x0;_0x4a13d6<_0x144b52[_0x3da130(0x33d)];_0x4a13d6++){if(_0x144b52[_0x4a13d6]===_0x54ad8d){_0x58c381=_0x4a13d6;if(!_0x4a83f7[_0x4a13d6])return _0x58c381;}}return _0x58c381;},VisuMZ[_0x541333(0x1db)][_0x541333(0x5d4)]=Game_Actor[_0x541333(0x5f1)][_0x541333(0x357)],Game_Actor[_0x541333(0x5f1)][_0x541333(0x357)]=function(_0x4fa034){const _0x586933=_0x541333;let _0x5a9c36=VisuMZ[_0x586933(0x1db)]['Game_Actor_paramPlus']['call'](this,_0x4fa034);for(const _0x33f0c2 of this['equips']()){if(_0x33f0c2)_0x5a9c36+=this['paramPlusItemsEquipsCoreCustomJS'](_0x33f0c2,_0x4fa034);}return _0x5a9c36;},Game_Actor[_0x541333(0x5f1)][_0x541333(0x4f2)]=function(_0x462e18,_0x5ca4a9){const _0x7b4cb1=_0x541333;if(this[_0x7b4cb1(0x352)])return 0x0;const _0x443c39=(DataManager[_0x7b4cb1(0x30e)](_0x462e18)?_0x7b4cb1(0x370):_0x7b4cb1(0x56f))[_0x7b4cb1(0x52b)](_0x462e18['id']),_0x1c6641=_0x7b4cb1(0x415)[_0x7b4cb1(0x52b)](_0x443c39,_0x5ca4a9);if(VisuMZ[_0x7b4cb1(0x1db)][_0x7b4cb1(0x4ae)][_0x1c6641]){if(_0x7b4cb1(0x2d2)!==_0x7b4cb1(0x2d2))_0x4c70ff['ItemsEquipsCore'][_0x7b4cb1(0x5e4)][_0x7b4cb1(0x562)](this,_0xb0d19d),this[_0x7b4cb1(0x330)](_0x5140da);else{this[_0x7b4cb1(0x352)]=!![];const _0x56e0dc=VisuMZ['ItemsEquipsCore'][_0x7b4cb1(0x4ae)][_0x1c6641]['call'](this,_0x462e18,_0x5ca4a9);return this[_0x7b4cb1(0x352)]=![],_0x56e0dc;}}else return 0x0;},Game_Actor[_0x541333(0x5f1)][_0x541333(0x48c)]=function(_0x5c3268){const _0x2f6d32=_0x541333;this[_0x2f6d32(0x42c)]=!![],this[_0x2f6d32(0x529)]=_0x5c3268;},VisuMZ[_0x541333(0x1db)]['Game_Party_initialize']=Game_Party[_0x541333(0x5f1)][_0x541333(0x45c)],Game_Party[_0x541333(0x5f1)][_0x541333(0x45c)]=function(){const _0x246216=_0x541333;VisuMZ[_0x246216(0x1db)][_0x246216(0x279)]['call'](this),this[_0x246216(0x4f8)]();},Game_Party['prototype']['initNewItemsList']=function(){const _0x4e3e6d=_0x541333;this[_0x4e3e6d(0x307)]=[];},Game_Party['prototype'][_0x541333(0x3cd)]=function(_0x9751fa){const _0x1c2daf=_0x541333;if(!$gameTemp['newLabelEnabled']())return![];if(this[_0x1c2daf(0x307)]===undefined)this[_0x1c2daf(0x4f8)]();let _0x222544='';if(DataManager[_0x1c2daf(0x577)](_0x9751fa))_0x222544=_0x1c2daf(0x592)[_0x1c2daf(0x52b)](_0x9751fa['id']);else{if(DataManager[_0x1c2daf(0x30e)](_0x9751fa))_0x1c2daf(0x262)!=='DnDaL'?(this[_0x1c2daf(0x526)][_0x1c2daf(0x5e5)](_0x1c2daf(0x3aa),this[_0x1c2daf(0x260)][_0x1c2daf(0x517)](this)),this[_0x1c2daf(0x526)][_0x1c2daf(0x5e5)](_0x1c2daf(0x4b8),this[_0x1c2daf(0x552)][_0x1c2daf(0x517)](this)),this['_slotWindow']['setHandler'](_0x1c2daf(0x2af),this[_0x1c2daf(0x335)]['bind'](this))):_0x222544=_0x1c2daf(0x400)[_0x1c2daf(0x52b)](_0x9751fa['id']);else{if(DataManager['isArmor'](_0x9751fa))_0x222544=_0x1c2daf(0x3c0)[_0x1c2daf(0x52b)](_0x9751fa['id']);else return;}}return this[_0x1c2daf(0x307)][_0x1c2daf(0x53c)](_0x222544);},Game_Party['prototype']['setNewItem']=function(_0x46767d){const _0x42c9f5=_0x541333;if(!$gameTemp[_0x42c9f5(0x487)]())return;if(this[_0x42c9f5(0x307)]===undefined)this['initNewItemsList']();let _0x2e7ba2='';if(DataManager[_0x42c9f5(0x577)](_0x46767d))_0x2e7ba2='item-%1'[_0x42c9f5(0x52b)](_0x46767d['id']);else{if(DataManager[_0x42c9f5(0x30e)](_0x46767d))_0x2e7ba2=_0x42c9f5(0x400)['format'](_0x46767d['id']);else{if(DataManager[_0x42c9f5(0x1a6)](_0x46767d))_0x2e7ba2='armor-%1'['format'](_0x46767d['id']);else return;}}if(!this[_0x42c9f5(0x307)][_0x42c9f5(0x53c)](_0x2e7ba2))this[_0x42c9f5(0x307)][_0x42c9f5(0x282)](_0x2e7ba2);},Game_Party[_0x541333(0x5f1)]['clearNewItem']=function(_0x3d8b6c){const _0x3b87c4=_0x541333;if(!$gameTemp[_0x3b87c4(0x487)]())return;if(this[_0x3b87c4(0x307)]===undefined)this[_0x3b87c4(0x4f8)]();let _0x3a150e='';if(DataManager[_0x3b87c4(0x577)](_0x3d8b6c))_0x3b87c4(0x5de)===_0x3b87c4(0x5b5)?this[_0x3b87c4(0x1ed)]():_0x3a150e='item-%1'[_0x3b87c4(0x52b)](_0x3d8b6c['id']);else{if(DataManager[_0x3b87c4(0x30e)](_0x3d8b6c)){if('NKTeJ'==='NKTeJ')_0x3a150e=_0x3b87c4(0x400)['format'](_0x3d8b6c['id']);else return _0x390b25[_0x3b87c4(0x1db)][_0x3b87c4(0x522)][_0x3b87c4(0x510)][_0x3b87c4(0x3af)];}else{if(DataManager[_0x3b87c4(0x1a6)](_0x3d8b6c))_0x3a150e='armor-%1'[_0x3b87c4(0x52b)](_0x3d8b6c['id']);else return;}}this[_0x3b87c4(0x307)][_0x3b87c4(0x53c)](_0x3a150e)&&this[_0x3b87c4(0x307)][_0x3b87c4(0x38d)](this[_0x3b87c4(0x307)][_0x3b87c4(0x525)](_0x3a150e),0x1);},VisuMZ[_0x541333(0x1db)][_0x541333(0x230)]=Game_Party[_0x541333(0x5f1)][_0x541333(0x2c7)],Game_Party[_0x541333(0x5f1)]['gainItem']=function(_0x55aa92,_0x1c6a4d,_0x1b84e0){const _0x207d1f=_0x541333,_0x1fac54=this[_0x207d1f(0x231)](_0x55aa92);VisuMZ['ItemsEquipsCore']['Game_Party_gainItem'][_0x207d1f(0x562)](this,_0x55aa92,_0x1c6a4d,_0x1b84e0);if(this[_0x207d1f(0x231)](_0x55aa92)>_0x1fac54)this[_0x207d1f(0x452)](_0x55aa92);},Game_Party[_0x541333(0x5f1)][_0x541333(0x574)]=function(_0x303321){return DataManager['maxItemAmount'](_0x303321);},VisuMZ[_0x541333(0x1db)]['Scene_ItemBase_activateItemWindow']=Scene_ItemBase[_0x541333(0x5f1)][_0x541333(0x42e)],Scene_ItemBase[_0x541333(0x5f1)][_0x541333(0x42e)]=function(){const _0x151f07=_0x541333;VisuMZ[_0x151f07(0x1db)][_0x151f07(0x531)]['call'](this),this['_itemWindow'][_0x151f07(0x1b1)]();},Scene_Item[_0x541333(0x5f1)]['isBottomHelpMode']=function(){const _0x57ffac=_0x541333;if(ConfigManager[_0x57ffac(0x5d1)]&&ConfigManager['uiHelpPosition']!==undefined)return _0x57ffac(0x267)!==_0x57ffac(0x3be)?ConfigManager['uiHelpPosition']:_0x23d161[_0x57ffac(0x1db)]['Settings']['ItemScene'][_0x57ffac(0x544)];else{if(this['isUseItemsEquipsCoreUpdatedLayout']()){if(_0x57ffac(0x4d8)===_0x57ffac(0x2d8))this['playCursorSound']();else return this[_0x57ffac(0x3c7)]()[_0x57ffac(0x2a3)](/LOWER/i);}else Scene_ItemBase[_0x57ffac(0x5f1)][_0x57ffac(0x434)]['call'](this);}},Scene_Item[_0x541333(0x5f1)][_0x541333(0x434)]=function(){const _0x5b670c=_0x541333;if(ConfigManager[_0x5b670c(0x5d1)]&&ConfigManager[_0x5b670c(0x292)]!==undefined){if(_0x5b670c(0x4fb)===_0x5b670c(0x4fb))return ConfigManager[_0x5b670c(0x292)];else this['drawIcon'](_0x4e167d,_0x337808['x'],_0x32431f['y']+0x2);}else{if(this[_0x5b670c(0x4ea)]())return this[_0x5b670c(0x3c7)]()[_0x5b670c(0x2a3)](/RIGHT/i);else Scene_ItemBase[_0x5b670c(0x5f1)][_0x5b670c(0x434)][_0x5b670c(0x562)](this);}},Scene_Item[_0x541333(0x5f1)][_0x541333(0x3c7)]=function(){const _0x41cab2=_0x541333;return VisuMZ[_0x41cab2(0x1db)][_0x41cab2(0x522)][_0x41cab2(0x394)]['LayoutStyle'];},Scene_Item['prototype'][_0x541333(0x539)]=function(){const _0x5a3106=_0x541333;return this[_0x5a3106(0x21e)]&&this['_categoryWindow'][_0x5a3106(0x539)]();},Scene_Item[_0x541333(0x5f1)][_0x541333(0x4ea)]=function(){const _0x273b5b=_0x541333;return VisuMZ[_0x273b5b(0x1db)][_0x273b5b(0x522)][_0x273b5b(0x394)][_0x273b5b(0x28b)];},VisuMZ[_0x541333(0x1db)][_0x541333(0x27e)]=Scene_Item[_0x541333(0x5f1)][_0x541333(0x2b3)],Scene_Item['prototype'][_0x541333(0x2b3)]=function(){const _0x5d690d=_0x541333;VisuMZ[_0x5d690d(0x1db)][_0x5d690d(0x27e)][_0x5d690d(0x562)](this),this[_0x5d690d(0x539)]()&&(_0x5d690d(0x21a)===_0x5d690d(0x21a)?this[_0x5d690d(0x2c6)]():this[_0x5d690d(0x2b8)](_0x4e416d[_0x5d690d(0x2f6)](_0x5d690d(0x2af))));},VisuMZ[_0x541333(0x1db)][_0x541333(0x1ea)]=Scene_Item[_0x541333(0x5f1)][_0x541333(0x381)],Scene_Item['prototype']['helpWindowRect']=function(){const _0x40b0a4=_0x541333;if(this[_0x40b0a4(0x4ea)]())return this[_0x40b0a4(0x3f8)]();else{if('TtGjX'!==_0x40b0a4(0x337)){if(!_0x4140f1[_0x40b0a4(0x5e9)](_0x53d212))return![];}else return VisuMZ['ItemsEquipsCore'][_0x40b0a4(0x1ea)][_0x40b0a4(0x562)](this);}},Scene_Item[_0x541333(0x5f1)][_0x541333(0x3f8)]=function(){const _0xb861fc=_0x541333,_0x59a1a7=0x0,_0x56c477=this['helpAreaTop'](),_0x598c0b=Graphics['boxWidth'],_0x36a1c6=this[_0xb861fc(0x32e)]();return new Rectangle(_0x59a1a7,_0x56c477,_0x598c0b,_0x36a1c6);},VisuMZ[_0x541333(0x1db)][_0x541333(0x57f)]=Scene_Item['prototype']['createCategoryWindow'],Scene_Item['prototype'][_0x541333(0x44d)]=function(){const _0x24538f=_0x541333;VisuMZ[_0x24538f(0x1db)][_0x24538f(0x57f)][_0x24538f(0x562)](this),this[_0x24538f(0x539)]()&&this[_0x24538f(0x5f2)]();},Scene_Item[_0x541333(0x5f1)]['postCreateCategoryWindowItemsEquipsCore']=function(){const _0x354af5=_0x541333;delete this['_categoryWindow'][_0x354af5(0x31f)]['ok'],delete this['_categoryWindow'][_0x354af5(0x31f)][_0x354af5(0x3aa)];},VisuMZ[_0x541333(0x1db)][_0x541333(0x595)]=Scene_Item[_0x541333(0x5f1)][_0x541333(0x5bd)],Scene_Item[_0x541333(0x5f1)]['categoryWindowRect']=function(){const _0x5a8207=_0x541333;if(this[_0x5a8207(0x4ea)]())return this[_0x5a8207(0x588)]();else{if(_0x5a8207(0x596)!=='fFDIT')return VisuMZ[_0x5a8207(0x1db)][_0x5a8207(0x595)][_0x5a8207(0x562)](this);else _0x33540a['isTriggered'](_0x5a8207(0x4b8))&&_0x3d190e[_0x5a8207(0x4fc)](_0x5a8207(0x228))&&this[_0x5a8207(0x1c2)](),_0x2e4f1f[_0x5a8207(0x2f6)](_0x5a8207(0x2af))&&_0x15ddf9[_0x5a8207(0x4fc)](_0x5a8207(0x228))&&this['cursorPageup']();}},Scene_Item[_0x541333(0x5f1)][_0x541333(0x588)]=function(){const _0x2ceaf8=_0x541333,_0x97bdd0=0x0,_0x269576=this['mainAreaTop'](),_0xf1b020=Graphics['boxWidth'],_0x4d7e63=this[_0x2ceaf8(0x5c9)](0x1,!![]);return new Rectangle(_0x97bdd0,_0x269576,_0xf1b020,_0x4d7e63);},VisuMZ[_0x541333(0x1db)][_0x541333(0x4c4)]=Scene_Item['prototype'][_0x541333(0x1cd)],Scene_Item[_0x541333(0x5f1)][_0x541333(0x1cd)]=function(){const _0x747fb0=_0x541333;VisuMZ[_0x747fb0(0x1db)][_0x747fb0(0x4c4)][_0x747fb0(0x562)](this);if(this['isUseModernControls']()){if(_0x747fb0(0x2f2)===_0x747fb0(0x2f2))this[_0x747fb0(0x338)]();else return _0x2c7572['ItemsEquipsCore'][_0x747fb0(0x522)]['StatusWindow']['LabelConsume'];}this[_0x747fb0(0x555)]()&&this[_0x747fb0(0x4c3)]();},VisuMZ[_0x541333(0x1db)][_0x541333(0x1ef)]=Scene_Item[_0x541333(0x5f1)][_0x541333(0x3df)],Scene_Item[_0x541333(0x5f1)]['itemWindowRect']=function(){const _0x151ed7=_0x541333;if(this[_0x151ed7(0x4ea)]())return this[_0x151ed7(0x448)]();else{const _0x104b03=VisuMZ['ItemsEquipsCore']['Scene_Item_itemWindowRect'][_0x151ed7(0x562)](this);return this[_0x151ed7(0x555)]()&&this[_0x151ed7(0x40f)]()&&(_0x151ed7(0x2f9)!==_0x151ed7(0x274)?_0x104b03['width']-=this['statusWidth']():_0x4dbd65=_0x151ed7(0x400)[_0x151ed7(0x52b)](_0x1cac3d['id'])),_0x104b03;}},Scene_Item['prototype'][_0x541333(0x448)]=function(){const _0x5ce104=_0x541333,_0x24bd21=this[_0x5ce104(0x434)]()?this[_0x5ce104(0x51c)]():0x0,_0x15ef68=this[_0x5ce104(0x21e)]['y']+this[_0x5ce104(0x21e)][_0x5ce104(0x242)],_0xf0d28e=Graphics[_0x5ce104(0x37c)]-this[_0x5ce104(0x51c)](),_0x2448c2=this[_0x5ce104(0x53e)]()-_0x15ef68;return new Rectangle(_0x24bd21,_0x15ef68,_0xf0d28e,_0x2448c2);},Scene_Item[_0x541333(0x5f1)][_0x541333(0x338)]=function(){const _0x184b60=_0x541333;this[_0x184b60(0x1b6)][_0x184b60(0x5e5)]('cancel',this[_0x184b60(0x260)][_0x184b60(0x517)](this));},Scene_Item[_0x541333(0x5f1)][_0x541333(0x555)]=function(){const _0x4b8c73=_0x541333;if(this['isUseItemsEquipsCoreUpdatedLayout']()){if(_0x4b8c73(0x3d8)===_0x4b8c73(0x3d8))return!![];else{this[_0x4b8c73(0x4f3)](_0x13afb5)['match'](/\\I\[(\d+)\]/i);const _0x167b15=_0x328aef(_0x2f870f['$1'])||0x0,_0x1bfd88=this[_0x4b8c73(0x347)](_0x3b7139),_0x36be37=_0x1bfd88['x']+_0x50e8a5[_0x4b8c73(0x254)]((_0x1bfd88[_0x4b8c73(0x5bc)]-_0x142cf0[_0x4b8c73(0x5d8)])/0x2),_0x5f47ae=_0x1bfd88['y']+(_0x1bfd88[_0x4b8c73(0x242)]-_0x495f2e[_0x4b8c73(0x233)])/0x2;this[_0x4b8c73(0x3e7)](_0x167b15,_0x36be37,_0x5f47ae);}}else{if(_0x4b8c73(0x2ab)===_0x4b8c73(0x2ab))return VisuMZ['ItemsEquipsCore'][_0x4b8c73(0x522)][_0x4b8c73(0x394)]['ShowShopStatus'];else for(const _0xb652ad of _0x572997['equipTypes']){const _0x3bdba6=_0x12e7cb['equipTypes'][_0x4b8c73(0x525)](_0xb652ad[_0x4b8c73(0x399)]());if(_0x3bdba6>0x0)_0x12a8a5[_0x4b8c73(0x2b4)][_0x4b8c73(0x282)](_0x3bdba6);}}},Scene_Item[_0x541333(0x5f1)][_0x541333(0x40f)]=function(){const _0x291fe2=_0x541333;return VisuMZ[_0x291fe2(0x1db)][_0x291fe2(0x522)][_0x291fe2(0x394)][_0x291fe2(0x446)];},Scene_Item[_0x541333(0x5f1)][_0x541333(0x4c3)]=function(){const _0x2e3a9b=_0x541333,_0x44d9f2=this[_0x2e3a9b(0x1bb)]();this['_statusWindow']=new Window_ShopStatus(_0x44d9f2),this[_0x2e3a9b(0x464)](this[_0x2e3a9b(0x1ee)]),this['_itemWindow'][_0x2e3a9b(0x3bc)](this[_0x2e3a9b(0x1ee)]);const _0x30fdaf=VisuMZ[_0x2e3a9b(0x1db)][_0x2e3a9b(0x522)][_0x2e3a9b(0x394)]['ItemMenuStatusBgType'];this[_0x2e3a9b(0x1ee)][_0x2e3a9b(0x1c1)](_0x30fdaf||0x0);},Scene_Item[_0x541333(0x5f1)][_0x541333(0x1bb)]=function(){const _0x234903=_0x541333;return this[_0x234903(0x4ea)]()?_0x234903(0x537)===_0x234903(0x34a)?this[_0x234903(0x21e)]&&this['_categoryWindow'][_0x234903(0x539)]():this[_0x234903(0x45a)]():VisuMZ[_0x234903(0x1db)]['Settings'][_0x234903(0x394)]['ItemMenuStatusRect'][_0x234903(0x562)](this);},Scene_Item['prototype'][_0x541333(0x45a)]=function(){const _0x44c487=_0x541333,_0x4455ee=this[_0x44c487(0x51c)](),_0x179b04=this[_0x44c487(0x1b6)][_0x44c487(0x242)],_0x23a48d=this[_0x44c487(0x434)]()?0x0:Graphics[_0x44c487(0x37c)]-this['statusWidth'](),_0x5c73fd=this[_0x44c487(0x1b6)]['y'];return new Rectangle(_0x23a48d,_0x5c73fd,_0x4455ee,_0x179b04);},Scene_Item[_0x541333(0x5f1)][_0x541333(0x51c)]=function(){const _0x5c15bb=_0x541333;return Scene_Shop[_0x5c15bb(0x5f1)][_0x5c15bb(0x51c)]();},Scene_Item['prototype'][_0x541333(0x2e2)]=function(){const _0x3000bb=_0x541333;if(!this['updatedLayoutStyle']())return![];if(!this['isUseModernControls']())return![];if(!this['_itemWindow'])return![];if(!this[_0x3000bb(0x1b6)][_0x3000bb(0x566)])return![];return this['updatedLayoutStyle']()&&this[_0x3000bb(0x539)]();},Scene_Item[_0x541333(0x5f1)]['buttonAssistKey1']=function(){const _0x477dd0=_0x541333;if(this[_0x477dd0(0x2e2)]())return this['_itemWindow'][_0x477dd0(0x4c6)]()===0x1?TextManager[_0x477dd0(0x317)](_0x477dd0(0x265),_0x477dd0(0x263)):TextManager['getInputMultiButtonStrings'](_0x477dd0(0x2af),'pagedown');return Scene_ItemBase[_0x477dd0(0x5f1)][_0x477dd0(0x19d)][_0x477dd0(0x562)](this);},Scene_Item['prototype'][_0x541333(0x22c)]=function(){const _0x1e06ca=_0x541333;if(this[_0x1e06ca(0x2e2)]()){if('NxuGt'===_0x1e06ca(0x300)){if(_0x229d2e[_0x1e06ca(0x58d)]()!==_0x1f6fb4[_0x1e06ca(0x58d)])for(const _0x57f1ed of _0x37a6cb[_0x1e06ca(0x293)]){if(_0x57f1ed)_0x57f1ed[_0x1e06ca(0x5d7)]();}}else return VisuMZ[_0x1e06ca(0x1db)][_0x1e06ca(0x522)][_0x1e06ca(0x394)][_0x1e06ca(0x544)];}return Scene_ItemBase['prototype'][_0x1e06ca(0x22c)]['call'](this);},Scene_Equip[_0x541333(0x5f1)][_0x541333(0x3cc)]=function(){const _0x505f17=_0x541333;if(ConfigManager['uiMenuStyle']&&ConfigManager[_0x505f17(0x4b3)]!==undefined)return _0x505f17(0x349)===_0x505f17(0x349)?ConfigManager[_0x505f17(0x4b3)]:_0x35bf43['ScopeRandomAllies']['format'](_0xf66b81(_0xeb457a['$1']));else{if(this[_0x505f17(0x4ea)]())return this['updatedLayoutStyle']()['match'](/LOWER/i);else{if('SYqRb'!==_0x505f17(0x58e))Scene_MenuBase[_0x505f17(0x5f1)][_0x505f17(0x434)]['call'](this);else{const _0x418869=_0x40abc4[_0x505f17(0x5f9)]('['+_0xaefea6['$1'][_0x505f17(0x2a3)](/\d+/g)+']');for(const _0x375201 of _0x418869){if(_0x47c3ec[_0x505f17(0x5e9)](_0x375201))return![];}}}}},Scene_Equip[_0x541333(0x5f1)][_0x541333(0x434)]=function(){const _0x428d3b=_0x541333;if(ConfigManager[_0x428d3b(0x5d1)]&&ConfigManager[_0x428d3b(0x292)]!==undefined)return ConfigManager['uiInputPosition'];else{if(this[_0x428d3b(0x4ea)]()){if(_0x428d3b(0x3fe)!==_0x428d3b(0x4aa))return this[_0x428d3b(0x3c7)]()[_0x428d3b(0x2a3)](/RIGHT/i);else{this[_0x428d3b(0x29e)](this[_0x428d3b(0x213)](null));const _0x502c03=_0xc39b2b[_0x428d3b(0x1db)][_0x428d3b(0x522)]['EquipScene'],_0x12be0c=this['itemLineRect'](_0x4e962c),_0x2f5901=_0x12be0c['y']+(this['lineHeight']()-_0x33fb19[_0x428d3b(0x233)])/0x2,_0x780de0=_0x94981d[_0x428d3b(0x5d8)]+0x4,_0x44fdeb=_0x589ac1[_0x428d3b(0x52c)](0x0,_0x12be0c[_0x428d3b(0x5bc)]-_0x780de0);this[_0x428d3b(0x4b0)](),this[_0x428d3b(0x3e7)](_0x502c03[_0x428d3b(0x31b)],_0x12be0c['x'],_0x2f5901),this['drawText'](_0x502c03[_0x428d3b(0x5e8)],_0x12be0c['x']+_0x780de0,_0x12be0c['y'],_0x44fdeb),this[_0x428d3b(0x29e)](!![]);}}else _0x428d3b(0x1d8)===_0x428d3b(0x1d8)?Scene_MenuBase[_0x428d3b(0x5f1)][_0x428d3b(0x434)][_0x428d3b(0x562)](this):(_0xfa60b7['ItemsEquipsCore']['Window_ItemCategory_initialize'][_0x428d3b(0x562)](this,_0x163653),this[_0x428d3b(0x237)](_0x595f26));}},Scene_Equip[_0x541333(0x5f1)][_0x541333(0x3c7)]=function(){const _0x3b8f82=_0x541333;return VisuMZ[_0x3b8f82(0x1db)][_0x3b8f82(0x522)][_0x3b8f82(0x59f)][_0x3b8f82(0x3e2)];},Scene_Equip[_0x541333(0x5f1)][_0x541333(0x539)]=function(){const _0xe4b0f9=_0x541333;return this['_commandWindow']&&this[_0xe4b0f9(0x3b3)][_0xe4b0f9(0x539)]();},Scene_Equip[_0x541333(0x5f1)]['isUseItemsEquipsCoreUpdatedLayout']=function(){const _0x17dc12=_0x541333;return VisuMZ[_0x17dc12(0x1db)]['Settings'][_0x17dc12(0x59f)][_0x17dc12(0x28b)];},VisuMZ[_0x541333(0x1db)]['Scene_Equip_create']=Scene_Equip[_0x541333(0x5f1)][_0x541333(0x2b3)],Scene_Equip[_0x541333(0x5f1)]['create']=function(){const _0x2e9fb4=_0x541333;VisuMZ[_0x2e9fb4(0x1db)]['Scene_Equip_create'][_0x2e9fb4(0x562)](this),this['isUseModernControls']()&&this[_0x2e9fb4(0x5a8)]();},VisuMZ[_0x541333(0x1db)][_0x541333(0x463)]=Scene_Equip['prototype'][_0x541333(0x381)],Scene_Equip[_0x541333(0x5f1)]['helpWindowRect']=function(){const _0x519570=_0x541333;return this[_0x519570(0x4ea)]()?this[_0x519570(0x3f8)]():'LshpF'===_0x519570(0x3ba)?_0x23cd9f[_0x519570(0x1db)][_0x519570(0x522)][_0x519570(0x2f1)][_0x519570(0x44e)]:VisuMZ[_0x519570(0x1db)][_0x519570(0x463)][_0x519570(0x562)](this);},Scene_Equip[_0x541333(0x5f1)][_0x541333(0x3f8)]=function(){const _0x3ccdbe=_0x541333,_0x3b14cd=0x0,_0x28e327=this['helpAreaTop'](),_0x11fc4c=Graphics['boxWidth'],_0x14efee=this[_0x3ccdbe(0x32e)]();return new Rectangle(_0x3b14cd,_0x28e327,_0x11fc4c,_0x14efee);},VisuMZ[_0x541333(0x1db)][_0x541333(0x30c)]=Scene_Equip['prototype'][_0x541333(0x1bb)],Scene_Equip[_0x541333(0x5f1)][_0x541333(0x1bb)]=function(){const _0x470226=_0x541333;return this['isUseItemsEquipsCoreUpdatedLayout']()?this[_0x470226(0x45a)]():VisuMZ[_0x470226(0x1db)]['Scene_Equip_statusWindowRect'][_0x470226(0x562)](this);},Scene_Equip[_0x541333(0x5f1)][_0x541333(0x45a)]=function(){const _0x38b0ba=_0x541333,_0x3f2102=this[_0x38b0ba(0x434)]()?0x0:Graphics['boxWidth']-this[_0x38b0ba(0x51c)](),_0x5dd056=this[_0x38b0ba(0x1c0)](),_0x5b7a79=this[_0x38b0ba(0x51c)](),_0x2a9f0b=this[_0x38b0ba(0x326)]();return new Rectangle(_0x3f2102,_0x5dd056,_0x5b7a79,_0x2a9f0b);},VisuMZ[_0x541333(0x1db)][_0x541333(0x4da)]=Scene_Equip[_0x541333(0x5f1)][_0x541333(0x47b)],Scene_Equip[_0x541333(0x5f1)][_0x541333(0x47b)]=function(){const _0x4932a9=_0x541333;if(this[_0x4932a9(0x4ea)]()){if(_0x4932a9(0x1a8)!==_0x4932a9(0x1a8))_0xe2f48c[_0x4932a9(0x285)]();else return this[_0x4932a9(0x298)]();}else return VisuMZ['ItemsEquipsCore'][_0x4932a9(0x4da)]['call'](this);},Scene_Equip[_0x541333(0x5f1)]['shouldCommandWindowExist']=function(){const _0xa9d6f9=_0x541333,_0x225934=VisuMZ[_0xa9d6f9(0x1db)]['Settings'][_0xa9d6f9(0x59f)];return _0x225934[_0xa9d6f9(0x37e)]||_0x225934[_0xa9d6f9(0x513)];},Scene_Equip[_0x541333(0x5f1)]['commandWindowRectItemsEquipsCore']=function(){const _0x58d34c=_0x541333,_0x8de5f2=this['shouldCommandWindowExist'](),_0x3924ca=this[_0x58d34c(0x434)]()?this[_0x58d34c(0x51c)]():0x0,_0x5aeb98=this[_0x58d34c(0x1c0)](),_0xc24e22=Graphics[_0x58d34c(0x37c)]-this[_0x58d34c(0x51c)](),_0x2e5592=_0x8de5f2?this[_0x58d34c(0x5c9)](0x1,!![]):0x0;return new Rectangle(_0x3924ca,_0x5aeb98,_0xc24e22,_0x2e5592);},VisuMZ['ItemsEquipsCore'][_0x541333(0x4ed)]=Scene_Equip[_0x541333(0x5f1)][_0x541333(0x3ae)],Scene_Equip[_0x541333(0x5f1)][_0x541333(0x3ae)]=function(){const _0x2f7f96=_0x541333;VisuMZ[_0x2f7f96(0x1db)][_0x2f7f96(0x4ed)][_0x2f7f96(0x562)](this),this['isUseModernControls']()&&(_0x2f7f96(0x31d)==='Psepy'?(this[_0x2f7f96(0x526)][_0x2f7f96(0x43f)](0x0),this[_0x2f7f96(0x526)][_0x2f7f96(0x51e)]()):this[_0x2f7f96(0x275)]());},VisuMZ[_0x541333(0x1db)][_0x541333(0x553)]=Scene_Equip[_0x541333(0x5f1)][_0x541333(0x269)],Scene_Equip[_0x541333(0x5f1)][_0x541333(0x269)]=function(){const _0x52b190=_0x541333;if(this['isUseItemsEquipsCoreUpdatedLayout']()){if(_0x52b190(0x561)===_0x52b190(0x474)){const _0x4b8f58=_0x3a5e3e(_0x4be3fe['$1'])||0x1;if(_0x1ef6c8>=_0x4b8f58)return!![];}else return this[_0x52b190(0x232)]();}else return'ITmpV'!=='ITmpV'?this[_0x52b190(0x1f4)]():VisuMZ[_0x52b190(0x1db)][_0x52b190(0x553)][_0x52b190(0x562)](this);},Scene_Equip[_0x541333(0x5f1)][_0x541333(0x232)]=function(){const _0x44cd5d=_0x541333,_0x2a245a=this[_0x44cd5d(0x47b)](),_0x405133=this['isRightInputMode']()?this[_0x44cd5d(0x51c)]():0x0,_0x544b97=_0x2a245a['y']+_0x2a245a[_0x44cd5d(0x242)],_0x5372f3=Graphics[_0x44cd5d(0x37c)]-this[_0x44cd5d(0x51c)](),_0x5bdda3=this[_0x44cd5d(0x326)]()-_0x2a245a[_0x44cd5d(0x242)];return new Rectangle(_0x405133,_0x544b97,_0x5372f3,_0x5bdda3);},VisuMZ['ItemsEquipsCore'][_0x541333(0x3e4)]=Scene_Equip[_0x541333(0x5f1)]['itemWindowRect'],Scene_Equip[_0x541333(0x5f1)][_0x541333(0x3df)]=function(){const _0x40468a=_0x541333;return this[_0x40468a(0x4ea)]()?_0x40468a(0x4be)!==_0x40468a(0x4be)?_0x547350[_0x40468a(0x1db)]['Settings'][_0x40468a(0x59f)]['CommandAddOptimize']:this[_0x40468a(0x269)]():VisuMZ[_0x40468a(0x1db)][_0x40468a(0x3e4)]['call'](this);},Scene_Equip[_0x541333(0x5f1)][_0x541333(0x51c)]=function(){const _0x53d0f4=_0x541333;return this['isUseItemsEquipsCoreUpdatedLayout']()?this[_0x53d0f4(0x56b)]():VisuMZ[_0x53d0f4(0x1db)]['Settings'][_0x53d0f4(0x59f)][_0x53d0f4(0x35d)];},Scene_Equip[_0x541333(0x5f1)][_0x541333(0x56b)]=function(){const _0x24ad91=_0x541333;return Math[_0x24ad91(0x254)](Graphics[_0x24ad91(0x37c)]/0x2);},Scene_Equip['prototype'][_0x541333(0x275)]=function(){const _0x4ef69a=_0x541333;this[_0x4ef69a(0x526)]['setHandler'](_0x4ef69a(0x3aa),this[_0x4ef69a(0x260)][_0x4ef69a(0x517)](this)),this[_0x4ef69a(0x526)]['setHandler'](_0x4ef69a(0x4b8),this['nextActor'][_0x4ef69a(0x517)](this)),this['_slotWindow'][_0x4ef69a(0x5e5)](_0x4ef69a(0x2af),this[_0x4ef69a(0x335)][_0x4ef69a(0x517)](this));},VisuMZ[_0x541333(0x1db)][_0x541333(0x4db)]=Scene_Equip[_0x541333(0x5f1)][_0x541333(0x5a8)],Scene_Equip[_0x541333(0x5f1)][_0x541333(0x5a8)]=function(){const _0x1c9934=_0x541333;this['isUseModernControls']()&&(this[_0x1c9934(0x3b3)][_0x1c9934(0x5bf)](),this[_0x1c9934(0x3b3)]['deactivate']()),VisuMZ[_0x1c9934(0x1db)]['Scene_Equip_commandEquip'][_0x1c9934(0x562)](this);},VisuMZ[_0x541333(0x1db)][_0x541333(0x449)]=Scene_Equip[_0x541333(0x5f1)][_0x541333(0x586)],Scene_Equip[_0x541333(0x5f1)][_0x541333(0x586)]=function(){const _0x518445=_0x541333;this[_0x518445(0x526)][_0x518445(0x593)]()>=0x0?(VisuMZ['ItemsEquipsCore'][_0x518445(0x449)][_0x518445(0x562)](this),this['onSlotOkAutoSelect']()):(this[_0x518445(0x526)][_0x518445(0x43f)](0x0),this[_0x518445(0x526)]['activate']());},Scene_Equip[_0x541333(0x5f1)][_0x541333(0x1ae)]=function(){const _0x475e0e=_0x541333;this[_0x475e0e(0x1b6)][_0x475e0e(0x210)]();const _0x4f3092=this[_0x475e0e(0x526)]['item'](),_0x44de32=this[_0x475e0e(0x1b6)][_0x475e0e(0x293)][_0x475e0e(0x525)](_0x4f3092),_0x7daa9c=Math[_0x475e0e(0x254)](this[_0x475e0e(0x1b6)]['maxVisibleItems']()/0x2)-0x1;this[_0x475e0e(0x1b6)][_0x475e0e(0x43f)](_0x44de32>=0x0?_0x44de32:0x0),this['_itemWindow'][_0x475e0e(0x54e)](this[_0x475e0e(0x1b6)][_0x475e0e(0x593)]()-_0x7daa9c);},VisuMZ[_0x541333(0x1db)][_0x541333(0x26e)]=Scene_Equip[_0x541333(0x5f1)][_0x541333(0x255)],Scene_Equip[_0x541333(0x5f1)]['onSlotCancel']=function(){const _0x11643b=_0x541333;VisuMZ['ItemsEquipsCore'][_0x11643b(0x26e)][_0x11643b(0x562)](this),this[_0x11643b(0x539)]()&&(this['_commandWindow'][_0x11643b(0x43f)](0x0),this[_0x11643b(0x526)][_0x11643b(0x48a)]());},VisuMZ['ItemsEquipsCore']['Scene_Equip_onActorChange']=Scene_Equip[_0x541333(0x5f1)]['onActorChange'],Scene_Equip[_0x541333(0x5f1)][_0x541333(0x58b)]=function(){const _0x5430d2=_0x541333;VisuMZ[_0x5430d2(0x1db)][_0x5430d2(0x1c8)][_0x5430d2(0x562)](this);if(this['isUseModernControls']()){if(_0x5430d2(0x490)!==_0x5430d2(0x203))this[_0x5430d2(0x3b3)]['deactivate'](),this[_0x5430d2(0x3b3)]['deselect'](),this[_0x5430d2(0x526)][_0x5430d2(0x43f)](0x0),this[_0x5430d2(0x526)][_0x5430d2(0x51e)]();else return _0x5621ea[_0x5430d2(0x1db)][_0x5430d2(0x419)][_0x5430d2(0x562)](this);}},Scene_Equip['prototype'][_0x541333(0x44a)]=function(){const _0x549b29=_0x541333;if(!this[_0x549b29(0x526)])return![];if(!this[_0x549b29(0x526)][_0x549b29(0x566)])return![];return this[_0x549b29(0x526)]['isShiftRemoveShortcutEnabled']();},Scene_Equip['prototype'][_0x541333(0x204)]=function(){const _0x55627c=_0x541333;if(this[_0x55627c(0x44a)]())return TextManager['getInputButtonString'](_0x55627c(0x228));return Scene_MenuBase[_0x55627c(0x5f1)][_0x55627c(0x204)][_0x55627c(0x562)](this);},Scene_Equip[_0x541333(0x5f1)][_0x541333(0x323)]=function(){const _0x51d83e=_0x541333;if(this[_0x51d83e(0x44a)]()){if(_0x51d83e(0x43b)===_0x51d83e(0x43b))return VisuMZ[_0x51d83e(0x1db)][_0x51d83e(0x522)][_0x51d83e(0x59f)][_0x51d83e(0x5c8)];else{const _0x1970ce=this[_0x51d83e(0x567)]['note'];if(_0x1970ce[_0x51d83e(0x2a3)](/<ALWAYS HIT>/i))return'100%';else{if(_0x1970ce['match'](/<ALWAYS HIT RATE: (\d+)([%％])>/i))return _0x51d83e(0x3f4)[_0x51d83e(0x52b)](_0x11e080(_0x283c2e['$1']));}}}return Scene_MenuBase[_0x51d83e(0x5f1)][_0x51d83e(0x323)][_0x51d83e(0x562)](this);},Scene_Equip[_0x541333(0x5f1)][_0x541333(0x20e)]=function(){const _0x3dae06=_0x541333;if(this['buttonAssistSlotWindowShift']())return this[_0x3dae06(0x3b7)][_0x3dae06(0x5bc)]/0x5/-0x3;return Scene_MenuBase['prototype']['buttonAssistOffset3'][_0x3dae06(0x562)](this);},Scene_Equip[_0x541333(0x5f1)][_0x541333(0x260)]=function(){const _0x49ac04=_0x541333;SceneManager[_0x49ac04(0x564)]();},VisuMZ[_0x541333(0x1db)]['Scene_Load_reloadMapIfUpdated']=Scene_Load[_0x541333(0x5f1)][_0x541333(0x1d6)],Scene_Load[_0x541333(0x5f1)]['reloadMapIfUpdated']=function(){const _0x337012=_0x541333;VisuMZ[_0x337012(0x1db)][_0x337012(0x27b)][_0x337012(0x562)](this),this['refreshActorEquipSlotsIfUpdated']();},Scene_Load['prototype'][_0x541333(0x302)]=function(){const _0x5426c2=_0x541333;if($gameSystem[_0x5426c2(0x58d)]()!==$dataSystem['versionId'])for(const _0x1c817f of $gameActors[_0x5426c2(0x293)]){if(_0x5426c2(0x314)!==_0x5426c2(0x310)){if(_0x1c817f)_0x1c817f['prepareNewEquipSlotsOnLoad']();}else _0x294b19[_0x5426c2(0x1db)][_0x5426c2(0x4ed)][_0x5426c2(0x562)](this),this['isUseModernControls']()&&this[_0x5426c2(0x275)]();}},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x3cc)]=function(){const _0x50c664=_0x541333;if(ConfigManager['uiMenuStyle']&&ConfigManager[_0x50c664(0x4b3)]!==undefined){if(_0x50c664(0x4ff)!==_0x50c664(0x1cc))return ConfigManager['uiHelpPosition'];else this[_0x50c664(0x4fd)](!![]);}else{if(this['isUseItemsEquipsCoreUpdatedLayout']())return this[_0x50c664(0x3c7)]()['match'](/LOWER/i);else Scene_MenuBase[_0x50c664(0x5f1)][_0x50c664(0x434)][_0x50c664(0x562)](this);}},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x434)]=function(){const _0x180634=_0x541333;if(ConfigManager[_0x180634(0x5d1)]&&ConfigManager[_0x180634(0x292)]!==undefined){if(_0x180634(0x325)!==_0x180634(0x325)){const _0x314c44=_0x180634(0x3fb);if(this[_0x180634(0x212)][_0x314c44])return this[_0x180634(0x212)][_0x314c44];return this['canConsumeItem']()?_0x3b6a7c[_0x180634(0x1db)]['Settings'][_0x180634(0x510)][_0x180634(0x3af)]:_0x4dfb2d[_0x180634(0x1db)][_0x180634(0x522)]['StatusWindow'][_0x180634(0x3e6)];}else return ConfigManager[_0x180634(0x292)];}else{if(this[_0x180634(0x4ea)]())return this[_0x180634(0x3c7)]()[_0x180634(0x2a3)](/RIGHT/i);else Scene_MenuBase[_0x180634(0x5f1)]['isRightInputMode'][_0x180634(0x562)](this);}},Scene_Shop[_0x541333(0x5f1)]['updatedLayoutStyle']=function(){const _0x292b8e=_0x541333;return VisuMZ[_0x292b8e(0x1db)]['Settings']['ShopScene'][_0x292b8e(0x3e2)];},Scene_Shop[_0x541333(0x5f1)]['isUseModernControls']=function(){const _0x5372f9=_0x541333;return this[_0x5372f9(0x21e)]&&this[_0x5372f9(0x21e)][_0x5372f9(0x539)]();},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x4ea)]=function(){const _0x2b400d=_0x541333;return VisuMZ[_0x2b400d(0x1db)][_0x2b400d(0x522)][_0x2b400d(0x3c6)][_0x2b400d(0x28b)];},VisuMZ[_0x541333(0x1db)][_0x541333(0x2bd)]=Scene_Shop[_0x541333(0x5f1)]['prepare'],Scene_Shop[_0x541333(0x5f1)][_0x541333(0x257)]=function(_0xd5fc25,_0x4467fe){const _0x4efb3d=_0x541333;_0xd5fc25=JsonEx[_0x4efb3d(0x472)](_0xd5fc25),VisuMZ[_0x4efb3d(0x1db)]['Scene_Shop_prepare'][_0x4efb3d(0x562)](this,_0xd5fc25,_0x4467fe),this[_0x4efb3d(0x401)]();},Scene_Shop['prototype']['adjustHiddenShownGoods']=function(){const _0x55e598=_0x541333;this['_goodsCount']=0x0;for(const _0x3ef8e0 of this[_0x55e598(0x4b7)]){this[_0x55e598(0x4d5)](_0x3ef8e0)?_0x55e598(0x467)!=='EEnGS'?this['_goodsCount']++:(this[_0x55e598(0x42c)]=!![],this['_shopStatusMenuAlly']=_0x24512e):_0x3ef8e0[0x0]=-0x1;}},Scene_Shop[_0x541333(0x5f1)]['isGoodShown']=function(_0x48cbaf){const _0x197875=_0x541333;if(_0x48cbaf[0x0]>0x2||_0x48cbaf[0x0]<0x0)return![];const _0x1be9eb=[$dataItems,$dataWeapons,$dataArmors][_0x48cbaf[0x0]][_0x48cbaf[0x1]];if(!_0x1be9eb)return![];const _0x168692=_0x1be9eb[_0x197875(0x266)]||'';if(_0x168692[_0x197875(0x2a3)](/<SHOW SHOP[ ](?:SW|SWITCH|SWITCHES):[ ]*(\d+(?:\s*,\s*\d+)*)>/i)){const _0x5bf901=JSON[_0x197875(0x5f9)]('['+RegExp['$1'][_0x197875(0x2a3)](/\d+/g)+']');for(const _0x400196 of _0x5bf901){if(_0x197875(0x570)!=='hoPOu')this[_0x197875(0x5fc)](_0x2f13ba[_0x197875(0x2f6)](_0x197875(0x263)));else{if(!$gameSwitches[_0x197875(0x5e9)](_0x400196))return![];}}return!![];}if(_0x168692['match'](/<SHOW SHOP ALL[ ](?:SW|SWITCH|SWITCHES):[ ]*(\d+(?:\s*,\s*\d+)*)>/i)){const _0x156f72=JSON[_0x197875(0x5f9)]('['+RegExp['$1'][_0x197875(0x2a3)](/\d+/g)+']');for(const _0x4751e1 of _0x156f72){if(!$gameSwitches[_0x197875(0x5e9)](_0x4751e1))return![];}return!![];}if(_0x168692[_0x197875(0x2a3)](/<SHOW SHOP ANY[ ](?:SW|SWITCH|SWITCHES):[ ]*(\d+(?:\s*,\s*\d+)*)>/i)){const _0x45239e=JSON[_0x197875(0x5f9)]('['+RegExp['$1'][_0x197875(0x2a3)](/\d+/g)+']');for(const _0x48bcbf of _0x45239e){if(_0x197875(0x3c4)!==_0x197875(0x2a4)){if($gameSwitches['value'](_0x48bcbf))return!![];}else _0x2a2ba6+=_0x3043f0(_0x33c9ff['$1']);}return![];}if(_0x168692[_0x197875(0x2a3)](/<HIDE SHOP[ ](?:SW|SWITCH|SWITCHES):[ ]*(\d+(?:\s*,\s*\d+)*)>/i)){const _0x343e7b=JSON['parse']('['+RegExp['$1'][_0x197875(0x2a3)](/\d+/g)+']');for(const _0x2ea240 of _0x343e7b){if(!$gameSwitches[_0x197875(0x5e9)](_0x2ea240))return!![];}return![];}if(_0x168692[_0x197875(0x2a3)](/<HIDE SHOP ALL[ ](?:SW|SWITCH|SWITCHES):[ ]*(\d+(?:\s*,\s*\d+)*)>/i)){const _0x2ddd3f=JSON['parse']('['+RegExp['$1'][_0x197875(0x2a3)](/\d+/g)+']');for(const _0xa03703 of _0x2ddd3f){if(!$gameSwitches['value'](_0xa03703))return!![];}return![];}if(_0x168692[_0x197875(0x2a3)](/<HIDE SHOP ANY[ ](?:SW|SWITCH|SWITCHES):[ ]*(\d+(?:\s*,\s*\d+)*)>/i)){const _0x16b017=JSON[_0x197875(0x5f9)]('['+RegExp['$1'][_0x197875(0x2a3)](/\d+/g)+']');for(const _0x2db7dd of _0x16b017){if($gameSwitches[_0x197875(0x5e9)](_0x2db7dd))return![];}return!![];}return!![];},VisuMZ[_0x541333(0x1db)][_0x541333(0x4ec)]=Scene_Shop['prototype']['create'],Scene_Shop[_0x541333(0x5f1)][_0x541333(0x2b3)]=function(){const _0x532ddc=_0x541333;VisuMZ['ItemsEquipsCore'][_0x532ddc(0x4ec)][_0x532ddc(0x562)](this),this[_0x532ddc(0x4ea)]()&&this[_0x532ddc(0x1d3)](),this[_0x532ddc(0x272)]();},Scene_Shop['prototype'][_0x541333(0x1d3)]=function(){const _0x333027=_0x541333;this[_0x333027(0x1ba)]['hide'](),this[_0x333027(0x481)][_0x333027(0x496)](),this['_buyWindow'][_0x333027(0x5bf)](),this[_0x333027(0x1ee)][_0x333027(0x496)]();},VisuMZ['ItemsEquipsCore']['Scene_Shop_helpWindowRect']=Scene_Shop['prototype'][_0x541333(0x381)],Scene_Shop[_0x541333(0x5f1)][_0x541333(0x381)]=function(){const _0x10cd59=_0x541333;if(this[_0x10cd59(0x4ea)]()){if(_0x10cd59(0x51d)!==_0x10cd59(0x4d6))return this[_0x10cd59(0x3f8)]();else{if(this[_0x10cd59(0x3e3)]['changeBuff'][_0xbbae3f]!==0x0)this[_0x10cd59(0x3e3)][_0x10cd59(0x276)]=!![];}}else return VisuMZ['ItemsEquipsCore'][_0x10cd59(0x3f3)]['call'](this);},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x3f8)]=function(){const _0x4ac399=_0x541333,_0x3c20cf=0x0,_0x3c0253=this[_0x4ac399(0x2a2)](),_0x1b5499=Graphics[_0x4ac399(0x37c)],_0x16e9cd=this['helpAreaHeight']();return new Rectangle(_0x3c20cf,_0x3c0253,_0x1b5499,_0x16e9cd);},VisuMZ['ItemsEquipsCore']['Scene_Shop_goldWindowRect']=Scene_Shop[_0x541333(0x5f1)][_0x541333(0x2d7)],Scene_Shop[_0x541333(0x5f1)][_0x541333(0x2d7)]=function(){const _0x32586f=_0x541333;return this[_0x32586f(0x4ea)]()?'klVdE'===_0x32586f(0x41b)?this[_0x32586f(0x40c)]():_0x5b6b7f[_0x32586f(0x1db)][_0x32586f(0x522)]['StatusWindow']['ParamChangeFontSize']:VisuMZ[_0x32586f(0x1db)][_0x32586f(0x51b)]['call'](this);},Scene_Shop['prototype'][_0x541333(0x40c)]=function(){const _0x1ba01e=_0x541333,_0x1c0f49=this[_0x1ba01e(0x478)](),_0x2132fe=this[_0x1ba01e(0x5c9)](0x1,!![]),_0x12efa5=this[_0x1ba01e(0x434)]()?0x0:Graphics['boxWidth']-_0x1c0f49,_0x32a133=this[_0x1ba01e(0x1c0)]();return new Rectangle(_0x12efa5,_0x32a133,_0x1c0f49,_0x2132fe);},VisuMZ[_0x541333(0x1db)][_0x541333(0x1e6)]=Scene_Shop['prototype'][_0x541333(0x47b)],Scene_Shop[_0x541333(0x5f1)]['commandWindowRect']=function(){const _0x3fe33f=_0x541333;if(this[_0x3fe33f(0x4ea)]()){if(_0x3fe33f(0x468)!=='OuUdb')this['cursorLeft'](_0xe67ac9[_0x3fe33f(0x2f6)](_0x3fe33f(0x265)));else return this[_0x3fe33f(0x298)]();}else return VisuMZ['ItemsEquipsCore'][_0x3fe33f(0x1e6)][_0x3fe33f(0x562)](this);},Scene_Shop[_0x541333(0x5f1)]['commandWindowRectItemsEquipsCore']=function(){const _0x20350e=_0x541333,_0x361922=this[_0x20350e(0x434)]()?this[_0x20350e(0x478)]():0x0,_0x140549=this['mainAreaTop'](),_0x310c0c=Graphics['boxWidth']-this[_0x20350e(0x478)](),_0x498e1f=this['calcWindowHeight'](0x1,!![]);return new Rectangle(_0x361922,_0x140549,_0x310c0c,_0x498e1f);},VisuMZ[_0x541333(0x1db)][_0x541333(0x1ec)]=Scene_Shop['prototype'][_0x541333(0x1fc)],Scene_Shop['prototype'][_0x541333(0x1fc)]=function(){const _0x401bde=_0x541333;return this['isUseItemsEquipsCoreUpdatedLayout']()?this[_0x401bde(0x56c)]():VisuMZ[_0x401bde(0x1db)][_0x401bde(0x1ec)]['call'](this);},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x56c)]=function(){const _0x24e9f2=_0x541333,_0x5db19b=this[_0x24e9f2(0x3b3)]['y']+this[_0x24e9f2(0x3b3)][_0x24e9f2(0x242)],_0x48cfa1=Graphics[_0x24e9f2(0x37c)]-this['statusWidth'](),_0x22a17d=this[_0x24e9f2(0x434)]()?Graphics[_0x24e9f2(0x37c)]-_0x48cfa1:0x0,_0x54d26e=this[_0x24e9f2(0x326)]()-this['_commandWindow']['height'];return new Rectangle(_0x22a17d,_0x5db19b,_0x48cfa1,_0x54d26e);},VisuMZ[_0x541333(0x1db)][_0x541333(0x34c)]=Scene_Shop[_0x541333(0x5f1)]['statusWindowRect'],Scene_Shop[_0x541333(0x5f1)][_0x541333(0x1bb)]=function(){const _0x2434d2=_0x541333;return this[_0x2434d2(0x4ea)]()?this[_0x2434d2(0x45a)]():_0x2434d2(0x239)!==_0x2434d2(0x3ec)?VisuMZ['ItemsEquipsCore'][_0x2434d2(0x34c)]['call'](this):!![];},Scene_Shop[_0x541333(0x5f1)]['statusWindowRectItemsEquipsCore']=function(){const _0x4044fc=_0x541333,_0x3bf9a0=this[_0x4044fc(0x51c)](),_0x2cf374=this['mainAreaHeight']()-this['_commandWindow']['height'],_0x4fb43c=this['isRightInputMode']()?0x0:Graphics[_0x4044fc(0x37c)]-_0x3bf9a0,_0x498c2c=this[_0x4044fc(0x3b3)]['y']+this['_commandWindow']['height'];return new Rectangle(_0x4fb43c,_0x498c2c,_0x3bf9a0,_0x2cf374);},VisuMZ[_0x541333(0x1db)][_0x541333(0x505)]=Scene_Shop[_0x541333(0x5f1)][_0x541333(0x30f)],Scene_Shop[_0x541333(0x5f1)]['buyWindowRect']=function(){const _0x488026=_0x541333;if(this['isUseItemsEquipsCoreUpdatedLayout']()){if(_0x488026(0x2ef)!==_0x488026(0x2ef))_0x121b4f[_0x488026(0x4fc)](_0x488026(0x228))&&this[_0x488026(0x543)]()?this[_0x488026(0x1c2)]():this[_0x488026(0x2dd)](_0x3f70d0[_0x488026(0x2f6)]('down'));else return this['buyWindowRectItemsEquipsCore']();}else{if(_0x488026(0x354)===_0x488026(0x35f)){const _0x4538d0=_0xc5289b[_0x488026(0x3f7)](this[_0x488026(0x4bb)][_0x488026(0x205)]());_0x4538d0['addLoadListener'](this[_0x488026(0x459)][_0x488026(0x517)](this));}else return VisuMZ[_0x488026(0x1db)][_0x488026(0x505)][_0x488026(0x562)](this);}},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x4ce)]=function(){const _0x5e1733=_0x541333,_0x113716=this[_0x5e1733(0x3b3)]['y']+this[_0x5e1733(0x3b3)][_0x5e1733(0x242)],_0x5e4d88=Graphics[_0x5e1733(0x37c)]-this[_0x5e1733(0x51c)](),_0x5a8492=this[_0x5e1733(0x326)]()-this[_0x5e1733(0x3b3)][_0x5e1733(0x242)],_0x48e9e0=this[_0x5e1733(0x434)]()?Graphics['boxWidth']-_0x5e4d88:0x0;return new Rectangle(_0x48e9e0,_0x113716,_0x5e4d88,_0x5a8492);},VisuMZ[_0x541333(0x1db)][_0x541333(0x1c3)]=Scene_Shop[_0x541333(0x5f1)][_0x541333(0x44d)],Scene_Shop['prototype'][_0x541333(0x44d)]=function(){const _0x820851=_0x541333;VisuMZ[_0x820851(0x1db)][_0x820851(0x1c3)][_0x820851(0x562)](this),this['isUseModernControls']()&&this[_0x820851(0x5f2)]();},VisuMZ[_0x541333(0x1db)]['Scene_Shop_categoryWindowRect']=Scene_Shop[_0x541333(0x5f1)][_0x541333(0x5bd)],Scene_Shop[_0x541333(0x5f1)][_0x541333(0x5bd)]=function(){const _0x1440e9=_0x541333;if(this['isUseItemsEquipsCoreUpdatedLayout']()){if(_0x1440e9(0x565)!==_0x1440e9(0x565)){if(this['buttonAssistSlotWindowShift']())return _0x5539a1['ItemsEquipsCore']['Settings']['EquipScene'][_0x1440e9(0x5c8)];return _0x2a7d77[_0x1440e9(0x5f1)][_0x1440e9(0x323)][_0x1440e9(0x562)](this);}else return this[_0x1440e9(0x588)]();}else{if(_0x1440e9(0x58c)!=='rAOKW')_0x538862=0x0;else return VisuMZ[_0x1440e9(0x1db)]['Scene_Shop_categoryWindowRect'][_0x1440e9(0x562)](this);}},Scene_Shop['prototype'][_0x541333(0x588)]=function(){const _0x53ad04=_0x541333,_0x4745a6=this[_0x53ad04(0x3b3)]['y'],_0x3f5d74=this['_commandWindow'][_0x53ad04(0x5bc)],_0x442719=this[_0x53ad04(0x5c9)](0x1,!![]),_0x2cb066=this[_0x53ad04(0x434)]()?Graphics[_0x53ad04(0x37c)]-_0x3f5d74:0x0;return new Rectangle(_0x2cb066,_0x4745a6,_0x3f5d74,_0x442719);},Scene_Shop['prototype'][_0x541333(0x5f2)]=function(){const _0x5a79b1=_0x541333;delete this[_0x5a79b1(0x21e)]['_handlers']['ok'],delete this[_0x5a79b1(0x21e)]['_handlers'][_0x5a79b1(0x3aa)];},VisuMZ[_0x541333(0x1db)][_0x541333(0x506)]=Scene_Shop[_0x541333(0x5f1)][_0x541333(0x291)],Scene_Shop[_0x541333(0x5f1)]['createSellWindow']=function(){const _0x2eb990=_0x541333;VisuMZ[_0x2eb990(0x1db)][_0x2eb990(0x506)][_0x2eb990(0x562)](this);if(this[_0x2eb990(0x4ea)]()){if(_0x2eb990(0x30b)!=='ugwGb')this[_0x2eb990(0x318)]();else{const _0x32046e=this['commandWindowRect'](),_0xc6740c=this[_0x2eb990(0x434)]()?this[_0x2eb990(0x51c)]():0x0,_0x285707=_0x32046e['y']+_0x32046e[_0x2eb990(0x242)],_0x2a39a0=_0x31994f['boxWidth']-this['statusWidth'](),_0x292d4c=this[_0x2eb990(0x326)]()-_0x32046e[_0x2eb990(0x242)];return new _0x29d28c(_0xc6740c,_0x285707,_0x2a39a0,_0x292d4c);}}},VisuMZ[_0x541333(0x1db)][_0x541333(0x2ae)]=Scene_Shop['prototype']['sellWindowRect'],Scene_Shop['prototype'][_0x541333(0x5b1)]=function(){const _0x17e682=_0x541333;if(this[_0x17e682(0x4ea)]()){if('RRDaP'!=='RRDaP'){const _0x320091=_0x53bc4a+_0x2e68c9+_0x133936*_0x141eac;this[_0x17e682(0x28c)](_0x320091,_0x17bc14,_0x522b40,_0x312c60-_0x28cc9f);}else return this[_0x17e682(0x1f4)]();}else return VisuMZ[_0x17e682(0x1db)][_0x17e682(0x2ae)][_0x17e682(0x562)](this);},Scene_Shop['prototype']['sellWindowRectItemsEquipsCore']=function(){const _0x37f7bb=_0x541333,_0x1a96e2=this[_0x37f7bb(0x21e)]['y']+this[_0x37f7bb(0x21e)][_0x37f7bb(0x242)],_0x54262a=Graphics[_0x37f7bb(0x37c)]-this['statusWidth'](),_0x378976=this['mainAreaHeight']()-this[_0x37f7bb(0x21e)][_0x37f7bb(0x242)],_0xe49488=this[_0x37f7bb(0x434)]()?Graphics['boxWidth']-_0x54262a:0x0;return new Rectangle(_0xe49488,_0x1a96e2,_0x54262a,_0x378976);},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x318)]=function(){const _0x21b53c=_0x541333;this[_0x21b53c(0x1cf)][_0x21b53c(0x3bc)](this[_0x21b53c(0x1ee)]);},Scene_Shop['prototype'][_0x541333(0x51c)]=function(){const _0x448c3d=_0x541333;return VisuMZ[_0x448c3d(0x1db)][_0x448c3d(0x522)][_0x448c3d(0x510)]['Width'];},VisuMZ[_0x541333(0x1db)][_0x541333(0x4f1)]=Scene_Shop[_0x541333(0x5f1)]['activateSellWindow'],Scene_Shop[_0x541333(0x5f1)]['activateSellWindow']=function(){const _0x4f019b=_0x541333;VisuMZ[_0x4f019b(0x1db)]['Scene_Shop_activateSellWindow'][_0x4f019b(0x562)](this);if(this[_0x4f019b(0x4ea)]()){if(_0x4f019b(0x25a)===_0x4f019b(0x359)){if(_0x2fdb45===_0x27a768)return;if(_0x7ee2d5[_0x4f019b(0x266)][_0x4f019b(0x2a3)](/<JS PARAMETERS>\s*([\s\S]*)\s*<\/JS PARAMETERS>/i)){const _0x3aa8f9=_0x36d6e2(_0x5ec359['$1']),_0x516d0b=(_0x4a86e5===_0x127d3f?_0x4f019b(0x370):'A%1')[_0x4f019b(0x52b)](_0x3c363f['id']),_0x18726e=_0x4f019b(0x303)[_0x4f019b(0x52b)](_0x3aa8f9);for(let _0x594d62=0x0;_0x594d62<0x8;_0x594d62++){if(_0x3aa8f9['match'](_0x219db8[_0x4f019b(0x1db)][_0x4f019b(0x4e6)][_0x4f019b(0x4c9)][_0x594d62])){const _0x3a349b=_0x4f019b(0x415)[_0x4f019b(0x52b)](_0x516d0b,_0x594d62);_0x2da61e[_0x4f019b(0x1db)][_0x4f019b(0x4ae)][_0x3a349b]=new _0x46abd4(_0x4f019b(0x37a),_0x4f019b(0x587),_0x18726e);}}}}else this['_statusWindow'][_0x4f019b(0x496)]();}this[_0x4f019b(0x1cf)]['updateHelp']();},VisuMZ['ItemsEquipsCore'][_0x541333(0x39c)]=Scene_Shop[_0x541333(0x5f1)][_0x541333(0x29d)],Scene_Shop[_0x541333(0x5f1)][_0x541333(0x29d)]=function(){const _0x2f9af1=_0x541333;VisuMZ[_0x2f9af1(0x1db)][_0x2f9af1(0x39c)][_0x2f9af1(0x562)](this);if(this['isUseItemsEquipsCoreUpdatedLayout']()){if('QORly'!==_0x2f9af1(0x3fd)){const _0x50ef32=this[_0x2f9af1(0x4f3)](_0x9d0a51);if(_0x50ef32[_0x2f9af1(0x2a3)](/\\I\[(\d+)\]/i)){const _0x4f87b8=_0x3bac4a(_0x499d33['$1'])||0x0,_0x2a0bb0=this[_0x2f9af1(0x347)](_0xbb8466),_0x1402df=_0x2a0bb0['x']+_0x5c4d58['floor']((_0x2a0bb0[_0x2f9af1(0x5bc)]-_0x23f19b[_0x2f9af1(0x5d8)])/0x2),_0x339279=_0x2a0bb0['y']+(_0x2a0bb0[_0x2f9af1(0x242)]-_0x409e77[_0x2f9af1(0x233)])/0x2;this[_0x2f9af1(0x3e7)](_0x4f87b8,_0x1402df,_0x339279);}}else this[_0x2f9af1(0x2e5)]();}},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x2e5)]=function(){const _0xd90597=_0x541333;this[_0xd90597(0x353)]=this['_buyWindowLastIndex']||0x0,this[_0xd90597(0x481)][_0xd90597(0x43f)](this[_0xd90597(0x353)]);},VisuMZ['ItemsEquipsCore'][_0x541333(0x601)]=Scene_Shop[_0x541333(0x5f1)]['commandSell'],Scene_Shop[_0x541333(0x5f1)][_0x541333(0x50b)]=function(){const _0x15d9af=_0x541333;VisuMZ[_0x15d9af(0x1db)][_0x15d9af(0x601)][_0x15d9af(0x562)](this),this['isUseItemsEquipsCoreUpdatedLayout']()&&this[_0x15d9af(0x46c)](),this[_0x15d9af(0x539)]()&&(this[_0x15d9af(0x21e)]['smoothSelect'](0x0),this['onCategoryOk']());},Scene_Shop[_0x541333(0x5f1)]['commandSellItemsEquipsCore']=function(){const _0xf9061d=_0x541333;this['_buyWindow'][_0xf9061d(0x285)](),this['_commandWindow'][_0xf9061d(0x285)]();},VisuMZ[_0x541333(0x1db)][_0x541333(0x2e9)]=Scene_Shop['prototype'][_0x541333(0x43a)],Scene_Shop[_0x541333(0x5f1)][_0x541333(0x43a)]=function(){const _0x797834=_0x541333;VisuMZ[_0x797834(0x1db)][_0x797834(0x2e9)]['call'](this);if(this[_0x797834(0x4ea)]()){if(_0x797834(0x371)!==_0x797834(0x371)){if(this[_0x797834(0x567)][_0x797834(0x266)][_0x797834(0x2a3)](/<CUSTOM STATUS INFO>\s*([\s\S]*)\s*<\/CUSTOM STATUS INFO>/i)){const _0x5e5110=_0x399e2c(_0x367ecf['$1'])['split'](/[\r\n]+/);for(const _0x343b1e of _0x5e5110){if(_0x343b1e[_0x797834(0x2a3)](/(.*):[ ](.*)/i)){const _0x3cd2af=_0x22248e(_0x7086f2['$1'])[_0x797834(0x399)](),_0x555d02=_0x2244cf(_0x3ad8e9['$2'])[_0x797834(0x399)]();this[_0x797834(0x423)](_0x3cd2af,_0x555d02,_0x447907,_0x504b0c,_0xa34051),_0x26d724+=this[_0x797834(0x3da)]();}}}return this[_0x797834(0x33e)](),_0x12dbcb;}else this[_0x797834(0x305)]();}},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x305)]=function(){const _0x27bb84=_0x541333;this[_0x27bb84(0x353)]=this[_0x27bb84(0x481)][_0x27bb84(0x593)](),this['_buyWindow'][_0x27bb84(0x496)](),this[_0x27bb84(0x481)][_0x27bb84(0x5bf)](),this[_0x27bb84(0x481)][_0x27bb84(0x55d)](0x0,0x0),this[_0x27bb84(0x1ee)][_0x27bb84(0x496)](),this[_0x27bb84(0x1ba)][_0x27bb84(0x285)]();},VisuMZ[_0x541333(0x1db)][_0x541333(0x270)]=Scene_Shop[_0x541333(0x5f1)][_0x541333(0x30a)],Scene_Shop[_0x541333(0x5f1)][_0x541333(0x30a)]=function(){const _0x2c1ecc=_0x541333;VisuMZ[_0x2c1ecc(0x1db)][_0x2c1ecc(0x270)][_0x2c1ecc(0x562)](this),this[_0x2c1ecc(0x4ea)]()&&this[_0x2c1ecc(0x25e)]();},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x25e)]=function(){const _0x532298=_0x541333;this['_buyWindow'][_0x532298(0x496)](),this['_commandWindow'][_0x532298(0x496)]();},VisuMZ[_0x541333(0x1db)][_0x541333(0x2cd)]=Scene_Shop['prototype'][_0x541333(0x56e)],Scene_Shop[_0x541333(0x5f1)][_0x541333(0x56e)]=function(){const _0x545fa3=_0x541333;VisuMZ[_0x545fa3(0x1db)][_0x545fa3(0x2cd)]['call'](this);if(this[_0x545fa3(0x4ea)]()){if(_0x545fa3(0x32c)===_0x545fa3(0x32c))this[_0x545fa3(0x4b1)]();else{if(_0x2aa420[_0x545fa3(0x3c3)](_0x38be10))return _0x1a88a0[_0x545fa3(0x498)];return!![];}}},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x4b1)]=function(){const _0xf3077a=_0x541333;this[_0xf3077a(0x21e)]['show']();},VisuMZ[_0x541333(0x1db)][_0x541333(0x5ee)]=Scene_Shop[_0x541333(0x5f1)]['onSellCancel'],Scene_Shop['prototype'][_0x541333(0x57a)]=function(){const _0x3ea146=_0x541333;VisuMZ['ItemsEquipsCore']['Scene_Shop_onSellCancel']['call'](this),this[_0x3ea146(0x539)]()&&(_0x3ea146(0x1bd)==='yoBzF'?(_0x53c346[_0x3ea146(0x1db)]['Scene_Shop_onSellOk'][_0x3ea146(0x562)](this),this[_0x3ea146(0x4ea)]()&&this[_0x3ea146(0x4b1)]()):this[_0x3ea146(0x30a)]()),this[_0x3ea146(0x4ea)]()&&this['_dummyWindow'][_0x3ea146(0x285)]();},VisuMZ['ItemsEquipsCore'][_0x541333(0x391)]=Scene_Shop['prototype'][_0x541333(0x27a)],Scene_Shop['prototype'][_0x541333(0x27a)]=function(){const _0xef2078=_0x541333;let _0x27b8b7=this[_0xef2078(0x3bd)]();const _0x2c0080=this[_0xef2078(0x567)];return _0x27b8b7=VisuMZ['ItemsEquipsCore'][_0xef2078(0x522)][_0xef2078(0x3c6)][_0xef2078(0x507)][_0xef2078(0x562)](this,_0x2c0080,_0x27b8b7),_0x27b8b7;},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x3bd)]=function(){const _0x3288f8=_0x541333;let _0x5f085c=this[_0x3288f8(0x567)]['price'];if(!this[_0x3288f8(0x567)])return 0x0;else{if(this[_0x3288f8(0x567)]['note']['match'](/<JS SELL PRICE>\s*([\s\S]*)\s*<\/JS SELL PRICE>/i)){const _0x24e149=String(RegExp['$1']);let _0x972aa8=this['_item'],_0x264309=_0x5f085c*this[_0x3288f8(0x54c)]();try{eval(_0x24e149);}catch(_0xb72f0f){if(_0x3288f8(0x45f)===_0x3288f8(0x45f)){if($gameTemp[_0x3288f8(0x5fb)]())console[_0x3288f8(0x3ea)](_0xb72f0f);}else _0x4dec93[_0x3288f8(0x5f1)][_0x3288f8(0x51e)]['call'](this),this['callUpdateHelp']();}if(isNaN(_0x264309))_0x264309=0x0;return Math['floor'](_0x264309);}else return this['_item'][_0x3288f8(0x266)][_0x3288f8(0x2a3)](/<SELL PRICE:[ ](\d+)>/i)?_0x3288f8(0x5b2)!==_0x3288f8(0x39a)?parseInt(RegExp['$1']):this[_0x3288f8(0x3c7)]()[_0x3288f8(0x2a3)](/RIGHT/i):Math[_0x3288f8(0x254)](this[_0x3288f8(0x4c5)]());}},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x4c5)]=function(){const _0x49973a=_0x541333;return this[_0x49973a(0x567)]['price']*this[_0x49973a(0x54c)]();},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x54c)]=function(){const _0x5fd0e2=_0x541333;return VisuMZ[_0x5fd0e2(0x1db)][_0x5fd0e2(0x522)][_0x5fd0e2(0x3c6)][_0x5fd0e2(0x2c0)];},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x2e2)]=function(){const _0x577f87=_0x541333;if(!this['updatedLayoutStyle']())return![];if(!this[_0x577f87(0x539)]())return![];if(!this[_0x577f87(0x1cf)])return![];if(!this[_0x577f87(0x1cf)][_0x577f87(0x566)])return![];return this[_0x577f87(0x3c7)]()&&this[_0x577f87(0x539)]();},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x19d)]=function(){const _0x10044b=_0x541333;if(this[_0x10044b(0x2e2)]())return this[_0x10044b(0x1cf)][_0x10044b(0x4c6)]()===0x1?TextManager[_0x10044b(0x317)]('left',_0x10044b(0x263)):TextManager[_0x10044b(0x317)](_0x10044b(0x2af),'pagedown');else{if(this[_0x10044b(0x54a)]&&this[_0x10044b(0x54a)]['active']){if(_0x10044b(0x477)===_0x10044b(0x477))return TextManager['getInputMultiButtonStrings'](_0x10044b(0x265),_0x10044b(0x263));else{if(_0x585801['uiMenuStyle']&&_0xcc9d18['uiHelpPosition']!==_0x504e96)return _0xf51ba3[_0x10044b(0x4b3)];else{if(this[_0x10044b(0x4ea)]())return this['updatedLayoutStyle']()[_0x10044b(0x2a3)](/LOWER/i);else _0x4e025a[_0x10044b(0x5f1)][_0x10044b(0x434)][_0x10044b(0x562)](this);}}}}return Scene_MenuBase[_0x10044b(0x5f1)][_0x10044b(0x19d)][_0x10044b(0x562)](this);},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x579)]=function(){const _0x52631e=_0x541333;if(this[_0x52631e(0x54a)]&&this[_0x52631e(0x54a)]['active'])return'Ktjft'===_0x52631e(0x598)?TextManager['getInputMultiButtonStrings']('up',_0x52631e(0x5ab)):_0x125405['ItemsEquipsCore'][_0x52631e(0x522)][_0x52631e(0x2f1)]['TextAlign'];return Scene_MenuBase[_0x52631e(0x5f1)][_0x52631e(0x579)][_0x52631e(0x562)](this);},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x22c)]=function(){const _0xba73e6=_0x541333;if(this[_0xba73e6(0x2e2)]()){if(_0xba73e6(0x45e)==='eSnzT')return VisuMZ['ItemsEquipsCore'][_0xba73e6(0x522)][_0xba73e6(0x394)][_0xba73e6(0x544)];else{const _0x4394bd=_0x5937b5[_0xba73e6(0x1e7)];this['drawItemKeyData'](_0x4394bd,_0x19ace2,_0x2f2f9c,_0x2a7948,!![]);const _0x5ea332=this[_0xba73e6(0x26f)]();this['drawItemKeyData'](_0x5ea332,_0x31e013,_0x35906f,_0x41632f,![],_0xba73e6(0x263));}}else{if(this[_0xba73e6(0x54a)]&&this['_numberWindow'][_0xba73e6(0x566)])return VisuMZ['ItemsEquipsCore']['Settings'][_0xba73e6(0x3c6)]['buttonAssistSmallIncrement'];}return Scene_MenuBase[_0xba73e6(0x5f1)][_0xba73e6(0x22c)][_0xba73e6(0x562)](this);},Scene_Shop[_0x541333(0x5f1)][_0x541333(0x3d6)]=function(){const _0x2f872a=_0x541333;if(this[_0x2f872a(0x54a)]&&this[_0x2f872a(0x54a)][_0x2f872a(0x566)]){if('jXWpU'==='gCEox'){const _0x4ec7ff=_0x4ad3de['iconWidth'],_0x59c93d=_0x5e2d3f['iconHeight'];this[_0x2f872a(0x350)]=new _0x6fd6be(_0x4ec7ff,_0x59c93d),this[_0x2f872a(0x3d3)](),this[_0x2f872a(0x2fa)]();}else return VisuMZ['ItemsEquipsCore']['Settings'][_0x2f872a(0x3c6)][_0x2f872a(0x42f)];}return Scene_MenuBase['prototype']['buttonAssistText2'][_0x2f872a(0x562)](this);},Scene_Shop['prototype']['resetShopSwitches']=function(){const _0x4bba2d=_0x541333;if(!SceneManager[_0x4bba2d(0x55c)]())return;const _0xc3f9ac=VisuMZ['ItemsEquipsCore'][_0x4bba2d(0x522)][_0x4bba2d(0x3c6)];if(_0xc3f9ac[_0x4bba2d(0x38f)]){if(_0x4bba2d(0x328)!==_0x4bba2d(0x328)){if(!_0x14eb84['value'](_0x172c5f))return![];}else $gameSwitches['setValue'](_0xc3f9ac[_0x4bba2d(0x38f)],![]);}if(_0xc3f9ac[_0x4bba2d(0x1ff)]){if(_0x4bba2d(0x252)===_0x4bba2d(0x1d5)){const _0x459b1f=_0x32239f[_0x4bba2d(0x1db)][_0x4bba2d(0x522)]['EquipScene'];return _0x459b1f[_0x4bba2d(0x37e)]||_0x459b1f[_0x4bba2d(0x513)];}else $gameSwitches[_0x4bba2d(0x32b)](_0xc3f9ac[_0x4bba2d(0x1ff)],![]);}},VisuMZ[_0x541333(0x1db)][_0x541333(0x59b)]=Scene_Shop[_0x541333(0x5f1)]['doBuy'],Scene_Shop[_0x541333(0x5f1)][_0x541333(0x308)]=function(_0x21faba){const _0x348c89=_0x541333;VisuMZ['ItemsEquipsCore'][_0x348c89(0x59b)]['call'](this,_0x21faba);if(_0x21faba<=0x0)return;const _0x37a50e=VisuMZ[_0x348c89(0x1db)]['Settings'][_0x348c89(0x3c6)];if(_0x37a50e[_0x348c89(0x38f)]){if('XGMqT'==='IzbSH')return _0x348c89(0x454);else $gameSwitches[_0x348c89(0x32b)](_0x37a50e[_0x348c89(0x38f)],!![]);}},VisuMZ['ItemsEquipsCore'][_0x541333(0x3ee)]=Scene_Shop[_0x541333(0x5f1)][_0x541333(0x56d)],Scene_Shop[_0x541333(0x5f1)][_0x541333(0x56d)]=function(_0x54b6b0){const _0x14cccf=_0x541333;VisuMZ[_0x14cccf(0x1db)][_0x14cccf(0x3ee)]['call'](this,_0x54b6b0);if(_0x54b6b0<=0x0)return;const _0x54e502=VisuMZ[_0x14cccf(0x1db)]['Settings'][_0x14cccf(0x3c6)];_0x54e502['SwitchBuy']&&$gameSwitches[_0x14cccf(0x32b)](_0x54e502[_0x14cccf(0x1ff)],!![]);};function Sprite_NewLabel(){const _0xf3a93f=_0x541333;this[_0xf3a93f(0x45c)](...arguments);}function _0x4480(){const _0x51dfbd=['kIfMi','NVsgw','uDTEb','ZwTTP','QgPNt','SCOPE','center','PobBS','_shopStatusMenuMode','armorTypes','activateItemWindow','buttonAssistLargeIncrement','ARRAYEVAL','ELEMENT','addOptimizeCommand','nonRemovableEtypes','isRightInputMode','\x5cI[%1]%2','ParseAllNotetags','getItemEffectsSelfTpGainText','\x5cI[%1]','gOjOy','onBuyCancel','wVIYv','Slots','AllWeapons','processCursorMove','smoothSelect','hxjfc','isSellCommandEnabled','discardEquip','opacity','code','categoryNameWindowCenter','ItemSceneAdjustItemList','rnWVo','itemWindowRectItemsEquipsCore','Scene_Equip_onSlotOk','buttonAssistSlotWindowShift','LabelRemove','_commandNameWindow','createCategoryWindow','Style','update','allowCommandWindowCursorUp','LabelRecoverTP','setNewItem','yGOnX','iconText','addSellCommand','clear','registerCommand','_slotId','onMenuImageLoad','statusWindowRectItemsEquipsCore','isRepeated','initialize','isShowNew','eSnzT','ZEbgO','getItemEffectsHpRecoveryLabel','removeDebuff','FieldUsable','Scene_Equip_helpWindowRect','addWindow','processShiftRemoveShortcut','Window_ShopBuy_price','fOmfM','OuUdb','getTextColor','WDjJo','_doubleTouch','commandSellItemsEquipsCore','hXPRr','addInnerChild','xcAgx','drawItemEffectsTpRecovery','_newLabelOpacity','makeDeepCopy','MenuPortraits','qOZSZ','cpOwO','SZSMl','LByQr','mainCommandWidth','setMp','oMTyI','commandWindowRect','HwPgC','Parse_Notetags_Category','gTxTm','getItemEffectsSelfTpGainLabel','FadeLimit','_buyWindow','Xlysf','2007qnvVqm','scope','repeats','weaponTypes','newLabelEnabled','drawEquipData','members','deactivate','LabelRepeats','setShopStatusWindowMode','CmdHideDisabled','battleMembers','4718pGiMpY','lMFFC','UWnEB','getItemEffectsTpRecoveryLabel','KeyItems','ParseWeaponNotetags','icon','show','JrPWa','optKeyItemsNumber','forceResetEquipSlots','Scope%1','ShowShopStatus','drawItemEffectsMpDamage','invKQ','ZVowr','keyItem','getItemEffectsMpRecoveryLabel','processHandling','clearNewLabelFromItem','OOvhS','drawItemCustomEntries','gDCNj','ZmJQb','ADDED\x20EFFECTS','meetsItemConditionsJS','NkcJu','JOlxQ','LUK','ConvertParams','\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20let\x20enabled\x20=\x20true;\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20const\x20user\x20=\x20this;\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20const\x20target\x20=\x20this;\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20const\x20a\x20=\x20this;\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20const\x20b\x20=\x20this;\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20try\x20{\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20%1\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20}\x20catch\x20(e)\x20{\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20if\x20($gameTemp.isPlaytest())\x20console.log(e);\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20}\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20return\x20enabled;\x0a\x20\x20\x20\x20\x20\x20\x20\x20','paramJS','ItemQuantityFmt','resetTextColor','onSellOkItemsEquipsCore','drawItemKeyData','uiHelpPosition','changeEquipById','getItemDamageElementLabel','translucentOpacity','_goods','pagedown','top','getItemEffectsTpRecoveryText','_actor','Window_Selectable_refresh','MultiplierStandard','PbySw','inpwp','Parse_Notetags_ParamJS','occasion','buffIconIndex','createStatusWindow','Scene_Item_createItemWindow','baseSellingPrice','maxCols','BatchShop','getItemRepeatsText','BorderRegExp','sell','EaAKH','isClearCommandEnabled','gaugeLineHeight','buyWindowRectItemsEquipsCore','getItemHitTypeText','drawItemNumber','iQDEh','CmdIconClear','object','ParamValueFontSize','isGoodShown','vIyKl','Step2Start','EGnjZ','jPMWb','Scene_Equip_commandWindowRect','Scene_Equip_commandEquip','zKmoK','Game_Actor_changeEquip','getItemDamageElementText','isOpenAndActive','NonRemoveETypes','sfIxQ','makeCommandList','addCancelCommand','paramValueByName','textWidth','RegExp','NnhWH','xlJrP','NUM','isUseItemsEquipsCoreUpdatedLayout','nOaXD','Scene_Shop_create','Scene_Equip_createSlotWindow','isEquipCommandEnabled','makeItemData','Type','Scene_Shop_activateSellWindow','paramPlusItemsEquipsCoreCustomJS','commandName','ceil','RenAq','getNextAvailableEtypeId','EEOGa','initNewItemsList','processTouchModernControls','middle','MZofK','isPressed','onTouchSelectModern','Window_ItemCategory_initialize','xkRKm','EFFECT_RECOVER_MP','ParamChangeFontSize','DrawPortraitJS','CcMWM','EFFECT_ADD_STATE','Scene_Shop_buyWindowRect','Scene_Shop_createSellWindow','SellPriceJS','getItemEffectsTpDamageText','value2','LabelApply','commandSell','CmdStyle','setItemWindow','dataId','hEVos','StatusWindow','refreshCursor','bMKqa','CommandAddClear','clamp','+%1','CannotEquipMarker','bind','getItemEffectsRemovedStatesBuffsLabel','ayywf','EVAL','Scene_Shop_goldWindowRect','statusWidth','QTHLI','activate','IZval','drawItemScope','IPxhG','Settings','description','NBORR','indexOf','_slotWindow','isUseParamNamesWithIcons','loadSystem','_shopStatusMenuAlly','process_VisuMZ_ItemsEquipsCore_Notetags','format','max','mainFontSize','RVwCi','yuncH','Step1Start','Scene_ItemBase_activateItemWindow','getItemSuccessRateText','placeItemNewLabel','updateCommandNameWindow','contentsBack','prepareNextScene','PbRXG','isOptimizeCommandEnabled','isUseModernControls','BackRectColor','getItemDamageAmountLabel','includes','VisuMZ_1_BattleCore','mainAreaBottom','TextAlign','_forcedSlots','qaLDh','canShiftRemoveEquipment','allowShiftScrolling','buttonAssistCategory','equip2','currencyUnit','category','nonOptimizeEtypes','windowPadding','_numberWindow','onTouchSelect','sellPriceRate','isBattleTest','setTopRow','OffsetY','getItemDamageAmountTextOriginal','Parse_Notetags_ParamValues','nextActor','Scene_Equip_slotWindowRect','cHVNW','allowCreateStatusWindow','ListWindowCols','FontColor','QgYAs','6162709CMZepl','FadeSpeed','Step2End','isSceneShop','smoothScrollTo','MP\x20DAMAGE','nliwc','drawItemEffectsHpRecovery','ChQJu','call','FaayZ','pop','ktPsX','active','_item','categoryNameWindowDrawText','WcrzP','xfpDj','geUpdatedLayoutStatusWidth','numberWindowRectItemsEquipsCore','doSell','onSellOk','A%1','hoPOu','XceRI','getItemOccasionText','EquipParams','maxItems','refreshItemsEquipsCoreNoMenuImage','releaseUnequippableItems','isItem','vuNWR','buttonAssistKey2','onSellCancel','itemDataFontSize','Blacklist','EFFECT_GAIN_TP','drawItemConsumable','Scene_Item_createCategoryWindow','updateChangedSlots','EFFECT_REMOVE_DEBUFF','addChild','currentExt','isDrawItemNumber','Step3End','onSlotOk','paramId','categoryWindowRectItemsEquipsCore','placeNewLabel','toUpperCase','onActorChange','rAOKW','versionId','YOTBi','isBuyCommandEnabled','New','100%','item-%1','index','Nonconsumable','Scene_Item_categoryWindowRect','DxCcb','auto','Ktjft','toLowerCase','_tempActor','Scene_Shop_doBuy','checkShiftRemoveShortcut','Step3Start','mpRate','EquipScene','mhp','fontSize','onTouchSelectModernControls','defaultItemMax','getItemColor','Damage\x20Formula\x20Error\x20for\x20%1','_category','JSpfh','commandEquip','EFFECT_ADD_DEBUFF','DrawParamJS','down','sbKyI','drawRemoveItem','AllItems','kiFKg','urrjd','sellWindowRect','qYMQC','XTFbW','categoryStyle','EPYQj','currentSymbol','vdLvF','NstCr','QklCe','drawParamText','yaFro','width','categoryWindowRect','MANUAL','deselect','isCancelled','efjOw','yfVMQ','PurchaseOnly','fill','isPageChangeRequested','itemAt','canUse','buttonAssistRemove','calcWindowHeight','fBZuG','textColor','iLDMd','isHandled','drawItemStyleIconText','LabelDamageMP','ScopeRandomEnemies','uiMenuStyle','drawItemCost','getItemDamageAmountLabelBattleCore','Game_Actor_paramPlus','Param','modifiedBuyPriceItemsEquipsCore','prepareNewEquipSlotsOnLoad','iconWidth','limitedPageUpDownSceneCheck','CmdIconCancel','constructor','Text','QnpUB','IssEt','ZVdbr','onDatabaseLoaded','setTempActor','_newLabelOpacityChange','getItemRepeatsLabel','Window_EquipCommand_initialize','setHandler','JZaDa','hideNewLabelSprites','RemoveEquipText','value','Occasion%1','playOkSound','remove','drawItemDamageAmount','Scene_Shop_onSellCancel','meetsItemConditions','QUANTITY','prototype','postCreateCategoryWindowItemsEquipsCore','drawing','QoL','Window_ShopSell_isEnabled','OqLeh','HiddenItemA','getItemEffectsMpRecoveryText','parse','drawTextEx','isPlaytest','cursorRight','usEOF','forceChangeEquip','AsZzX','convertInitEquipsToItems','Scene_Shop_commandSell','buttonAssistKey1','USER\x20TP\x20GAIN','REPEAT','elementId','initNewLabelSprites','SpeedNeg2000','getItemEffectsHpRecoveryText','EquipAdjustHpMp','ShiftShortcutKey','isArmor','Parse_Notetags_EquipSlots','KSaJc','isEquipCommandAdded','aoNry','itemHasEquipLimit','ShopMenuStatusStandard','addItemCategory','onSlotOkAutoSelect','equipTypes','wZWWT','callUpdateHelp','Window_EquipStatus_refresh','cmaHu','Kycjc','ARRAYJSON','_itemWindow','iiCeg','ARRAYFUNC','price','_dummyWindow','statusWindowRect','addBuyCommand','JYVMu','drawItemSpeed','_resetFontColor','mainAreaTop','setBackgroundType','cursorPagedown','Scene_Shop_createCategoryWindow','ParseArmorNotetags','Speed1000','equipAdjustHpMp','DrawItemData','Scene_Equip_onActorChange','Window_ItemList_drawItem','hideDisabledCommands','drawItemOccasion','zQgsD','createItemWindow','setObject','_sellWindow','commandStyle','getItemEffectsMpDamageText','1499697mlGSbL','postCreateItemsEquipsCore','hpRate','ftcok','reloadMapIfUpdated','xBwCs','PXyCc','oPUnK','10520766tycdKu','ItemsEquipsCore','MDF','drawActorParamDifference','rateMP','flatHP','updateNewLabelOpacity','GhzUM','kPwxq','revertGlobalNamespaceVariables','elements','values','Scene_Shop_commandWindowRect','possession','drawItemRepeats','qTbcv','Scene_Item_helpWindowRect','drawPossession','Scene_Shop_numberWindowRect','cursorPageup','_statusWindow','Scene_Item_itemWindowRect','currentClass','addClearCommand','dVCaG','visible','sellWindowRectItemsEquipsCore','OyefV','AhiFN','VKAOJ','contents','ParseClassNotetags','lbWFw','tkVGq','numberWindowRect','qRJnH','normalColor','SwitchSell','phvfl','NonOptimizeETypes','blt','rLqrC','buttonAssistKey3','getMenuImage','drawParamsItemsEquipsCore','clearNewItem','HP\x20DAMAGE','DEF','LabelRecoverHP','BattleUsable','%1\x20is\x20incorrectly\x20placed\x20on\x20the\x20plugin\x20list.\x0aIt\x20is\x20a\x20Tier\x20%2\x20plugin\x20placed\x20over\x20other\x20Tier\x20%3\x20plugins.\x0aPlease\x20reorder\x20the\x20plugin\x20list\x20from\x20smallest\x20to\x20largest\x20tier\x20numbers.','commandNameWindowDrawBackground','buttonAssistOffset3','innerWidth','refresh','setHp','_customItemInfo','isEnabled','Speed1','NxknR','ATK','replace','Window_Selectable_setHelpWindowItem','isClearEquipOk','rmaKe','damage','qRSVd','LNzrM','_categoryWindow','updateHelp','hmZJU','yiSsB','620dvdUji','Window_EquipItem_includes','smallParamFontSize','Icon','VisuMZ_1_MainMenuCore','eGzQa','shift','vtjCL','getItemEffectsHpDamageLabel','actorParams','buttonAssistText1','getItemEffects','ecQLu','Window_EquipItem_isEnabled','Game_Party_gainItem','numItems','slotWindowRectItemsEquipsCore','iconHeight','sHAAA','rateHP','isClicked','createCategoryNameWindow','getItemSpeedText','qghpl','atypeId','hitIndex','changeEquip','LabelRecoverMP','return\x200','ziBwR','_equips','equipSlotIndex','height','round','Game_Actor_forceChangeEquip','MaxIcons','consumable','_purchaseOnly','onTouchOk','OSfij','isHovered','STRUCT','drawItemSuccessRate','Window_ItemList_maxCols','_newLabelOpacityUpperLimit','drawUpdatedAfterParamValue','pTROP','select','RwTPR','getItemEffectsAddedStatesBuffsText','floor','onSlotCancel','prepareItemCustomData','prepare','itemTextAlign','?????','bcepM','setupItemDamageTempActors','cenpX','RegularItems','onCategoryCancelItemsEquipsCore','etypeId','popScene','atk','DnDaL','right','categories','left','note','kPtnd','removeState','slotWindowRect','setHelpWindowItem','LabelSelfGainTP','kBjtE','gainTP','Scene_Equip_onSlotCancel','getItemQuantityText','Scene_Shop_onCategoryCancel','qhaKD','resetShopSwitches','periE','xmvMq','postCreateSlotWindowItemsEquipsCore','addStateBuffChanges','ScopeAlliesButUser','drawItemEffectsSelfTpGain','Game_Party_initialize','sellingPrice','Scene_Load_reloadMapIfUpdated','thZEG','getItemHitTypeLabel','Scene_Item_create','paramchangeTextColor','drawItemDamageElement','initEquips','push','itypeId','buy','hide','text','drawItemHitType','TP\x20RECOVERY','tpGain','SSIMj','EnableLayout','drawItemDarkRect','SpeedNeg999','ConvertNumberToString','DrawIcons','commandStyleCheck','createSellWindow','uiInputPosition','_data','getItemSuccessRateLabel','vsZIE','ScopeRandomAllies','HiddenItemB','commandWindowRectItemsEquipsCore','categoryItemTypes','prepareRefreshItemsEquipsCoreLayout','meetsItemConditionsNotetags','paintOpacity','commandBuy','changePaintOpacity','jMHnZ','MAT','isCommandEnabled','helpAreaTop','match','TkdfL','Ggtqp','_list','drawItemEffectsAddedStatesBuffs','addCommand','Window_ItemCategory_setItemWindow','forceChangeEquipSlots','VJvOT','maxBattleMembers','isOptimizeEquipOk','Scene_Shop_sellWindowRect','pageup','List','drawItemActorMenuImage','vzPgN','create','equipSlots','LabelDamageHP','isEquipItem','isClearCommandAdded','cursorLeft','Window_ItemList_updateHelp','colSpacing','isSoleArmorType','commandNameWindowCenter','Scene_Shop_prepare','isShiftShortcutKeyForRemove','Whitelist','SellPriceRate','smHza','iconIndex','NoChangeMarker','DAMAGE\x20MULTIPLIER','drawCustomShopGraphic','onCategoryOk','gainItem','cursorUp','10VscVtw','dJWDq','pQWsd','HbgXM','Scene_Shop_onSellOk','JInGE','commandNameWindowDrawText','jqwRC','ElementWeapon','oQhot','isOpen','TP\x20DAMAGE','loadCharacter','changeBuff','goldWindowRect','ZpmOr','drawCurrencyValue','processCursorMoveModernControls','status','jJFYB','cursorDown','drawItemEffectsMpRecovery','drawItemName','itemPadding','iKPtY','buttonAssistItemListRequirement','ParseItemNotetags','addEquipCommand','commandBuyItemsEquipsCore','armor','XSNBK','RiOyw','Scene_Shop_onBuyCancel','DrawFaceJS','VisuMZ_0_CoreEngine','getItemSpeedLabel','+%1%','selfTP','dSPev','BzOig','Categories','YvbiL','AllArmors','CmdIconEquip','Window_ShopCommand_initialize','isTriggered','vBBLh','canConsumeItem','NGFPL','drawNewLabelText','powerUpColor','checkItemConditionsSwitchNotetags','drawActorCharacter','isCursorMovable','removeStateBuffChanges','rOcaO','processCursorHomeEndTrigger','refreshActorEquipSlotsIfUpdated','\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20let\x20MaxHP\x20=\x200;\x20let\x20MaxMP\x20=\x200;\x20let\x20ATK\x20=\x200;\x20let\x20DEF\x20=\x200;\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20let\x20MAT\x20=\x200;\x20let\x20MDF\x20=\x200;\x20let\x20AGI\x20=\x200;\x20let\x20LUK\x20=\x200;\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20const\x20user\x20=\x20this;\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20const\x20target\x20=\x20this;\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20const\x20a\x20=\x20this;\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20const\x20b\x20=\x20this;\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20try\x20{\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20%1\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20}\x20catch\x20(e)\x20{\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20if\x20($gameTemp.isPlaytest())\x20console.log(e);\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20}\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20return\x20[MaxHP,\x20MaxMP,\x20ATK,\x20DEF,\x20MAT,\x20MDF,\x20AGI,\x20LUK][paramId];\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20','isEquipChangeOk','onBuyCancelItemsEquipsCore','BuyPriceJS','_newItemsList','doBuy','NeverUsable','onCategoryCancel','gwUZM','Scene_Equip_statusWindowRect','innerHeight','isWeapon','buyWindowRect','CqZBd','Game_Actor_discardEquip','EFFECT_REMOVE_STATE','SpeedNeg1999','SitYu','addState','zrtJB','getInputMultiButtonStrings','postCreateSellWindowItemsEquipsCore','IconSet','CFEty','RemoveEquipIcon','optimize','ChjAy','createNewLabelSprite','_handlers','Scene_Boot_onDatabaseLoaded','getItemsEquipsCoreBackColor2','qKrLo','buttonAssistText3','CmdTextAlign','bvLqw','mainAreaHeight','createBitmap','noTvv','ngfUx','changeTextColor','setValue','ieXGZ','mainFontFace','helpAreaHeight','eDbrU','createCommandNameWindow','UIDlf','graXt','getItemDamageAmountText','param','previousActor','process_VisuMZ_ItemsEquipsCore_EquipSlots','TtGjX','postCreateItemWindowModernControls','KcBgx','0000','_bypassReleaseUnequippableItemsItemsEquipsCore','EcENG','length','resetFontSettings','Parse_Notetags_EnableJS','tradeItemWithParty','Step1End','YnLdv','IsvCK','updateCategoryNameWindow','value1','LabelSuccessRate','itemLineRect','OCCASION','xoZel','GRise','equips','Scene_Shop_statusWindowRect','Translucent','ItemMenuStatusRect','izrTV','bitmap','drawCustomShopGraphicLoad','_calculatingJSParameters','_buyWindowLastIndex','HMjis','drawItemEquipType','LabelDamageTP','paramPlus','IncludeShopItem','iyBaZ','_bypassNewLabel','oUPHs','ElementNone','StatusWindowWidth','ItemQuantityFontSize','fMQkm','scrollTo','IPlVb','FHwQw','ActorResetEquipSlots','ExtDisplayedParams','UYwlJ','REMOVED\x20EFFECTS','processDrawIcon','zhSQl','xVQDU','NTsKB','_newLabelSprites','VisTA','_resetFontSize','_money','Game_BattlerBase_param','W%1','QauVM','formula','MP\x20RECOVERY','map','onTouchCancel','UnHRq','loadFaceImages','getItemDamageAmountLabelOriginal','Game_Actor_tradeItemWithParty','item','zLmTK','boxWidth','_goodsCount','CommandAddOptimize','drawItemDamage','exit','helpWindowRect','getItemEffectsMpDamageLabel','×%1','categoryNameWindowDrawBackground','paramValueFontSize','systemColor','LPmww','pXtOu','flatMP','_scene','inkxa','isOptimizeCommandAdded','splice','4720288bycbYV','SwitchBuy','_categoryNameWindow','Scene_Shop_sellingPrice','ARRAYSTRUCT','drawItemEffectsRemovedStatesBuffs','ItemScene','getItemEffectsRemovedStatesBuffsText','Speed0','powerDownColor','DObXM','trim','UDyEg','ZCKPy','Scene_Shop_commandBuy','SUCCESS\x20RATE','MaxItems','sbOVg','CmdIconOptimize','fontSizeRatio','WKQZr','process_VisuMZ_ItemsEquipsCore_RegExp','SwitchID','processCursorSpecialCheckModernControls','53255ELXtPQ','UQggA','qGrtc','getItemEffectsAddedStatesBuffsLabel','cancel','drawItemEffectsHpDamage','drawItemEffectsTpDamage','isDualWield','createSlotWindow','Consumable','QsPAa','split','drawItem','_commandWindow','wtypeId','getItemConsumableLabel','HGvtn','_buttonAssistWindow','Actors','vvdNt','IEkyT','HIT\x20TYPE','setStatusWindow','determineBaseSellingPrice','oEwIE','name','armor-%1','drawParamName','isShiftRemoveShortcutEnabled','isKeyItem','PNbbq','kKdgW','ShopScene','updatedLayoutStyle','isMainMenuCoreMenuImageOptionAvailable','1103147qQdsfG','MaxHP','canEquip','isBottomHelpMode','isNewItem','playBuzzerSound','characterName','_tempActorA','CmdIconBuy','drawText','drawNewLabelIcon','fillRect','dHmkC','buttonAssistText2','Parse_Notetags_Batch','epjvk','drawItemStyleIcon','lineHeight','Parse_Notetags_Prices','type','FUNC','getItemEffectsHpDamageText','itemWindowRect','nhocA','HP\x20RECOVERY','LayoutStyle','_itemData','Scene_Equip_itemWindowRect','VgLKh','NotConsumable','drawIcon','drawUpdatedParamValueDiff','(%1)','log','optimizeEquipments','InNOs','getMatchingInitEquip','Scene_Shop_doSell','filter','drawItemEffects','weapon','categoryList','Scene_Shop_helpWindowRect','%1%','qTkxs','bqjQo','loadPicture','helpWindowRectItemsEquipsCore','textSizeEx','PNeGs','CONSUMABLE','LabelSpeed','QORly','BHIRq','DamageType%1','weapon-%1','adjustHiddenShownGoods','drawItemData','playCursorSound','updateMoneyAmount','Window_Selectable_update','CoreEngine','PZfAC','zYDAp','ZIaXT','actor','equip','goldWindowRectItemsEquipsCore','removeBuff','hbwfF','adjustItemWidthByStatus','mmp','wYAwW','Window_Selectable_initialize','YOzwa','number','%1-%2','Window_ShopBuy_refresh','DrawEquipData','getColor','Window_ItemList_colSpacing','_tempActorB','klVdE','hitType','isHoverEnabled','auqqd','setItem','AGI','isSoleWeaponType','damageColor','drawItemCustomEntryLine'];_0x4480=function(){return _0x51dfbd;};return _0x4480();}Sprite_NewLabel[_0x541333(0x5f1)]=Object[_0x541333(0x2b3)](Sprite[_0x541333(0x5f1)]),Sprite_NewLabel[_0x541333(0x5f1)][_0x541333(0x5db)]=Sprite_NewLabel,Sprite_NewLabel['prototype'][_0x541333(0x45c)]=function(){const _0x454615=_0x541333;Sprite[_0x454615(0x5f1)]['initialize'][_0x454615(0x562)](this),this[_0x454615(0x327)]();},Sprite_NewLabel[_0x541333(0x5f1)][_0x541333(0x327)]=function(){const _0x56f0b4=_0x541333,_0x5a56bb=ImageManager[_0x56f0b4(0x5d8)],_0x4ef4b3=ImageManager[_0x56f0b4(0x233)];this[_0x56f0b4(0x350)]=new Bitmap(_0x5a56bb,_0x4ef4b3),this[_0x56f0b4(0x3d3)](),this[_0x56f0b4(0x2fa)]();},Sprite_NewLabel['prototype'][_0x541333(0x3d3)]=function(){const _0x457d37=_0x541333,_0x113667=VisuMZ['ItemsEquipsCore']['Settings']['New']['Icon'];if(_0x113667<=0x0)return;const _0x435922=ImageManager[_0x457d37(0x528)](_0x457d37(0x319)),_0x3d3e96=ImageManager['iconWidth'],_0x5ad821=ImageManager[_0x457d37(0x233)],_0x1a8297=_0x113667%0x10*_0x3d3e96,_0x1cbacd=Math[_0x457d37(0x254)](_0x113667/0x10)*_0x5ad821;this[_0x457d37(0x350)][_0x457d37(0x202)](_0x435922,_0x1a8297,_0x1cbacd,_0x3d3e96,_0x5ad821,0x0,0x0);},Sprite_NewLabel[_0x541333(0x5f1)][_0x541333(0x2fa)]=function(){const _0x17c9b6=_0x541333,_0xc4e7f1=VisuMZ[_0x17c9b6(0x1db)][_0x17c9b6(0x522)][_0x17c9b6(0x590)],_0x5a767a=_0xc4e7f1[_0x17c9b6(0x5dc)];if(_0x5a767a==='')return;const _0x327343=ImageManager[_0x17c9b6(0x5d8)],_0x12c52d=ImageManager[_0x17c9b6(0x233)];this[_0x17c9b6(0x350)]['fontFace']=_0xc4e7f1['FontFace']||$gameSystem[_0x17c9b6(0x32d)](),this[_0x17c9b6(0x350)][_0x17c9b6(0x5cb)]=this[_0x17c9b6(0x469)](),this[_0x17c9b6(0x350)][_0x17c9b6(0x5a1)]=_0xc4e7f1['FontSize'],this[_0x17c9b6(0x350)][_0x17c9b6(0x3d2)](_0x5a767a,0x0,_0x12c52d/0x2,_0x327343,_0x12c52d/0x2,'center');},Sprite_NewLabel[_0x541333(0x5f1)][_0x541333(0x469)]=function(){const _0x199733=_0x541333,_0x306267=VisuMZ['ItemsEquipsCore'][_0x199733(0x522)][_0x199733(0x590)][_0x199733(0x557)];return _0x306267[_0x199733(0x2a3)](/#(.*)/i)?'#'+String(RegExp['$1']):ColorManager['textColor'](_0x306267);},Window_Base[_0x541333(0x5f1)][_0x541333(0x2df)]=function(_0x44d52b,_0x5393a4,_0x2c8029,_0x2cb67c){const _0x5aeb7b=_0x541333;if(_0x44d52b){const _0x5ec719=_0x2c8029+(this['lineHeight']()-ImageManager[_0x5aeb7b(0x233)])/0x2,_0x17070e=ImageManager[_0x5aeb7b(0x5d8)]+0x4,_0x38ce14=Math[_0x5aeb7b(0x52c)](0x0,_0x2cb67c-_0x17070e);this['changeTextColor'](ColorManager[_0x5aeb7b(0x5a4)](_0x44d52b)),this['drawIcon'](_0x44d52b['iconIndex'],_0x5393a4,_0x5ec719),this[_0x5aeb7b(0x3d2)](_0x44d52b[_0x5aeb7b(0x3bf)],_0x5393a4+_0x17070e,_0x2c8029,_0x38ce14),this[_0x5aeb7b(0x4b0)]();}},Window_Base[_0x541333(0x5f1)][_0x541333(0x4d0)]=function(_0x36b354,_0x2d0c8f,_0xb128e5,_0x5593d2){const _0x56b137=_0x541333;if(this['isDrawItemNumber'](_0x36b354)){if(_0x56b137(0x4e1)!=='sfIxQ')return _0x15ffba['ItemsEquipsCore'][_0x56b137(0x522)]['EquipScene'][_0x56b137(0x4d4)];else{this[_0x56b137(0x33e)]();const _0x18dbea=VisuMZ[_0x56b137(0x1db)]['Settings']['ItemScene'],_0x4baaf9=_0x18dbea[_0x56b137(0x4af)],_0x551462=_0x4baaf9[_0x56b137(0x52b)]($gameParty[_0x56b137(0x231)](_0x36b354));this[_0x56b137(0x1f8)][_0x56b137(0x5a1)]=_0x18dbea[_0x56b137(0x35e)],this[_0x56b137(0x3d2)](_0x551462,_0x2d0c8f,_0xb128e5,_0x5593d2,'right'),this['resetFontSettings']();}}},Window_Base[_0x541333(0x5f1)][_0x541333(0x584)]=function(_0x504c40){const _0x5cc00a=_0x541333;if(DataManager[_0x5cc00a(0x3c3)](_0x504c40))return $dataSystem[_0x5cc00a(0x498)];return!![];},Window_Base[_0x541333(0x5f1)]['drawItemDarkRect']=function(_0x30e0c3,_0x346aed,_0x1d35e7,_0x443b6d,_0xb90e09){const _0x18a8f3=_0x541333;_0xb90e09=Math[_0x18a8f3(0x52c)](_0xb90e09||0x1,0x1);while(_0xb90e09--){if(_0x18a8f3(0x524)!==_0x18a8f3(0x4dc)){_0x443b6d=_0x443b6d||this['lineHeight'](),this['contentsBack'][_0x18a8f3(0x29c)]=0xa0;const _0x28d5eb=ColorManager['gaugeBackColor']();this[_0x18a8f3(0x535)][_0x18a8f3(0x3d4)](_0x30e0c3+0x1,_0x346aed+0x1,_0x1d35e7-0x2,_0x443b6d-0x2,_0x28d5eb),this[_0x18a8f3(0x535)][_0x18a8f3(0x29c)]=0xff;}else this['drawItemStyleIcon'](_0x2169b3);}},VisuMZ[_0x541333(0x1db)]['Window_Selectable_initialize']=Window_Selectable[_0x541333(0x5f1)][_0x541333(0x45c)],Window_Selectable[_0x541333(0x5f1)]['initialize']=function(_0x30fe71){const _0x335515=_0x541333;this['initNewLabelSprites'](),VisuMZ['ItemsEquipsCore'][_0x335515(0x412)][_0x335515(0x562)](this,_0x30fe71);},Window_Selectable[_0x541333(0x5f1)][_0x541333(0x1a1)]=function(){const _0x38db51=_0x541333;this[_0x38db51(0x36b)]={},this[_0x38db51(0x471)]=0xff,this['_newLabelOpacityChange']=VisuMZ[_0x38db51(0x1db)][_0x38db51(0x522)][_0x38db51(0x590)][_0x38db51(0x55a)],this[_0x38db51(0x24e)]=VisuMZ['ItemsEquipsCore'][_0x38db51(0x522)][_0x38db51(0x590)][_0x38db51(0x480)];},Window_Selectable[_0x541333(0x5f1)][_0x541333(0x45d)]=function(){return![];},VisuMZ[_0x541333(0x1db)][_0x541333(0x218)]=Window_Selectable['prototype'][_0x541333(0x26a)],Window_Selectable[_0x541333(0x5f1)][_0x541333(0x26a)]=function(_0x244d98){const _0x30cf2e=_0x541333;VisuMZ[_0x30cf2e(0x1db)]['Window_Selectable_setHelpWindowItem']['call'](this,_0x244d98);if(this[_0x30cf2e(0x45d)]())this[_0x30cf2e(0x4a2)](_0x244d98);},Window_Selectable[_0x541333(0x5f1)][_0x541333(0x4a2)]=function(_0xbbc213){const _0x298f68=_0x541333;if(!_0xbbc213)return;$gameParty[_0x298f68(0x207)](_0xbbc213);let _0x28769d='';if(DataManager['isItem'](_0xbbc213))_0x28769d=_0x298f68(0x592)[_0x298f68(0x52b)](_0xbbc213['id']);else{if(DataManager['isWeapon'](_0xbbc213))_0x28769d=_0x298f68(0x400)[_0x298f68(0x52b)](_0xbbc213['id']);else{if(DataManager[_0x298f68(0x1a6)](_0xbbc213))_0x28769d=_0x298f68(0x3c0)[_0x298f68(0x52b)](_0xbbc213['id']);else return;}}const _0x53d90e=this[_0x298f68(0x36b)][_0x28769d];if(_0x53d90e)_0x53d90e['hide']();},VisuMZ[_0x541333(0x1db)]['Window_Selectable_refresh']=Window_Selectable[_0x541333(0x5f1)][_0x541333(0x210)],Window_Selectable[_0x541333(0x5f1)]['refresh']=function(){const _0x3099b9=_0x541333;this['hideNewLabelSprites'](),VisuMZ[_0x3099b9(0x1db)][_0x3099b9(0x4bc)][_0x3099b9(0x562)](this);},Window_Selectable['prototype'][_0x541333(0x5e7)]=function(){const _0x794caa=_0x541333;for(const _0x2938e9 of Object[_0x794caa(0x1e5)](this['_newLabelSprites'])){_0x2938e9[_0x794caa(0x285)]();}},VisuMZ[_0x541333(0x1db)][_0x541333(0x405)]=Window_Selectable[_0x541333(0x5f1)][_0x541333(0x44f)],Window_Selectable['prototype']['update']=function(){const _0x5b8866=_0x541333;this[_0x5b8866(0x1e0)](),VisuMZ['ItemsEquipsCore']['Window_Selectable_update'][_0x5b8866(0x562)](this);},Window_Selectable[_0x541333(0x5f1)][_0x541333(0x1e0)]=function(){const _0x53f7ef=_0x541333;if(!this[_0x53f7ef(0x45d)]())return;const _0x1c6718=this[_0x53f7ef(0x24e)];this[_0x53f7ef(0x471)]+=this[_0x53f7ef(0x5e2)];(this['_newLabelOpacity']>=_0x1c6718||this[_0x53f7ef(0x471)]<=0x0)&&(_0x53f7ef(0x343)===_0x53f7ef(0x343)?this[_0x53f7ef(0x5e2)]*=-0x1:_0x43c769=_0x4c16c4[_0x53f7ef(0x49f)]);this[_0x53f7ef(0x471)]=this['_newLabelOpacity']['clamp'](0x0,_0x1c6718);for(const _0x34a482 of Object[_0x53f7ef(0x1e5)](this[_0x53f7ef(0x36b)])){_0x34a482[_0x53f7ef(0x443)]=this[_0x53f7ef(0x471)];}},Window_Selectable[_0x541333(0x5f1)][_0x541333(0x31e)]=function(_0x3e9ddb){const _0x4b82b9=_0x541333,_0xab20f1=this[_0x4b82b9(0x36b)];if(_0xab20f1[_0x3e9ddb])return _0xab20f1[_0x3e9ddb];else{const _0x2efd54=new Sprite_NewLabel();return _0xab20f1[_0x3e9ddb]=_0x2efd54,this[_0x4b82b9(0x46e)](_0x2efd54),_0x2efd54;}},Window_Selectable['prototype'][_0x541333(0x589)]=function(_0x3f8905,_0x1f0a48,_0x9ae35f){const _0x486b20=_0x541333;let _0x51894a='';if(DataManager[_0x486b20(0x577)](_0x3f8905))_0x51894a='item-%1'[_0x486b20(0x52b)](_0x3f8905['id']);else{if(DataManager[_0x486b20(0x30e)](_0x3f8905)){if('iLDMd'===_0x486b20(0x5cc))_0x51894a='weapon-%1'[_0x486b20(0x52b)](_0x3f8905['id']);else{const _0x54bca1=this[_0x486b20(0x3b3)]['y']+this['_commandWindow'][_0x486b20(0x242)],_0x23e708=_0x375109[_0x486b20(0x37c)]-this[_0x486b20(0x51c)](),_0x554f14=this[_0x486b20(0x434)]()?_0xb86c4c[_0x486b20(0x37c)]-_0x23e708:0x0,_0x1218ac=this['mainAreaHeight']()-this['_commandWindow'][_0x486b20(0x242)];return new _0x322f0f(_0x554f14,_0x54bca1,_0x23e708,_0x1218ac);}}else{if(DataManager[_0x486b20(0x1a6)](_0x3f8905))_0x51894a=_0x486b20(0x3c0)[_0x486b20(0x52b)](_0x3f8905['id']);else{if('zhSQl'!==_0x486b20(0x368))_0x11069c[_0x486b20(0x5f1)][_0x486b20(0x33e)][_0x486b20(0x562)](this),this[_0x486b20(0x1f8)][_0x486b20(0x5a1)]=this['_resetFontSize']||this[_0x486b20(0x1f8)][_0x486b20(0x5a1)],this[_0x486b20(0x1f8)][_0x486b20(0x5cb)]=this[_0x486b20(0x1bf)]||this[_0x486b20(0x1f8)][_0x486b20(0x5cb)];else return;}}}const _0x2a70bb=this['createNewLabelSprite'](_0x51894a);_0x2a70bb['move'](_0x1f0a48,_0x9ae35f),_0x2a70bb[_0x486b20(0x496)](),_0x2a70bb['opacity']=this['_newLabelOpacity'];},Window_ItemCategory[_0x541333(0x3f2)]=VisuMZ['ItemsEquipsCore'][_0x541333(0x522)][_0x541333(0x2f1)][_0x541333(0x2b0)],Window_ItemCategory[_0x541333(0x299)]=[_0x541333(0x5f7),_0x541333(0x297),_0x541333(0x594),_0x541333(0x3af),'AlwaysUsable',_0x541333(0x20b),_0x541333(0x462),_0x541333(0x309)],VisuMZ[_0x541333(0x1db)][_0x541333(0x4fe)]=Window_ItemCategory[_0x541333(0x5f1)][_0x541333(0x45c)],Window_ItemCategory[_0x541333(0x5f1)]['initialize']=function(_0x139ea5){const _0x2cb547=_0x541333;VisuMZ[_0x2cb547(0x1db)]['Window_ItemCategory_initialize'][_0x2cb547(0x562)](this,_0x139ea5),this[_0x2cb547(0x237)](_0x139ea5);},Window_ItemCategory[_0x541333(0x5f1)][_0x541333(0x237)]=function(_0x473e78){const _0xb31a84=_0x541333,_0x680af1=new Rectangle(0x0,0x0,_0x473e78['width'],_0x473e78[_0xb31a84(0x242)]);this['_categoryNameWindow']=new Window_Base(_0x680af1),this[_0xb31a84(0x390)][_0xb31a84(0x443)]=0x0,this['addChild'](this[_0xb31a84(0x390)]),this[_0xb31a84(0x344)]();},Window_ItemCategory[_0x541333(0x5f1)][_0x541333(0x539)]=function(){const _0x5a9859=_0x541333;return Imported[_0x5a9859(0x2eb)]&&Window_HorzCommand['prototype'][_0x5a9859(0x539)][_0x5a9859(0x562)](this);},Window_ItemCategory[_0x541333(0x5f1)][_0x541333(0x301)]=function(){},Window_ItemCategory[_0x541333(0x5f1)][_0x541333(0x5eb)]=function(){const _0x5d16a1=_0x541333;if(!this[_0x5d16a1(0x539)]())Window_HorzCommand[_0x5d16a1(0x5f1)]['playOkSound'][_0x5d16a1(0x562)](this);},Window_ItemCategory[_0x541333(0x5f1)]['maxCols']=function(){const _0x513d89=_0x541333;return this[_0x513d89(0x2a6)]?this[_0x513d89(0x574)]():0x4;},Window_ItemCategory['prototype']['update']=function(){const _0x369841=_0x541333;Window_HorzCommand[_0x369841(0x5f1)]['update']['call'](this),this['_itemWindow']&&this['_itemWindow']['setCategory'](this[_0x369841(0x583)]());},Window_ItemCategory['prototype'][_0x541333(0x2da)]=function(){const _0xf89cd6=_0x541333;if(this[_0xf89cd6(0x2fe)]()){const _0x1e661=this[_0xf89cd6(0x593)]();if(this[_0xf89cd6(0x1b6)]&&this[_0xf89cd6(0x1b6)][_0xf89cd6(0x4c6)]()<=0x1)Input[_0xf89cd6(0x45b)](_0xf89cd6(0x263))&&this[_0xf89cd6(0x5fc)](Input[_0xf89cd6(0x2f6)](_0xf89cd6(0x263))),Input[_0xf89cd6(0x45b)]('left')&&this['cursorLeft'](Input[_0xf89cd6(0x2f6)]('left'));else{if(this[_0xf89cd6(0x1b6)]&&this['_itemWindow'][_0xf89cd6(0x4c6)]()>0x1){if(_0xf89cd6(0x2c1)!=='PImFx')Input['isRepeated'](_0xf89cd6(0x4b8))&&!Input[_0xf89cd6(0x4fc)](_0xf89cd6(0x228))&&this[_0xf89cd6(0x5fc)](Input[_0xf89cd6(0x2f6)](_0xf89cd6(0x4b8))),Input['isRepeated']('pageup')&&!Input['isPressed'](_0xf89cd6(0x228))&&(_0xf89cd6(0x5b8)!==_0xf89cd6(0x5b8)?(_0x33de04+=_0xa66bc9(_0x108363['$1']),_0x34d8b9+=_0x4cf099(_0x32ee5f['$2'])):this['cursorLeft'](Input[_0xf89cd6(0x2f6)](_0xf89cd6(0x2af))));else{const _0x514aa9=_0x5ca151+(this['lineHeight']()-_0x361229[_0xf89cd6(0x233)])/0x2,_0x325b98=_0xfe267b[_0xf89cd6(0x5d8)]+0x4,_0x50f2fe=_0x283d3e[_0xf89cd6(0x52c)](0x0,_0x50e017-_0x325b98);this['changeTextColor'](_0x1beef0[_0xf89cd6(0x5a4)](_0x48049b)),this[_0xf89cd6(0x3e7)](_0x2c614e['iconIndex'],_0x5c0eef,_0x514aa9),this[_0xf89cd6(0x3d2)](_0x48085f['name'],_0x569d26+_0x325b98,_0x2f33e0,_0x50f2fe),this[_0xf89cd6(0x4b0)]();}}}this[_0xf89cd6(0x593)]()!==_0x1e661&&this[_0xf89cd6(0x403)]();}},Window_ItemCategory[_0x541333(0x5f1)][_0x541333(0x4a1)]=function(){const _0x8f4ce0=_0x541333;if(this[_0x8f4ce0(0x539)]())return;Window_HorzCommand['prototype'][_0x8f4ce0(0x4a1)]['call'](this);},Window_ItemCategory['prototype'][_0x541333(0x41d)]=function(){const _0x623bd8=_0x541333;return this[_0x623bd8(0x539)]()?![]:Window_HorzCommand[_0x623bd8(0x5f1)]['isHoverEnabled'][_0x623bd8(0x562)](this);},Window_ItemCategory[_0x541333(0x5f1)][_0x541333(0x4f9)]=function(){const _0x31e1e4=_0x541333;if(this[_0x31e1e4(0x4df)]()){if(_0x31e1e4(0x3b9)!=='vvdNt'){const _0x26f76f=new _0x317368(0x0,0x0,_0x30c028[_0x31e1e4(0x5bc)],_0x52e48d[_0x31e1e4(0x242)]);this[_0x31e1e4(0x44c)]=new _0x5eb69f(_0x26f76f),this[_0x31e1e4(0x44c)][_0x31e1e4(0x443)]=0x0,this['addChild'](this[_0x31e1e4(0x44c)]),this[_0x31e1e4(0x534)]();}else{TouchInput['isTriggered']()&&(_0x31e1e4(0x52f)===_0x31e1e4(0x1d7)?!this[_0x31e1e4(0x3a5)]()&&_0x342dcf[_0x31e1e4(0x5f1)][_0x31e1e4(0x2da)]['call'](this):this[_0x31e1e4(0x54b)](!![]));if(TouchInput[_0x31e1e4(0x236)]())_0x31e1e4(0x273)==='periE'?this[_0x31e1e4(0x248)]():(_0x47b0e5[_0x31e1e4(0x1db)][_0x31e1e4(0x449)][_0x31e1e4(0x562)](this),this['onSlotOkAutoSelect']());else TouchInput[_0x31e1e4(0x5c0)]()&&this[_0x31e1e4(0x375)]();}}},Window_ItemCategory[_0x541333(0x5f1)]['onTouchSelect']=function(_0x40b3af){const _0x40805c=_0x541333;if(this[_0x40805c(0x539)]())this[_0x40805c(0x4fd)](!![]);else{if(_0x40805c(0x1b7)!==_0x40805c(0x407))Window_HorzCommand[_0x40805c(0x5f1)][_0x40805c(0x54b)][_0x40805c(0x562)](this,_0x40b3af);else{const _0x3d206b=this[_0x40805c(0x3b3)]['y']+this[_0x40805c(0x3b3)][_0x40805c(0x242)],_0x355ffa=_0x104c07[_0x40805c(0x37c)]-this[_0x40805c(0x51c)](),_0x4689ea=this[_0x40805c(0x326)]()-this[_0x40805c(0x3b3)]['height'],_0x2afca5=this['isRightInputMode']()?_0x5ee0db[_0x40805c(0x37c)]-_0x355ffa:0x0;return new _0x44de35(_0x2afca5,_0x3d206b,_0x355ffa,_0x4689ea);}}},Window_ItemCategory[_0x541333(0x5f1)][_0x541333(0x4fd)]=function(_0x41fee8){const _0x1fffe8=_0x541333;this[_0x1fffe8(0x46b)]=![];if(this[_0x1fffe8(0x2fe)]()){const _0x50738a=this['index'](),_0x1547c9=this['hitIndex']();if(_0x1547c9>=0x0&&_0x1547c9!==this['index']()){if(_0x1fffe8(0x4bf)===_0x1fffe8(0x4bf))this[_0x1fffe8(0x251)](_0x1547c9);else{if(!_0x4ca31a[_0x1fffe8(0x5e9)](_0x2676b1))return![];}}if(_0x41fee8&&this[_0x1fffe8(0x593)]()!==_0x50738a){if('qTbcv'===_0x1fffe8(0x1e9))this[_0x1fffe8(0x403)]();else{const _0x92178a=_0x687141[_0x1fffe8(0x5f9)]('['+_0x149fe7['$1'][_0x1fffe8(0x2a3)](/\d+/g)+']');for(const _0x41d6a0 of _0x92178a){if(!_0x48ba95['value'](_0x41d6a0))return![];}}}}},Window_ItemCategory[_0x541333(0x5f1)][_0x541333(0x4e2)]=function(){const _0x451eeb=_0x541333;for(const _0x881de7 of Window_ItemCategory[_0x451eeb(0x3f2)]){this['addItemCategory'](_0x881de7);}this['select'](this['index']());},Window_ItemCategory[_0x541333(0x5f1)][_0x541333(0x1ad)]=function(_0x27dc96){const _0x31c77a=_0x541333,_0x2e93f1=_0x27dc96[_0x31c77a(0x4f0)],_0x5265ea=_0x27dc96[_0x31c77a(0x225)],_0x270ef6=_0x27dc96[_0x31c77a(0x3a4)]||0x0;if(_0x270ef6>0x0&&!$gameSwitches[_0x31c77a(0x5e9)](_0x270ef6))return;let _0x43086b='',_0x4a0a27=_0x31c77a(0x547),_0x4c4e4a=_0x2e93f1;if(_0x2e93f1[_0x31c77a(0x2a3)](/Category:(.*)/i))_0x43086b=String(RegExp['$1'])['trim']();else{if(Window_ItemCategory['categoryItemTypes'][_0x31c77a(0x53c)](_0x2e93f1))_0x31c77a(0x3d5)===_0x31c77a(0x3d5)?_0x43086b=VisuMZ[_0x31c77a(0x1db)]['Settings']['Categories'][_0x2e93f1]:this[_0x31c77a(0x2c6)]();else{if(['AllItems','RegularItems'][_0x31c77a(0x53c)](_0x2e93f1))_0x43086b=TextManager[_0x31c77a(0x37a)];else{if(_0x2e93f1===_0x31c77a(0x493))_0x43086b=TextManager[_0x31c77a(0x49f)];else{if(_0x2e93f1===_0x31c77a(0x43d))_0x43086b=TextManager[_0x31c77a(0x3f1)];else{if(_0x2e93f1===_0x31c77a(0x2f3)){if('GtYTt'==='iYGcE')return this[_0x31c77a(0x3f8)]();else _0x43086b=TextManager[_0x31c77a(0x2e6)];}else{if(_0x2e93f1[_0x31c77a(0x2a3)](/WTYPE:(\d+)/i))_0x43086b=$dataSystem[_0x31c77a(0x486)][Number(RegExp['$1'])]||'';else{if(_0x2e93f1[_0x31c77a(0x2a3)](/ATYPE:(\d+)/i))_0x43086b=$dataSystem[_0x31c77a(0x42d)][Number(RegExp['$1'])]||'';else _0x2e93f1[_0x31c77a(0x2a3)](/ETYPE:(\d+)/i)&&(_0x43086b=$dataSystem['equipTypes'][Number(RegExp['$1'])]||'');}}}}}}}_0x5265ea>0x0&&this[_0x31c77a(0x5b4)]()!==_0x31c77a(0x286)&&(_0x43086b=_0x31c77a(0x435)[_0x31c77a(0x52b)](_0x5265ea,_0x43086b)),this[_0x31c77a(0x2a8)](_0x43086b,_0x4a0a27,!![],_0x4c4e4a);},Window_ItemCategory[_0x541333(0x5f1)][_0x541333(0x258)]=function(){const _0x4b54a9=_0x541333;return VisuMZ[_0x4b54a9(0x1db)]['Settings'][_0x4b54a9(0x2f1)][_0x4b54a9(0x53f)];},Window_ItemCategory[_0x541333(0x5f1)]['drawItem']=function(_0xb88eba){const _0x2d5320=_0x541333,_0x8dad68=this['categoryStyleCheck'](_0xb88eba);if(_0x8dad68===_0x2d5320(0x454))_0x2d5320(0x3f5)===_0x2d5320(0x5ca)?this['_categoryWindow'][_0x2d5320(0x48a)]():this[_0x2d5320(0x5ce)](_0xb88eba);else{if(_0x8dad68===_0x2d5320(0x495)){if(_0x2d5320(0x413)!==_0x2d5320(0x5af))this['drawItemStyleIcon'](_0xb88eba);else{_0x50d470[_0x2d5320(0x5f1)][_0x2d5320(0x21f)]['call'](this);if(this[_0x2d5320(0x4bb)]&&this[_0x2d5320(0x1ee)]&&this[_0x2d5320(0x458)]>=0x0){const _0x2e8445=_0x2f192d['makeDeepCopy'](this[_0x2d5320(0x4bb)]);_0x2e8445[_0x2d5320(0x59a)]=!![],_0x2e8445[_0x2d5320(0x5fe)](this[_0x2d5320(0x458)],this['item']()),this[_0x2d5320(0x1ee)][_0x2d5320(0x5e1)](_0x2e8445);}}}else Window_HorzCommand[_0x2d5320(0x5f1)][_0x2d5320(0x3b2)][_0x2d5320(0x562)](this,_0xb88eba);}},Window_ItemCategory[_0x541333(0x5f1)][_0x541333(0x5b4)]=function(){const _0xb2431f=_0x541333;return VisuMZ['ItemsEquipsCore'][_0xb2431f(0x522)][_0xb2431f(0x2f1)]['Style'];},Window_ItemCategory[_0x541333(0x5f1)]['categoryStyleCheck']=function(_0x1e6216){const _0x480def=_0x541333;if(_0x1e6216<0x0)return'text';const _0x3f9c50=this[_0x480def(0x5b4)]();if(_0x3f9c50!==_0x480def(0x597)){if('rqQlq'===_0x480def(0x28a))this[_0x480def(0x5f2)]();else return _0x3f9c50;}else{const _0x3211b5=this['commandName'](_0x1e6216);if(_0x3211b5[_0x480def(0x2a3)](/\\I\[(\d+)\]/i)){const _0x7b2adb=this[_0x480def(0x347)](_0x1e6216),_0x41fd1=this['textSizeEx'](_0x3211b5)[_0x480def(0x5bc)];if(_0x41fd1<=_0x7b2adb[_0x480def(0x5bc)]){if(_0x480def(0x2e8)!==_0x480def(0x2e8))this[_0x480def(0x3a3)](),_0x4ee988[_0x480def(0x1db)][_0x480def(0x320)][_0x480def(0x562)](this),this[_0x480def(0x52a)]();else return _0x480def(0x454);}else return _0x480def(0x495);}else return'text';}},Window_ItemCategory[_0x541333(0x5f1)]['drawItemStyleIconText']=function(_0x52f8d6){const _0x453e5d=_0x541333,_0x26530f=this[_0x453e5d(0x347)](_0x52f8d6),_0x4bdaef=this[_0x453e5d(0x4f3)](_0x52f8d6),_0x2c776a=this['textSizeEx'](_0x4bdaef)['width'];this[_0x453e5d(0x29e)](this['isCommandEnabled'](_0x52f8d6));const _0x14ea4d=this[_0x453e5d(0x258)]();if(_0x14ea4d===_0x453e5d(0x263))this['drawTextEx'](_0x4bdaef,_0x26530f['x']+_0x26530f[_0x453e5d(0x5bc)]-_0x2c776a,_0x26530f['y'],_0x2c776a);else{if(_0x14ea4d===_0x453e5d(0x42a)){const _0x4ababc=_0x26530f['x']+Math[_0x453e5d(0x254)]((_0x26530f['width']-_0x2c776a)/0x2);this['drawTextEx'](_0x4bdaef,_0x4ababc,_0x26530f['y'],_0x2c776a);}else _0x453e5d(0x3b0)!=='DarvM'?this[_0x453e5d(0x5fa)](_0x4bdaef,_0x26530f['x'],_0x26530f['y'],_0x2c776a):_0x35bf9c[_0x453e5d(0x5f1)][_0x453e5d(0x434)][_0x453e5d(0x562)](this);}},Window_ItemCategory['prototype'][_0x541333(0x3d9)]=function(_0x22b1fd){const _0x3359bf=_0x541333,_0x5c5b1a=this[_0x3359bf(0x4f3)](_0x22b1fd);if(_0x5c5b1a[_0x3359bf(0x2a3)](/\\I\[(\d+)\]/i)){const _0x1e9d5e=Number(RegExp['$1'])||0x0,_0x1b059d=this[_0x3359bf(0x347)](_0x22b1fd),_0x39dd08=_0x1b059d['x']+Math[_0x3359bf(0x254)]((_0x1b059d['width']-ImageManager[_0x3359bf(0x5d8)])/0x2),_0x27c822=_0x1b059d['y']+(_0x1b059d[_0x3359bf(0x242)]-ImageManager[_0x3359bf(0x233)])/0x2;this[_0x3359bf(0x3e7)](_0x1e9d5e,_0x39dd08,_0x27c822);}},VisuMZ[_0x541333(0x1db)][_0x541333(0x2a9)]=Window_ItemCategory['prototype'][_0x541333(0x50d)],Window_ItemCategory[_0x541333(0x5f1)][_0x541333(0x50d)]=function(_0x4e5300){const _0x5a9525=_0x541333;VisuMZ['ItemsEquipsCore'][_0x5a9525(0x2a9)][_0x5a9525(0x562)](this,_0x4e5300),_0x4e5300[_0x5a9525(0x21e)]=this;},Window_ItemCategory[_0x541333(0x5f1)][_0x541333(0x1b1)]=function(){const _0x2077ca=_0x541333;Window_HorzCommand[_0x2077ca(0x5f1)][_0x2077ca(0x1b1)]['call'](this);if(this[_0x2077ca(0x390)])this['updateCategoryNameWindow']();},Window_ItemCategory[_0x541333(0x5f1)][_0x541333(0x344)]=function(){const _0x351351=_0x541333,_0x37b1b0=this[_0x351351(0x390)];_0x37b1b0[_0x351351(0x1f8)][_0x351351(0x456)]();const _0x245a38=this['categoryStyleCheck'](this[_0x351351(0x593)]());if(_0x245a38===_0x351351(0x495)){const _0x255bc0=this[_0x351351(0x347)](this[_0x351351(0x593)]());let _0x2ef824=this[_0x351351(0x4f3)](this['index']());_0x2ef824=_0x2ef824[_0x351351(0x217)](/\\I\[(\d+)\]/gi,''),_0x37b1b0[_0x351351(0x33e)](),this['categoryNameWindowDrawBackground'](_0x2ef824,_0x255bc0),this[_0x351351(0x568)](_0x2ef824,_0x255bc0),this[_0x351351(0x445)](_0x2ef824,_0x255bc0);}},Window_ItemCategory[_0x541333(0x5f1)][_0x541333(0x384)]=function(_0x203546,_0x5207e3){},Window_ItemCategory[_0x541333(0x5f1)]['categoryNameWindowDrawText']=function(_0x5d576a,_0x50793c){const _0x213df7=_0x541333,_0x355bef=this[_0x213df7(0x390)];_0x355bef[_0x213df7(0x3d2)](_0x5d576a,0x0,_0x50793c['y'],_0x355bef['innerWidth'],'center');},Window_ItemCategory[_0x541333(0x5f1)][_0x541333(0x445)]=function(_0x3bae72,_0x37d594){const _0x3add25=_0x541333,_0x1e603f=this[_0x3add25(0x390)],_0x3587f6=$gameSystem[_0x3add25(0x549)](),_0x1281e7=_0x37d594['x']+Math['floor'](_0x37d594[_0x3add25(0x5bc)]/0x2)+_0x3587f6;_0x1e603f['x']=_0x1e603f[_0x3add25(0x5bc)]/-0x2+_0x1281e7,_0x1e603f['y']=Math[_0x3add25(0x254)](_0x37d594[_0x3add25(0x242)]/0x2);},Window_ItemList['prototype']['processCursorMoveModernControls']=function(){const _0x2e584a=_0x541333;if(this[_0x2e584a(0x2fe)]()){if('imand'==='nKCnv'){const _0x525f1=_0x2a32ad[_0x2e584a(0x52c)](_0x10e9e3(_0x1a373e),0x0)/_0x381266['a'][_0x2e584a(0x261)];return this[_0x2e584a(0x1e3)](),_0x1f922e(_0x525f1)?_0x2e584a(0x259):'%1%'[_0x2e584a(0x52b)](_0x43c2ae[_0x2e584a(0x243)](_0x525f1*0x64));}else{const _0x3f2ecd=this[_0x2e584a(0x593)]();if(this[_0x2e584a(0x4c6)]()<=0x1)!this[_0x2e584a(0x5cd)]('pagedown')&&Input[_0x2e584a(0x2f6)](_0x2e584a(0x4b8))&&this[_0x2e584a(0x1c2)](),!this[_0x2e584a(0x5cd)](_0x2e584a(0x2af))&&Input['isTriggered']('pageup')&&this[_0x2e584a(0x1ed)]();else{if(this[_0x2e584a(0x4c6)]()>0x1){Input[_0x2e584a(0x45b)](_0x2e584a(0x263))&&this[_0x2e584a(0x5fc)](Input['isTriggered']('right'));Input[_0x2e584a(0x45b)](_0x2e584a(0x265))&&this[_0x2e584a(0x2b8)](Input[_0x2e584a(0x2f6)](_0x2e584a(0x265)));if(this[_0x2e584a(0x5d9)]()){if(Input[_0x2e584a(0x2f6)](_0x2e584a(0x4b8))&&Input[_0x2e584a(0x4fc)](_0x2e584a(0x228))){if(_0x2e584a(0x3a2)!==_0x2e584a(0x3a2))return _0x21a7f3[_0x2e584a(0x2eb)]&&_0x4da3ec[_0x2e584a(0x5f1)][_0x2e584a(0x539)]['call'](this);else this[_0x2e584a(0x1c2)]();}if(Input[_0x2e584a(0x2f6)](_0x2e584a(0x2af))&&Input[_0x2e584a(0x4fc)](_0x2e584a(0x228))){if(_0x2e584a(0x558)!==_0x2e584a(0x558)){const _0x32696e=_0x385e03['loadSystem']('IconSet'),_0x20ca4b=_0x598185['iconWidth'],_0x367d40=_0x1a4276[_0x2e584a(0x233)],_0x28c9a6=_0x25653f%0x10*_0x20ca4b,_0x1c2f1c=_0x4f7fbd[_0x2e584a(0x254)](_0x3ab6c1/0x10)*_0x367d40,_0x17527c=_0x4e3809['ceil'](_0x20ca4b*this[_0x2e584a(0x3a1)]()),_0x163e03=_0x52353d[_0x2e584a(0x4f4)](_0x367d40*this[_0x2e584a(0x3a1)]());this[_0x2e584a(0x1f8)]['blt'](_0x32696e,_0x28c9a6,_0x1c2f1c,_0x20ca4b,_0x367d40,_0x97c419,_0x3877b4,_0x17527c,_0x163e03);}else this[_0x2e584a(0x1ed)]();}}else Input[_0x2e584a(0x2f6)](_0x2e584a(0x4b8))&&(_0x2e584a(0x35b)===_0x2e584a(0x35b)?this[_0x2e584a(0x1c2)]():this[_0x2e584a(0x3d9)](_0x140bf1)),Input[_0x2e584a(0x2f6)](_0x2e584a(0x2af))&&this[_0x2e584a(0x1ed)]();}}if(Input[_0x2e584a(0x45b)]('down')){if(Input[_0x2e584a(0x4fc)]('shift')&&this['allowShiftScrolling']()){if('AhiFN'!==_0x2e584a(0x1f6))return _0x52c057[_0x2e584a(0x1db)][_0x2e584a(0x223)]['call'](this,_0x13f4d6);else this[_0x2e584a(0x1c2)]();}else{if('yiSsB'!==_0x2e584a(0x221)){const _0x3ccae6=this[_0x2e584a(0x3b3)]['y'],_0x5485dd=this[_0x2e584a(0x3b3)][_0x2e584a(0x5bc)],_0x253c94=this[_0x2e584a(0x5c9)](0x1,!![]),_0x3075ad=this[_0x2e584a(0x434)]()?_0x5d4b43['boxWidth']-_0x5485dd:0x0;return new _0x15524f(_0x3075ad,_0x3ccae6,_0x5485dd,_0x253c94);}else this[_0x2e584a(0x2dd)](Input[_0x2e584a(0x2f6)](_0x2e584a(0x5ab)));}}Input[_0x2e584a(0x45b)]('up')&&(_0x2e584a(0x36c)==='VisTA'?Input[_0x2e584a(0x4fc)]('shift')&&this[_0x2e584a(0x543)]()?this[_0x2e584a(0x1ed)]():this[_0x2e584a(0x2c8)](Input[_0x2e584a(0x2f6)]('up')):this[_0x2e584a(0x54b)](!![]));if(Imported[_0x2e584a(0x2eb)]){if(_0x2e584a(0x271)===_0x2e584a(0x32f)){this[_0x2e584a(0x212)]={};if(!this[_0x2e584a(0x567)])return;const _0x5e19c7=this[_0x2e584a(0x567)][_0x2e584a(0x266)];if(_0x5e19c7[_0x2e584a(0x2a3)](/<STATUS INFO>\s*([\s\S]*)\s*<\/STATUS INFO>/i)){const _0x169dd2=_0x55e3ee(_0x17bdf5['$1'])['split'](/[\r\n]+/);for(const _0x34264e of _0x169dd2){if(_0x34264e[_0x2e584a(0x2a3)](/(.*):[ ](.*)/i)){const _0x7891fd=_0x164b78(_0x52f030['$1'])['toUpperCase']()[_0x2e584a(0x399)](),_0x5d10c6=_0x223f55(_0x1146ad['$2'])[_0x2e584a(0x399)]();this[_0x2e584a(0x212)][_0x7891fd]=_0x5d10c6;}}}}else this[_0x2e584a(0x301)]();}this[_0x2e584a(0x593)]()!==_0x3f2ecd&&this[_0x2e584a(0x403)]();}}},Window_ItemList[_0x541333(0x5f1)]['limitedPageUpDownSceneCheck']=function(){const _0x24af84=_0x541333,_0x1e73b3=SceneManager[_0x24af84(0x38a)],_0x1f3bdb=[Scene_Item,Scene_Shop];return _0x1f3bdb[_0x24af84(0x53c)](_0x1e73b3[_0x24af84(0x5db)]);},Window_ItemList[_0x541333(0x5f1)][_0x541333(0x51e)]=function(){const _0x4fca30=_0x541333;Window_Selectable['prototype'][_0x4fca30(0x51e)]['call'](this),this[_0x4fca30(0x21e)]&&this[_0x4fca30(0x21e)][_0x4fca30(0x539)]()&&this['_categoryWindow'][_0x4fca30(0x51e)]();},Window_ItemList[_0x541333(0x5f1)][_0x541333(0x48a)]=function(){const _0x68b34e=_0x541333;Window_Selectable[_0x68b34e(0x5f1)][_0x68b34e(0x48a)][_0x68b34e(0x562)](this),this[_0x68b34e(0x21e)]&&this[_0x68b34e(0x21e)][_0x68b34e(0x539)]()&&this['_categoryWindow'][_0x68b34e(0x48a)]();},Window_ItemList[_0x541333(0x5f1)]['setCategory']=function(_0x20e765){const _0x258724=_0x541333;if(this['_category']!==_0x20e765){this[_0x258724(0x5a6)]=_0x20e765,this[_0x258724(0x210)]();if(this[_0x258724(0x21e)]&&this[_0x258724(0x21e)]['isUseModernControls']()){if(_0x258724(0x369)!==_0x258724(0x369))return _0x146e3d[_0x258724(0x1db)][_0x258724(0x522)][_0x258724(0x394)][_0x258724(0x34e)][_0x258724(0x562)](this);else this[_0x258724(0x43f)](0x0);}else{if(_0x258724(0x22e)!=='GqUtS')this[_0x258724(0x360)](0x0,0x0);else return _0x441ea4[_0x525280];}}},VisuMZ[_0x541333(0x1db)][_0x541333(0x24d)]=Window_ItemList[_0x541333(0x5f1)]['maxCols'],Window_ItemList['prototype'][_0x541333(0x4c6)]=function(){const _0x3b37b5=_0x541333;if(SceneManager[_0x3b37b5(0x38a)][_0x3b37b5(0x5db)]===Scene_Battle)return VisuMZ[_0x3b37b5(0x1db)][_0x3b37b5(0x24d)][_0x3b37b5(0x562)](this);else return SceneManager['_scene'][_0x3b37b5(0x5db)]===Scene_Map?VisuMZ['ItemsEquipsCore'][_0x3b37b5(0x24d)][_0x3b37b5(0x562)](this):VisuMZ[_0x3b37b5(0x1db)]['Settings']['ItemScene'][_0x3b37b5(0x556)];},VisuMZ[_0x541333(0x1db)][_0x541333(0x419)]=Window_ItemList['prototype'][_0x541333(0x2ba)],Window_ItemList[_0x541333(0x5f1)][_0x541333(0x2ba)]=function(){const _0x562cad=_0x541333;return this['maxCols']()<=0x1?Window_Selectable['prototype'][_0x562cad(0x2ba)]['call'](this):VisuMZ[_0x562cad(0x1db)][_0x562cad(0x419)][_0x562cad(0x562)](this);},Window_ItemList[_0x541333(0x5f1)][_0x541333(0x53c)]=function(_0x462ed){const _0x5381b8=_0x541333;switch(this[_0x5381b8(0x5a6)]){case _0x5381b8(0x5ae):return DataManager[_0x5381b8(0x577)](_0x462ed);case _0x5381b8(0x25d):return DataManager[_0x5381b8(0x577)](_0x462ed)&&_0x462ed[_0x5381b8(0x283)]===0x1;case _0x5381b8(0x493):return DataManager[_0x5381b8(0x577)](_0x462ed)&&_0x462ed[_0x5381b8(0x283)]===0x2;case _0x5381b8(0x5f7):return DataManager[_0x5381b8(0x577)](_0x462ed)&&_0x462ed['itypeId']===0x3;case _0x5381b8(0x297):return DataManager['isItem'](_0x462ed)&&_0x462ed[_0x5381b8(0x283)]===0x4;case _0x5381b8(0x3af):return DataManager[_0x5381b8(0x577)](_0x462ed)&&_0x462ed[_0x5381b8(0x246)];case _0x5381b8(0x594):return DataManager['isItem'](_0x462ed)&&!_0x462ed['consumable'];case'AlwaysUsable':return DataManager[_0x5381b8(0x577)](_0x462ed)&&[0x0][_0x5381b8(0x53c)](_0x462ed[_0x5381b8(0x4c1)]);case _0x5381b8(0x20b):return DataManager['isItem'](_0x462ed)&&[0x0,0x1][_0x5381b8(0x53c)](_0x462ed[_0x5381b8(0x4c1)]);case'FieldUsable':return DataManager['isItem'](_0x462ed)&&[0x0,0x2]['includes'](_0x462ed[_0x5381b8(0x4c1)]);case _0x5381b8(0x309):return DataManager['isItem'](_0x462ed)&&[0x3][_0x5381b8(0x53c)](_0x462ed['occasion']);case _0x5381b8(0x43d):return DataManager[_0x5381b8(0x30e)](_0x462ed);case _0x5381b8(0x2f3):return DataManager[_0x5381b8(0x1a6)](_0x462ed);default:if(this[_0x5381b8(0x5a6)][_0x5381b8(0x2a3)](/WTYPE:(\d+)/i))return DataManager[_0x5381b8(0x30e)](_0x462ed)&&_0x462ed['wtypeId']===Number(RegExp['$1']);else{if(this[_0x5381b8(0x5a6)]['match'](/WTYPE:(.*)/i)){if(_0x5381b8(0x3e0)===_0x5381b8(0x3e0)){const _0x248983=$dataSystem['weaponTypes'][_0x5381b8(0x525)](String(RegExp['$1'])[_0x5381b8(0x399)]());return DataManager[_0x5381b8(0x30e)](_0x462ed)&&_0x462ed['wtypeId']===_0x248983;}else{if(!_0x3a7c9b[_0x5381b8(0x5e9)](_0x5aac85))return!![];}}else{if(this[_0x5381b8(0x5a6)]['match'](/ATYPE:(\d+)/i))return DataManager[_0x5381b8(0x1a6)](_0x462ed)&&_0x462ed[_0x5381b8(0x23a)]===Number(RegExp['$1']);else{if(this[_0x5381b8(0x5a6)][_0x5381b8(0x2a3)](/ATYPE:(.*)/i)){const _0x904906=$dataSystem[_0x5381b8(0x42d)]['indexOf'](String(RegExp['$1'])[_0x5381b8(0x399)]());return DataManager['isArmor'](_0x462ed)&&_0x462ed[_0x5381b8(0x23a)]===_0x904906;}else{if(this[_0x5381b8(0x5a6)][_0x5381b8(0x2a3)](/ETYPE:(\d+)/i))return!!_0x462ed&&_0x462ed[_0x5381b8(0x25f)]===Number(RegExp['$1']);else{if(this['_category']['match'](/ETYPE:(.*)/i)){if(_0x5381b8(0x503)!=='CcMWM'){const _0x2471e3=_0x5f0776[_0x5381b8(0x5f9)]('['+_0x4361c0['$1']['match'](/\d+/g)+']');for(const _0x341748 of _0x2471e3){if(!_0x193efb['value'](_0x341748))return![];}return!![];}else{const _0x198a98=$dataSystem[_0x5381b8(0x1af)][_0x5381b8(0x525)](String(RegExp['$1'])[_0x5381b8(0x399)]());return DataManager[_0x5381b8(0x1a6)](_0x462ed)&&_0x462ed[_0x5381b8(0x25f)]===_0x198a98;}}else{if(this[_0x5381b8(0x5a6)][_0x5381b8(0x2a3)](/Category:(.*)/i))return!!_0x462ed&&_0x462ed[_0x5381b8(0x264)][_0x5381b8(0x53c)](String(RegExp['$1'])['toUpperCase']()[_0x5381b8(0x399)]());}}}}}}}return![];},Window_ItemList[_0x541333(0x5f1)][_0x541333(0x45d)]=function(){return!![];},VisuMZ[_0x541333(0x1db)]['Window_ItemList_drawItem']=Window_ItemList[_0x541333(0x5f1)][_0x541333(0x3b2)],Window_ItemList[_0x541333(0x5f1)][_0x541333(0x3b2)]=function(_0x20fd85){const _0x3e35d4=_0x541333;VisuMZ[_0x3e35d4(0x1db)][_0x3e35d4(0x1c9)][_0x3e35d4(0x562)](this,_0x20fd85),this[_0x3e35d4(0x533)](_0x20fd85);},Window_ItemList[_0x541333(0x5f1)][_0x541333(0x4d0)]=function(_0x1f72de,_0x58faf4,_0x2e0c51,_0xc599be){const _0x5dba56=_0x541333;Window_Selectable[_0x5dba56(0x5f1)][_0x5dba56(0x4d0)][_0x5dba56(0x562)](this,_0x1f72de,_0x58faf4,_0x2e0c51,_0xc599be);},Window_ItemList[_0x541333(0x5f1)][_0x541333(0x533)]=function(_0x24c408){const _0x1ea92f=_0x541333,_0x562dea=this[_0x1ea92f(0x5c6)](_0x24c408);if(!_0x562dea||!this['isShowNew']())return;if(!$gameParty[_0x1ea92f(0x3cd)](_0x562dea))return;const _0xd3675d=this['itemLineRect'](_0x24c408),_0x4c3380=_0xd3675d['x'],_0x253d80=_0xd3675d['y']+(this[_0x1ea92f(0x3da)]()-ImageManager[_0x1ea92f(0x233)])/0x2,_0x473bf6=VisuMZ[_0x1ea92f(0x1db)][_0x1ea92f(0x522)][_0x1ea92f(0x590)]['OffsetX'],_0x599fea=VisuMZ['ItemsEquipsCore'][_0x1ea92f(0x522)][_0x1ea92f(0x590)][_0x1ea92f(0x54f)];this[_0x1ea92f(0x589)](_0x562dea,_0x4c3380+_0x473bf6,_0x253d80+_0x599fea);},Window_ItemList['prototype'][_0x541333(0x3bc)]=function(_0x57554b){const _0x1033bb=_0x541333;this[_0x1033bb(0x1ee)]=_0x57554b,this[_0x1033bb(0x1b1)]();},VisuMZ[_0x541333(0x1db)]['Window_ItemList_updateHelp']=Window_ItemList[_0x541333(0x5f1)]['updateHelp'],Window_ItemList[_0x541333(0x5f1)][_0x541333(0x21f)]=function(){const _0x1cbf67=_0x541333;VisuMZ[_0x1cbf67(0x1db)]['Window_ItemList_updateHelp'][_0x1cbf67(0x562)](this);if(this[_0x1cbf67(0x1ee)]&&this[_0x1cbf67(0x1ee)][_0x1cbf67(0x5db)]===Window_ShopStatus){if('MtGcp'!=='VQEbX')this[_0x1cbf67(0x1ee)][_0x1cbf67(0x41f)](this[_0x1cbf67(0x37a)]());else{if(this[_0x1cbf67(0x59a)])return;if(!_0xa16b06[_0x1cbf67(0x1db)][_0x1cbf67(0x522)][_0x1cbf67(0x59f)][_0x1cbf67(0x1a4)])return;const _0x20b379=_0x301095[_0x1cbf67(0x243)](_0x10c433[_0x1cbf67(0x1d4)]()*this[_0x1cbf67(0x5a0)]),_0x43a9c4=_0xb0dcd[_0x1cbf67(0x243)](_0x35c03e[_0x1cbf67(0x59e)]()*this[_0x1cbf67(0x410)]);if(this['hp']>0x0)this[_0x1cbf67(0x211)](_0x20b379);if(this['mp']>0x0)this[_0x1cbf67(0x479)](_0x43a9c4);}}},Window_BattleItem[_0x541333(0x5f1)][_0x541333(0x213)]=function(_0x8c515){const _0x1915aa=_0x541333;return BattleManager['actor']()?BattleManager['actor']()[_0x1915aa(0x5c7)](_0x8c515):Window_ItemList['prototype'][_0x1915aa(0x213)]['call'](this,_0x8c515);},Window_EventItem[_0x541333(0x5f1)][_0x541333(0x45d)]=function(){return![];},Window_EquipStatus['prototype'][_0x541333(0x4ea)]=function(){const _0x4fa869=_0x541333;return VisuMZ[_0x4fa869(0x1db)][_0x4fa869(0x522)][_0x4fa869(0x59f)]['EnableLayout'];},VisuMZ['ItemsEquipsCore'][_0x541333(0x1b2)]=Window_EquipStatus[_0x541333(0x5f1)][_0x541333(0x210)],Window_EquipStatus['prototype']['refresh']=function(){const _0x3b686f=_0x541333;this['hideAdditionalSprites'](),this[_0x3b686f(0x33e)]();if(this['_actor'])this[_0x3b686f(0x4bb)][_0x3b686f(0x210)]();this[_0x3b686f(0x4ea)]()?this[_0x3b686f(0x29a)]():_0x3b686f(0x1e1)!==_0x3b686f(0x1e1)?_0xb46a8[_0x3b686f(0x5f1)][_0x3b686f(0x434)][_0x3b686f(0x562)](this):VisuMZ[_0x3b686f(0x1db)]['Window_EquipStatus_refresh']['call'](this);},Window_EquipStatus[_0x541333(0x5f1)][_0x541333(0x29a)]=function(){const _0x21330f=_0x541333;this[_0x21330f(0x1f8)][_0x21330f(0x456)]();if(!this[_0x21330f(0x4bb)])return;if(this[_0x21330f(0x3c8)]()){if(_0x21330f(0x295)===_0x21330f(0x5ff))_0x540ed4[_0x21330f(0x5f1)][_0x21330f(0x4d0)][_0x21330f(0x562)](this,_0x1524f6,_0x56cd22,_0x59e2aa,_0x254331);else{const _0x56124f=ImageManager[_0x21330f(0x3f7)](this['_actor'][_0x21330f(0x205)]());_0x56124f['addLoadListener'](this[_0x21330f(0x459)][_0x21330f(0x517)](this));}}else{if('inkxa'===_0x21330f(0x38b))this[_0x21330f(0x575)]();else return this[_0x21330f(0x269)]();}},Window_EquipStatus['prototype']['isMainMenuCoreMenuImageOptionAvailable']=function(){const _0x3e081b=_0x541333;return Imported[_0x3e081b(0x226)]&&this[_0x3e081b(0x4bb)][_0x3e081b(0x205)]()!==''&&VisuMZ[_0x3e081b(0x1db)]['Settings'][_0x3e081b(0x59f)][_0x3e081b(0x473)];},Window_EquipStatus['prototype'][_0x541333(0x459)]=function(){const _0x3ece62=_0x541333;VisuMZ[_0x3ece62(0x1db)][_0x3ece62(0x522)]['EquipScene'][_0x3ece62(0x502)]['call'](this),this[_0x3ece62(0x206)]();},Window_EquipStatus[_0x541333(0x5f1)][_0x541333(0x575)]=function(){const _0x561d53=_0x541333;VisuMZ[_0x561d53(0x1db)][_0x561d53(0x522)][_0x561d53(0x59f)][_0x561d53(0x2ea)][_0x561d53(0x562)](this),this[_0x561d53(0x206)]();},Window_EquipStatus['prototype'][_0x541333(0x206)]=function(){const _0x575d32=_0x541333;this[_0x575d32(0x33e)](),VisuMZ[_0x575d32(0x1db)][_0x575d32(0x522)][_0x575d32(0x59f)][_0x575d32(0x5aa)][_0x575d32(0x562)](this);},Window_EquipStatus[_0x541333(0x5f1)][_0x541333(0x2b1)]=function(_0x2a5978,_0x18c682,_0x57dbb8,_0x5d29e5,_0x1c21c9){const _0x41f7a7=_0x541333,_0x338fc7=ImageManager[_0x41f7a7(0x3f7)](_0x2a5978[_0x41f7a7(0x205)]()),_0x2868be=this['innerWidth']-_0x338fc7['width'];_0x18c682+=_0x2868be/0x2;if(_0x2868be<0x0)_0x5d29e5-=_0x2868be;Window_StatusBase[_0x41f7a7(0x5f1)][_0x41f7a7(0x2b1)][_0x41f7a7(0x562)](this,_0x2a5978,_0x18c682,_0x57dbb8,_0x5d29e5,_0x1c21c9);},Window_EquipStatus[_0x541333(0x5f1)][_0x541333(0x22b)]=function(){const _0x39c320=_0x541333;return Imported[_0x39c320(0x2eb)]?VisuMZ['CoreEngine'][_0x39c320(0x522)][_0x39c320(0x5d5)][_0x39c320(0x364)]:[0x0,0x1,0x2,0x3,0x4,0x5,0x6,0x7];},Window_EquipStatus[_0x541333(0x5f1)][_0x541333(0x385)]=function(){const _0x3db276=_0x541333;return VisuMZ[_0x3db276(0x1db)][_0x3db276(0x522)][_0x3db276(0x59f)][_0x3db276(0x4d4)];},Window_EquipStatus[_0x541333(0x5f1)][_0x541333(0x527)]=function(){const _0x4d6078=_0x541333;return Imported[_0x4d6078(0x2eb)]&&VisuMZ['CoreEngine'][_0x4d6078(0x522)][_0x4d6078(0x5d5)]['DrawIcons'];},Window_EquipStatus[_0x541333(0x5f1)]['drawUpdatedParamName']=function(_0x3c8efb,_0x20b7d7,_0x465066,_0x20829a){const _0x154b29=_0x541333,_0x5a5b48=this['itemPadding']();if(Imported[_0x154b29(0x2eb)]){if(_0x154b29(0x322)!==_0x154b29(0x322)){const _0x230e87=_0x2586d4[_0x154b29(0x38a)]['_actor'];_0x230e87&&(this[_0x154b29(0x542)](this[_0x154b29(0x593)]())?(this[_0x154b29(0x465)](),this['updateHelp']()):this[_0x154b29(0x3ce)]());}else this[_0x154b29(0x5ba)](_0x20b7d7+_0x5a5b48,_0x465066,_0x20829a,_0x3c8efb,![]);}else this[_0x154b29(0x3d2)](TextManager['param'](_0x3c8efb),_0x20b7d7+_0x5a5b48,_0x465066,_0x20829a);},Window_EquipStatus[_0x541333(0x5f1)]['drawUpdatedBeforeParamValue']=function(_0x19c18c,_0x4183b5,_0x2bf1a0,_0x5d5fd3){const _0x5f1619=_0x541333,_0x3f64cc=this[_0x5f1619(0x2e0)]();let _0x43a536=0x0;Imported[_0x5f1619(0x2eb)]?_0x43a536=this[_0x5f1619(0x4bb)][_0x5f1619(0x4e4)](_0x19c18c,!![]):_0x43a536=this[_0x5f1619(0x4bb)]['param'](_0x19c18c);const _0x830ad0=_0x43a536;this[_0x5f1619(0x3d2)](_0x43a536,_0x4183b5,_0x2bf1a0,_0x5d5fd3-_0x3f64cc,_0x5f1619(0x263));},Window_EquipStatus[_0x541333(0x5f1)][_0x541333(0x24f)]=function(_0xa66d5c,_0x55f81d,_0x3692c2,_0x81b231){const _0x400615=_0x541333,_0x47e221=this[_0x400615(0x2e0)]();let _0x5c6ab6=0x0,_0x104124=0x0,_0x4c4709='';if(this[_0x400615(0x59a)]){Imported['VisuMZ_0_CoreEngine']?_0x400615(0x424)===_0x400615(0x569)?_0x226005[_0x400615(0x5f1)][_0x400615(0x3b2)][_0x400615(0x562)](this,_0x48dfa2):(_0x5c6ab6=this[_0x400615(0x4bb)]['paramValueByName'](_0xa66d5c,![]),_0x104124=this[_0x400615(0x59a)][_0x400615(0x4e4)](_0xa66d5c,![]),_0x4c4709=this[_0x400615(0x59a)][_0x400615(0x4e4)](_0xa66d5c,!![])):(_0x5c6ab6=this[_0x400615(0x4bb)][_0x400615(0x334)](_0xa66d5c),_0x104124=this[_0x400615(0x59a)]['param'](_0xa66d5c),_0x4c4709=this[_0x400615(0x59a)][_0x400615(0x334)](_0xa66d5c));const _0x53e562=_0x5c6ab6,_0x590d2f=_0x104124;diffValue=_0x590d2f-_0x53e562,this['changeTextColor'](ColorManager['paramchangeTextColor'](diffValue)),this[_0x400615(0x3d2)](_0x4c4709,_0x55f81d,_0x3692c2,_0x81b231-_0x47e221,'right');}},Window_EquipStatus[_0x541333(0x5f1)][_0x541333(0x3e8)]=function(_0x48c287,_0x46a393,_0x4f5e53,_0x35187a){const _0x7532ec=_0x541333,_0xf1df86=this[_0x7532ec(0x2e0)]();let _0x35c156=0x0,_0x57c6e5=0x0,_0x109227=![];if(this['_tempActor']){Imported[_0x7532ec(0x2eb)]?(_0x35c156=this['_actor']['paramValueByName'](_0x48c287,![]),_0x57c6e5=this['_tempActor']['paramValueByName'](_0x48c287,![]),_0x109227=String(this['_actor'][_0x7532ec(0x4e4)](_0x48c287,!![]))[_0x7532ec(0x2a3)](/([%％])/i)):(_0x35c156=this[_0x7532ec(0x4bb)][_0x7532ec(0x334)](_0x48c287),_0x57c6e5=this[_0x7532ec(0x59a)]['param'](_0x48c287),_0x109227=_0x35c156%0x1!==0x0||_0x57c6e5%0x1!==0x0);const _0x22329f=_0x35c156,_0x2ea975=_0x57c6e5,_0x45d220=_0x2ea975-_0x22329f;let _0x26d4db=_0x45d220;if(_0x109227)_0x26d4db=Math[_0x7532ec(0x243)](_0x45d220*0x64)+'%';_0x45d220!==0x0&&(this['changeTextColor'](ColorManager[_0x7532ec(0x27f)](_0x45d220)),_0x26d4db=(_0x45d220>0x0?'(+%1)':_0x7532ec(0x3e9))[_0x7532ec(0x52b)](_0x26d4db),this[_0x7532ec(0x3d2)](_0x26d4db,_0x46a393+_0xf1df86,_0x4f5e53,_0x35187a,_0x7532ec(0x265)));}},Window_EquipStatus[_0x541333(0x5f1)][_0x541333(0x28c)]=function(_0xa69511,_0x53a3f1,_0x417357,_0x5996e5,_0x54fe5d){const _0x456171=_0x541333;if(VisuMZ[_0x456171(0x1db)]['Settings'][_0x456171(0x59f)]['DrawBackRect']===![])return;_0x54fe5d=Math[_0x456171(0x52c)](_0x54fe5d||0x1,0x1);while(_0x54fe5d--){if('KADTv'==='djgIg')_0x17766e+=_0x147c0c[_0x456171(0x5d8)]+0x4;else{_0x5996e5=_0x5996e5||this[_0x456171(0x3da)](),this[_0x456171(0x1f8)][_0x456171(0x29c)]=0xa0;const _0xdb1978=ColorManager['getItemsEquipsCoreBackColor2']();this['contents'][_0x456171(0x3d4)](_0xa69511+0x1,_0x53a3f1+0x1,_0x417357-0x2,_0x5996e5-0x2,_0xdb1978),this['contents']['paintOpacity']=0xff;}}},ColorManager[_0x541333(0x321)]=function(){const _0x42ded9=_0x541333,_0x505400=VisuMZ[_0x42ded9(0x1db)][_0x42ded9(0x522)][_0x42ded9(0x59f)];let _0x2745a1=_0x505400[_0x42ded9(0x53a)]!==undefined?_0x505400['BackRectColor']:0x13;return ColorManager[_0x42ded9(0x418)](_0x2745a1);},VisuMZ[_0x541333(0x1db)][_0x541333(0x5e4)]=Window_EquipCommand['prototype'][_0x541333(0x45c)],Window_EquipCommand[_0x541333(0x5f1)][_0x541333(0x45c)]=function(_0x380b52){const _0x573a4a=_0x541333;VisuMZ['ItemsEquipsCore'][_0x573a4a(0x5e4)][_0x573a4a(0x562)](this,_0x380b52),this[_0x573a4a(0x330)](_0x380b52);},Window_EquipCommand['prototype'][_0x541333(0x330)]=function(_0x27a61a){const _0x2117f3=_0x541333,_0x552ae3=new Rectangle(0x0,0x0,_0x27a61a['width'],_0x27a61a[_0x2117f3(0x242)]);this[_0x2117f3(0x44c)]=new Window_Base(_0x552ae3),this[_0x2117f3(0x44c)][_0x2117f3(0x443)]=0x0,this[_0x2117f3(0x582)](this[_0x2117f3(0x44c)]),this['updateCommandNameWindow']();},Window_EquipCommand['prototype'][_0x541333(0x1b1)]=function(){const _0x495661=_0x541333;Window_HorzCommand[_0x495661(0x5f1)]['callUpdateHelp'][_0x495661(0x562)](this);if(this[_0x495661(0x44c)])this[_0x495661(0x534)]();},Window_EquipCommand[_0x541333(0x5f1)]['updateCommandNameWindow']=function(){const _0x37643f=_0x541333,_0x190ae0=this['_commandNameWindow'];_0x190ae0['contents'][_0x37643f(0x456)]();const _0x26f89a=this[_0x37643f(0x290)](this[_0x37643f(0x593)]());if(_0x26f89a==='icon'){const _0x39a165=this['itemLineRect'](this['index']());let _0x1aeab5=this['commandName'](this[_0x37643f(0x593)]());_0x1aeab5=_0x1aeab5[_0x37643f(0x217)](/\\I\[(\d+)\]/gi,''),_0x190ae0[_0x37643f(0x33e)](),this[_0x37643f(0x20d)](_0x1aeab5,_0x39a165),this['commandNameWindowDrawText'](_0x1aeab5,_0x39a165),this[_0x37643f(0x2bc)](_0x1aeab5,_0x39a165);}},Window_EquipCommand['prototype']['commandNameWindowDrawBackground']=function(_0x4268c1,_0x55f38d){},Window_EquipCommand[_0x541333(0x5f1)]['commandNameWindowDrawText']=function(_0x3b4907,_0xc022b3){const _0x54c25e=_0x541333,_0x3b2812=this['_commandNameWindow'];_0x3b2812[_0x54c25e(0x3d2)](_0x3b4907,0x0,_0xc022b3['y'],_0x3b2812[_0x54c25e(0x20f)],_0x54c25e(0x42a));},Window_EquipCommand[_0x541333(0x5f1)][_0x541333(0x2bc)]=function(_0xb8ef6b,_0x5300c5){const _0x1aeca9=_0x541333,_0x8f770d=this[_0x1aeca9(0x44c)],_0x96ecd1=$gameSystem[_0x1aeca9(0x549)](),_0x529a14=_0x5300c5['x']+Math[_0x1aeca9(0x254)](_0x5300c5[_0x1aeca9(0x5bc)]/0x2)+_0x96ecd1;_0x8f770d['x']=_0x8f770d[_0x1aeca9(0x5bc)]/-0x2+_0x529a14,_0x8f770d['y']=Math['floor'](_0x5300c5[_0x1aeca9(0x242)]/0x2);},Window_EquipCommand[_0x541333(0x5f1)][_0x541333(0x539)]=function(){return Imported['VisuMZ_0_CoreEngine']&&Window_HorzCommand['prototype']['isUseModernControls']['call'](this);},Window_EquipCommand[_0x541333(0x5f1)]['playOkSound']=function(){const _0x4094ce=_0x541333;if(this[_0x4094ce(0x5b6)]()===_0x4094ce(0x40b))Window_HorzCommand['prototype'][_0x4094ce(0x5eb)][_0x4094ce(0x562)](this);},Window_EquipCommand[_0x541333(0x5f1)]['processCursorMoveModernControls']=function(){const _0x561637=_0x541333;!this[_0x561637(0x3a5)]()&&('aVIdg'===_0x561637(0x1f2)?_0x26b3ff[_0x561637(0x264)][_0x561637(0x282)](_0x34cac5['toUpperCase']()[_0x561637(0x399)]()):Window_HorzCommand[_0x561637(0x5f1)][_0x561637(0x2da)][_0x561637(0x562)](this));},Window_EquipCommand['prototype'][_0x541333(0x3a5)]=function(){const _0x479e99=_0x541333;if(!this[_0x479e99(0x2fe)]())return![];if(SceneManager[_0x479e99(0x38a)][_0x479e99(0x5db)]!==Scene_Equip)return![];return Input[_0x479e99(0x2f6)](_0x479e99(0x5ab))&&(this[_0x479e99(0x403)](),SceneManager[_0x479e99(0x38a)][_0x479e99(0x5a8)](),SceneManager['_scene'][_0x479e99(0x526)]['smoothSelect'](-0x1)),![];},Window_EquipCommand[_0x541333(0x5f1)][_0x541333(0x4c6)]=function(){const _0x5e6b0f=_0x541333;return this[_0x5e6b0f(0x2a6)]?this[_0x5e6b0f(0x2a6)][_0x5e6b0f(0x33d)]:0x3;},Window_EquipCommand[_0x541333(0x5f1)][_0x541333(0x4f9)]=function(){const _0x23f1c1=_0x541333;if(this[_0x23f1c1(0x2d3)]()&&this['visible']&&SceneManager[_0x23f1c1(0x38a)]['constructor']===Scene_Equip){if(this[_0x23f1c1(0x41d)]()&&TouchInput['isHovered']())this['onTouchSelectModernControls'](![]);else TouchInput[_0x23f1c1(0x2f6)]()&&this[_0x23f1c1(0x5a2)](!![]);TouchInput[_0x23f1c1(0x236)]()&&this[_0x23f1c1(0x248)]();}},Window_EquipCommand['prototype'][_0x541333(0x5a2)]=function(_0xab4bd5){const _0x57d3ac=_0x541333;this['_doubleTouch']=![];const _0x1c396e=this[_0x57d3ac(0x593)](),_0x53dc67=this['hitIndex'](),_0x276a25=SceneManager[_0x57d3ac(0x38a)]['_slotWindow'];if(_0x276a25['isOpen']()&&_0x276a25[_0x57d3ac(0x1f3)]){if(_0x53dc67>=0x0){if(_0x53dc67===this[_0x57d3ac(0x593)]()){if('fZKux'!=='fZKux'){const _0x20dd8e=_0x16c52e[_0x57d3ac(0x5f1)][_0x57d3ac(0x4c2)](0x1,_0xd7b517);if(_0x20dd8e>0x0){_0x4bb7c0+=_0x57d3ac(0x438)[_0x57d3ac(0x52b)](_0x20dd8e),_0x30b0cb++;if(_0x57bd47>=_0x3aa8ca)return _0x1b5652;}}else this[_0x57d3ac(0x46b)]=!![];}this[_0x57d3ac(0x51e)](),this[_0x57d3ac(0x251)](_0x53dc67);}else _0x276a25['hitIndex']()>=0x0&&(this[_0x57d3ac(0x48a)](),this[_0x57d3ac(0x5bf)]());}_0xab4bd5&&this[_0x57d3ac(0x593)]()!==_0x1c396e&&this['playCursorSound']();},Window_EquipCommand['prototype']['makeCommandList']=function(){const _0x562619=_0x541333;this[_0x562619(0x2e4)](),this[_0x562619(0x432)](),this[_0x562619(0x1f1)]();},Window_EquipCommand['prototype']['refresh']=function(){const _0x2709e3=_0x541333;Window_HorzCommand[_0x2709e3(0x5f1)][_0x2709e3(0x210)][_0x2709e3(0x562)](this),this[_0x2709e3(0x511)]();},Window_EquipCommand[_0x541333(0x5f1)][_0x541333(0x2e4)]=function(){const _0x41d8b7=_0x541333;if(!this[_0x41d8b7(0x1a9)]())return;const _0x4bf4b4=this['commandStyle'](),_0x229d58=VisuMZ[_0x41d8b7(0x1db)][_0x41d8b7(0x522)][_0x41d8b7(0x59f)][_0x41d8b7(0x2f4)],_0x456845=_0x4bf4b4===_0x41d8b7(0x286)?TextManager[_0x41d8b7(0x545)]:'\x5cI[%1]%2'['format'](_0x229d58,TextManager[_0x41d8b7(0x545)]),_0x20b5a2=this[_0x41d8b7(0x4ee)]();this[_0x41d8b7(0x2a8)](_0x456845,_0x41d8b7(0x40b),_0x20b5a2);},Window_EquipCommand[_0x541333(0x5f1)][_0x541333(0x1a9)]=function(){const _0x235e6a=_0x541333;return!this[_0x235e6a(0x539)]();},Window_EquipCommand[_0x541333(0x5f1)]['isEquipCommandEnabled']=function(){return!![];},Window_EquipCommand[_0x541333(0x5f1)][_0x541333(0x432)]=function(){const _0x1150c3=_0x541333;if(!this[_0x1150c3(0x38c)]())return;const _0x57a9b9=this[_0x1150c3(0x1d0)](),_0x5f4070=VisuMZ['ItemsEquipsCore'][_0x1150c3(0x522)][_0x1150c3(0x59f)][_0x1150c3(0x3a0)],_0x423aa0=_0x57a9b9===_0x1150c3(0x286)?TextManager['optimize']:_0x1150c3(0x435)[_0x1150c3(0x52b)](_0x5f4070,TextManager[_0x1150c3(0x31c)]),_0x43699e=this[_0x1150c3(0x538)]();this[_0x1150c3(0x2a8)](_0x423aa0,_0x1150c3(0x31c),_0x43699e);},Window_EquipCommand[_0x541333(0x5f1)][_0x541333(0x38c)]=function(){const _0x21b308=_0x541333;return VisuMZ['ItemsEquipsCore'][_0x21b308(0x522)][_0x21b308(0x59f)][_0x21b308(0x37e)];},Window_EquipCommand['prototype'][_0x541333(0x538)]=function(){return!![];},Window_EquipCommand[_0x541333(0x5f1)][_0x541333(0x1f1)]=function(){const _0x19629e=_0x541333;if(!this[_0x19629e(0x2b7)]())return;const _0x525243=this[_0x19629e(0x1d0)](),_0xe53a74=VisuMZ[_0x19629e(0x1db)][_0x19629e(0x522)][_0x19629e(0x59f)][_0x19629e(0x4d2)],_0x34f0a5=_0x525243===_0x19629e(0x286)?TextManager[_0x19629e(0x456)]:_0x19629e(0x435)[_0x19629e(0x52b)](_0xe53a74,TextManager[_0x19629e(0x456)]),_0x2d7bcd=this['isClearCommandEnabled']();this[_0x19629e(0x2a8)](_0x34f0a5,_0x19629e(0x456),_0x2d7bcd);},Window_EquipCommand[_0x541333(0x5f1)][_0x541333(0x2b7)]=function(){const _0x5f0911=_0x541333;return VisuMZ[_0x5f0911(0x1db)][_0x5f0911(0x522)][_0x5f0911(0x59f)][_0x5f0911(0x513)];},Window_EquipCommand['prototype'][_0x541333(0x4cc)]=function(){return!![];},Window_EquipCommand[_0x541333(0x5f1)]['itemTextAlign']=function(){const _0x509f6e=_0x541333;return VisuMZ[_0x509f6e(0x1db)]['Settings'][_0x509f6e(0x59f)]['CmdTextAlign'];},Window_EquipCommand[_0x541333(0x5f1)][_0x541333(0x3b2)]=function(_0x1ee21a){const _0x5b7fd5=_0x541333,_0x522a90=this[_0x5b7fd5(0x290)](_0x1ee21a);if(_0x522a90==='iconText')this[_0x5b7fd5(0x5ce)](_0x1ee21a);else _0x522a90==='icon'?this[_0x5b7fd5(0x3d9)](_0x1ee21a):Window_HorzCommand['prototype'][_0x5b7fd5(0x3b2)]['call'](this,_0x1ee21a);},Window_EquipCommand['prototype'][_0x541333(0x1d0)]=function(){const _0x278fb0=_0x541333;return VisuMZ[_0x278fb0(0x1db)][_0x278fb0(0x522)][_0x278fb0(0x59f)][_0x278fb0(0x50c)];},Window_EquipCommand['prototype']['commandStyleCheck']=function(_0x89daf7){const _0x594550=_0x541333;if(_0x89daf7<0x0)return _0x594550(0x286);const _0x2c0402=this[_0x594550(0x1d0)]();if(_0x2c0402!==_0x594550(0x597))return _0x2c0402;else{if(this[_0x594550(0x574)]()>0x0){const _0xe69aa6=this[_0x594550(0x4f3)](_0x89daf7);if(_0xe69aa6['match'](/\\I\[(\d+)\]/i)){const _0x49c142=this[_0x594550(0x347)](_0x89daf7),_0x3fd24c=this['textSizeEx'](_0xe69aa6)[_0x594550(0x5bc)];if(_0x3fd24c<=_0x49c142['width']){if(_0x594550(0x409)!==_0x594550(0x4a5))return _0x594550(0x454);else this[_0x594550(0x33e)](),_0x539820[_0x594550(0x1db)][_0x594550(0x522)][_0x594550(0x59f)][_0x594550(0x5aa)][_0x594550(0x562)](this);}else return _0x594550(0x495);}}}return _0x594550(0x286);},Window_EquipCommand[_0x541333(0x5f1)]['drawItemStyleIconText']=function(_0x302561){const _0x4c8bd6=_0x541333,_0x14130c=this[_0x4c8bd6(0x347)](_0x302561),_0x46f3ef=this[_0x4c8bd6(0x4f3)](_0x302561),_0x1ede24=this[_0x4c8bd6(0x3f9)](_0x46f3ef)[_0x4c8bd6(0x5bc)];this[_0x4c8bd6(0x29e)](this[_0x4c8bd6(0x2a1)](_0x302561));const _0x5bf2ef=this[_0x4c8bd6(0x258)]();if(_0x5bf2ef===_0x4c8bd6(0x263))_0x4c8bd6(0x5f6)!==_0x4c8bd6(0x5f6)?(this[_0x4c8bd6(0x1bc)](),this[_0x4c8bd6(0x455)](),this[_0x4c8bd6(0x4e3)]()):this['drawTextEx'](_0x46f3ef,_0x14130c['x']+_0x14130c['width']-_0x1ede24,_0x14130c['y'],_0x1ede24);else{if(_0x5bf2ef===_0x4c8bd6(0x42a)){if('lRzmt'!==_0x4c8bd6(0x2b2)){const _0x3f23e4=_0x14130c['x']+Math['floor']((_0x14130c[_0x4c8bd6(0x5bc)]-_0x1ede24)/0x2);this[_0x4c8bd6(0x5fa)](_0x46f3ef,_0x3f23e4,_0x14130c['y'],_0x1ede24);}else{_0x2117a8[_0x4c8bd6(0x1db)][_0x4c8bd6(0x59b)][_0x4c8bd6(0x562)](this,_0x3b9fb4);if(_0x48ff8a<=0x0)return;const _0x3d7c37=_0x920528[_0x4c8bd6(0x1db)][_0x4c8bd6(0x522)][_0x4c8bd6(0x3c6)];_0x3d7c37[_0x4c8bd6(0x38f)]&&_0x5b9cbe[_0x4c8bd6(0x32b)](_0x3d7c37[_0x4c8bd6(0x38f)],!![]);}}else this[_0x4c8bd6(0x5fa)](_0x46f3ef,_0x14130c['x'],_0x14130c['y'],_0x1ede24);}},Window_EquipCommand['prototype'][_0x541333(0x3d9)]=function(_0x429a63){const _0x3ddaf8=_0x541333;this['commandName'](_0x429a63)[_0x3ddaf8(0x2a3)](/\\I\[(\d+)\]/i);const _0x408ada=Number(RegExp['$1'])||0x0,_0xb3b33e=this[_0x3ddaf8(0x347)](_0x429a63),_0x180bda=_0xb3b33e['x']+Math['floor']((_0xb3b33e[_0x3ddaf8(0x5bc)]-ImageManager['iconWidth'])/0x2),_0x105030=_0xb3b33e['y']+(_0xb3b33e[_0x3ddaf8(0x242)]-ImageManager[_0x3ddaf8(0x233)])/0x2;this[_0x3ddaf8(0x3e7)](_0x408ada,_0x180bda,_0x105030);},Window_EquipSlot[_0x541333(0x5f1)][_0x541333(0x539)]=function(){const _0x3e7067=_0x541333;return Imported['VisuMZ_0_CoreEngine']&&Window_HorzCommand[_0x3e7067(0x5f1)][_0x3e7067(0x539)][_0x3e7067(0x562)](this);},Window_EquipSlot[_0x541333(0x5f1)]['activate']=function(){const _0x5db0f1=_0x541333;Window_StatusBase[_0x5db0f1(0x5f1)][_0x5db0f1(0x51e)][_0x5db0f1(0x562)](this),this[_0x5db0f1(0x1b1)]();},Window_EquipSlot[_0x541333(0x5f1)][_0x541333(0x43e)]=function(){const _0x32db6b=_0x541333;Window_StatusBase[_0x32db6b(0x5f1)][_0x32db6b(0x43e)]['call'](this),this['checkShiftRemoveShortcut']();},Window_EquipSlot['prototype'][_0x541333(0x59c)]=function(){const _0x2ff9c9=_0x541333;if(!this[_0x2ff9c9(0x3c2)]())return;if(Input[_0x2ff9c9(0x2f6)](_0x2ff9c9(0x228))&&this[_0x2ff9c9(0x37a)]()){if(_0x2ff9c9(0x388)!==_0x2ff9c9(0x388))this['postCreateSlotWindowItemsEquipsCore']();else{const _0x48241b=SceneManager[_0x2ff9c9(0x38a)][_0x2ff9c9(0x4bb)];if(_0x48241b){if(_0x2ff9c9(0x362)!=='MepNr')this['canShiftRemoveEquipment'](this[_0x2ff9c9(0x593)]())?(this['processShiftRemoveShortcut'](),this[_0x2ff9c9(0x21f)]()):this[_0x2ff9c9(0x3ce)]();else return this[_0x2ff9c9(0x548)]()[_0x2ff9c9(0x53c)](this[_0x2ff9c9(0x2b4)]()[_0x45556e])?![]:this[_0x2ff9c9(0x304)](_0x2d7cf7);}}}},Window_EquipSlot[_0x541333(0x5f1)][_0x541333(0x542)]=function(_0x86a651){const _0x202cc4=_0x541333,_0x5d9822=SceneManager[_0x202cc4(0x38a)][_0x202cc4(0x4bb)];if(!_0x5d9822)return;if(!_0x5d9822[_0x202cc4(0x304)](this[_0x202cc4(0x593)]()))return![];const _0x1ed778=_0x5d9822[_0x202cc4(0x2b4)]()[this[_0x202cc4(0x593)]()];if(_0x5d9822[_0x202cc4(0x433)]()[_0x202cc4(0x53c)](_0x1ed778)){if('QklCe'!==_0x202cc4(0x5b9)){const _0xf33f20=_0x2d73c3-(_0x4bb609-_0x1cf70e)/0x2;this[_0x202cc4(0x1dd)](_0x2a8350,_0x258603,_0x33cbff,_0xf33f20,_0x3f9418),_0x4ffbe7+=_0x283dc4;}else return![];}return!![];;},Window_EquipSlot[_0x541333(0x5f1)][_0x541333(0x465)]=function(){const _0x3ea645=_0x541333;SoundManager['playEquip']();const _0x1a370c=SceneManager[_0x3ea645(0x38a)]['_actor'];_0x1a370c['changeEquip'](this[_0x3ea645(0x593)](),null),this['refresh'](),this[_0x3ea645(0x1b6)][_0x3ea645(0x210)](),this[_0x3ea645(0x1b1)]();const _0x2a6ca6=SceneManager['_scene']['_statusWindow'];if(_0x2a6ca6)_0x2a6ca6['refresh']();},Window_EquipSlot['prototype'][_0x541333(0x3c2)]=function(){const _0x45653c=_0x541333;if(!this['active'])return![];if(!VisuMZ[_0x45653c(0x1db)][_0x45653c(0x522)][_0x45653c(0x59f)][_0x45653c(0x1a5)])return![];return!![];},Window_EquipSlot[_0x541333(0x5f1)]['processCursorMoveModernControls']=function(){const _0x3ebff2=_0x541333;!this[_0x3ebff2(0x3a5)]()&&Window_StatusBase['prototype'][_0x3ebff2(0x2da)]['call'](this);},Window_EquipSlot[_0x541333(0x5f1)]['processCursorSpecialCheckModernControls']=function(){const _0x3658cc=_0x541333;if(!this[_0x3658cc(0x2fe)]())return![];if(SceneManager[_0x3658cc(0x38a)]['constructor']!==Scene_Equip)return![];if(this[_0x3658cc(0x450)]())return this[_0x3658cc(0x403)](),Input['clear'](),SceneManager[_0x3658cc(0x38a)][_0x3658cc(0x255)](),![];else{if(Input[_0x3658cc(0x45b)](_0x3658cc(0x5ab))){const _0x2fd550=this['index']();return Input[_0x3658cc(0x4fc)](_0x3658cc(0x228))?this[_0x3658cc(0x1c2)]():_0x3658cc(0x5c2)!==_0x3658cc(0x3f6)?this['cursorDown'](Input['isTriggered'](_0x3658cc(0x5ab))):(_0x95e389[_0x3658cc(0x1db)]['Scene_Item_createCategoryWindow'][_0x3658cc(0x562)](this),this['isUseModernControls']()&&this[_0x3658cc(0x5f2)]()),this[_0x3658cc(0x593)]()!==_0x2fd550&&this[_0x3658cc(0x403)](),!![];}else{if(this['isShiftShortcutKeyForRemove']()&&Input[_0x3658cc(0x2f6)]('shift')){if(_0x3658cc(0x339)===_0x3658cc(0x398))_0x143e4b[_0x3658cc(0x443)]=this[_0x3658cc(0x471)];else return!![];}}}return![];},Window_EquipSlot['prototype'][_0x541333(0x450)]=function(){const _0x411b72=_0x541333;if(this[_0x411b72(0x593)]()!==0x0)return![];const _0x2f1a3b=VisuMZ[_0x411b72(0x1db)][_0x411b72(0x522)][_0x411b72(0x59f)];if(!_0x2f1a3b[_0x411b72(0x37e)]&&!_0x2f1a3b[_0x411b72(0x513)])return![];return Input[_0x411b72(0x2f6)]('up');},Window_EquipSlot[_0x541333(0x5f1)][_0x541333(0x2be)]=function(){const _0x2d00b8=_0x541333;return VisuMZ[_0x2d00b8(0x1db)]['Settings'][_0x2d00b8(0x59f)]['ShiftShortcutKey'];},Window_EquipSlot[_0x541333(0x5f1)][_0x541333(0x4f9)]=function(){const _0x5a2fc3=_0x541333;if(this['isOpen']()&&this[_0x5a2fc3(0x1f3)]&&SceneManager[_0x5a2fc3(0x38a)][_0x5a2fc3(0x5db)]===Scene_Equip){if(this[_0x5a2fc3(0x41d)]()&&TouchInput[_0x5a2fc3(0x24a)]())this[_0x5a2fc3(0x5a2)](![]);else TouchInput[_0x5a2fc3(0x2f6)]()&&this[_0x5a2fc3(0x5a2)](!![]);if(TouchInput[_0x5a2fc3(0x236)]())this[_0x5a2fc3(0x248)]();else{if(TouchInput[_0x5a2fc3(0x5c0)]()){if(_0x5a2fc3(0x249)!==_0x5a2fc3(0x249))return _0x1726b4[_0x5a2fc3(0x1db)][_0x5a2fc3(0x522)][_0x5a2fc3(0x510)][_0x5a2fc3(0x1a2)];else this[_0x5a2fc3(0x375)]();}}}},Window_EquipSlot['prototype'][_0x541333(0x5a2)]=function(_0x160bc3){const _0xe39dc4=_0x541333;this['_doubleTouch']=![];const _0x39a836=this[_0xe39dc4(0x593)](),_0x43ba46=this['hitIndex'](),_0x2676a4=SceneManager['_scene'][_0xe39dc4(0x3b3)];if(_0x2676a4['isOpen']()&&_0x2676a4[_0xe39dc4(0x1f3)]){if(_0x43ba46>=0x0){if(_0xe39dc4(0x408)==='KCHBD')return this[_0xe39dc4(0x5cb)](_0x26e37d(_0x18dd0c['$1'])[_0xe39dc4(0x514)](0x0,0x1f));else _0x43ba46===this[_0xe39dc4(0x593)]()&&(this['_doubleTouch']=!![]),this['activate'](),this['select'](_0x43ba46);}else{if(_0x2676a4[_0xe39dc4(0x23b)]()>=0x0){if(_0xe39dc4(0x4a3)!==_0xe39dc4(0x4a3))return!![];else this[_0xe39dc4(0x48a)](),this['deselect']();}}}if(_0x160bc3&&this[_0xe39dc4(0x593)]()!==_0x39a836){if(_0xe39dc4(0x4d9)!==_0xe39dc4(0x4d9)){this[_0xe39dc4(0x33e)](),this['contents']['fontSize']=this[_0xe39dc4(0x224)]();let _0x3ed0bb=this[_0xe39dc4(0x4e5)](_0x446805[_0xe39dc4(0x334)](_0x2bcabc))+0x4+_0x461542;return _0x3ef08b[_0xe39dc4(0x2eb)]?(this[_0xe39dc4(0x5ba)](_0x3c97c5,_0x211145,_0x3790ac,_0x586980,!![]),_0x55bdd2[_0xe39dc4(0x406)]['Settings']['Param']['DrawIcons']&&(_0x3ed0bb+=_0x1f625c[_0xe39dc4(0x5d8)]+0x4)):(this['changeTextColor'](_0x4c0da4[_0xe39dc4(0x386)]()),this[_0xe39dc4(0x3d2)](_0x17d9fd[_0xe39dc4(0x334)](_0x4a7197),_0x5a5bf3,_0x55e849,_0x45e2c6)),this[_0xe39dc4(0x33e)](),_0x3ed0bb;}else this[_0xe39dc4(0x403)]();}},Window_EquipSlot['prototype']['equipSlotIndex']=function(){const _0x4919f6=_0x541333;return this[_0x4919f6(0x593)]();},VisuMZ[_0x541333(0x1db)][_0x541333(0x223)]=Window_EquipItem[_0x541333(0x5f1)][_0x541333(0x53c)],Window_EquipItem['prototype'][_0x541333(0x53c)]=function(_0x486b9f){const _0x251e28=_0x541333;return _0x486b9f===null&&this['nonRemovableEtypes']()[_0x251e28(0x53c)](this['etypeId']())?![]:VisuMZ['ItemsEquipsCore'][_0x251e28(0x223)][_0x251e28(0x562)](this,_0x486b9f);},VisuMZ[_0x541333(0x1db)][_0x541333(0x22f)]=Window_EquipItem[_0x541333(0x5f1)][_0x541333(0x213)],Window_EquipItem[_0x541333(0x5f1)]['isEnabled']=function(_0x1dad05){const _0xed62af=_0x541333;if(_0x1dad05&&this[_0xed62af(0x4bb)]){if(this[_0xed62af(0x1ab)](_0x1dad05))return![];if(this[_0xed62af(0x421)](_0x1dad05))return![];if(this['isSoleArmorType'](_0x1dad05))return![];}if(!_0x1dad05)return!this[_0xed62af(0x433)]()[_0xed62af(0x53c)](this[_0xed62af(0x25f)]());return VisuMZ[_0xed62af(0x1db)][_0xed62af(0x22f)][_0xed62af(0x562)](this,_0x1dad05);},Window_EquipItem[_0x541333(0x5f1)]['itemHasEquipLimit']=function(_0x18e2b1){const _0x1a878c=_0x541333,_0x34adbb=_0x18e2b1[_0x1a878c(0x266)];if(_0x34adbb[_0x1a878c(0x2a3)](/<EQUIP COPY LIMIT:[ ](\d+)>/i)){const _0x2453e1=Number(RegExp['$1'])||0x1;let _0x505561=0x0;const _0x25f05c=this[_0x1a878c(0x4bb)][_0x1a878c(0x34b)](),_0x20b066=SceneManager[_0x1a878c(0x38a)][_0x1a878c(0x526)]['equipSlotIndex']();_0x25f05c[_0x20b066]=null;for(const _0xad9fa8 of _0x25f05c){if(_0x1a878c(0x512)===_0x1a878c(0x332)){const _0x8a1d80=_0x810447[_0x1a878c(0x48e)]()[_0x1a878c(0x525)](_0x4cce14),_0x36e741=_0x41a1f3+_0xc63534+_0x8a1d80*_0xfca587;this['changePaintOpacity'](_0x300563[_0x1a878c(0x3cb)](this['_item'])),this['drawActorCharacter'](_0x5bf653,_0x36e741+_0x4b4f00/0x2,_0x33174a);let _0x4df916=_0x3d7fb0;for(const _0x1f28f2 of _0x4d0af4){const _0x48281d=_0x4df916-(_0x3ebc61-_0x53b5b7)/0x2;this[_0x1a878c(0x1dd)](_0x4c4604,_0x1f28f2,_0x36e741,_0x48281d,_0x506c55),_0x4df916+=_0x1587ea;}}else{if(!_0xad9fa8)continue;if(DataManager[_0x1a878c(0x30e)](_0x18e2b1)===DataManager[_0x1a878c(0x30e)](_0xad9fa8)){if(_0x1a878c(0x227)!==_0x1a878c(0x476)){if(_0x18e2b1['id']===_0xad9fa8['id'])_0x505561+=0x1;}else{const _0x1ecb3d=this['itemPadding']();_0x3ebbc4[_0x1a878c(0x2eb)]?this[_0x1a878c(0x5ba)](_0x1bea04+_0x1ecb3d,_0xeb57ce,_0x5315f5,_0xde310c,![]):this[_0x1a878c(0x3d2)](_0x15232c['param'](_0x21c672),_0x2a5240+_0x1ecb3d,_0x449f52,_0x29b200);}}}}return _0x505561>=_0x2453e1;}else return![];},Window_EquipItem['prototype'][_0x541333(0x421)]=function(_0x358056){const _0x14c829=_0x541333;if(!DataManager[_0x14c829(0x30e)](_0x358056))return![];const _0x20de87=/<EQUIP WEAPON TYPE LIMIT:[ ](\d+)>/i;let _0x191801=0x0;const _0x363e76=this[_0x14c829(0x4bb)][_0x14c829(0x34b)](),_0x43bebd=SceneManager['_scene'][_0x14c829(0x526)][_0x14c829(0x241)]();_0x363e76[_0x43bebd]=null;for(const _0x1b2395 of _0x363e76){if(_0x14c829(0x3e5)===_0x14c829(0x3e5)){if(!_0x1b2395)continue;if(!DataManager[_0x14c829(0x30e)](_0x1b2395))continue;if(_0x358056[_0x14c829(0x3b4)]===_0x1b2395[_0x14c829(0x3b4)]){_0x191801+=0x1;if(_0x358056[_0x14c829(0x266)]['match'](_0x20de87)){const _0x8c0d61=Number(RegExp['$1'])||0x1;if(_0x191801>=_0x8c0d61)return!![];}if(_0x1b2395[_0x14c829(0x266)][_0x14c829(0x2a3)](_0x20de87)){const _0x48e126=Number(RegExp['$1'])||0x1;if(_0x191801>=_0x48e126)return!![];}}}else{if(this[_0x14c829(0x41d)]()&&_0x27f1e9['isHovered']())this[_0x14c829(0x5a2)](![]);else _0x8f66f0[_0x14c829(0x2f6)]()&&this[_0x14c829(0x5a2)](!![]);_0x3a4dc0[_0x14c829(0x236)]()&&this['onTouchOk']();}}return![];},Window_EquipItem[_0x541333(0x5f1)][_0x541333(0x2bb)]=function(_0x2b9b82){const _0x1c11b5=_0x541333;if(!DataManager[_0x1c11b5(0x1a6)](_0x2b9b82))return![];const _0xbf88db=/<EQUIP ARMOR TYPE LIMIT:[ ](\d+)>/i;let _0x1ce8f5=0x0;const _0x296b46=this[_0x1c11b5(0x4bb)][_0x1c11b5(0x34b)](),_0x3c9602=SceneManager[_0x1c11b5(0x38a)][_0x1c11b5(0x526)][_0x1c11b5(0x241)]();_0x296b46[_0x3c9602]=null;for(const _0x1591e7 of _0x296b46){if(!_0x1591e7)continue;if(!DataManager[_0x1c11b5(0x1a6)](_0x1591e7))continue;if(_0x2b9b82['atypeId']===_0x1591e7['atypeId']){_0x1ce8f5+=0x1;if(_0x2b9b82[_0x1c11b5(0x266)][_0x1c11b5(0x2a3)](_0xbf88db)){const _0x5e423d=Number(RegExp['$1'])||0x1;if(_0x1ce8f5>=_0x5e423d)return!![];}if(_0x1591e7['note'][_0x1c11b5(0x2a3)](_0xbf88db)){const _0x1353c6=Number(RegExp['$1'])||0x1;if(_0x1ce8f5>=_0x1353c6)return!![];}}}return![];},Window_EquipItem[_0x541333(0x5f1)][_0x541333(0x433)]=function(){const _0x26712a=_0x541333;return VisuMZ[_0x26712a(0x1db)][_0x26712a(0x522)][_0x26712a(0x59f)][_0x26712a(0x4e0)];},Window_EquipItem[_0x541333(0x5f1)]['drawItem']=function(_0x229984){const _0x212df7=_0x541333,_0x4fe69c=this[_0x212df7(0x5c6)](_0x229984);if(_0x4fe69c)Window_ItemList['prototype']['drawItem'][_0x212df7(0x562)](this,_0x229984);else{if(_0x212df7(0x4eb)===_0x212df7(0x4eb))this['drawRemoveItem'](_0x229984);else{if(!_0x47d783['value'](_0x404aae))return!![];}}},Window_EquipItem['prototype'][_0x541333(0x5ad)]=function(_0x222e99){const _0x376f8c=_0x541333;this[_0x376f8c(0x29e)](this['isEnabled'](null));const _0x298975=VisuMZ[_0x376f8c(0x1db)][_0x376f8c(0x522)]['EquipScene'],_0xf13668=this[_0x376f8c(0x347)](_0x222e99),_0x8abc90=_0xf13668['y']+(this[_0x376f8c(0x3da)]()-ImageManager[_0x376f8c(0x233)])/0x2,_0x4cbcc3=ImageManager['iconWidth']+0x4,_0x5d3a4b=Math[_0x376f8c(0x52c)](0x0,_0xf13668[_0x376f8c(0x5bc)]-_0x4cbcc3);this[_0x376f8c(0x4b0)](),this[_0x376f8c(0x3e7)](_0x298975[_0x376f8c(0x31b)],_0xf13668['x'],_0x8abc90),this[_0x376f8c(0x3d2)](_0x298975['RemoveEquipText'],_0xf13668['x']+_0x4cbcc3,_0xf13668['y'],_0x5d3a4b),this[_0x376f8c(0x29e)](!![]);},Window_EquipItem[_0x541333(0x5f1)][_0x541333(0x21f)]=function(){const _0x598e94=_0x541333;Window_ItemList[_0x598e94(0x5f1)][_0x598e94(0x21f)]['call'](this);if(this['_actor']&&this[_0x598e94(0x1ee)]&&this[_0x598e94(0x458)]>=0x0){const _0x2ae1da=JsonEx[_0x598e94(0x472)](this[_0x598e94(0x4bb)]);_0x2ae1da['_tempActor']=!![],_0x2ae1da[_0x598e94(0x5fe)](this[_0x598e94(0x458)],this['item']()),this['_statusWindow'][_0x598e94(0x5e1)](_0x2ae1da);}},VisuMZ[_0x541333(0x1db)]['Window_ShopCommand_initialize']=Window_ShopCommand['prototype'][_0x541333(0x45c)],Window_ShopCommand[_0x541333(0x5f1)][_0x541333(0x45c)]=function(_0x2a1311){const _0x13f0dc=_0x541333;VisuMZ['ItemsEquipsCore'][_0x13f0dc(0x2f5)][_0x13f0dc(0x562)](this,_0x2a1311),this[_0x13f0dc(0x330)](_0x2a1311);},Window_ShopCommand[_0x541333(0x5f1)]['createCommandNameWindow']=function(_0x4b28a1){const _0xef3e9c=_0x541333,_0x42f565=new Rectangle(0x0,0x0,_0x4b28a1[_0xef3e9c(0x5bc)],_0x4b28a1[_0xef3e9c(0x242)]);this['_commandNameWindow']=new Window_Base(_0x42f565),this[_0xef3e9c(0x44c)][_0xef3e9c(0x443)]=0x0,this[_0xef3e9c(0x582)](this['_commandNameWindow']),this[_0xef3e9c(0x534)]();},Window_ShopCommand[_0x541333(0x5f1)]['callUpdateHelp']=function(){const _0x392e3a=_0x541333;Window_HorzCommand[_0x392e3a(0x5f1)]['callUpdateHelp'][_0x392e3a(0x562)](this);if(this['_commandNameWindow'])this[_0x392e3a(0x534)]();},Window_ShopCommand['prototype']['updateCommandNameWindow']=function(){const _0x102eef=_0x541333,_0x358bb5=this[_0x102eef(0x44c)];_0x358bb5[_0x102eef(0x1f8)][_0x102eef(0x456)]();const _0x438e44=this[_0x102eef(0x290)](this[_0x102eef(0x593)]());if(_0x438e44==='icon'){if(_0x102eef(0x5dd)!==_0x102eef(0x5dd)){const _0x3b1e6b=_0x102eef(0x5f0);if(this[_0x102eef(0x212)][_0x3b1e6b])return this['_customItemInfo'][_0x3b1e6b];const _0x3b9abe=_0x36aaf8[_0x102eef(0x1db)][_0x102eef(0x522)][_0x102eef(0x394)][_0x102eef(0x4af)];return _0x3b9abe[_0x102eef(0x52b)](_0x26d757[_0x102eef(0x231)](this[_0x102eef(0x567)]));}else{const _0x40921c=this[_0x102eef(0x347)](this[_0x102eef(0x593)]());let _0x14f823=this[_0x102eef(0x4f3)](this['index']());_0x14f823=_0x14f823[_0x102eef(0x217)](/\\I\[(\d+)\]/gi,''),_0x358bb5[_0x102eef(0x33e)](),this['commandNameWindowDrawBackground'](_0x14f823,_0x40921c),this[_0x102eef(0x2cf)](_0x14f823,_0x40921c),this[_0x102eef(0x2bc)](_0x14f823,_0x40921c);}}},Window_ShopCommand[_0x541333(0x5f1)][_0x541333(0x20d)]=function(_0x45dbf2,_0x28e97e){},Window_ShopCommand[_0x541333(0x5f1)][_0x541333(0x2cf)]=function(_0x5dd70d,_0x1d2d51){const _0x35c67d=_0x541333,_0x10d1f8=this[_0x35c67d(0x44c)];_0x10d1f8[_0x35c67d(0x3d2)](_0x5dd70d,0x0,_0x1d2d51['y'],_0x10d1f8[_0x35c67d(0x20f)],_0x35c67d(0x42a));},Window_ShopCommand[_0x541333(0x5f1)][_0x541333(0x2bc)]=function(_0x12a93f,_0x5b7adf){const _0x10ea19=_0x541333,_0x5bbce9=this[_0x10ea19(0x44c)],_0x3a6ca2=$gameSystem[_0x10ea19(0x549)](),_0x25ffa2=_0x5b7adf['x']+Math[_0x10ea19(0x254)](_0x5b7adf[_0x10ea19(0x5bc)]/0x2)+_0x3a6ca2;_0x5bbce9['x']=_0x5bbce9[_0x10ea19(0x5bc)]/-0x2+_0x25ffa2,_0x5bbce9['y']=Math[_0x10ea19(0x254)](_0x5b7adf[_0x10ea19(0x242)]/0x2);},Window_ShopCommand[_0x541333(0x5f1)][_0x541333(0x4c6)]=function(){const _0x473ebd=_0x541333;return this[_0x473ebd(0x2a6)]?this[_0x473ebd(0x2a6)][_0x473ebd(0x33d)]:0x3;},Window_ShopCommand['prototype'][_0x541333(0x1ca)]=function(){const _0x37b250=_0x541333;return VisuMZ[_0x37b250(0x1db)]['Settings']['ShopScene'][_0x37b250(0x48d)];},Window_ShopCommand[_0x541333(0x5f1)][_0x541333(0x4e2)]=function(){const _0x327c94=_0x541333;this[_0x327c94(0x1bc)](),this['addSellCommand'](),this[_0x327c94(0x4e3)]();},Window_ShopCommand[_0x541333(0x5f1)][_0x541333(0x210)]=function(){const _0x1484ca=_0x541333;Window_HorzCommand[_0x1484ca(0x5f1)][_0x1484ca(0x210)][_0x1484ca(0x562)](this),this[_0x1484ca(0x511)]();},Window_ShopCommand[_0x541333(0x5f1)][_0x541333(0x1bc)]=function(){const _0x1db4c9=_0x541333,_0x465c92=this[_0x1db4c9(0x1d0)](),_0xdfb191=VisuMZ[_0x1db4c9(0x1db)][_0x1db4c9(0x522)]['ShopScene'][_0x1db4c9(0x3d1)],_0x5aa87b=_0x465c92===_0x1db4c9(0x286)?TextManager[_0x1db4c9(0x284)]:'\x5cI[%1]%2'[_0x1db4c9(0x52b)](_0xdfb191,TextManager[_0x1db4c9(0x284)]),_0x4a2e54=this[_0x1db4c9(0x58f)]();if(this['hideDisabledCommands']()&&!_0x4a2e54)return;this[_0x1db4c9(0x2a8)](_0x5aa87b,_0x1db4c9(0x284),_0x4a2e54);},Window_ShopCommand[_0x541333(0x5f1)][_0x541333(0x58f)]=function(){const _0x4e6126=_0x541333;return SceneManager[_0x4e6126(0x38a)][_0x4e6126(0x5db)]===Scene_Shop?SceneManager[_0x4e6126(0x38a)][_0x4e6126(0x37d)]>0x0:_0x4e6126(0x39f)!==_0x4e6126(0x39f)?this['updatedLayoutStyle']()[_0x4e6126(0x2a3)](/LOWER/i):!![];},Window_ShopCommand[_0x541333(0x5f1)][_0x541333(0x455)]=function(){const _0x4948b8=_0x541333,_0x36cb99=this['commandStyle'](),_0x498932=VisuMZ[_0x4948b8(0x1db)]['Settings'][_0x4948b8(0x3c6)]['CmdIconSell'],_0x58be25=_0x36cb99===_0x4948b8(0x286)?TextManager[_0x4948b8(0x4ca)]:'\x5cI[%1]%2'['format'](_0x498932,TextManager[_0x4948b8(0x4ca)]),_0x2f5b90=this['isSellCommandEnabled']();if(this['hideDisabledCommands']()&&!_0x2f5b90)return;this[_0x4948b8(0x2a8)](_0x58be25,_0x4948b8(0x4ca),_0x2f5b90);},Window_ShopCommand['prototype'][_0x541333(0x441)]=function(){const _0x308a43=_0x541333;return!this[_0x308a43(0x247)];},Window_ShopCommand[_0x541333(0x5f1)]['addCancelCommand']=function(){const _0x51b1bf=_0x541333,_0x1d0cce=this['commandStyle'](),_0xc1c4da=VisuMZ['ItemsEquipsCore'][_0x51b1bf(0x522)]['ShopScene'][_0x51b1bf(0x5da)],_0x419461=VisuMZ[_0x51b1bf(0x1db)][_0x51b1bf(0x522)][_0x51b1bf(0x3c6)]['CmdCancelRename'],_0x3a895a=_0x1d0cce===_0x51b1bf(0x286)?_0x419461:_0x51b1bf(0x435)['format'](_0xc1c4da,_0x419461);this[_0x51b1bf(0x2a8)](_0x3a895a,_0x51b1bf(0x3aa));},Window_ShopCommand[_0x541333(0x5f1)][_0x541333(0x258)]=function(){const _0x3dbe99=_0x541333;return VisuMZ['ItemsEquipsCore'][_0x3dbe99(0x522)][_0x3dbe99(0x3c6)][_0x3dbe99(0x324)];},Window_ShopCommand['prototype'][_0x541333(0x3b2)]=function(_0x29d3b4){const _0x4f2bc4=_0x541333,_0x9c57fd=this[_0x4f2bc4(0x290)](_0x29d3b4);if(_0x9c57fd==='iconText')_0x4f2bc4(0x521)===_0x4f2bc4(0x3b6)?this[_0x4f2bc4(0x5f2)]():this[_0x4f2bc4(0x5ce)](_0x29d3b4);else{if(_0x9c57fd===_0x4f2bc4(0x495)){if(_0x4f2bc4(0x56a)!=='xfpDj')return _0x4f49a9[_0x4f2bc4(0x1db)][_0x4f2bc4(0x522)][_0x4f2bc4(0x59f)][_0x4f2bc4(0x3e2)];else this[_0x4f2bc4(0x3d9)](_0x29d3b4);}else Window_HorzCommand[_0x4f2bc4(0x5f1)]['drawItem'][_0x4f2bc4(0x562)](this,_0x29d3b4);}},Window_ShopCommand['prototype']['commandStyle']=function(){const _0x11b112=_0x541333;return VisuMZ[_0x11b112(0x1db)][_0x11b112(0x522)][_0x11b112(0x3c6)][_0x11b112(0x50c)];},Window_ShopCommand[_0x541333(0x5f1)][_0x541333(0x290)]=function(_0x41f03c){const _0x6e4352=_0x541333;if(_0x41f03c<0x0)return _0x6e4352(0x286);const _0x503995=this['commandStyle']();if(_0x503995!==_0x6e4352(0x597)){if(_0x6e4352(0x220)==='mkAPp'){const _0x3e1a4e=_0x5a2e66[_0x4d09f2];_0x3e1a4e&&_0x3e1a4e[_0x6e4352(0x25f)]===_0x267205+0x1&&_0x2481ba[_0x6e4352(0x282)](_0x3e1a4e);}else return _0x503995;}else{if(this[_0x6e4352(0x574)]()>0x0){const _0x223745=this[_0x6e4352(0x4f3)](_0x41f03c);if(_0x223745[_0x6e4352(0x2a3)](/\\I\[(\d+)\]/i)){const _0x35de9a=this['itemLineRect'](_0x41f03c),_0x2fd89d=this[_0x6e4352(0x3f9)](_0x223745)['width'];if(_0x2fd89d<=_0x35de9a[_0x6e4352(0x5bc)])return'KlXlu'==='Tagtn'?_0x58b105['ItemsEquipsCore'][_0x6e4352(0x522)]['ShopScene'][_0x6e4352(0x28b)]:_0x6e4352(0x454);else{if('xHXGm'!=='xHXGm'){const _0x2ab3cb=this['isRightInputMode']()?this[_0x6e4352(0x478)]():0x0,_0x4e5bde=this['mainAreaTop'](),_0x26b81e=_0x55f076[_0x6e4352(0x37c)]-this[_0x6e4352(0x478)](),_0x51b94c=this['calcWindowHeight'](0x1,!![]);return new _0x4c2868(_0x2ab3cb,_0x4e5bde,_0x26b81e,_0x51b94c);}else return _0x6e4352(0x495);}}}}return _0x6e4352(0x286);},Window_ShopCommand[_0x541333(0x5f1)][_0x541333(0x5ce)]=function(_0x326dae){const _0x4d2b1c=_0x541333,_0x24727e=this['itemLineRect'](_0x326dae),_0x10fc54=this['commandName'](_0x326dae),_0x2e82e2=this[_0x4d2b1c(0x3f9)](_0x10fc54)[_0x4d2b1c(0x5bc)];this['changePaintOpacity'](this['isCommandEnabled'](_0x326dae));const _0x17737b=this[_0x4d2b1c(0x258)]();if(_0x17737b==='right'){if(_0x4d2b1c(0x4f5)!==_0x4d2b1c(0x55f))this['drawTextEx'](_0x10fc54,_0x24727e['x']+_0x24727e[_0x4d2b1c(0x5bc)]-_0x2e82e2,_0x24727e['y'],_0x2e82e2);else{const _0x112d54=_0x13740b[_0x4d2b1c(0x40a)](0x1);this[_0x4d2b1c(0x3d0)]=_0x2aa408[_0x4d2b1c(0x472)](_0x112d54),this['_tempActorB']=_0x19278d[_0x4d2b1c(0x472)](_0x112d54);}}else{if(_0x17737b===_0x4d2b1c(0x42a)){if('ddOEk'!==_0x4d2b1c(0x5b0)){const _0x560887=_0x24727e['x']+Math[_0x4d2b1c(0x254)]((_0x24727e[_0x4d2b1c(0x5bc)]-_0x2e82e2)/0x2);this[_0x4d2b1c(0x5fa)](_0x10fc54,_0x560887,_0x24727e['y'],_0x2e82e2);}else _0x3ed4a6[_0x4d2b1c(0x1db)][_0x4d2b1c(0x522)][_0x4d2b1c(0x510)][_0x4d2b1c(0x1c7)][_0x4d2b1c(0x562)](this);}else this[_0x4d2b1c(0x5fa)](_0x10fc54,_0x24727e['x'],_0x24727e['y'],_0x2e82e2);}},Window_ShopCommand[_0x541333(0x5f1)][_0x541333(0x3d9)]=function(_0x245dc7){const _0x185035=_0x541333;this['commandName'](_0x245dc7)[_0x185035(0x2a3)](/\\I\[(\d+)\]/i);const _0x61ee95=Number(RegExp['$1'])||0x0,_0x19b7e8=this['itemLineRect'](_0x245dc7),_0x449cef=_0x19b7e8['x']+Math[_0x185035(0x254)]((_0x19b7e8[_0x185035(0x5bc)]-ImageManager[_0x185035(0x5d8)])/0x2),_0x541f69=_0x19b7e8['y']+(_0x19b7e8[_0x185035(0x242)]-ImageManager[_0x185035(0x233)])/0x2;this[_0x185035(0x3e7)](_0x61ee95,_0x449cef,_0x541f69);},VisuMZ[_0x541333(0x1db)][_0x541333(0x416)]=Window_ShopBuy[_0x541333(0x5f1)][_0x541333(0x210)],Window_ShopBuy[_0x541333(0x5f1)][_0x541333(0x210)]=function(){const _0x47e063=_0x541333;this[_0x47e063(0x404)](),VisuMZ['ItemsEquipsCore'][_0x47e063(0x416)][_0x47e063(0x562)](this);},Window_ShopBuy['prototype'][_0x541333(0x404)]=function(){const _0x4058c5=_0x541333;SceneManager[_0x4058c5(0x38a)][_0x4058c5(0x5db)]===Scene_Shop&&(_0x4058c5(0x1b0)!==_0x4058c5(0x1b0)?this[_0x4058c5(0x375)]():this[_0x4058c5(0x36e)]=SceneManager[_0x4058c5(0x38a)]['money']());},VisuMZ[_0x541333(0x1db)][_0x541333(0x466)]=Window_ShopBuy['prototype']['price'],Window_ShopBuy['prototype'][_0x541333(0x1b9)]=function(_0x27625c){const _0x3a73bc=_0x541333;if(!_0x27625c)return 0x0;let _0x3c301b=VisuMZ['ItemsEquipsCore'][_0x3a73bc(0x466)][_0x3a73bc(0x562)](this,_0x27625c);return Math[_0x3a73bc(0x52c)](0x0,this['modifiedBuyPriceItemsEquipsCore'](_0x27625c,_0x3c301b));},Window_ShopBuy[_0x541333(0x5f1)][_0x541333(0x5d6)]=function(_0x23ea30,_0x48a05e){const _0x2a5639=_0x541333,_0x1cbba6=_0x23ea30[_0x2a5639(0x266)];if(_0x1cbba6[_0x2a5639(0x2a3)](/<JS BUY PRICE>\s*([\s\S]*)\s*<\/JS BUY PRICE>/i)){if('JInGE'!==_0x2a5639(0x2ce))this[_0x2a5639(0x21e)][_0x2a5639(0x43f)](0x0),this[_0x2a5639(0x2c6)]();else{const _0x3e0d5b=String(RegExp['$1']);try{eval(_0x3e0d5b);}catch(_0xe50ba3){if($gameTemp['isPlaytest']())console[_0x2a5639(0x3ea)](_0xe50ba3);}}}_0x48a05e=VisuMZ['ItemsEquipsCore']['Settings'][_0x2a5639(0x3c6)][_0x2a5639(0x306)][_0x2a5639(0x562)](this,_0x23ea30,_0x48a05e);if(isNaN(_0x48a05e))_0x48a05e=0x0;return Math[_0x2a5639(0x254)](_0x48a05e);},Window_ShopBuy[_0x541333(0x5f1)][_0x541333(0x3b2)]=function(_0x41194f){const _0x238e41=_0x541333;this[_0x238e41(0x33e)]();const _0x28341b=this['itemAt'](_0x41194f),_0x49d3b4=this[_0x238e41(0x347)](_0x41194f),_0x1bd106=_0x49d3b4['width'];this[_0x238e41(0x29e)](this[_0x238e41(0x213)](_0x28341b)),this[_0x238e41(0x2df)](_0x28341b,_0x49d3b4['x'],_0x49d3b4['y'],_0x1bd106),this[_0x238e41(0x5d2)](_0x28341b,_0x49d3b4),this[_0x238e41(0x29e)](!![]);},Window_ShopBuy[_0x541333(0x5f1)][_0x541333(0x5d2)]=function(_0xc63cdb,_0x2530ba){const _0x1a0755=_0x541333,_0x4940c9=this[_0x1a0755(0x1b9)](_0xc63cdb);this[_0x1a0755(0x2d9)](_0x4940c9,TextManager[_0x1a0755(0x546)],_0x2530ba['x'],_0x2530ba['y'],_0x2530ba['width']);},Window_ShopSell[_0x541333(0x5f1)][_0x541333(0x4c6)]=function(){const _0x1585dc=_0x541333;return SceneManager[_0x1585dc(0x38a)]['isUseItemsEquipsCoreUpdatedLayout']()?0x1:0x2;},VisuMZ[_0x541333(0x1db)][_0x541333(0x5f5)]=Window_ShopSell[_0x541333(0x5f1)]['isEnabled'],Window_ShopSell[_0x541333(0x5f1)][_0x541333(0x213)]=function(_0x501a15){const _0x37d5a6=_0x541333;if(!_0x501a15)return![];const _0x58e20d=_0x501a15[_0x37d5a6(0x266)];if(_0x58e20d[_0x37d5a6(0x2a3)](/<CANNOT SELL>/i))return![];if(_0x58e20d[_0x37d5a6(0x2a3)](/<CAN SELL>/i))return!![];if(_0x58e20d['match'](/<CANNOT SELL[ ](?:SW|SWITCH|SWITCHES):[ ]*(\d+(?:\s*,\s*\d+)*)>/i)){if(_0x37d5a6(0x5df)===_0x37d5a6(0x36a)){if(!this[_0x37d5a6(0x539)]())_0x5734e0[_0x37d5a6(0x5f1)]['playOkSound']['call'](this);}else{const _0xcc52e6=JSON[_0x37d5a6(0x5f9)]('['+RegExp['$1']['match'](/\d+/g)+']');for(const _0xf3e753 of _0xcc52e6){if('QOyUT'!=='nCjsT'){if(!$gameSwitches[_0x37d5a6(0x5e9)](_0xf3e753))return![];}else return this[_0x37d5a6(0x403)](),_0x4ce904[_0x37d5a6(0x456)](),_0x56eeed[_0x37d5a6(0x38a)][_0x37d5a6(0x255)](),![];}}}if(_0x58e20d[_0x37d5a6(0x2a3)](/<CANNOT SELL ALL[ ](?:SW|SWITCH|SWITCHES):[ ]*(\d+(?:\s*,\s*\d+)*)>/i)){const _0x604833=JSON['parse']('['+RegExp['$1'][_0x37d5a6(0x2a3)](/\d+/g)+']');for(const _0x223dc1 of _0x604833){if(!$gameSwitches[_0x37d5a6(0x5e9)](_0x223dc1))return![];}}if(_0x58e20d[_0x37d5a6(0x2a3)](/<CANNOT SELL ANY[ ](?:SW|SWITCH|SWITCHES):[ ]*(\d+(?:\s*,\s*\d+)*)>/i)){if(_0x37d5a6(0x497)===_0x37d5a6(0x497)){const _0x3a4249=JSON[_0x37d5a6(0x5f9)]('['+RegExp['$1']['match'](/\d+/g)+']');for(const _0x4f0d0f of _0x3a4249){if(_0x37d5a6(0x46d)!==_0x37d5a6(0x46d)){if(_0x3f077f['isPlaytest']())_0x35fa51[_0x37d5a6(0x3ea)](_0x3bfe15);}else{if($gameSwitches['value'](_0x4f0d0f))return![];}}}else this[_0x37d5a6(0x46b)]=!![];}return VisuMZ[_0x37d5a6(0x1db)][_0x37d5a6(0x5f5)][_0x37d5a6(0x562)](this,_0x501a15);},Window_ShopStatus['prototype'][_0x541333(0x5c5)]=function(){return![];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x377)]=function(){const _0xbeca61=_0x541333;Window_StatusBase[_0xbeca61(0x5f1)]['loadFaceImages'][_0xbeca61(0x562)](this);for(const _0x4d0f8a of $gameParty[_0xbeca61(0x489)]()){ImageManager[_0xbeca61(0x2d5)](_0x4d0f8a[_0xbeca61(0x3cf)]());}},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x4b6)]=function(){const _0x2c8726=_0x541333;return VisuMZ[_0x2c8726(0x1db)][_0x2c8726(0x522)][_0x2c8726(0x510)][_0x2c8726(0x34d)];},Window_ShopStatus['prototype'][_0x541333(0x210)]=function(){const _0x51d8d2=_0x541333;this['contents'][_0x51d8d2(0x456)](),this['contentsBack']['clear'](),this['_item']&&(this[_0x51d8d2(0x33e)](),this[_0x51d8d2(0x29e)](!![]),this[_0x51d8d2(0x256)](),this[_0x51d8d2(0x2b6)]()?this[_0x51d8d2(0x488)]():this[_0x51d8d2(0x402)](),this[_0x51d8d2(0x2c5)]());},Window_ShopStatus['prototype'][_0x541333(0x1eb)]=function(_0x366959,_0x51fc4c){const _0x5a46ae=_0x541333;if(!this['isEquipItem']()&&!DataManager[_0x5a46ae(0x577)](this[_0x5a46ae(0x567)]))return;const _0x4e2e4d=this[_0x5a46ae(0x20f)]-this[_0x5a46ae(0x2e0)]()-_0x366959,_0x2e91da=this[_0x5a46ae(0x4e5)](_0x5a46ae(0x33a));this[_0x5a46ae(0x32a)](ColorManager[_0x5a46ae(0x386)]()),this[_0x5a46ae(0x3d2)](TextManager[_0x5a46ae(0x1e7)],_0x366959+this[_0x5a46ae(0x2e0)](),_0x51fc4c,_0x4e2e4d-_0x2e91da),this['resetTextColor'](),this[_0x5a46ae(0x4d0)](this[_0x5a46ae(0x567)],_0x366959,_0x51fc4c,_0x4e2e4d);},Window_ShopStatus[_0x541333(0x5f1)]['drawItemDarkRect']=function(_0x477378,_0x4de885,_0x517f6c,_0x2363d3,_0x5bc6e8){const _0x5cea7a=_0x541333;if(VisuMZ[_0x5cea7a(0x1db)][_0x5cea7a(0x522)][_0x5cea7a(0x510)]['DrawBackRect']===![])return;_0x5bc6e8=Math[_0x5cea7a(0x52c)](_0x5bc6e8||0x1,0x1);while(_0x5bc6e8--){_0x2363d3=_0x2363d3||this['lineHeight'](),this[_0x5cea7a(0x535)][_0x5cea7a(0x29c)]=0xa0;const _0x381517=ColorManager['getItemsEquipsCoreBackColor1']();this['contentsBack']['fillRect'](_0x477378+0x1,_0x4de885+0x1,_0x517f6c-0x2,_0x2363d3-0x2,_0x381517),this[_0x5cea7a(0x535)]['paintOpacity']=0xff;}},ColorManager['getItemsEquipsCoreBackColor1']=function(){const _0x315f90=_0x541333,_0xbdcf73=VisuMZ[_0x315f90(0x1db)][_0x315f90(0x522)]['StatusWindow'];let _0x4c8167=_0xbdcf73['BackRectColor']!==undefined?_0xbdcf73[_0x315f90(0x53a)]:0x13;return ColorManager[_0x315f90(0x418)](_0x4c8167);},Window_ShopStatus['prototype'][_0x541333(0x488)]=function(){const _0x255e83=_0x541333;if(VisuMZ[_0x255e83(0x1db)][_0x255e83(0x522)]['StatusWindow'][_0x255e83(0x417)]){if(_0x255e83(0x5c1)!==_0x255e83(0x2cb)){VisuMZ['ItemsEquipsCore'][_0x255e83(0x522)][_0x255e83(0x510)][_0x255e83(0x417)][_0x255e83(0x562)](this);return;}else{if(!_0x477270)return 0x0;let _0x5d5fdc=_0x1467a3[_0x255e83(0x1db)][_0x255e83(0x466)][_0x255e83(0x562)](this,_0x23b548);return _0x42dfa2[_0x255e83(0x52c)](0x0,this[_0x255e83(0x5d6)](_0x3b770d,_0x5d5fdc));}}const _0x90f50c=this[_0x255e83(0x3da)](),_0x1267a5=this[_0x255e83(0x4cd)]()+0x8;let _0x13eae4=0x0,_0x1e12ed=0x0,_0x19ccab=this[_0x255e83(0x20f)],_0x1319f4=this[_0x255e83(0x30d)],_0x5ea90e=Math[_0x255e83(0x254)](_0x19ccab/0x2),_0x59e78d=_0x13eae4+_0x19ccab-_0x5ea90e;this[_0x255e83(0x2df)](this['_item'],_0x13eae4+this[_0x255e83(0x2e0)](),_0x1e12ed,_0x19ccab-this[_0x255e83(0x2e0)]()*0x2),this[_0x255e83(0x28c)](_0x13eae4,_0x1e12ed,_0x19ccab),_0x1e12ed+=_0x90f50c;if(this['drawItemEquipType'](_0x13eae4,_0x1e12ed,_0x5ea90e))_0x1e12ed+=0x0;if(this['drawItemQuantity'](_0x59e78d,_0x1e12ed,_0x5ea90e))_0x1e12ed+=_0x90f50c;const _0x49242a=this[_0x255e83(0x22b)](),_0x110273=_0x1e12ed;_0x1e12ed=_0x1319f4-_0x49242a['length']*_0x1267a5-0x4;let _0x2f55aa=_0x13eae4,_0x2c1ac1=0x0,_0x2a2db1=_0x1e12ed;for(const _0xf45a05 of _0x49242a){_0x2c1ac1=Math[_0x255e83(0x52c)](this[_0x255e83(0x3c1)](_0xf45a05,_0x13eae4+0x4,_0x1e12ed+0x4,_0x19ccab),_0x2c1ac1),_0x1e12ed+=_0x1267a5;}const _0x359558=$gameParty[_0x255e83(0x2ac)](),_0x1754d4=Math[_0x255e83(0x254)]((_0x19ccab-_0x2c1ac1)/_0x359558);_0x2c1ac1=_0x19ccab-_0x1754d4*_0x359558;for(const _0x25f5a4 of $gameParty['battleMembers']()){const _0x5c91df=$gameParty[_0x255e83(0x48e)]()[_0x255e83(0x525)](_0x25f5a4),_0x396d41=_0x2f55aa+_0x2c1ac1+_0x5c91df*_0x1754d4;this[_0x255e83(0x29e)](_0x25f5a4[_0x255e83(0x3cb)](this[_0x255e83(0x567)])),this[_0x255e83(0x2fd)](_0x25f5a4,_0x396d41+_0x1754d4/0x2,_0x2a2db1);let _0x575853=_0x2a2db1;for(const _0x225b6b of _0x49242a){if(_0x255e83(0x21c)==='qRSVd'){const _0x1841c6=_0x575853-(_0x90f50c-_0x1267a5)/0x2;this[_0x255e83(0x1dd)](_0x25f5a4,_0x225b6b,_0x396d41,_0x1841c6,_0x1754d4),_0x575853+=_0x1267a5;}else _0x2097f2[_0x255e83(0x5f1)]['refresh'][_0x255e83(0x562)](this),this['refreshCursor']();}}this[_0x255e83(0x28c)](_0x2f55aa,_0x110273,_0x2c1ac1,_0x2a2db1-_0x110273);for(let _0x557d56=0x0;_0x557d56<_0x359558;_0x557d56++){const _0x180848=_0x2f55aa+_0x2c1ac1+_0x557d56*_0x1754d4;this[_0x255e83(0x28c)](_0x180848,_0x110273,_0x1754d4,_0x2a2db1-_0x110273);}for(const _0x18e358 of _0x49242a){this[_0x255e83(0x28c)](_0x2f55aa,_0x2a2db1,_0x2c1ac1,_0x1267a5);for(let _0x59473b=0x0;_0x59473b<_0x359558;_0x59473b++){if(_0x255e83(0x329)===_0x255e83(0x329)){const _0x17a36c=_0x2f55aa+_0x2c1ac1+_0x59473b*_0x1754d4;this['drawItemDarkRect'](_0x17a36c,_0x2a2db1,_0x1754d4,_0x1267a5);}else return this[_0x255e83(0x4ea)]()?!![]:_0x5c6b15[_0x255e83(0x1db)][_0x255e83(0x522)]['ItemScene'][_0x255e83(0x49b)];}_0x2a2db1+=_0x1267a5;}},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x355)]=function(_0x20b362,_0x4fe0a2,_0x1a13f9){const _0x2bbede=_0x541333;if(!this['isEquipItem']())return![];const _0x48ae99=$dataSystem[_0x2bbede(0x1af)][this[_0x2bbede(0x567)][_0x2bbede(0x25f)]];return this[_0x2bbede(0x4b2)](_0x48ae99,_0x20b362,_0x4fe0a2,_0x1a13f9,!![]),this[_0x2bbede(0x28c)](_0x20b362,_0x4fe0a2,_0x1a13f9),this[_0x2bbede(0x33e)](),!![];},Window_ShopStatus[_0x541333(0x5f1)]['getItemQuantityText']=function(){const _0x48e8ce=_0x541333,_0x249fe6=VisuMZ[_0x48e8ce(0x1db)][_0x48e8ce(0x522)]['ItemScene'][_0x48e8ce(0x4af)];return _0x249fe6[_0x48e8ce(0x52b)]($gameParty[_0x48e8ce(0x231)](this[_0x48e8ce(0x567)]));},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x22b)]=function(){const _0x5dd691=_0x541333;let _0x3afc09=[0x0,0x1,0x2,0x3,0x4,0x5,0x6,0x7];return Imported['VisuMZ_0_CoreEngine']&&(_0x3afc09=VisuMZ[_0x5dd691(0x406)][_0x5dd691(0x522)][_0x5dd691(0x5d5)][_0x5dd691(0x364)]),_0x3afc09=_0x3afc09[_0x5dd691(0x374)](_0x5bd127=>typeof _0x5bd127===_0x5dd691(0x414)?_0x5bd127:_0x5bd127['toUpperCase']()[_0x5dd691(0x399)]()),_0x3afc09;},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x224)]=function(){const _0x58d75f=_0x541333;return VisuMZ[_0x58d75f(0x1db)][_0x58d75f(0x522)][_0x58d75f(0x510)][_0x58d75f(0x501)];},Window_ShopStatus['prototype'][_0x541333(0x3c1)]=function(_0x3eb7f7,_0xbe3394,_0x4eb121,_0x556440){const _0x1fa03f=_0x541333;this['resetFontSettings'](),this['contents'][_0x1fa03f(0x5a1)]=this[_0x1fa03f(0x224)]();let _0x591326=this[_0x1fa03f(0x4e5)](TextManager[_0x1fa03f(0x334)](_0x3eb7f7))+0x4+_0xbe3394;if(Imported[_0x1fa03f(0x2eb)]){this[_0x1fa03f(0x5ba)](_0xbe3394,_0x4eb121,_0x556440,_0x3eb7f7,!![]);if(VisuMZ[_0x1fa03f(0x406)][_0x1fa03f(0x522)][_0x1fa03f(0x5d5)][_0x1fa03f(0x28f)]){if(_0x1fa03f(0x1f5)===_0x1fa03f(0x439)){const _0x2c116e=0x0,_0x4f78d9=this[_0x1fa03f(0x2a2)](),_0x459202=_0x1a9426[_0x1fa03f(0x37c)],_0x46b011=this['helpAreaHeight']();return new _0xf97e15(_0x2c116e,_0x4f78d9,_0x459202,_0x46b011);}else _0x591326+=ImageManager[_0x1fa03f(0x5d8)]+0x4;}}else this[_0x1fa03f(0x32a)](ColorManager[_0x1fa03f(0x386)]()),this[_0x1fa03f(0x3d2)](TextManager[_0x1fa03f(0x334)](_0x3eb7f7),_0xbe3394,_0x4eb121,_0x556440);return this['resetFontSettings'](),_0x591326;},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x1dd)]=function(_0x17f856,_0x47bf55,_0x255381,_0x4d7d11,_0x2ae172){const _0x42ada1=_0x541333;_0x255381+=this[_0x42ada1(0x2e0)](),_0x2ae172-=this[_0x42ada1(0x2e0)]()*0x2;const _0x58601d=VisuMZ[_0x42ada1(0x1db)][_0x42ada1(0x522)][_0x42ada1(0x510)];this[_0x42ada1(0x1f8)][_0x42ada1(0x5a1)]=_0x58601d[_0x42ada1(0x501)],this['changePaintOpacity'](_0x17f856[_0x42ada1(0x3cb)](this['_item']));if(_0x17f856['isEquipped'](this['_item'])){const _0x43a9f5=_0x58601d['AlreadyEquipMarker'];this[_0x42ada1(0x3d2)](_0x43a9f5,_0x255381,_0x4d7d11,_0x2ae172,_0x42ada1(0x42a));}else{if(_0x17f856[_0x42ada1(0x3cb)](this[_0x42ada1(0x567)])){const _0x399559=JsonEx[_0x42ada1(0x472)](_0x17f856);_0x399559[_0x42ada1(0x59a)]=!![];const _0x22fd0e=_0x399559['equipSlots']()[_0x42ada1(0x525)](this['_item']['etypeId']);if(_0x22fd0e>=0x0)_0x399559[_0x42ada1(0x5fe)](_0x22fd0e,this[_0x42ada1(0x567)]);let _0x1b2393=0x0,_0x4c9bb1=0x0,_0x463f50=0x0;if(Imported[_0x42ada1(0x2eb)]){if(_0x42ada1(0x5b7)===_0x42ada1(0x5b7))_0x1b2393=_0x399559[_0x42ada1(0x4e4)](_0x47bf55),_0x4c9bb1=_0x1b2393-_0x17f856['paramValueByName'](_0x47bf55),this[_0x42ada1(0x32a)](ColorManager[_0x42ada1(0x27f)](_0x4c9bb1)),_0x463f50=(_0x4c9bb1>=0x0?'+':'')+VisuMZ[_0x42ada1(0x28e)](_0x4c9bb1,0x0,_0x47bf55);else{const _0x5689e8=_0x42ada1(0x4a7);if(!this[_0x42ada1(0x3e3)][_0x42ada1(0x276)]&&!this['_customItemInfo'][_0x5689e8])return![];const _0x3f511a=this[_0x42ada1(0x3a9)]();this['drawItemKeyData'](_0x3f511a,_0x2c7079,_0x168e8f,_0x5f0b81,!![]);const _0x32550f=this[_0x42ada1(0x253)]();return this[_0x42ada1(0x4b2)](_0x32550f,_0xc718a5,_0x18f6d7,_0x2364a5,![],'right'),this['drawItemDarkRect'](_0x181805,_0x1309aa,_0x201e41),this['resetFontSettings'](),!![];}}else _0x1b2393=_0x399559['param'](_0x47bf55),_0x4c9bb1=_0x1b2393-_0x17f856['param'](_0x47bf55),this[_0x42ada1(0x32a)](ColorManager[_0x42ada1(0x27f)](_0x4c9bb1)),_0x463f50=(_0x4c9bb1>=0x0?'+':'')+_0x4c9bb1;if(_0x463f50==='+0')_0x463f50=_0x58601d[_0x42ada1(0x2c3)];this[_0x42ada1(0x3d2)](_0x463f50,_0x255381,_0x4d7d11,_0x2ae172,_0x42ada1(0x42a));}else{const _0x6658e8=_0x58601d[_0x42ada1(0x516)];this[_0x42ada1(0x3d2)](_0x6658e8,_0x255381,_0x4d7d11,_0x2ae172,'center');}}this[_0x42ada1(0x33e)](),this[_0x42ada1(0x29e)](!![]);},Window_ShopStatus['prototype'][_0x541333(0x402)]=function(){const _0x35a13e=_0x541333;VisuMZ[_0x35a13e(0x1db)][_0x35a13e(0x522)][_0x35a13e(0x510)]['DrawItemData']['call'](this);},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x256)]=function(){const _0x24bedc=_0x541333;this['_customItemInfo']={};if(!this[_0x24bedc(0x567)])return;const _0x3b1340=this[_0x24bedc(0x567)]['note'];if(_0x3b1340[_0x24bedc(0x2a3)](/<STATUS INFO>\s*([\s\S]*)\s*<\/STATUS INFO>/i)){const _0x4b8b62=String(RegExp['$1'])[_0x24bedc(0x3b1)](/[\r\n]+/);for(const _0x58c80b of _0x4b8b62){if(_0x58c80b[_0x24bedc(0x2a3)](/(.*):[ ](.*)/i)){const _0x3a015a=String(RegExp['$1'])['toUpperCase']()['trim'](),_0x133c52=String(RegExp['$2'])[_0x24bedc(0x399)]();this[_0x24bedc(0x212)][_0x3a015a]=_0x133c52;}}}},Window_ShopStatus['prototype']['itemDataFontSize']=function(){const _0x2614f1=_0x541333;return Math[_0x2614f1(0x52c)](0x1,$gameSystem[_0x2614f1(0x52d)]()-0x4);},Window_ShopStatus[_0x541333(0x5f1)]['resetFontSettings']=function(){const _0x290290=_0x541333;Window_StatusBase['prototype'][_0x290290(0x33e)][_0x290290(0x562)](this),this[_0x290290(0x1f8)]['fontSize']=this[_0x290290(0x36d)]||this[_0x290290(0x1f8)]['fontSize'],this[_0x290290(0x1f8)]['textColor']=this['_resetFontColor']||this['contents'][_0x290290(0x5cb)];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x3a1)]=function(){const _0x6698db=_0x541333;return this['contents'][_0x6698db(0x5a1)]/$gameSystem[_0x6698db(0x52d)]();},Window_ShopStatus[_0x541333(0x5f1)]['drawIcon']=function(_0x1bb1d8,_0x4fc0b6,_0x1517b3){const _0x498aaf=_0x541333,_0x5a8f07=ImageManager[_0x498aaf(0x528)](_0x498aaf(0x319)),_0x5bbdf4=ImageManager['iconWidth'],_0x32abd4=ImageManager[_0x498aaf(0x233)],_0x78c659=_0x1bb1d8%0x10*_0x5bbdf4,_0x516c73=Math[_0x498aaf(0x254)](_0x1bb1d8/0x10)*_0x32abd4,_0xa395f5=Math[_0x498aaf(0x4f4)](_0x5bbdf4*this[_0x498aaf(0x3a1)]()),_0x5235c2=Math[_0x498aaf(0x4f4)](_0x32abd4*this[_0x498aaf(0x3a1)]());this['contents'][_0x498aaf(0x202)](_0x5a8f07,_0x78c659,_0x516c73,_0x5bbdf4,_0x32abd4,_0x4fc0b6,_0x1517b3,_0xa395f5,_0x5235c2);},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x367)]=function(_0x323bc5,_0x3adc89){const _0x583e6b=_0x541333;_0x3adc89[_0x583e6b(0x5f3)]&&this[_0x583e6b(0x3e7)](_0x323bc5,_0x3adc89['x'],_0x3adc89['y']+0x2);_0x3adc89['x']+=Math['ceil'](ImageManager[_0x583e6b(0x5d8)]*this['fontSizeRatio']());if(this[_0x583e6b(0x3a1)]()===0x1)_0x3adc89['x']+=0x4;},Window_ShopStatus[_0x541333(0x5f1)]['drawItemKeyData']=function(_0x57fe2e,_0x3f7a64,_0x4df212,_0x2c0bab,_0x46ee5c,_0x19900e){const _0x4b4228=_0x541333;_0x57fe2e=_0x57fe2e||'',_0x19900e=_0x19900e||_0x4b4228(0x265),this[_0x4b4228(0x36d)]=this[_0x4b4228(0x57b)](),this[_0x4b4228(0x1bf)]=_0x46ee5c?ColorManager[_0x4b4228(0x386)]():this[_0x4b4228(0x1f8)]['textColor'],_0x3f7a64+=this[_0x4b4228(0x2e0)](),_0x2c0bab-=this['itemPadding']()*0x2;const _0x17f3d7=this[_0x4b4228(0x3f9)](_0x57fe2e);if(_0x19900e===_0x4b4228(0x42a))_0x3f7a64=_0x3f7a64+Math[_0x4b4228(0x254)]((_0x2c0bab-_0x17f3d7[_0x4b4228(0x5bc)])/0x2);else _0x19900e===_0x4b4228(0x263)&&(_0x4b4228(0x29f)===_0x4b4228(0x29f)?_0x3f7a64=_0x3f7a64+_0x2c0bab-_0x17f3d7['width']:(this[_0x4b4228(0x33e)](),this[_0x4b4228(0x29e)](!![]),this[_0x4b4228(0x256)](),this[_0x4b4228(0x2b6)]()?this[_0x4b4228(0x488)]():this[_0x4b4228(0x402)](),this[_0x4b4228(0x2c5)]()));_0x4df212+=(this['lineHeight']()-_0x17f3d7[_0x4b4228(0x242)])/0x2,this[_0x4b4228(0x5fa)](_0x57fe2e,_0x3f7a64,_0x4df212,_0x2c0bab),this[_0x4b4228(0x36d)]=undefined,this[_0x4b4228(0x1bf)]=undefined,this[_0x4b4228(0x33e)]();},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x57e)]=function(_0x159728,_0x15f534,_0x45d278){const _0x25cff6=_0x541333;if(!DataManager[_0x25cff6(0x577)](this['_item']))return![];const _0x326e2c=this['getItemConsumableLabel']();this[_0x25cff6(0x4b2)](_0x326e2c,_0x159728,_0x15f534,_0x45d278,!![]);const _0x568470=this['getItemConsumableText']();return this['drawItemKeyData'](_0x568470,_0x159728,_0x15f534,_0x45d278,![],'right'),this[_0x25cff6(0x28c)](_0x159728,_0x15f534,_0x45d278),this[_0x25cff6(0x33e)](),!![];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x3b5)]=function(){const _0x39754b=_0x541333;return VisuMZ[_0x39754b(0x1db)]['Settings'][_0x39754b(0x510)]['LabelConsume'];},Window_ShopStatus['prototype']['getItemConsumableText']=function(){const _0x49eab9=_0x541333,_0x468d1e=_0x49eab9(0x3fb);if(this[_0x49eab9(0x212)][_0x468d1e])return this[_0x49eab9(0x212)][_0x468d1e];return this['canConsumeItem']()?VisuMZ[_0x49eab9(0x1db)][_0x49eab9(0x522)]['StatusWindow'][_0x49eab9(0x3af)]:VisuMZ[_0x49eab9(0x1db)][_0x49eab9(0x522)][_0x49eab9(0x510)]['NotConsumable'];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x2f8)]=function(){const _0xb04525=_0x541333;return VisuMZ['CoreEngine']&&VisuMZ['CoreEngine'][_0xb04525(0x522)][_0xb04525(0x5f4)]['KeyItemProtect']&&DataManager['isKeyItem'](this[_0xb04525(0x567)])?_0xb04525(0x47c)!==_0xb04525(0x47c)?_0x1e9834['ItemsEquipsCore'][_0xb04525(0x1ec)][_0xb04525(0x562)](this):![]:this[_0xb04525(0x567)]['consumable'];},Window_ShopStatus['prototype']['drawItemQuantity']=function(_0x416b03,_0x585ea8,_0x2f1ee7){const _0x3549f3=_0x541333;if(!this['isEquipItem']()&&!DataManager[_0x3549f3(0x577)](this['_item']))return![];if(DataManager[_0x3549f3(0x3c3)](this[_0x3549f3(0x567)])&&!$dataSystem[_0x3549f3(0x498)]){if(_0x3549f3(0x5a7)===_0x3549f3(0x2d0)){_0x38356e['prototype'][_0x3549f3(0x377)][_0x3549f3(0x562)](this);for(const _0x4be393 of _0x172bee[_0x3549f3(0x489)]()){_0x5baca7[_0x3549f3(0x2d5)](_0x4be393['characterName']());}}else{const _0x4a3ca5=TextManager[_0x3549f3(0x49f)];this[_0x3549f3(0x4b2)](_0x4a3ca5,_0x416b03,_0x585ea8,_0x2f1ee7,!![],_0x3549f3(0x42a));}}else{const _0x29d997=TextManager[_0x3549f3(0x1e7)];this[_0x3549f3(0x4b2)](_0x29d997,_0x416b03,_0x585ea8,_0x2f1ee7,!![]);const _0x2146fd=this[_0x3549f3(0x26f)]();this[_0x3549f3(0x4b2)](_0x2146fd,_0x416b03,_0x585ea8,_0x2f1ee7,![],_0x3549f3(0x263));}return this[_0x3549f3(0x28c)](_0x416b03,_0x585ea8,_0x2f1ee7),this[_0x3549f3(0x33e)](),!![];},Window_ShopStatus['prototype'][_0x541333(0x26f)]=function(){const _0x4194dc=_0x541333,_0x4e7f0d=_0x4194dc(0x5f0);if(this['_customItemInfo'][_0x4e7f0d])return this[_0x4194dc(0x212)][_0x4e7f0d];const _0x2cc9f9=VisuMZ[_0x4194dc(0x1db)][_0x4194dc(0x522)][_0x4194dc(0x394)][_0x4194dc(0x4af)];return _0x2cc9f9[_0x4194dc(0x52b)]($gameParty[_0x4194dc(0x231)](this['_item']));},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x1cb)]=function(_0x56ff7d,_0xe2e1cf,_0x5b3415){const _0x365741=_0x541333,_0x5c6701=this['getItemOccasionText']();return this[_0x365741(0x4b2)](_0x5c6701,_0x56ff7d,_0xe2e1cf,_0x5b3415,![],_0x365741(0x42a)),this[_0x365741(0x28c)](_0x56ff7d,_0xe2e1cf,_0x5b3415),this['resetFontSettings'](),!![];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x572)]=function(){const _0x572f59=_0x541333,_0x1c56f2=_0x572f59(0x348);if(this[_0x572f59(0x212)][_0x1c56f2])return this[_0x572f59(0x212)][_0x1c56f2];const _0x39f618=VisuMZ['ItemsEquipsCore']['Settings']['StatusWindow'],_0x3b17d0=_0x572f59(0x5ea)[_0x572f59(0x52b)](this[_0x572f59(0x567)][_0x572f59(0x4c1)]);return _0x39f618[_0x3b17d0];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x520)]=function(_0x368db0,_0x248da4,_0x483e1e){const _0xbb8802=_0x541333,_0x1af223=this['getItemScopeText']();return this[_0xbb8802(0x4b2)](_0x1af223,_0x368db0,_0x248da4,_0x483e1e,![],_0xbb8802(0x42a)),this[_0xbb8802(0x28c)](_0x368db0,_0x248da4,_0x483e1e),this[_0xbb8802(0x33e)](),!![];},Window_ShopStatus[_0x541333(0x5f1)]['getItemScopeText']=function(){const _0x2f112f=_0x541333,_0x583ae8=_0x2f112f(0x429);if(this[_0x2f112f(0x212)][_0x583ae8])return this['_customItemInfo'][_0x583ae8];const _0x3fd43a=VisuMZ[_0x2f112f(0x1db)]['Settings'][_0x2f112f(0x510)];if(Imported[_0x2f112f(0x53d)]){if(_0x2f112f(0x250)!=='iPXvQ'){const _0x315ee4=this['_item'][_0x2f112f(0x266)];if(_0x315ee4[_0x2f112f(0x2a3)](/<TARGET:[ ](.*)>/i)){const _0x4dc6f5=String(RegExp['$1']);if(_0x4dc6f5[_0x2f112f(0x2a3)](/(\d+) RANDOM ANY/i))return _0x3fd43a['ScopeRandomAny']['format'](Number(RegExp['$1']));else{if(_0x4dc6f5['match'](/(\d+) RANDOM (?:ENEMY|ENEMIES|FOE|FOES)/i)){if(_0x2f112f(0x5ac)===_0x2f112f(0x5ac))return _0x3fd43a[_0x2f112f(0x5d0)][_0x2f112f(0x52b)](Number(RegExp['$1']));else this['changeTextColor'](_0x309377[_0x2f112f(0x397)]());}else{if(_0x4dc6f5[_0x2f112f(0x2a3)](/(\d+) RANDOM (?:ALLY|ALLIES|FRIEND|FRIENDS)/i))return _0x3fd43a[_0x2f112f(0x296)][_0x2f112f(0x52b)](Number(RegExp['$1']));else{if(_0x4dc6f5[_0x2f112f(0x2a3)](/ALL (?:ALLY|ALLIES|FRIEND|FRIENDS) (?:BUT|EXCEPT) (?:USER|SELF)/i))return _0x3fd43a[_0x2f112f(0x277)];}}}}}else return _0x591d7b[_0x2f112f(0x317)](_0x2f112f(0x2af),_0x2f112f(0x4b8));}const _0x44b0a2=_0x2f112f(0x49a)[_0x2f112f(0x52b)](this[_0x2f112f(0x567)][_0x2f112f(0x484)]);return _0x3fd43a[_0x44b0a2];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x1be)]=function(_0x443e91,_0x4e5405,_0x1769e2){const _0x42d3c0=_0x541333,_0x52213b=this[_0x42d3c0(0x2ec)]();this['drawItemKeyData'](_0x52213b,_0x443e91,_0x4e5405,_0x1769e2,!![]);const _0xe743bf=this[_0x42d3c0(0x238)]();return this[_0x42d3c0(0x4b2)](_0xe743bf,_0x443e91,_0x4e5405,_0x1769e2,![],_0x42d3c0(0x263)),this[_0x42d3c0(0x28c)](_0x443e91,_0x4e5405,_0x1769e2),this['resetFontSettings'](),!![];},Window_ShopStatus['prototype']['getItemSpeedLabel']=function(){const _0x2af4c4=_0x541333;return VisuMZ[_0x2af4c4(0x1db)][_0x2af4c4(0x522)][_0x2af4c4(0x510)][_0x2af4c4(0x3fc)];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x238)]=function(){const _0x59229e=_0x541333,_0x56f1fc='SPEED';if(this['_customItemInfo'][_0x56f1fc])return this[_0x59229e(0x212)][_0x56f1fc];const _0x51b76d=this[_0x59229e(0x567)]['speed'];if(_0x51b76d>=0x7d0)return VisuMZ[_0x59229e(0x1db)][_0x59229e(0x522)]['StatusWindow']['Speed2000'];else{if(_0x51b76d>=0x3e8)return VisuMZ[_0x59229e(0x1db)][_0x59229e(0x522)]['StatusWindow'][_0x59229e(0x1c5)];else{if(_0x51b76d>0x0)return VisuMZ[_0x59229e(0x1db)][_0x59229e(0x522)]['StatusWindow'][_0x59229e(0x214)];else{if(_0x51b76d===0x0)return VisuMZ[_0x59229e(0x1db)]['Settings'][_0x59229e(0x510)][_0x59229e(0x396)];else{if(_0x51b76d>-0x3e8)return VisuMZ[_0x59229e(0x1db)][_0x59229e(0x522)][_0x59229e(0x510)]['SpeedNeg999'];else{if(_0x51b76d>-0x7d0)return VisuMZ[_0x59229e(0x1db)][_0x59229e(0x522)]['StatusWindow'][_0x59229e(0x313)];else{if(_0x51b76d<=-0x7d0){if(_0x59229e(0x33c)!=='qzBmL')return VisuMZ[_0x59229e(0x1db)][_0x59229e(0x522)][_0x59229e(0x510)][_0x59229e(0x1a2)];else{const _0x28d793=_0x19f5e7[_0x59229e(0x266)];if(_0x28d793[_0x59229e(0x2a3)](/<JS BUY PRICE>\s*([\s\S]*)\s*<\/JS BUY PRICE>/i)){const _0x1d8c6d=_0x2857fe(_0x9d19e3['$1']);try{_0x3c5d05(_0x1d8c6d);}catch(_0x51d046){if(_0x109b21['isPlaytest']())_0x32925c[_0x59229e(0x3ea)](_0x51d046);}}_0x345d60=_0xd7382b[_0x59229e(0x1db)][_0x59229e(0x522)][_0x59229e(0x3c6)][_0x59229e(0x306)][_0x59229e(0x562)](this,_0x931e51,_0x1c8cc5);if(_0x39bcc5(_0x4d696d))_0x33c699=0x0;return _0x20f085[_0x59229e(0x254)](_0x24abda);}}else return'YJwgt'!=='xYTIB'?_0x59229e(0x259):this[_0x59229e(0x4ea)]()?this[_0x59229e(0x298)]():_0x32a9f4[_0x59229e(0x1db)][_0x59229e(0x1e6)]['call'](this);}}}}}}},Window_ShopStatus['prototype'][_0x541333(0x24c)]=function(_0x31851d,_0x23efef,_0x31b246){const _0x2d85ef=_0x541333,_0x28d64e=this[_0x2d85ef(0x294)]();this['drawItemKeyData'](_0x28d64e,_0x31851d,_0x23efef,_0x31b246,!![]);const _0x59ae55=this[_0x2d85ef(0x532)]();return this[_0x2d85ef(0x4b2)](_0x59ae55,_0x31851d,_0x23efef,_0x31b246,![],'right'),this['drawItemDarkRect'](_0x31851d,_0x23efef,_0x31b246),this[_0x2d85ef(0x33e)](),!![];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x294)]=function(){const _0x1e2983=_0x541333;return VisuMZ[_0x1e2983(0x1db)]['Settings']['StatusWindow'][_0x1e2983(0x346)];},Window_ShopStatus['prototype']['getItemSuccessRateText']=function(){const _0x5ce1f0=_0x541333,_0x2454b9=_0x5ce1f0(0x39d);if(this[_0x5ce1f0(0x212)][_0x2454b9])return this['_customItemInfo'][_0x2454b9];if(Imported[_0x5ce1f0(0x53d)]){const _0x1dccd5=this[_0x5ce1f0(0x567)]['note'];if(_0x1dccd5['match'](/<ALWAYS HIT>/i))return _0x5ce1f0(0x591);else{if(_0x1dccd5['match'](/<ALWAYS HIT RATE: (\d+)([%％])>/i))return _0x5ce1f0(0x3f4)[_0x5ce1f0(0x52b)](Number(RegExp['$1']));}}return'%1%'['format'](this[_0x5ce1f0(0x567)]['successRate']);},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x1e8)]=function(_0x2637ec,_0x3d6216,_0x460c55){const _0x1f8a38=_0x541333,_0x3f234d=this[_0x1f8a38(0x5e3)]();this[_0x1f8a38(0x4b2)](_0x3f234d,_0x2637ec,_0x3d6216,_0x460c55,!![]);const _0x1e7d9f=this['getItemRepeatsText']();return this[_0x1f8a38(0x4b2)](_0x1e7d9f,_0x2637ec,_0x3d6216,_0x460c55,![],'right'),this['drawItemDarkRect'](_0x2637ec,_0x3d6216,_0x460c55),this[_0x1f8a38(0x33e)](),!![];},Window_ShopStatus['prototype'][_0x541333(0x5e3)]=function(){const _0x4b6665=_0x541333;return VisuMZ[_0x4b6665(0x1db)][_0x4b6665(0x522)]['StatusWindow'][_0x4b6665(0x48b)];},Window_ShopStatus[_0x541333(0x5f1)]['getItemRepeatsText']=function(){const _0x462808=_0x541333,_0x26bb1a=_0x462808(0x19f);if(this[_0x462808(0x212)][_0x26bb1a])return this['_customItemInfo'][_0x26bb1a];const _0xdb3933=_0x462808(0x383);return _0xdb3933[_0x462808(0x52b)](this['_item'][_0x462808(0x485)]);},Window_ShopStatus['prototype'][_0x541333(0x287)]=function(_0x5acc43,_0x359fb4,_0x4f5b3d){const _0x4b7986=_0x541333,_0x2316bb=this['getItemHitTypeLabel']();this[_0x4b7986(0x4b2)](_0x2316bb,_0x5acc43,_0x359fb4,_0x4f5b3d,!![]);const _0xb56e6a=this[_0x4b7986(0x4cf)]();return this[_0x4b7986(0x4b2)](_0xb56e6a,_0x5acc43,_0x359fb4,_0x4f5b3d,![],_0x4b7986(0x263)),this[_0x4b7986(0x28c)](_0x5acc43,_0x359fb4,_0x4f5b3d),this[_0x4b7986(0x33e)](),!![];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x27d)]=function(){const _0x29e9f2=_0x541333;return VisuMZ[_0x29e9f2(0x1db)][_0x29e9f2(0x522)][_0x29e9f2(0x510)]['LabelHitType'];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x4cf)]=function(){const _0x519afa=_0x541333,_0xaa39dc=_0x519afa(0x3bb);if(this[_0x519afa(0x212)][_0xaa39dc])return this[_0x519afa(0x212)][_0xaa39dc];const _0x57ad08=VisuMZ[_0x519afa(0x1db)][_0x519afa(0x522)][_0x519afa(0x510)],_0x46bb32='HitType%1'[_0x519afa(0x52b)](this['_item'][_0x519afa(0x41c)]);return _0x57ad08[_0x46bb32];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x37f)]=function(_0x452d18,_0xfbba4f,_0x2bafa0){const _0x2a27ec=_0x541333;if(this['_item'][_0x2a27ec(0x21b)]['type']<=0x0)return _0xfbba4f;if(this[_0x2a27ec(0x280)](_0x452d18,_0xfbba4f,_0x2bafa0))_0xfbba4f+=this[_0x2a27ec(0x3da)]();if(this[_0x2a27ec(0x5ed)](_0x452d18,_0xfbba4f,_0x2bafa0))_0xfbba4f+=this['lineHeight']();return this[_0x2a27ec(0x33e)](),_0xfbba4f;},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x280)]=function(_0x2cf396,_0x2f8141,_0x17ba67){const _0x2098ed=_0x541333,_0xf421d1=this['getItemDamageElementLabel']();this[_0x2098ed(0x4b2)](_0xf421d1,_0x2cf396,_0x2f8141,_0x17ba67,!![]);const _0x51e73b=this[_0x2098ed(0x4de)]();return this[_0x2098ed(0x4b2)](_0x51e73b,_0x2cf396,_0x2f8141,_0x17ba67,![],_0x2098ed(0x263)),this[_0x2098ed(0x28c)](_0x2cf396,_0x2f8141,_0x17ba67),this[_0x2098ed(0x33e)](),!![];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x4b5)]=function(){const _0x1a3d86=_0x541333;return VisuMZ['ItemsEquipsCore'][_0x1a3d86(0x522)][_0x1a3d86(0x510)]['LabelElement'];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x4de)]=function(){const _0x48be79=_0x541333,_0x419b0c=_0x48be79(0x431);if(this[_0x48be79(0x212)][_0x419b0c])return this[_0x48be79(0x212)][_0x419b0c];if(this[_0x48be79(0x567)][_0x48be79(0x21b)]['elementId']<=-0x1)return VisuMZ[_0x48be79(0x1db)][_0x48be79(0x522)][_0x48be79(0x510)][_0x48be79(0x2d1)];else{if(this[_0x48be79(0x567)][_0x48be79(0x21b)][_0x48be79(0x1a0)]===0x0){if(_0x48be79(0x428)!==_0x48be79(0x428))this[_0x48be79(0x1c2)]();else return VisuMZ[_0x48be79(0x1db)]['Settings'][_0x48be79(0x510)][_0x48be79(0x35c)];}else{if('GwDyc'===_0x48be79(0x25c)){_0x26c53d[_0x48be79(0x2eb)]?(_0x41744d=this[_0x48be79(0x4bb)]['paramValueByName'](_0x441157,![]),_0x37f81d=this[_0x48be79(0x59a)]['paramValueByName'](_0xe78b13,![]),_0x2021d8=this['_tempActor'][_0x48be79(0x4e4)](_0x5377b6,!![])):(_0x36b474=this[_0x48be79(0x4bb)][_0x48be79(0x334)](_0x16063b),_0x1d04eb=this[_0x48be79(0x59a)][_0x48be79(0x334)](_0x4cb5f3),_0xc72b1e=this[_0x48be79(0x59a)][_0x48be79(0x334)](_0x12a769));const _0x226323=_0x231483,_0x497b12=_0x821312;_0x12234=_0x497b12-_0x226323,this[_0x48be79(0x32a)](_0x57f842[_0x48be79(0x27f)](_0x149c13)),this[_0x48be79(0x3d2)](_0x597f23,_0x106e4c,_0x4b9109,_0x2d38b6-_0x215932,_0x48be79(0x263));}else return $dataSystem[_0x48be79(0x1e4)][this['_item'][_0x48be79(0x21b)]['elementId']];}}},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x5ed)]=function(_0x51e006,_0x5cb8b4,_0x4a0b9b){const _0x3adcd4=_0x541333,_0x46a4d5=this['getItemDamageAmountLabel']();this['drawItemKeyData'](_0x46a4d5,_0x51e006,_0x5cb8b4,_0x4a0b9b,!![]),this[_0x3adcd4(0x25b)]();const _0x409a26=this[_0x3adcd4(0x333)](),_0x25d933=ColorManager[_0x3adcd4(0x422)]([0x0,0x0,0x2,0x1,0x3,0x1,0x3][this['_item'][_0x3adcd4(0x21b)][_0x3adcd4(0x3dc)]]);return this[_0x3adcd4(0x32a)](_0x25d933),this[_0x3adcd4(0x4b2)](_0x409a26,_0x51e006,_0x5cb8b4,_0x4a0b9b,![],_0x3adcd4(0x263)),this[_0x3adcd4(0x28c)](_0x51e006,_0x5cb8b4,_0x4a0b9b),this[_0x3adcd4(0x33e)](),!![];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x53b)]=function(){const _0x35a7eb=_0x541333;if(Imported['VisuMZ_1_BattleCore']&&DataManager['getDamageStyle'](this[_0x35a7eb(0x567)])!=='MANUAL'){if('XTFbW'===_0x35a7eb(0x5b3))return this[_0x35a7eb(0x5d3)]();else{if(!this[_0x35a7eb(0x38c)]())return;const _0x39f6cc=this[_0x35a7eb(0x1d0)](),_0x430980=_0x5d9490[_0x35a7eb(0x1db)]['Settings'][_0x35a7eb(0x59f)][_0x35a7eb(0x3a0)],_0x3a095c=_0x39f6cc===_0x35a7eb(0x286)?_0x19380a[_0x35a7eb(0x31c)]:_0x35a7eb(0x435)[_0x35a7eb(0x52b)](_0x430980,_0x21c88e['optimize']),_0x9e24c7=this[_0x35a7eb(0x538)]();this[_0x35a7eb(0x2a8)](_0x3a095c,_0x35a7eb(0x31c),_0x9e24c7);}}else{if(_0x35a7eb(0x2e7)===_0x35a7eb(0x2e7))return this[_0x35a7eb(0x378)]();else _0x3ed0f6['prototype']['isRightInputMode'][_0x35a7eb(0x562)](this);}},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x378)]=function(){const _0x38ecb2=_0x541333,_0x56bcc1=VisuMZ[_0x38ecb2(0x1db)][_0x38ecb2(0x522)][_0x38ecb2(0x510)],_0x12170c=_0x38ecb2(0x3ff)[_0x38ecb2(0x52b)](this[_0x38ecb2(0x567)]['damage'][_0x38ecb2(0x3dc)]),_0xaf331c=[null,TextManager['hp'],TextManager['mp'],TextManager['hp'],TextManager['mp'],TextManager['hp'],TextManager['mp']][this['_item'][_0x38ecb2(0x21b)]['type']];return _0x56bcc1[_0x12170c][_0x38ecb2(0x52b)](_0xaf331c);},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x25b)]=function(){const _0x153bd4=_0x541333,_0x6787f3=$gameActors[_0x153bd4(0x40a)](0x1);this[_0x153bd4(0x3d0)]=JsonEx[_0x153bd4(0x472)](_0x6787f3),this[_0x153bd4(0x41a)]=JsonEx[_0x153bd4(0x472)](_0x6787f3);},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x333)]=function(){const _0x4e7d45=_0x541333,_0x1c3b72=_0x4e7d45(0x2c4);if(this[_0x4e7d45(0x212)][_0x1c3b72])return this[_0x4e7d45(0x212)][_0x1c3b72];return Imported[_0x4e7d45(0x53d)]&&DataManager['getDamageStyle'](this[_0x4e7d45(0x567)])!==_0x4e7d45(0x5be)?this['getItemDamageAmountTextBattleCore']():this[_0x4e7d45(0x550)]();},Window_ShopStatus['prototype'][_0x541333(0x550)]=function(){const _0x4d60ab=_0x541333;window['a']=this[_0x4d60ab(0x3d0)],window['b']=this['_tempActorB'],this[_0x4d60ab(0x3d0)][_0x4d60ab(0x48c)](!![]),this['_tempActorB']['setShopStatusWindowMode']([0x3,0x4]['includes'](this[_0x4d60ab(0x567)][_0x4d60ab(0x21b)][_0x4d60ab(0x3dc)]));let _0x345f12=this[_0x4d60ab(0x567)][_0x4d60ab(0x21b)][_0x4d60ab(0x372)];try{const _0x2a6ebe=Math[_0x4d60ab(0x52c)](eval(_0x345f12),0x0)/window['a']['atk'];return this[_0x4d60ab(0x1e3)](),isNaN(_0x2a6ebe)?_0x4d60ab(0x1fa)===_0x4d60ab(0x1fa)?'?????':_0x3148c0[_0x4d60ab(0x1db)][_0x4d60ab(0x522)]['StatusWindow'][_0x4d60ab(0x50a)]:_0x4d60ab(0x3f4)['format'](Math[_0x4d60ab(0x243)](_0x2a6ebe*0x64));}catch(_0x2e150d){return $gameTemp['isPlaytest']()&&('deQam'===_0x4d60ab(0x200)?_0x943eae['push'](_0x2c3dd5):(console[_0x4d60ab(0x3ea)](_0x4d60ab(0x5a5)['format'](this[_0x4d60ab(0x567)][_0x4d60ab(0x3bf)])),console['log'](_0x2e150d))),this['revertGlobalNamespaceVariables'](),_0x4d60ab(0x259);}},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x1e3)]=function(){window['a']=undefined,window['b']=undefined;},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x3f0)]=function(_0x23f341,_0x19a893,_0x516623){const _0x27062d=_0x541333;if(!this[_0x27062d(0x4ef)]())return _0x19a893;if(this[_0x27062d(0x560)](_0x23f341,_0x19a893,_0x516623))_0x19a893+=this[_0x27062d(0x3da)]();if(this[_0x27062d(0x2de)](_0x23f341,_0x19a893,_0x516623))_0x19a893+=this[_0x27062d(0x3da)]();if(this[_0x27062d(0x470)](_0x23f341,_0x19a893,_0x516623))_0x19a893+=this['lineHeight']();if(this[_0x27062d(0x3ab)](_0x23f341,_0x19a893,_0x516623))_0x19a893+=this[_0x27062d(0x3da)]();if(this[_0x27062d(0x49c)](_0x23f341,_0x19a893,_0x516623))_0x19a893+=this[_0x27062d(0x3da)]();if(this[_0x27062d(0x3ac)](_0x23f341,_0x19a893,_0x516623))_0x19a893+=this[_0x27062d(0x3da)]();if(this[_0x27062d(0x278)](_0x23f341,_0x19a893,_0x516623))_0x19a893+=this['lineHeight']();if(this[_0x27062d(0x2a7)](_0x23f341,_0x19a893,_0x516623))_0x19a893+=this[_0x27062d(0x3da)]();if(this[_0x27062d(0x393)](_0x23f341,_0x19a893,_0x516623))_0x19a893+=this[_0x27062d(0x3da)]();return this['resetFontSettings'](),_0x19a893;},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x22d)]=function(){return this['_item']['effects'];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x4ef)]=function(){const _0x5de187=_0x541333;let _0x2fd835=![];this[_0x5de187(0x3e3)]={'rateHP':0x0,'flatHP':0x0,'rateMP':0x0,'flatMP':0x0,'gainTP':0x0,'selfTP':0x0,'addState':[],'removeState':[],'changeBuff':[0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0],'removeBuff':[],'removeDebuff':[],'addStateBuffChanges':![],'removeStateBuffChanges':![]};const _0x1a91d2=this[_0x5de187(0x22d)]();for(const _0x3c32f6 of _0x1a91d2){switch(_0x3c32f6[_0x5de187(0x444)]){case Game_Action['EFFECT_RECOVER_HP']:this[_0x5de187(0x3e3)][_0x5de187(0x235)]+=_0x3c32f6[_0x5de187(0x345)],this[_0x5de187(0x3e3)][_0x5de187(0x1df)]+=_0x3c32f6[_0x5de187(0x509)],_0x2fd835=!![];break;case Game_Action[_0x5de187(0x500)]:this[_0x5de187(0x3e3)][_0x5de187(0x1de)]+=_0x3c32f6[_0x5de187(0x345)],this[_0x5de187(0x3e3)]['flatMP']+=_0x3c32f6['value2'],_0x2fd835=!![];break;case Game_Action[_0x5de187(0x57d)]:this[_0x5de187(0x3e3)][_0x5de187(0x26d)]+=_0x3c32f6['value1'],_0x2fd835=!![];break;case Game_Action[_0x5de187(0x504)]:this[_0x5de187(0x3e3)][_0x5de187(0x315)][_0x5de187(0x282)](_0x3c32f6[_0x5de187(0x50e)]),_0x2fd835=!![];break;case Game_Action[_0x5de187(0x312)]:this[_0x5de187(0x3e3)][_0x5de187(0x268)][_0x5de187(0x282)](_0x3c32f6[_0x5de187(0x50e)]),this[_0x5de187(0x3e3)]['removeStateBuffChanges']=!![],_0x2fd835=!![];break;case Game_Action['EFFECT_ADD_BUFF']:this[_0x5de187(0x3e3)]['changeBuff'][_0x3c32f6[_0x5de187(0x50e)]]+=0x1,_0x2fd835=!![];break;case Game_Action[_0x5de187(0x5a9)]:this['_itemData'][_0x5de187(0x2d6)][_0x3c32f6[_0x5de187(0x50e)]]-=0x1,_0x2fd835=!![];break;case Game_Action['EFFECT_REMOVE_BUFF']:this[_0x5de187(0x3e3)][_0x5de187(0x40d)][_0x5de187(0x282)](_0x3c32f6['dataId']),this['_itemData'][_0x5de187(0x2ff)]=!![],_0x2fd835=!![];break;case Game_Action[_0x5de187(0x581)]:this['_itemData'][_0x5de187(0x461)][_0x5de187(0x282)](_0x3c32f6[_0x5de187(0x50e)]),this['_itemData']['removeStateBuffChanges']=!![],_0x2fd835=!![];break;}}if(this[_0x5de187(0x3e3)][_0x5de187(0x315)]['length']>0x0)this['_itemData'][_0x5de187(0x276)]=!![];for(let _0x306b95=0x0;_0x306b95<this[_0x5de187(0x3e3)]['changeBuff'][_0x5de187(0x33d)];_0x306b95++){if(this['_itemData'][_0x5de187(0x2d6)][_0x306b95]!==0x0)this[_0x5de187(0x3e3)][_0x5de187(0x276)]=!![];}this['_item'][_0x5de187(0x289)]!==0x0&&(_0x5de187(0x491)===_0x5de187(0x491)?(this['_itemData']['selfTP']=this[_0x5de187(0x567)]['tpGain'],_0x2fd835=!![]):_0x5a809e=_0x5de187(0x400)[_0x5de187(0x52b)](_0x30a111['id']));const _0x4f13f5=[_0x5de187(0x3e1),_0x5de187(0x373),_0x5de187(0x288),_0x5de187(0x208),_0x5de187(0x55e),_0x5de187(0x2d4),_0x5de187(0x19e),_0x5de187(0x4a7),_0x5de187(0x366)];for(const _0xfd4fca of _0x4f13f5){if(this[_0x5de187(0x212)][_0xfd4fca]){_0x2fd835=!![];break;}}return _0x2fd835;},Window_ShopStatus['prototype'][_0x541333(0x560)]=function(_0x72f25f,_0x1c31e3,_0x41cfab){const _0x3d12a4=_0x541333,_0x2af064=_0x3d12a4(0x3e1);if(this[_0x3d12a4(0x3e3)][_0x3d12a4(0x235)]<=0x0&&this[_0x3d12a4(0x3e3)][_0x3d12a4(0x1df)]<=0x0&&!this[_0x3d12a4(0x212)][_0x2af064])return![];const _0x58dea8=this[_0x3d12a4(0x460)]();this[_0x3d12a4(0x4b2)](_0x58dea8,_0x72f25f,_0x1c31e3,_0x41cfab,!![]);const _0x54efe4=this['getItemEffectsHpRecoveryText']();return this[_0x3d12a4(0x32a)](ColorManager[_0x3d12a4(0x422)](0x1)),this[_0x3d12a4(0x4b2)](_0x54efe4,_0x72f25f,_0x1c31e3,_0x41cfab,![],_0x3d12a4(0x263)),this['drawItemDarkRect'](_0x72f25f,_0x1c31e3,_0x41cfab),this[_0x3d12a4(0x33e)](),!![];},Window_ShopStatus[_0x541333(0x5f1)]['getItemEffectsHpRecoveryLabel']=function(){const _0x124184=_0x541333,_0x2ece62=VisuMZ[_0x124184(0x1db)]['Settings']['StatusWindow'][_0x124184(0x20a)];return _0x2ece62[_0x124184(0x52b)](TextManager['hp']);},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x1a3)]=function(){const _0x1876f4=_0x541333,_0x329382=_0x1876f4(0x3e1);if(this[_0x1876f4(0x212)][_0x329382])return this[_0x1876f4(0x212)][_0x329382];let _0x14c56a='';if(this[_0x1876f4(0x3e3)]['rateHP']>0x0)_0x14c56a+=_0x1876f4(0x2ed)[_0x1876f4(0x52b)](Math[_0x1876f4(0x254)](this['_itemData'][_0x1876f4(0x235)]*0x64));if(this['_itemData'][_0x1876f4(0x235)]>0x0&&this[_0x1876f4(0x3e3)][_0x1876f4(0x1df)]>0x0)_0x14c56a+='\x20';if(this[_0x1876f4(0x3e3)][_0x1876f4(0x1df)]>0x0)_0x14c56a+=_0x1876f4(0x515)[_0x1876f4(0x52b)](this[_0x1876f4(0x3e3)]['flatHP']);return _0x14c56a;},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x2de)]=function(_0x313289,_0x31a8d5,_0x2ad014){const _0x273b9a=_0x541333,_0x2ab131=_0x273b9a(0x373);if(this[_0x273b9a(0x3e3)][_0x273b9a(0x1de)]<=0x0&&this[_0x273b9a(0x3e3)]['flatMP']<=0x0&&!this[_0x273b9a(0x212)][_0x2ab131])return![];const _0x2cb0e2=this[_0x273b9a(0x4a0)]();this[_0x273b9a(0x4b2)](_0x2cb0e2,_0x313289,_0x31a8d5,_0x2ad014,!![]);const _0x23a6cb=this['getItemEffectsMpRecoveryText']();return this[_0x273b9a(0x32a)](ColorManager[_0x273b9a(0x422)](0x3)),this[_0x273b9a(0x4b2)](_0x23a6cb,_0x313289,_0x31a8d5,_0x2ad014,![],_0x273b9a(0x263)),this[_0x273b9a(0x28c)](_0x313289,_0x31a8d5,_0x2ad014),this[_0x273b9a(0x33e)](),!![];},Window_ShopStatus[_0x541333(0x5f1)]['getItemEffectsMpRecoveryLabel']=function(){const _0x333982=_0x541333,_0x84d7e2=VisuMZ[_0x333982(0x1db)][_0x333982(0x522)][_0x333982(0x510)][_0x333982(0x23d)];return _0x84d7e2[_0x333982(0x52b)](TextManager['mp']);},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x5f8)]=function(){const _0x26d36f=_0x541333,_0xf735d9=_0x26d36f(0x373);if(this[_0x26d36f(0x212)][_0xf735d9])return this[_0x26d36f(0x212)][_0xf735d9];let _0xb533ae='';if(this[_0x26d36f(0x3e3)][_0x26d36f(0x1de)]>0x0)_0xb533ae+=_0x26d36f(0x2ed)[_0x26d36f(0x52b)](Math['floor'](this[_0x26d36f(0x3e3)][_0x26d36f(0x1de)]*0x64));if(this[_0x26d36f(0x3e3)][_0x26d36f(0x1de)]>0x0&&this[_0x26d36f(0x3e3)][_0x26d36f(0x389)]>0x0)_0xb533ae+='\x20';if(this['_itemData'][_0x26d36f(0x389)]>0x0)_0xb533ae+=_0x26d36f(0x515)['format'](this[_0x26d36f(0x3e3)]['flatMP']);return _0xb533ae;},Window_ShopStatus['prototype'][_0x541333(0x470)]=function(_0x49eda5,_0x374634,_0x5c71f6){const _0x1a5aa5=_0x541333,_0x59b015=_0x1a5aa5(0x288);if(this['_itemData'][_0x1a5aa5(0x26d)]<=0x0&&!this[_0x1a5aa5(0x212)][_0x59b015])return![];const _0x156658=this[_0x1a5aa5(0x492)]();this[_0x1a5aa5(0x4b2)](_0x156658,_0x49eda5,_0x374634,_0x5c71f6,!![]);const _0x369396=this[_0x1a5aa5(0x4ba)]();return this[_0x1a5aa5(0x32a)](ColorManager[_0x1a5aa5(0x2fb)]()),this[_0x1a5aa5(0x4b2)](_0x369396,_0x49eda5,_0x374634,_0x5c71f6,![],'right'),this[_0x1a5aa5(0x28c)](_0x49eda5,_0x374634,_0x5c71f6),this[_0x1a5aa5(0x33e)](),!![];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x492)]=function(){const _0xef2e65=_0x541333,_0x4bd972=VisuMZ[_0xef2e65(0x1db)][_0xef2e65(0x522)][_0xef2e65(0x510)][_0xef2e65(0x451)];return _0x4bd972['format'](TextManager['tp']);},Window_ShopStatus['prototype'][_0x541333(0x4ba)]=function(){const _0x10f9bf=_0x541333,_0xc744e3='TP\x20RECOVERY';if(this[_0x10f9bf(0x212)][_0xc744e3])return this[_0x10f9bf(0x212)][_0xc744e3];let _0x4296f4='';return _0x4296f4+=_0x10f9bf(0x515)['format'](this[_0x10f9bf(0x3e3)][_0x10f9bf(0x26d)]),_0x4296f4;},Window_ShopStatus['prototype'][_0x541333(0x278)]=function(_0x47ea5d,_0x5aaee1,_0x3ff6ce){const _0x3abc9a=_0x541333,_0x5c93aa='USER\x20TP\x20GAIN';if(this['_itemData'][_0x3abc9a(0x2ee)]===0x0&&!this[_0x3abc9a(0x212)][_0x5c93aa])return![];const _0x3983e8=this[_0x3abc9a(0x47f)]();this[_0x3abc9a(0x4b2)](_0x3983e8,_0x47ea5d,_0x5aaee1,_0x3ff6ce,!![]);const _0x19e486=this[_0x3abc9a(0x437)]();if(this[_0x3abc9a(0x3e3)][_0x3abc9a(0x2ee)]>0x0)_0x3abc9a(0x4f7)!==_0x3abc9a(0x4f7)?_0x2017fa['ItemsEquipsCore'][_0x3abc9a(0x311)][_0x3abc9a(0x562)](this,_0x15b2c7):this['changeTextColor'](ColorManager[_0x3abc9a(0x2fb)]());else{if('ZwTTP'!==_0x3abc9a(0x427))return _0x3abc9a(0x495);else this[_0x3abc9a(0x32a)](ColorManager[_0x3abc9a(0x397)]());}return this['drawItemKeyData'](_0x19e486,_0x47ea5d,_0x5aaee1,_0x3ff6ce,![],_0x3abc9a(0x263)),this['drawItemDarkRect'](_0x47ea5d,_0x5aaee1,_0x3ff6ce),this[_0x3abc9a(0x33e)](),!![];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x47f)]=function(){const _0x36c93d=_0x541333,_0x3edc7c=VisuMZ[_0x36c93d(0x1db)][_0x36c93d(0x522)]['StatusWindow'][_0x36c93d(0x26b)];return _0x3edc7c[_0x36c93d(0x52b)](TextManager['tp']);},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x437)]=function(){const _0x21342e=_0x541333,_0x372a56=_0x21342e(0x19e);if(this['_customItemInfo'][_0x372a56])return this[_0x21342e(0x212)][_0x372a56];let _0x417856='';if(this[_0x21342e(0x3e3)]['selfTP']>0x0){if(_0x21342e(0x52e)!==_0x21342e(0x52e)){const _0x4157df=this['itemLineRect'](this[_0x21342e(0x593)]());let _0x388173=this['commandName'](this[_0x21342e(0x593)]());_0x388173=_0x388173['replace'](/\\I\[(\d+)\]/gi,''),_0x141768[_0x21342e(0x33e)](),this[_0x21342e(0x20d)](_0x388173,_0x4157df),this[_0x21342e(0x2cf)](_0x388173,_0x4157df),this[_0x21342e(0x2bc)](_0x388173,_0x4157df);}else _0x417856+=_0x21342e(0x515)['format'](this[_0x21342e(0x3e3)][_0x21342e(0x2ee)]);}else{if(_0x21342e(0x482)==='gPhub'){const _0xc26e57=_0x21342e(0x208);if(this['_itemData']['rateHP']>=0x0&&this[_0x21342e(0x3e3)][_0x21342e(0x1df)]>=0x0&&!this[_0x21342e(0x212)][_0xc26e57])return![];const _0xab6564=this[_0x21342e(0x22a)]();this[_0x21342e(0x4b2)](_0xab6564,_0x1be8d3,_0x195c64,_0x3fa7a6,!![]);const _0x2aba66=this['getItemEffectsHpDamageText']();return this[_0x21342e(0x32a)](_0x4c1db1[_0x21342e(0x422)](0x0)),this[_0x21342e(0x4b2)](_0x2aba66,_0x4a0084,_0x113338,_0x515c7a,![],_0x21342e(0x263)),this['drawItemDarkRect'](_0x245b09,_0x2c19a4,_0x422762),this[_0x21342e(0x33e)](),!![];}else _0x417856+='%1'['format'](this[_0x21342e(0x3e3)]['selfTP']);}return _0x417856;},Window_ShopStatus['prototype'][_0x541333(0x3ab)]=function(_0x24f0a6,_0x41ccc3,_0x6fe9b7){const _0x2ddaa8=_0x541333,_0x5ac689=_0x2ddaa8(0x208);if(this[_0x2ddaa8(0x3e3)][_0x2ddaa8(0x235)]>=0x0&&this['_itemData'][_0x2ddaa8(0x1df)]>=0x0&&!this[_0x2ddaa8(0x212)][_0x5ac689])return![];const _0x54b9ab=this[_0x2ddaa8(0x22a)]();this[_0x2ddaa8(0x4b2)](_0x54b9ab,_0x24f0a6,_0x41ccc3,_0x6fe9b7,!![]);const _0x27d4b3=this['getItemEffectsHpDamageText']();return this['changeTextColor'](ColorManager[_0x2ddaa8(0x422)](0x0)),this[_0x2ddaa8(0x4b2)](_0x27d4b3,_0x24f0a6,_0x41ccc3,_0x6fe9b7,![],_0x2ddaa8(0x263)),this[_0x2ddaa8(0x28c)](_0x24f0a6,_0x41ccc3,_0x6fe9b7),this[_0x2ddaa8(0x33e)](),!![];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x22a)]=function(){const _0x1bd487=_0x541333,_0x32352b=VisuMZ[_0x1bd487(0x1db)][_0x1bd487(0x522)][_0x1bd487(0x510)][_0x1bd487(0x2b5)];return _0x32352b['format'](TextManager['hp']);},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x3de)]=function(){const _0xfeacba=_0x541333,_0x5d9a67=_0xfeacba(0x208);if(this['_customItemInfo'][_0x5d9a67])return this[_0xfeacba(0x212)][_0x5d9a67];let _0x47a935='';if(this[_0xfeacba(0x3e3)]['rateHP']<0x0)_0x47a935+=_0xfeacba(0x3f4)['format'](Math[_0xfeacba(0x254)](this[_0xfeacba(0x3e3)][_0xfeacba(0x235)]*0x64));if(this[_0xfeacba(0x3e3)][_0xfeacba(0x235)]<0x0&&this['_itemData'][_0xfeacba(0x1df)]<0x0)_0x47a935+='\x20';if(this['_itemData'][_0xfeacba(0x1df)]<0x0)_0x47a935+='%1'['format'](this[_0xfeacba(0x3e3)][_0xfeacba(0x1df)]);return _0x47a935;},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x49c)]=function(_0xb74679,_0xa622f7,_0x45611b){const _0x490aa4=_0x541333,_0x28bdee='MP\x20DAMAGE';if(this[_0x490aa4(0x3e3)][_0x490aa4(0x1de)]>=0x0&&this['_itemData']['flatMP']>=0x0&&!this[_0x490aa4(0x212)][_0x28bdee])return![];const _0x59bf62=this[_0x490aa4(0x382)]();this[_0x490aa4(0x4b2)](_0x59bf62,_0xb74679,_0xa622f7,_0x45611b,!![]);const _0x219597=this[_0x490aa4(0x1d1)]();return this[_0x490aa4(0x32a)](ColorManager['damageColor'](0x2)),this[_0x490aa4(0x4b2)](_0x219597,_0xb74679,_0xa622f7,_0x45611b,![],_0x490aa4(0x263)),this[_0x490aa4(0x28c)](_0xb74679,_0xa622f7,_0x45611b),this[_0x490aa4(0x33e)](),!![];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x382)]=function(){const _0x5c84df=_0x541333,_0x211a56=VisuMZ[_0x5c84df(0x1db)]['Settings'][_0x5c84df(0x510)][_0x5c84df(0x5cf)];return _0x211a56['format'](TextManager['mp']);},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x1d1)]=function(){const _0x2e0686=_0x541333,_0x493059=_0x2e0686(0x55e);if(this['_customItemInfo'][_0x493059])return this['_customItemInfo'][_0x493059];let _0x132c1b='';if(this[_0x2e0686(0x3e3)][_0x2e0686(0x1de)]<0x0)_0x132c1b+=_0x2e0686(0x3f4)[_0x2e0686(0x52b)](Math[_0x2e0686(0x254)](this['_itemData']['rateMP']*0x64));if(this[_0x2e0686(0x3e3)][_0x2e0686(0x1de)]<0x0&&this[_0x2e0686(0x3e3)]['flatMP']<0x0)_0x132c1b+='\x20';if(this[_0x2e0686(0x3e3)][_0x2e0686(0x389)]<0x0)_0x132c1b+='%1'[_0x2e0686(0x52b)](this[_0x2e0686(0x3e3)][_0x2e0686(0x389)]);return _0x132c1b;},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x3ac)]=function(_0x2780df,_0x409fab,_0x5bba5e){const _0x27d0fd=_0x541333,_0x23a036=_0x27d0fd(0x2d4);if(this['_itemData'][_0x27d0fd(0x26d)]>=0x0&&!this[_0x27d0fd(0x212)][_0x23a036])return![];const _0x3ed734=this['getItemEffectsTpDamageLabel']();this['drawItemKeyData'](_0x3ed734,_0x2780df,_0x409fab,_0x5bba5e,!![]);const _0x30e849=this['getItemEffectsTpDamageText']();return this['changeTextColor'](ColorManager[_0x27d0fd(0x397)]()),this['drawItemKeyData'](_0x30e849,_0x2780df,_0x409fab,_0x5bba5e,![],_0x27d0fd(0x263)),this['drawItemDarkRect'](_0x2780df,_0x409fab,_0x5bba5e),this[_0x27d0fd(0x33e)](),!![];},Window_ShopStatus[_0x541333(0x5f1)]['getItemEffectsTpDamageLabel']=function(){const _0x5b781f=_0x541333,_0x4e1e5e=VisuMZ['ItemsEquipsCore'][_0x5b781f(0x522)]['StatusWindow'][_0x5b781f(0x356)];return _0x4e1e5e['format'](TextManager['tp']);},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x508)]=function(){const _0x341f36=_0x541333,_0x45d48c=_0x341f36(0x2d4);if(this[_0x341f36(0x212)][_0x45d48c])return this[_0x341f36(0x212)][_0x45d48c];let _0xa65022='';return _0xa65022+='%1'[_0x341f36(0x52b)](this[_0x341f36(0x3e3)]['gainTP']),_0xa65022;},Window_ShopStatus[_0x541333(0x5f1)]['drawItemEffectsAddedStatesBuffs']=function(_0x3819ef,_0x14a00d,_0x320a9a){const _0x3c7c6e=_0x541333,_0x49d0fe=_0x3c7c6e(0x4a7);if(!this[_0x3c7c6e(0x3e3)][_0x3c7c6e(0x276)]&&!this[_0x3c7c6e(0x212)][_0x49d0fe])return![];const _0x579f32=this[_0x3c7c6e(0x3a9)]();this[_0x3c7c6e(0x4b2)](_0x579f32,_0x3819ef,_0x14a00d,_0x320a9a,!![]);const _0x3158a2=this['getItemEffectsAddedStatesBuffsText']();return this[_0x3c7c6e(0x4b2)](_0x3158a2,_0x3819ef,_0x14a00d,_0x320a9a,![],'right'),this[_0x3c7c6e(0x28c)](_0x3819ef,_0x14a00d,_0x320a9a),this[_0x3c7c6e(0x33e)](),!![];},Window_ShopStatus[_0x541333(0x5f1)]['getItemEffectsAddedStatesBuffsLabel']=function(){const _0x16c8cc=_0x541333;return VisuMZ[_0x16c8cc(0x1db)]['Settings']['StatusWindow'][_0x16c8cc(0x50a)];},Window_ShopStatus['prototype']['getItemEffectsAddedStatesBuffsText']=function(){const _0x7f2154=_0x541333,_0x36a090=_0x7f2154(0x4a7);if(this['_customItemInfo'][_0x36a090])return this[_0x7f2154(0x212)][_0x36a090];let _0x3bb938='',_0x375c91=0x0;const _0x464962=0x8;for(const _0x22f3a5 of this[_0x7f2154(0x3e3)]['addState']){const _0x560319=$dataStates[_0x22f3a5];if(_0x560319&&_0x560319[_0x7f2154(0x2c2)]>0x0){_0x3bb938+=_0x7f2154(0x438)[_0x7f2154(0x52b)](_0x560319[_0x7f2154(0x2c2)]),_0x375c91++;if(_0x375c91>=_0x464962)return _0x3bb938;}}for(let _0x4603a0=0x0;_0x4603a0<this[_0x7f2154(0x3e3)][_0x7f2154(0x2d6)][_0x7f2154(0x33d)];_0x4603a0++){const _0x237df7=this[_0x7f2154(0x3e3)][_0x7f2154(0x2d6)][_0x4603a0],_0x2e7d96=Game_BattlerBase[_0x7f2154(0x5f1)][_0x7f2154(0x4c2)](_0x237df7,_0x4603a0);if(_0x2e7d96>0x0){_0x3bb938+=_0x7f2154(0x438)['format'](_0x2e7d96),_0x375c91++;if(_0x375c91>=_0x464962)return _0x3bb938;}}return _0x3bb938;},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x393)]=function(_0xe85869,_0x189f6a,_0x2823bf){const _0x5f16b9=_0x541333,_0x238374='REMOVED\x20EFFECTS';if(!this[_0x5f16b9(0x3e3)][_0x5f16b9(0x2ff)]&&!this[_0x5f16b9(0x212)][_0x238374])return![];const _0xac44e8=this[_0x5f16b9(0x518)]();this[_0x5f16b9(0x4b2)](_0xac44e8,_0xe85869,_0x189f6a,_0x2823bf,!![]);const _0x23a02b=this[_0x5f16b9(0x395)]();return this[_0x5f16b9(0x4b2)](_0x23a02b,_0xe85869,_0x189f6a,_0x2823bf,![],_0x5f16b9(0x263)),this[_0x5f16b9(0x28c)](_0xe85869,_0x189f6a,_0x2823bf),this[_0x5f16b9(0x33e)](),!![];},Window_ShopStatus[_0x541333(0x5f1)]['getItemEffectsRemovedStatesBuffsLabel']=function(){const _0x2a83e1=_0x541333;return VisuMZ['ItemsEquipsCore']['Settings'][_0x2a83e1(0x510)][_0x2a83e1(0x44b)];},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x395)]=function(){const _0xa5a291=_0x541333,_0x24e5e1=_0xa5a291(0x366);if(this[_0xa5a291(0x212)][_0x24e5e1])return this[_0xa5a291(0x212)][_0x24e5e1];let _0x47f214='',_0x4d8f93=0x0;const _0x2ec99d=VisuMZ[_0xa5a291(0x1db)][_0xa5a291(0x522)][_0xa5a291(0x510)][_0xa5a291(0x245)];for(const _0x230e84 of this['_itemData'][_0xa5a291(0x268)]){if(_0xa5a291(0x453)!=='vSbln'){const _0x3e61db=$dataStates[_0x230e84];if(_0x3e61db&&_0x3e61db[_0xa5a291(0x2c2)]>0x0){_0x47f214+=_0xa5a291(0x438)[_0xa5a291(0x52b)](_0x3e61db[_0xa5a291(0x2c2)]),_0x4d8f93++;if(_0x4d8f93>=_0x2ec99d)return _0x47f214;}}else return!!_0x34f1ff&&_0xe9414e['etypeId']===_0x1f3241(_0x273482['$1']);}for(let _0x2c964b=0x0;_0x2c964b<this[_0xa5a291(0x3e3)][_0xa5a291(0x40d)][_0xa5a291(0x33d)];_0x2c964b++){if(_0xa5a291(0x2cc)!==_0xa5a291(0x47a)){const _0xb8d0d=Game_BattlerBase['prototype'][_0xa5a291(0x4c2)](0x1,_0x2c964b);if(_0xb8d0d>0x0){_0x47f214+=_0xa5a291(0x438)[_0xa5a291(0x52b)](_0xb8d0d),_0x4d8f93++;if(_0x4d8f93>=_0x2ec99d)return _0x47f214;}}else{const _0x33bd44=_0x4e0afb[_0xa5a291(0x5f9)]('['+_0x29e514['$1'][_0xa5a291(0x2a3)](/\d+/g)+']');for(const _0xb05add of _0x33bd44){if(_0x5d986a['value'](_0xb05add))return![];}return!![];}}for(let _0x24fb99=0x0;_0x24fb99<this['_itemData'][_0xa5a291(0x461)][_0xa5a291(0x33d)];_0x24fb99++){const _0x501dac=Game_BattlerBase['prototype'][_0xa5a291(0x4c2)](-0x1,_0x24fb99);if(_0x501dac>0x0){if(_0xa5a291(0x47e)===_0xa5a291(0x3a7))return _0x5d3bf9['ItemsEquipsCore'][_0xa5a291(0x522)][_0xa5a291(0x510)]['ElementWeapon'];else{_0x47f214+=_0xa5a291(0x438)[_0xa5a291(0x52b)](_0x501dac),_0x4d8f93++;if(_0x4d8f93>=_0x2ec99d)return _0x47f214;}}}return _0x47f214;},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x4a4)]=function(_0xd96ee2,_0x5c5f4a,_0x1327b4){const _0xce420b=_0x541333;if(this['_item']['note'][_0xce420b(0x2a3)](/<CUSTOM STATUS INFO>\s*([\s\S]*)\s*<\/CUSTOM STATUS INFO>/i)){if(_0xce420b(0x571)===_0xce420b(0x571)){const _0xe0e6d=String(RegExp['$1'])[_0xce420b(0x3b1)](/[\r\n]+/);for(const _0x40c1a6 of _0xe0e6d){if('uDTEb'===_0xce420b(0x426)){if(_0x40c1a6[_0xce420b(0x2a3)](/(.*):[ ](.*)/i)){if(_0xce420b(0x21d)!==_0xce420b(0x4a9)){const _0x388663=String(RegExp['$1'])[_0xce420b(0x399)](),_0x2d653f=String(RegExp['$2'])[_0xce420b(0x399)]();this['drawItemCustomEntryLine'](_0x388663,_0x2d653f,_0xd96ee2,_0x5c5f4a,_0x1327b4),_0x5c5f4a+=this['lineHeight']();}else{const _0x759d7f=this[_0xce420b(0x3e3)][_0xce420b(0x2d6)][_0xf23aca],_0x1b75af=_0x2f0da7['prototype'][_0xce420b(0x4c2)](_0x759d7f,_0x380bbc);if(_0x1b75af>0x0){_0x5552f+=_0xce420b(0x438)[_0xce420b(0x52b)](_0x1b75af),_0x3de4b6++;if(_0x136e03>=_0x417bfd)return _0x6ba922;}}}}else{const _0x353524=_0x4b2808[_0xce420b(0x472)](this);_0x353524['_tempActor']=!![],this['_equips'][_0x3bf740][_0xce420b(0x1ce)](null),this[_0xce420b(0x33b)]=!![],this['equipAdjustHpMp'](_0x353524),this['_bypassReleaseUnequippableItemsItemsEquipsCore']=_0x305043;}}}else{_0x42a60c[_0xce420b(0x2f6)]()&&this[_0xce420b(0x54b)](!![]);if(_0x5e94d9[_0xce420b(0x236)]())this[_0xce420b(0x248)]();else _0x1e351d[_0xce420b(0x5c0)]()&&this[_0xce420b(0x375)]();}}return this[_0xce420b(0x33e)](),_0x5c5f4a;},Window_ShopStatus['prototype'][_0x541333(0x423)]=function(_0x4093aa,_0x282864,_0x5f2032,_0x23b1ba,_0x173726){const _0x54fcfb=_0x541333;this[_0x54fcfb(0x4b2)](_0x4093aa,_0x5f2032,_0x23b1ba,_0x173726,!![]),this[_0x54fcfb(0x4b2)](_0x282864,_0x5f2032,_0x23b1ba,_0x173726,![],'right'),this['drawItemDarkRect'](_0x5f2032,_0x23b1ba,_0x173726),this[_0x54fcfb(0x33e)]();},Window_ShopStatus[_0x541333(0x5f1)][_0x541333(0x2c5)]=function(){const _0x172612=_0x541333;if(!this[_0x172612(0x567)])return;const _0x53111a=this['_item'][_0x172612(0x266)],_0x5737d1=/<SHOP (?:PICTURE|IMAGE|PICTURE NAME|PICTURE FILENAME|IMAGE NAME|IMAGE FILENAME):[ ](.*)>/gi,_0x312e0a=_0x53111a[_0x172612(0x2a3)](_0x5737d1);if(_0x312e0a)for(const _0x2d7a0c of _0x312e0a){_0x2d7a0c[_0x172612(0x2a3)](_0x5737d1);const _0x1f9b4a=String(RegExp['$1'])[_0x172612(0x399)]()||'';if(_0x1f9b4a==='')continue;const _0xb3f689=ImageManager[_0x172612(0x3f7)](_0x1f9b4a);_0xb3f689['addLoadListener'](this[_0x172612(0x351)]['bind'](this,_0xb3f689,this[_0x172612(0x567)]));}},Window_ShopStatus['prototype'][_0x541333(0x351)]=function(_0x5c42f2,_0x3ba24f){const _0x33f19f=_0x541333;if(this[_0x33f19f(0x567)]!==_0x3ba24f)return;if(!_0x5c42f2)return;if(_0x5c42f2['width']<=0x0||_0x5c42f2[_0x33f19f(0x242)]<=0x0)return;const _0x1649ab=_0x3ba24f[_0x33f19f(0x266)];let _0x35d256='background';_0x1649ab['match'](/<SHOP (?:PICTURE|IMAGE) LAYER:[ ]FOREGROUND>/i)&&(_0x35d256='foreground');const _0x40b63f=_0x35d256==='background'?this[_0x33f19f(0x535)]:this[_0x33f19f(0x1f8)];let _0x52ac46=this[_0x33f19f(0x20f)],_0x4082fe=this[_0x33f19f(0x30d)];_0x1649ab[_0x33f19f(0x2a3)](/<SHOP (?:PICTURE|IMAGE) MAX WIDTH:[ ](\d+)>/i)&&(_0x52ac46=Number(RegExp['$1']));_0x1649ab[_0x33f19f(0x2a3)](/<SHOP (?:PICTURE|IMAGE) MAX HEIGHT:[ ](\d+)>/i)&&(_0x33f19f(0x365)===_0x33f19f(0x365)?_0x4082fe=Number(RegExp['$1']):_0x3acf00=_0xc3f337(_0x329612['$1']));_0x1649ab['match'](/<SHOP (?:PICTURE|IMAGE) MAX DIMENSIONS:[ ](\d+),[ ]*(\d+)>/i)&&(_0x33f19f(0x3a8)!==_0x33f19f(0x361)?(_0x52ac46=Number(RegExp['$1']),_0x4082fe=Number(RegExp['$2'])):(this['drawParamText'](_0x5d3d87,_0x4ff5bd,_0x59d51d,_0x3850bd,!![]),_0x261331[_0x33f19f(0x406)]['Settings']['Param']['DrawIcons']&&(_0x1b9d25+=_0x1eb8a8[_0x33f19f(0x5d8)]+0x4)));const _0x2fb8a0=Math['min'](0x1,_0x52ac46/_0x5c42f2[_0x33f19f(0x5bc)],_0x4082fe/_0x5c42f2[_0x33f19f(0x242)]);let _0x4781a2=0x0,_0x387f0a=0x0,_0x3f8e79=Math[_0x33f19f(0x254)](_0x5c42f2['width']*_0x2fb8a0),_0x32061e=Math[_0x33f19f(0x254)](_0x5c42f2[_0x33f19f(0x242)]*_0x2fb8a0),_0x350ac9=_0x33f19f(0x42a);_0x1649ab[_0x33f19f(0x2a3)](/<SHOP (?:PICTURE|IMAGE) (?:ALIGN|ALIGNMENT):[ ](LEFT|CENTER|RIGHT)>/i)&&('dJWDq'!==_0x33f19f(0x2ca)?this[_0x33f19f(0x37d)]++:_0x350ac9=String(RegExp['$1'])[_0x33f19f(0x599)]()[_0x33f19f(0x399)]());if(_0x350ac9===_0x33f19f(0x265))_0x4781a2=0x0;else _0x350ac9===_0x33f19f(0x42a)?_0x4781a2=Math[_0x33f19f(0x243)]((this['innerWidth']-_0x3f8e79)/0x2):_0x4781a2=this[_0x33f19f(0x20f)]-_0x3f8e79;let _0x285d73=_0x33f19f(0x4fa);_0x1649ab['match'](/<SHOP (?:PICTURE|IMAGE) POSITION:[ ](TOP|MIDDLE|BOTTOM)>/i)&&(_0x285d73=String(RegExp['$1'])[_0x33f19f(0x599)]()[_0x33f19f(0x399)]());if(_0x285d73===_0x33f19f(0x4b9))_0x387f0a=0x0;else{if(_0x285d73===_0x33f19f(0x4fa)){if(_0x33f19f(0x1b4)===_0x33f19f(0x1b4))_0x387f0a=Math['round']((this[_0x33f19f(0x30d)]-_0x32061e)/0x2);else return this[_0x33f19f(0x1fe)]();}else{if(_0x33f19f(0x331)!==_0x33f19f(0x331))return this[_0x33f19f(0x56b)]();else _0x387f0a=this[_0x33f19f(0x30d)]-_0x32061e;}}if(_0x1649ab[_0x33f19f(0x2a3)](/<SHOP (?:PICTURE|IMAGE) OFFSET X:[ ]([\+\-]\d+)>/i)){if('ZRhck'!==_0x33f19f(0x46f))_0x4781a2+=Number(RegExp['$1']);else{const _0x4df8a7=this[_0x33f19f(0x347)](_0x289b09),_0x513169=this[_0x33f19f(0x3f9)](_0x5e904e)[_0x33f19f(0x5bc)];return _0x513169<=_0x4df8a7[_0x33f19f(0x5bc)]?_0x33f19f(0x454):_0x33f19f(0x495);}}_0x1649ab[_0x33f19f(0x2a3)](/<SHOP (?:PICTURE|IMAGE) OFFSET Y:[ ]([\+\-]\d+)>/i)&&(_0x387f0a+=Number(RegExp['$1']));_0x1649ab['match'](/<SHOP (?:PICTURE|IMAGE) OFFSET:[ ]([\+\-]\d+),[ ]*([\+\-]\d+)>/i)&&(_0x4781a2+=Number(RegExp['$1']),_0x387f0a+=Number(RegExp['$2']));let _0xd5b814=0xff;if(_0x1649ab[_0x33f19f(0x2a3)](/<SHOP (?:PICTURE|IMAGE) OPACITY:[ ](\d+)>/i))_0xd5b814=Number(RegExp['$1']);else _0x1649ab[_0x33f19f(0x2a3)](/<SHOP (?:PICTURE|IMAGE) OPACITY:[ ](\d+)([%％])>/i)&&(_0xd5b814=Math[_0x33f19f(0x243)](Number(RegExp['$1'])*0.01*0xff)[_0x33f19f(0x514)](0x0,0xff));_0x40b63f['paintOpacity']=_0xd5b814,_0x40b63f['blt'](_0x5c42f2,0x0,0x0,_0x5c42f2[_0x33f19f(0x5bc)],_0x5c42f2['height'],_0x4781a2,_0x387f0a,_0x3f8e79,_0x32061e),_0x40b63f[_0x33f19f(0x29c)]=0xff;};